@@ -32,15 +32,12 @@ class CompilerOptions(config.base.Configure):
         flags.extend(['-mfp16-format=ieee']) #  arm for utilizing 16 bit storage of floating point
         if config.setCompilers.Configure.isClang(compiler, self.log):
           flags.extend(['-Qunused-arguments'])
-        if self.argDB['with-visibility']:
+        if self.argDB['with-visibility'] and language != 'CUDA':
           flags.extend(['-fvisibility=hidden'])
-        arg = nargs.Arg.findArgument('with-errorchecking', self.clArgs)
-        if not nargs.ArgBool('with-errorchecking', arg if arg is not None else '1', isTemporary=True).getValue():
-          flags.extend(['-Wno-unused-but-set-variable'])
+        if language == 'CUDA':
+          flags.extend(['-x cuda'])
       elif bopt == 'g':
         flags.extend(['-g3','-O0'])
-      elif bopt == 'gcov':
-        flags.extend(['--coverage','-Og']) # --coverage is equal to -fprofile-arcs -ftest-coverage. Use -Og to have accurate coverage results and good performance
       elif bopt == 'O':
         flags.append('-g')
         if config.setCompilers.Configure.isClang(compiler, self.log):
@@ -60,7 +57,7 @@ class CompilerOptions(config.base.Configure):
           flags.append('-g')
           flags.append('-O3')
       # Windows Intel
-      elif compiler.find('win32fe icl') >= 0:
+      elif compiler.find('win_icl') >= 0:
         if bopt == '':
           flags.extend(['-Qstd=c99'])
           if self.argDB['with-shared-libraries']:
@@ -72,7 +69,7 @@ class CompilerOptions(config.base.Configure):
         elif bopt == 'O':
           flags.extend(['-O3', '-QxW'])
       # Windows Microsoft
-      elif compiler.find('win32fe cl') >= 0:
+      elif compiler.find('win_cl') >= 0:
         if bopt == '':
           dir(self)
           # cause compiler to generate only a single copy of static strings; needed usage of __func__ in PETSc
@@ -87,10 +84,6 @@ class CompilerOptions(config.base.Configure):
           flags.extend(['-Z7','-Od'])
         elif bopt == 'O':
           flags.extend(['-O2', '-QxW'])
-      # Windows Borland
-      elif compiler.find('win32fe bcc32') >= 0:
-        if bopt == '':
-          flags.append('-RT -w-8019 -w-8060 -w-8057 -w-8004 -w-8066')
       elif config.setCompilers.Configure.isNVCC(compiler, self.log):
         if bopt == 'g':
           # nvcc --help says:
@@ -138,7 +131,9 @@ class CompilerOptions(config.base.Configure):
     # GNU g++
     if config.setCompilers.Configure.isGNU(compiler, self.log) or config.setCompilers.Configure.isClang(compiler, self.log):
       if bopt == '':
-        flags.extend(['-Wall', '-Wwrite-strings', '-Wno-strict-aliasing','-Wno-unknown-pragmas', '-Wno-lto-type-mismatch'])
+        flags.extend(['-Wall', '-Wwrite-strings', '-Wno-strict-aliasing', '-Wno-unknown-pragmas', '-Wno-lto-type-mismatch'])
+        if config.setCompilers.Configure.isGNU(compiler, self.log):
+          flags.extend(['-Wno-psabi'])
         if not any([
             # skip -fstack-protector for brew gcc - as this gives SEGV
             config.setCompilers.Configure.isDarwin(self.log) and config.setCompilers.Configure.isGNU(compiler, self.log),
@@ -152,9 +147,6 @@ class CompilerOptions(config.base.Configure):
         # flags.extend([('-x','c++')])
         if self.argDB['with-visibility']:
           flags.extend(['-fvisibility=hidden'])
-        arg = nargs.Arg.findArgument('with-errorchecking', self.clArgs)
-        if not nargs.ArgBool('with-errorchecking', arg if arg is not None else '1', isTemporary=True).getValue():
-          flags.extend(['-Wno-unused-but-set-variable'])
       elif bopt in ['g']:
         # -g3 causes an as SEGV on OSX
         if config.setCompilers.Configure.isHIP(compiler, self.log):
@@ -162,8 +154,6 @@ class CompilerOptions(config.base.Configure):
           flags.extend(['-g'])
         else:
           flags.extend(['-g','-O0'])
-      elif bopt == 'gcov':
-        flags.extend(['--coverage','-Og'])
       elif bopt in ['O']:
         flags.append('-g')
         if 'USER' in os.environ:
@@ -190,7 +180,7 @@ class CompilerOptions(config.base.Configure):
           flags.append('-g')
           flags.append('-O3')
       # Windows Intel
-      elif compiler.find('win32fe icl') >= 0:
+      elif compiler.find('win_icl') >= 0:
         if bopt == '':
           if self.argDB['with-shared-libraries']:
             flags.extend(['-MD','-GR','-EHsc'])
@@ -201,7 +191,7 @@ class CompilerOptions(config.base.Configure):
         elif bopt in ['O']:
           flags.extend(['-O3', '-QxW'])
       # Windows Microsoft
-      elif compiler.find('win32fe cl') >= 0:
+      elif compiler.find('win_cl') >= 0:
         if bopt == '':
           # cause compiler to generate only a single copy of static strings; needed usage of __func__ in PETSc
           flags.extend(['-GF'])
@@ -215,10 +205,6 @@ class CompilerOptions(config.base.Configure):
           flags.extend(['-Z7','-Zm200','-Od'])
         elif bopt == 'O':
           flags.extend(['-O2','-QxW','-Zm200'])
-      # Windows Borland
-      elif compiler.find('win32fe bcc32') >= 0:
-        if bopt == '':
-          flags.append('-RT -w-8019 -w-8060 -w-8057 -w-8004 -w-8066')
       # NEC
       elif config.setCompilers.Configure.isNEC(compiler, self.log):
         if bopt == '':
@@ -264,11 +250,11 @@ class CompilerOptions(config.base.Configure):
           flags.extend(['-Wno-unused-variable']) # older gfortran warns about unused common block constants
         if config.setCompilers.Configure.isGfortran45x(compiler, self.log):
           flags.extend(['-Wno-line-truncation']) # Work around bug in this series, fixed in 4.6: https://gcc.gnu.org/bugzilla/show_bug.cgi?id=42852
+        if config.setCompilers.Configure.isMINGW(compiler, self.log):
+          flags.extend(['-fallow-invalid-boz'])
       elif bopt == 'g':
         # g77 3.2.3 preprocesses the file into nothing if we give -g3
         flags.extend(['-g','-O0'])
-      elif bopt == 'gcov':
-        flags.extend(['--coverage','-Og'])
       elif bopt == 'O':
         flags.append('-g')
         flags.extend(['-O'])
@@ -288,7 +274,7 @@ class CompilerOptions(config.base.Configure):
           flags.append('-g')
           flags.append('-O3')
       # Windows Intel
-      elif compiler.find('win32fe ifl') >= 0 or compiler.find('win32fe ifort') >= 0:
+      elif compiler.find('win_ifort') >= 0:
         if bopt == '':
           if self.argDB['with-shared-libraries']:
             flags.extend(['-MD'])
@@ -298,14 +284,6 @@ class CompilerOptions(config.base.Configure):
          flags.extend(['-Z7','-Od'])
         elif bopt == 'O':
           flags.extend(['-O3', '-QxW'])
-      # Compaq Visual FORTRAN
-      elif compiler.find('win32fe f90') >= 0 or compiler.find('win32fe df') >= 0:
-        if bopt == '':
-          flags.append('-threads')
-        elif bopt == 'g':
-          flags.extend(['-debug:full','-Od'])
-        elif bopt == 'O':
-          flags.extend(['-optimize:5', '-fast'])
       # NEC
       elif config.setCompilers.Configure.isNEC(compiler, self.log):
         if bopt == '':
@@ -327,10 +305,9 @@ class CompilerOptions(config.base.Configure):
     return flags
 
   def getCompilerFlags(self, language, compiler, bopt):
-    if bopt == 'gcov' and (language == 'CUDA' or language == 'HIP' or language == 'SYCL'):
-      return ''
-    if bopt == 'gcov' and not config.setCompilers.Configure.isGNU(compiler, self.log) and not config.setCompilers.Configure.isClang(compiler, self.log):
-      raise RuntimeError('Have --with-gcov but the compiler is neither GCC nor Clang, we do not know how to do gcov with other compilers')
+    if bopt == 'gcov':
+      raise RuntimeError('Internal error! bopt = gcov is deprecated')
+
     flags = ''
     if language == 'C' or language == 'CUDA':
       flags = self.getCFlags(compiler, bopt, language)
@@ -374,6 +351,9 @@ class CompilerOptions(config.base.Configure):
           #PGI/Windows writes an empty '\r\n' on the first line of output
           if output.count('\n') > 1 and output.split('\n')[0] == '\r':
             version = output.split('\r\n')[1]
+          #NVCC
+          elif output.find('Cuda compiler driver') >= 0:
+            version = output.split('\n')[3]
           else:
             version = output.split('\n')[0]
 
