@@ -20,11 +20,12 @@ class Configure(config.base.Configure):
     self.headerPrefix     = ''
     self.substPrefix      = ''
     self.fortranMangling  = 'unchanged'
-    self.fincs            = []
-    self.flibs            = []
     self.fmainlibs        = []
-    self.clibs            = []
-    self.cxxlibs          = []
+    self.fincs            = []
+    self.flibs            = []  # libraries needed for linking using the C or C++ compiler Fortran source code compiled with Fortran
+    self.clibs            = []  # libraries needed for linking using the C++ or Fortran compiler C source code compiled with C
+    self.cxxlibs          = []  # libraries needed for linking using the C or Fortran compiler C++ source code compiled with C++
+                                # clibs is only used in this file. The final link line that PETSc users use includes cxxlibs and flibs
     self.skipdefaultpaths = []
     self.cxxCompileC      = False
     self.cxxRestrict      = ' '
@@ -122,14 +123,14 @@ class Configure(config.base.Configure):
     '''Check for the CXX restrict keyword equivalent to C99 restrict'''
     with self.Language('Cxx'):
       for kw in ['__restrict', ' __restrict__', 'restrict', ' ']:
-        if self.checkCompile('', 'float * '+kw+' x;'):
+        if self.checkCompile('', 'float * '+kw+' x;\n(void)x'):
           self.cxxRestrict = kw
           break
     self.logPrint('Set Cxx restrict keyword to : '+self.cxxRestrict, 4, 'compilers')
     self.addDefine('CXX_RESTRICT', self.cxxRestrict)
     return
 
-  def checkCrossLink(self, func1, func2, language1 = 'C', language2='FC',extraObjs = []):
+  def checkCrossLink(self, func1, func2, language1 = 'C', language2='FC',extraObjs = None, extralibs=None):
     '''Compiles C/C++ and Fortran code and tries to link them together; the C and Fortran code are independent so no name mangling is needed
        language1 is used to compile the first code, language2 compiles the second and links them togetether'''
     obj1 = os.path.join(self.tmpDir, 'confc.o')
@@ -150,8 +151,12 @@ class Configure(config.base.Configure):
     self.pushLanguage(language2)
     oldLIBS = self.setCompilers.LIBS
     self.setCompilers.LIBS = obj1+' '+self.setCompilers.LIBS
-    if extraObjs:
-      self.setCompilers.LIBS = ' '.join(extraObjs)+' '+' '.join([self.libraries.getLibArgument(lib) for lib in self.clibs])+' '+self.setCompilers.LIBS
+    if extraObjs or extralibs:
+      if extraObjs is None:
+        extraObjs = []
+      if extralibs is None:
+        extralibs = self.clibs
+      self.setCompilers.LIBS = ' '.join(extraObjs)+' '+' '.join([self.libraries.getLibArgument(lib) for lib in extralibs])+' '+self.setCompilers.LIBS
     found = self.checkLink("", func2,codeBegin = " ", codeEnd = " ")
     self.setCompilers.LIBS = oldLIBS
     self.popLanguage()
@@ -160,7 +165,7 @@ class Configure(config.base.Configure):
     return found
 
   def checkCLibraries(self):
-    '''Determines the libraries needed to link with C compiled code'''
+    '''Determines the libraries needed to link using the C++ or Fortran compiler C source code compiled with C. Result is stored in clibs'''
     skipclibraries = 1
     if hasattr(self.setCompilers, 'FC'):
       self.setCompilers.saveLog()
@@ -358,7 +363,7 @@ class Configure(config.base.Configure):
 
   def checkCFormatting(self):
     '''Activate format string checking if using the GNU compilers'''
-    '''No checking because we use additional formating conventions'''
+    '''No checking because we use additional formatting conventions'''
     if self.isGCC and 0:
       self.gccFormatChecking = ('PRINTF_FORMAT_CHECK(A,B)', '__attribute__((format (printf, A, B)))')
       self.logPrint('Added gcc printf format checking', 4, 'compilers')
@@ -370,19 +375,19 @@ class Configure(config.base.Configure):
   def checkDynamicLoadFlag(self):
     '''Checks that dlopen() takes RTLD_XXX, and defines PETSC_HAVE_RTLD_XXX if it does'''
     if self.setCompilers.dynamicLibraries:
-      if self.checkLink('#include <dlfcn.h>\nchar *libname;\n', 'dlopen(libname, RTLD_LAZY);dlopen(libname, RTLD_NOW);dlopen(libname, RTLD_LOCAL);dlopen(libname, RTLD_GLOBAL);\n'):
+      if self.checkLink('#include <dlfcn.h>\nchar *libname;\n', 'dlopen(libname, RTLD_LAZY);dlopen(libname, RTLD_NOW);dlopen(libname, RTLD_LOCAL);dlopen(libname, RTLD_GLOBAL)'):
         self.addDefine('HAVE_RTLD_LAZY', 1)
         self.addDefine('HAVE_RTLD_NOW', 1)
         self.addDefine('HAVE_RTLD_LOCAL', 1)
         self.addDefine('HAVE_RTLD_GLOBAL', 1)
         return
-      if self.checkLink('#include <dlfcn.h>\nchar *libname;\n', 'dlopen(libname, RTLD_LAZY);\n'):
+      if self.checkLink('#include <dlfcn.h>\nchar *libname;\n', 'dlopen(libname, RTLD_LAZY)'):
         self.addDefine('HAVE_RTLD_LAZY', 1)
-      if self.checkLink('#include <dlfcn.h>\nchar *libname;\n', 'dlopen(libname, RTLD_NOW);\n'):
+      if self.checkLink('#include <dlfcn.h>\nchar *libname;\n', 'dlopen(libname, RTLD_NOW)'):
         self.addDefine('HAVE_RTLD_NOW', 1)
-      if self.checkLink('#include <dlfcn.h>\nchar *libname;\n', 'dlopen(libname, RTLD_LOCAL);\n'):
+      if self.checkLink('#include <dlfcn.h>\nchar *libname;\n', 'dlopen(libname, RTLD_LOCAL)'):
         self.addDefine('HAVE_RTLD_LOCAL', 1)
-      if self.checkLink('#include <dlfcn.h>\nchar *libname;\n', 'dlopen(libname, RTLD_GLOBAL);\n'):
+      if self.checkLink('#include <dlfcn.h>\nchar *libname;\n', 'dlopen(libname, RTLD_GLOBAL)'):
         self.addDefine('HAVE_RTLD_GLOBAL', 1)
     return
 
@@ -395,7 +400,7 @@ class Configure(config.base.Configure):
     cxxObj.sourceExtension = self.framework.getCompilerObject('C').sourceExtension
     for flag in ['', '-+', '-x cxx -tlocal', '-Kc++']:
       try:
-        self.setCompilers.addCompilerFlag(flag, body = 'class somename { int i; };')
+        self.setCompilers.addCompilerFlag(flag, body = 'class somename { public: int i; };\nsomename b;\nb.i = 0;\n(void)b.i')
         self.cxxCompileC = True
         break
       except RuntimeError:
@@ -403,7 +408,7 @@ class Configure(config.base.Configure):
     if not self.cxxCompileC:
       for flag in ['-x c++', '-TP','-P']:
         try:
-          self.setCompilers.addCompilerFlag(flag, body = 'class somename { int i; };', compilerOnly = 1)
+          self.setCompilers.addCompilerFlag(flag, body = 'class somename { public: int i; };\nsomename b;\nb.i = 0;\n(void)b.i', compilerOnly = 1)
           self.cxxCompileC = True
           break
         except RuntimeError:
@@ -443,10 +448,11 @@ class Configure(config.base.Configure):
     self.popLanguage()
 
   def checkCxxLibraries(self):
-    '''Determines the libraries needed to link with C++ from C and Fortran'''
+    '''Determines the libraries needed to link using the C or Fortran compiler C++ source code compiled with C++. Result is stored in cxxlibs'''
     skipcxxlibraries = 1
     self.setCompilers.saveLog()
     body   = '''#include <iostream>\n#include <vector>\nvoid asub(void)\n{std::vector<int> v;\ntry  { throw 20;  }  catch (int e)  { std::cout << "An exception occurred";  }}'''
+    oldLibs = ''
     try:
       if self.checkCrossLink(body,"int main(int argc,char **args)\n{return 0;}\n",language1='C++',language2='C'):
         self.logWrite(self.setCompilers.restoreLog())
@@ -459,8 +465,10 @@ class Configure(config.base.Configure):
           self.setCompilers.LIBS = '-lc++ '+self.setCompilers.LIBS
           self.setCompilers.saveLog()
           if self.checkCrossLink(body,"int main(int argc,char **args)\n{return 0;}\n",language1='C++',language2='C'):
+            self.setCompilers.LIBS = oldLibs
             self.logWrite(self.setCompilers.restoreLog())
             self.logPrint('C++ requires -lc++ to link with C compiler', 3, 'compilers')
+            self.cxxlibs.append('-lc++')
             skipcxxlibraries = 1
           else:
             self.logWrite(self.setCompilers.restoreLog())
@@ -472,8 +480,10 @@ class Configure(config.base.Configure):
           self.setCompilers.LIBS = '-lnc++ '+self.setCompilers.LIBS
           self.setCompilers.saveLog()
           if self.checkCrossLink(body,"int main(int argc,char **args)\n{return 0;}\n",language1='C++',language2='C'):
+            self.setCompilers.LIBS = oldLibs
             self.logWrite(self.setCompilers.restoreLog())
             self.logPrint('C++ requires -lnc++ to link with C compiler', 3, 'compilers')
+            self.cxxlibs.append('-lnc++')
             skipcxxlibraries = 1
           else:
             self.logWrite(self.setCompilers.restoreLog())
@@ -485,8 +495,10 @@ class Configure(config.base.Configure):
           oldLibs = self.setCompilers.LIBS
           self.setCompilers.LIBS = '-lstdc++ '+self.setCompilers.LIBS
           if self.checkCrossLink(body,"int main(int argc,char **args)\n{return 0;}\n",language1='C++',language2='C'):
+            self.setCompilers.LIBS = oldLibs
             self.logWrite(self.setCompilers.restoreLog())
             self.logPrint('C++ requires -lstdc++ to link with C compiler', 3, 'compilers')
+            self.cxxlibs.append('-lstdc++')
             skipcxxlibraries = 1
           else:
             self.logWrite(self.setCompilers.restoreLog())
@@ -498,56 +510,24 @@ class Configure(config.base.Configure):
       self.logPrint('Error message from compiling {'+str(e)+'}', 4, 'compilers')
       self.logPrint('C++ code cannot directly be linked with C linker, therefore will determine needed C++ libraries')
       skipcxxlibraries = 0
-    if hasattr(self.setCompilers, 'FC'):
+    if skipcxxlibraries and hasattr(self.setCompilers, 'FC'):
       self.setCompilers.saveLog()
+      oldLibs = self.setCompilers.LIBS
+      self.setCompilers.LIBS = ' '.join([self.libraries.getLibArgument(lib) for lib in self.cxxlibs])+' '+self.setCompilers.LIBS
       try:
         if self.checkCrossLink(body,"     program main\n      print*,'testing'\n      stop\n      end\n",language1='C++',language2='FC'):
           self.logWrite(self.setCompilers.restoreLog())
-          self.logPrint('C++ libraries are not needed when using FC linker')
+          self.logPrint('Additional C++ libraries are not needed when using FC linker')
         else:
+          self.logWrite(self.setCompilers.restoreLog())
+          self.logPrint('Additional C++ libraries are needed when using FC linker')
           skipcxxlibraries = 0
-          if self.setCompilers.isDarwin(self.log) and config.setCompilers.Configure.isClang(self.getCompiler('C'), self.log):
-            oldLibs = self.setCompilers.LIBS
-            self.setCompilers.LIBS = '-lc++ '+self.setCompilers.LIBS
-            self.setCompilers.saveLog()
-            if self.checkCrossLink(body,"     program main\n      print*,'testing'\n      stop\n      end\n",language1='C++',language2='FC'):
-              self.logWrite(self.setCompilers.restoreLog())
-              self.logPrint('C++ requires -lc++ to link with FC compiler', 3, 'compilers')
-              skipcxxlibraries = 1
-            else:
-              self.logWrite(self.setCompilers.restoreLog())
-              self.setCompilers.LIBS = oldLibs
-              self.logPrint('C++ code cannot directly be linked with C linker using -lc++, therefore will determine needed C++ libraries')
-              skipcxxlibraries = 0
-          if self.setCompilers.isNEC(self.getCompiler('C'),self.log):
-            oldLibs = self.setCompilers.LIBS
-            self.setCompilers.LIBS = '-lnc++ '+self.setCompilers.LIBS
-            self.setCompilers.saveLog()
-            if self.checkCrossLink(body,"     program main\n      print*,'testing'\n      stop\n      end\n",language1='C++',language2='FC'):
-              self.logWrite(self.setCompilers.restoreLog())
-              self.logPrint('C++ requires -lnc++ to link with FC compiler', 3, 'compilers')
-              skipcxxlibraries = 1
-            else:
-              self.logWrite(self.setCompilers.restoreLog())
-              self.setCompilers.LIBS = oldLibs
-              self.logPrint('C++ code cannot directly be linked with C linker using -lnc++, therefore will determine needed C++ libraries')
-              skipcxxlibraries = 0
-          if not skipcxxlibraries:
-            self.logWrite(self.setCompilers.restoreLog())
-            oldLibs = self.setCompilers.LIBS
-            self.setCompilers.LIBS = '-lstdc++ '+self.setCompilers.LIBS
-            if self.checkCrossLink(body,"     program main\n      print*,'testing'\n      stop\n      end\n",language1='C++',language2='FC'):
-              self.logPrint('C++ requires -lstdc++ to link with FC compiler', 3, 'compilers')
-              skipcxxlibraries = 1
-            else:
-              self.setCompilers.LIBS = oldLibs
-              self.logPrint('C++ code cannot directly be linked with FC linker, therefore will determine needed C++ libraries')
-              skipcxxlibraries = 0
       except RuntimeError as e:
         self.logWrite(self.setCompilers.restoreLog())
         self.logPrint('Error message from compiling {'+str(e)+'}', 4, 'compilers')
         self.logPrint('C++ code cannot directly be linked with FC linker, therefore will determine needed C++ libraries')
         skipcxxlibraries = 0
+    self.setCompilers.LIBS = oldLibs
 
     if skipcxxlibraries: return
 
@@ -833,7 +813,7 @@ Otherwise you need a different combination of C, C++, and Fortran compilers")
     return
 
   def checkFortranLibraries(self):
-    '''Substitutes for FLIBS the libraries needed to link with Fortran
+    '''Substitutes for FLIBS the libraries needed to link using the C or C++ compiler Fortran source code compiled with Fortran. Result is stored in flibs.
 
     This macro is intended to be used in those situations when it is
     necessary to mix, e.g. C++ and Fortran 77, source code into a single
@@ -877,6 +857,20 @@ Otherwise you need a different combination of C, C++, and Fortran compilers")
       else:
         skipfortranlibraries = 0
         self.logWrite(self.setCompilers.restoreLog())
+        oldLibs = self.setCompilers.LIBS
+        self.setCompilers.LIBS = '-lgfortran '+self.setCompilers.LIBS
+        self.setCompilers.saveLog()
+        if self.checkCrossLink(fbody,cbody,language1='FC',language2='C'):
+          self.logWrite(self.setCompilers.restoreLog())
+          self.logPrint('Fortran requires -lgfortran to link with C compiler', 3, 'compilers')
+          self.setCompilers.LIBS = oldLibs
+          self.flibs.append('-lgfortran')
+          skipfortranlibraries = 1
+        else:
+          self.logWrite(self.setCompilers.restoreLog())
+          self.setCompilers.LIBS = oldLibs
+          self.logPrint('Fortran code cannot directly be linked with C linker, therefore will determine needed Fortran libraries')
+          skipfortranlibraries = 0
         if iscray:
           oldLibs = self.setCompilers.LIBS
           self.setCompilers.LIBS = '-lmpifort_cray '+self.setCompilers.LIBS
@@ -884,6 +878,8 @@ Otherwise you need a different combination of C, C++, and Fortran compilers")
           if self.checkCrossLink(fbody,cbody,language1='FC',language2='C'):
             self.logWrite(self.setCompilers.restoreLog())
             self.logPrint('Fortran requires -lmpifort_cray to link with C compiler', 3, 'compilers')
+            self.setCompilers.LIBS = oldLibs
+            self.flibs.append('-lmpifort_cray')
             skipfortranlibraries = 1
           else:
             self.logWrite(self.setCompilers.restoreLog())
@@ -897,17 +893,22 @@ Otherwise you need a different combination of C, C++, and Fortran compilers")
       skipfortranlibraries = 0
     if skipfortranlibraries and hasattr(self.setCompilers, 'CXX'):
       self.setCompilers.saveLog()
+      oldLibs = self.setCompilers.LIBS
       try:
+        self.setCompilers.LIBS =  ' '.join([self.libraries.getLibArgument(lib) for lib in self.flibs]) + ' ' + self.setCompilers.LIBS
         if self.checkCrossLink(fbody,cxxbody,language1='FC',language2='C++'):
           self.logWrite(self.setCompilers.restoreLog())
-          self.logPrint('Fortran libraries are not needed when using C++ linker')
+          self.setCompilers.LIBS = oldLibs
+          self.logPrint('Additional Fortran libraries are not needed when using C++ linker')
         else:
           self.logWrite(self.setCompilers.restoreLog())
+          self.setCompilers.LIBS = oldLibs
           self.logPrint('Fortran code cannot directly be linked with C++ linker, therefore will determine needed Fortran libraries')
           skipfortranlibraries = 0
       except RuntimeError as e:
         self.logWrite(self.setCompilers.restoreLog())
         self.logPrint('Error message from compiling {'+str(e)+'}', 4, 'compilers')
+        self.setCompilers.LIBS = oldLibs
         self.logPrint('Fortran code cannot directly be linked with CXX linker, therefore will determine needed Fortran libraries')
         skipfortranlibraries = 0
 
@@ -1393,7 +1394,7 @@ Otherwise you need a different combination of C, C++, and Fortran compilers")
     for (int i=0; i<2; i++){
       x[i] = i*j*(*z);
     }
-    """
+    (void)x"""
     self.setCompilers.pushLanguage('C')
     flags_to_try = ['','-std=c99','-std=gnu99','-std=c11','-std=gnu11','-c99']
     for flag in flags_to_try:
@@ -1401,18 +1402,41 @@ Otherwise you need a different combination of C, C++, and Fortran compilers")
       if self.setCompilers.checkCompilerFlag(flag, includes, body):
         self.logWrite(self.setCompilers.restoreLog())
         self.c99flag = flag
-        self.setCompilers.CPPFLAGS += ' ' + flag
+        if flag:
+          self.setCompilers.CPPFLAGS += ' ' + flag
         self.framework.logPrint('Accepted C99 compile flag: '+flag)
         break
       else:
         self.logWrite(self.setCompilers.restoreLog())
     self.setCompilers.popLanguage()
     if self.c99flag is None:
-      if self.isGCC: additionalErrorMsg = '\nPerhaps you have an Intel compiler environment or module set that is interferring with the GNU compilers.\nTry removing that environment or module and running ./configure again.'
+      if self.isGCC: additionalErrorMsg = '\nPerhaps you have an Intel compiler environment or module set that is interfering with the GNU compilers.\nTry removing that environment or module and running ./configure again.'
       else: additionalErrorMsg = ''
       raise RuntimeError('PETSc requires c99 compiler! Configure could not determine compatible compiler flag.\nPerhaps you can specify it via CFLAGS.'+additionalErrorMsg)
     return
 
+  def checkStdAtomic(self,cxx=False):
+    includes = """
+    #if defined(__cplusplus)
+    #include <atomic>
+    using namespace std;
+    #else
+    #include <stdatomic.h>
+    #endif
+    double dcount = 0;
+    atomic_flag cat = ATOMIC_FLAG_INIT;
+    """
+    body = """
+    do {} while (atomic_flag_test_and_set(&cat));
+    dcount++;
+    atomic_flag_clear(&cat);
+    """
+    if self.checkCompile(includes, body):
+      if cxx:
+        self.addDefine('HAVE_CXX_ATOMIC', 1)
+      else:
+        self.addDefine('HAVE_STDATOMIC_H', 1)
+
   def configure(self):
     import config.setCompilers
     if hasattr(self.setCompilers, 'CC'):
@@ -1420,6 +1444,7 @@ Otherwise you need a different combination of C, C++, and Fortran compilers")
       self.executeTest(self.checkC99Flag)
       self.executeTest(self.checkCFormatting)
       self.executeTest(self.checkDynamicLoadFlag)
+      self.executeTest(self.checkStdAtomic)
       if self.argDB['with-clib-autodetect']:
         self.executeTest(self.checkCLibraries)
       self.executeTest(self.checkDependencyGenerationFlag)
@@ -1429,8 +1454,11 @@ Otherwise you need a different combination of C, C++, and Fortran compilers")
     if hasattr(self.setCompilers, 'CXX'):
       self.isGCXX = config.setCompilers.Configure.isGNU(self.setCompilers.CXX, self.log)
       self.executeTest(self.checkCxxRestrict)
-      self.executeTest(self.checkCxxOptionalExtensions)
+      # Adding -x c++ it causes Clang to SEGV, http://llvm.org/bugs/show_bug.cgi?id=12924
+      if not config.setCompilers.Configure.isClang(self.setCompilers.CXX, self.log):
+        self.executeTest(self.checkCxxOptionalExtensions)
       self.executeTest(self.checkCxxComplexFix)
+      self.executeTest(self.checkStdAtomic,kargs={'cxx' : True})
       if self.argDB['with-cxxlib-autodetect']:
         self.executeTest(self.checkCxxLibraries)
       # To skip Sun C++ compiler warnings/errors
