@@ -47,6 +47,8 @@ class Configure(config.package.Package):
     help.addArgument('BLAS/LAPACK', '-with-blaslapack-suffix=<string>',nargs.ArgLibrary(None, None, 'Indicate a suffix for BLAS/LAPACK subroutine names.'))
     help.addArgument('BLAS/LAPACK', '-with-64-bit-blas-indices', nargs.ArgBool(None, 0, 'Try to use 64 bit integers for BLAS/LAPACK; will error if not available'))
     help.addArgument('BLAS/LAPACK', '-known-64-bit-blas-indices=<bool>', nargs.ArgBool(None, None, 'Indicate if using 64 bit integer BLAS'))
+    help.addArgument('BLAS/LAPACK', '-known-snrm2-returns-double=<bool>', nargs.ArgBool(None, None, 'Indicate if BLAS snrm2() returns a double'))
+    help.addArgument('BLAS/LAPACK', '-known-sdot-returns-double=<bool>', nargs.ArgBool(None, None, 'Indicate if BLAS sdot() returns a double'))        
     return
 
   def getPrefix(self):
@@ -234,7 +236,6 @@ class Configure(config.package.Package):
         yield ('Default compiler locations with gfortran', None, ['liblapack.a', 'libblas.a','libgfortran.a'],'unknown','unknown')
         self.logWrite('Did not detect default BLAS and LAPACK locations so using the value of MKLROOT to search as --with-blas-lapack-dir='+mkl)
         self.argDB['with-blaslapack-dir'] = mkl
-        self.checkingMKLROOTautomatically = 1
 
     if self.argDB['with-64-bit-blas-indices']:
       flexiblas = 'libflexiblas64.a'
@@ -429,6 +430,8 @@ class Configure(config.package.Package):
       for lapack in ['libflame.a','liblapack.a']:
         yield ('Default BLIS/AMD-AOCL', lib, lapack,'unknown','unknown')
     yield ('Default compiler locations', 'libblas.a', 'liblapack.a','unknown','unknown')
+    yield ('Default compiler locations (all contained in libblas)', None, 'libblas.a','unknown','unknown')
+    yield ('Default NVHPC', None, ['liblapack.a','libblas.a','libnvf.a','librt.a'],'unknown','unknown')
     yield ('Default OpenBLAS', None, 'libopenblas.a','unknown','unknown')
     # Intel on Mac
     for ITHREAD in ITHREADS:
@@ -541,6 +544,20 @@ class Configure(config.package.Package):
     if self.suffix != '':
       self.addDefine('BLASLAPACK_SUFFIX', self.suffix)
 
+    if self.f2cblaslapack.found:
+      oldLibs = self.compilers.LIBS
+      routine___float128 = self.mangleBlasNoPrefix('qdot')
+      routine___fp16 = self.mangleBlasNoPrefix('hdot')
+      self.libraries.saveLog()
+      if self.defaultPrecision != '__float128':
+        found = self.libraries.check(self.blasLibrary, routine___float128, fortranMangle = 0)
+        if found: self.addDefine('HAVE_F2CBLASLAPACK___FLOAT128_BINDINGS', 1)
+      if self.defaultPrecision != '__fp16':
+        found = self.libraries.check(self.blasLibrary, routine___fp16, fortranMangle = 0)
+        if found: self.addDefine('HAVE_F2CBLASLAPACK___FP16_BINDINGS', 1)
+      self.logWrite(self.libraries.restoreLog())
+      self.compilers.LIBS = oldLibs
+
     self.found = 1
     if not self.f2cblaslapack.found and not self.fblaslapack.found:
       self.executeTest(self.checkMKL)
@@ -603,6 +620,10 @@ class Configure(config.package.Package):
       self.versionname    = 'INTEL_MKL_VERSION'
       self.versioninclude = 'mkl_version.h'
       self.versiontitle   = 'Intel MKL Version'
+      if hasattr(self,'dinclude'):
+        [self.dinclude.append(inc) for inc in self.include if inc not in self.dinclude]
+      else:
+        self.dinclude = self.include
       self.checkVersion()
       if self.foundversion:
         self.addDefine('HAVE_MKL_INCLUDES',1)
@@ -744,10 +765,10 @@ class Configure(config.package.Package):
       else:
         self.has64bitindices = 0
     elif self.argDB['with-batch']:
-      self.logPrintBox('***** WARNING: Cannot determine if BLAS/LAPACK uses 32 bit or 64 bit integers\n\
-in batch-mode! Assuming 32 bit integers. Run with --known-64-bit-blas-indices\n\
-if you know they are 64 bit. Run with --known-64-bit-blas-indices=0 to remove\n\
-this warning message *****')
+      self.logPrintWarning('Cannot determine if BLAS/LAPACK uses 32 bit or 64 bit integers \
+in batch-mode! Assuming 32 bit integers. Run with --known-64-bit-blas-indices \
+if you know they are 64 bit. Run with --known-64-bit-blas-indices=0 to remove \
+this warning message')
       self.has64bitindices = 0
       self.log.write('In batch mode with unknown size of BLAS/LAPACK defaulting to 32 bit\n')
     else:
@@ -788,10 +809,10 @@ this warning message *****')
       if self.argDB['known-sdot-returns-double']:
         self.addDefine('BLASLAPACK_SDOT_RETURNS_DOUBLE', 1)
     elif self.argDB['with-batch']:
-      self.logPrintBox('***** WARNING: Cannot determine if BLAS sdot() returns a float or a double\n\
-in batch-mode! Assuming float. Run with --known-sdot-returns-double=1\n\
-if you know it returns a double (very unlikely). Run with\n\
---known-sdor-returns-double=0 to remove this warning message *****')
+      self.logPrintWarning('Cannot determine if BLAS sdot() returns a float or a double \
+in batch-mode! Assuming float. Run with --known-sdot-returns-double=1 \
+if you know it returns a double (very unlikely). Run with \
+--known-sdot-returns-double=0 to remove this warning message')
     else:
       includes = '''#include <sys/types.h>\n#include <stdlib.h>\n#include <stdio.h>\n#include <stddef.h>\n'''
       body     = '''extern float '''+self.mangleBlasNoPrefix('sdot')+'''(const int*,const float*,const int *,const float*,const int*);
@@ -820,10 +841,10 @@ if you know it returns a double (very unlikely). Run with\n\
       if self.argDB['known-snrm2-returns-double']:
         self.addDefine('BLASLAPACK_SNRM2_RETURNS_DOUBLE', 1)
     elif self.argDB['with-batch']:
-      self.logPrintBox('***** WARNING: Cannot determine if BLAS snrm2() returns a float or a double\n\
-in batch-mode! Assuming float. Run with --known-snrm2-returns-double=1\n\
-if you know it returns a double (very unlikely). Run with\n\
---known-snrm2-returns-double=0 to remove this warning message *****')
+      self.logPrintWarning('Cannot determine if BLAS snrm2() returns a float or a double \
+in batch-mode! Assuming float. Run with --known-snrm2-returns-double=1 \
+if you know it returns a double (very unlikely). Run with \
+--known-snrm2-returns-double=0 to remove this warning message')
     else:
       includes = '''#include <sys/types.h>\n#include <stdlib.h>\n#include <stdio.h>\n#include <stddef.h>\n'''
       body     = '''extern float '''+self.mangleBlasNoPrefix('snrm2')+'''(const int*,const float*,const int*);
