@@ -34,10 +34,13 @@ class Configure(config.package.Package):
                              ['libmpi.a','liblam.a']]
     liblist_msmpi         = [[os.path.join('amd64','msmpifec.lib'),os.path.join('amd64','msmpi.lib')],
                              [os.path.join('i386','msmpifec.lib'),os.path.join('i386','msmpi.lib')],
+                             [os.path.join('x64','msmpifec.lib'),os.path.join('x64','msmpi.lib')],
+                             [os.path.join('x86','msmpifec.lib'),os.path.join('x86','msmpi.lib')],
                              ['msmpi.lib']]
     liblist_other         = [['libmpich.a','libpthread.a'],['libmpi++.a','libmpi.a']]
     liblist_single        = [['libmpi.a'],['libmpich.a'],['mpi.lib'],['mpich2.lib'],['mpich.lib'],
-                             [os.path.join('amd64','msmpi.lib')],[os.path.join('i386','msmpi.lib')]]
+                             [os.path.join('amd64','msmpi.lib')],[os.path.join('i386','msmpi.lib')],
+                             [os.path.join('x64','msmpi.lib')],[os.path.join('x86','msmpi.lib')]]
     self.liblist          = liblist_mpich + liblist_lam + liblist_msmpi + liblist_other + liblist_single
     # defaults to --with-mpi=yes
     self.required         = 1
@@ -66,6 +69,7 @@ class Configure(config.package.Package):
     config.package.Package.setupHelp(self,help)
     import nargs
     help.addArgument('MPI', '-with-mpiexec=<prog>',                              nargs.Arg(None, None, 'The utility used to launch MPI jobs. (should support "-n <np>" option)'))
+    help.addArgument('MPI', '-with-mpiexec-tail=<prog>',                         nargs.Arg(None, None, 'The utility you want to put at the very end of "mpiexec -n <np> ..." and right before your executable to launch MPI jobs.'))
     help.addArgument('MPI', '-with-mpi-compilers=<bool>',                        nargs.ArgBool(None, 1, 'Try to use the MPI compilers, e.g. mpicc'))
     help.addArgument('MPI', '-known-mpi-shared-libraries=<bool>',                nargs.ArgBool(None, None, 'Indicates the MPI libraries are shared (the usual test will be skipped)'))
     help.addArgument('MPI', '-with-mpi-f90module-visibility=<bool>',             nargs.ArgBool(None, 1, 'Indicates the MPI f90 module is available via petsc module. When disabled, mpi_f08 can be used from user code'))
@@ -84,6 +88,7 @@ class Configure(config.package.Package):
   def __str__(self):
     output  = config.package.Package.__str__(self)
     if self.mpiexec: output  += '  mpiexec: '+self.mpiexec+'\n'
+    if self.mpiexec_tail: output  += '  mpiexec_tail: '+self.mpiexec_tail+'\n'
     if self.mpi_pkg: output  += '  Implementation: '+self.mpi_pkg+'\n'
     if hasattr(self,'includepaths'):
       output  += '  MPI C++ include paths: '+ self.includepaths+'\n'
@@ -157,7 +162,7 @@ class Configure(config.package.Package):
 
   def checkSharedLibrary_ThisIsBroken(self):
   # TODO: Fix this routine, currently
-  #       * the visibility flag is passed to the compiling/linking so the symbols are not visable to the loader and the test fails (this is easily fixed)
+  #       * the visibility flag is passed to the compiling/linking so the symbols are not visible to the loader and the test fails (this is easily fixed)
   #       * even with that fixed the dlsym() is unable to locate the checkInit symbol in the library even though nm shows it is there; I am not sure the cause
     '''Sets flag indicating if MPI libraries are shared or not and
     determines if MPI libraries CANNOT be used by shared libraries'''
@@ -172,7 +177,7 @@ shared - run with --known-mpi-shared-libraries=1 option to remove this \
 warning message')
         elif not self.argDB['known-mpi-shared-libraries']:
           raise RuntimeError('Provided MPI library is flagged as static library! If its linked\n\
-into multipe shared libraries that an application uses, sometimes\n\
+into multiple shared libraries that an application uses, sometimes\n\
 compiles go through - but one might get run-time errors.  Either\n\
 reconfigure PETSc with --with-shared-libraries=0 or provide MPI with\n\
 shared libraries and run with --known-mpi-shared-libraries=1')
@@ -185,6 +190,17 @@ shared libraries and run with --known-mpi-shared-libraries=1')
     #  raise RuntimeError('Shared libraries cannot be built using MPI provided.\nEither reconfigure with --with-shared-libraries=0 or rebuild MPI with shared library support')
     return
 
+  def configureMPIEXEC_TAIL(self):
+    '''Checking for location of mpiexec_tail'''
+    if 'with-mpiexec-tail' in self.argDB:
+      self.argDB['with-mpiexec-tail'] = os.path.expanduser(self.argDB['with-mpiexec-tail'])
+      # If found, the call below defines a make macro MPIEXEC_TAIL with full path
+      if not self.getExecutable(self.argDB['with-mpiexec-tail'], getFullPath=1, resultName = 'mpiexec_tail'):
+        raise RuntimeError('Invalid mpiexec-tail specified: '+str(self.argDB['with-mpiexec-tail']))
+    else:
+      self.mpiexec_tail =''
+      self.addMakeMacro('MPIEXEC_TAIL', '')
+
   def configureMPIEXEC(self):
     '''Checking for location of mpiexec'''
     mpiexecargs = ''
@@ -235,7 +251,7 @@ shared libraries and run with --known-mpi-shared-libraries=1')
           raise RuntimeError('Could not locate MPIEXEC - please specify --with-mpiexec option')
       # Support for spaces and () in executable names; also needs to handle optional arguments at the end
       # TODO: This support for spaces and () should be moved to core BuildSystem
-      self.mpiexec = self.mpiexec.replace(' ', '\\ ').replace('(', '\\(').replace(')', '\\)').replace('\ -',' -')
+      self.mpiexec = self.mpiexec.replace(' ', r'\\ ').replace('(', r'\\(').replace(')', r'\\)').replace(r'\ -',' -')
       if (hasattr(self, 'ompi_major_version') and int(self.ompi_major_version) >= 3):
         (out, err, ret) = Configure.executeShellCommand(self.mpiexec+' -help all', checkCommand = noCheck, timeout = 60, log = self.log, threads = 1)
         if out.find('--oversubscribe') >=0:
@@ -398,30 +414,30 @@ Unable to run hostname to check the network')
       raise RuntimeError('PETSc requires some of the MPI-2.0 (1997), MPI-2.1 (2008) functions - they are not available with the specified MPI library')
 
     if self.checkLink('#include <mpi.h>\n', 'int count=2; int blocklens[2]={0,1}; MPI_Aint indices[2]={0,1}; MPI_Datatype old_types[2]={MPI_INT,MPI_DOUBLE}; MPI_Datatype *newtype = 0;\n \
-                                             if (MPI_Type_create_struct(count, blocklens, indices, old_types, newtype));\n'):
+                                             if (MPI_Type_create_struct(count, blocklens, indices, old_types, newtype)) { }\n'):
       self.haveTypeCreateStruct = 1
     else:
       self.haveTypeCreateStruct = 0
       self.framework.addDefine('MPI_Type_create_struct(count,lens,displs,types,newtype)', 'MPI_Type_struct((count),(lens),(displs),(types),(newtype))')
-    if self.checkLink('#include <mpi.h>\n', 'MPI_Comm_errhandler_fn * p_err_fun = 0; MPI_Errhandler * p_errhandler = 0; if (MPI_Comm_create_errhandler(p_err_fun,p_errhandler));\n'):
+    if self.checkLink('#include <mpi.h>\n', 'MPI_Comm_errhandler_fn * p_err_fun = 0; MPI_Errhandler * p_errhandler = 0; if (MPI_Comm_create_errhandler(p_err_fun,p_errhandler)) { }\n'):
       self.haveCommCreateErrhandler = 1
     else:
       self.haveCommCreateErrhandler = 0
       self.framework.addDefine('MPI_Comm_create_errhandler(p_err_fun,p_errhandler)', 'MPI_Errhandler_create((p_err_fun),(p_errhandler))')
-    if self.checkLink('#include <mpi.h>\n', 'if (MPI_Comm_set_errhandler(MPI_COMM_WORLD,MPI_ERRORS_RETURN));\n'):
+    if self.checkLink('#include <mpi.h>\n', 'if (MPI_Comm_set_errhandler(MPI_COMM_WORLD,MPI_ERRORS_RETURN)) { }\n'):
       self.haveCommSetErrhandler = 1
     else:
       self.haveCommSetErrhandler = 0
       self.framework.addDefine('MPI_Comm_set_errhandler(comm,p_errhandler)', 'MPI_Errhandler_set((comm),(p_errhandler))')
-    if self.checkLink('#include <mpi.h>\n', 'if (MPI_Reduce_local(0, 0, 0, MPI_INT, MPI_SUM));'): # MPI_Reduce_local is in MPI-2.2
+    if self.checkLink('#include <mpi.h>\n', 'if (MPI_Reduce_local(0, 0, 0, MPI_INT, MPI_SUM)) { }\n'): # MPI_Reduce_local is in MPI-2.2
       self.haveReduceLocal = 1
       self.addDefine('HAVE_MPI_REDUCE_LOCAL',1)
-    if self.checkLink('#include <mpi.h>\n', 'char version[MPI_MAX_LIBRARY_VERSION_STRING];int verlen;if (MPI_Get_library_version(version,&verlen));\n'):
+    if self.checkLink('#include <mpi.h>\n', 'char version[MPI_MAX_LIBRARY_VERSION_STRING];int verlen;if (MPI_Get_library_version(version,&verlen)) { }\n'):
       self.addDefine('HAVE_MPI_GET_LIBRARY_VERSION', 1)
     # Even MPI_Win_create is in MPI 2.0, we do this test to suppress MPIUNI, which does not support MPI one-sided.
-    if self.checkLink('#include <mpi.h>\n', 'int base[100]; MPI_Win win; if (MPI_Win_create(base,100,4,MPI_INFO_NULL,MPI_COMM_WORLD,&win));\n'):
+    if self.checkLink('#include <mpi.h>\n', 'int base[100]; MPI_Win win = 0; if (MPI_Win_create(base,100,4,MPI_INFO_NULL,MPI_COMM_WORLD,&win)) { }'):
       self.addDefine('HAVE_MPI_WIN_CREATE', 1)
-    if not self.checkLink('#include <mpi.h>\n', 'int ptr[1]; MPI_Win win; if (MPI_Accumulate(ptr,1,MPI_INT,0,0,1,MPI_INT,MPI_REPLACE,win));\n'):
+    if not self.checkLink('#include <mpi.h>\n', 'int ptr[1] = {0}; MPI_Win win = 0; if (MPI_Accumulate(ptr,1,MPI_INT,0,0,1,MPI_INT,MPI_REPLACE,win)) { }'):
       raise RuntimeError('PETSc requires MPI_REPLACE (introduced in MPI-2.1 in 2008). Please update or switch to MPI that supports MPI_REPLACE. Let us know at petsc-maint@mcs.anl.gov if this is not possible')
     # flag broken one-sided tests
     if not 'HAVE_MSMPI' in self.defines and not (hasattr(self, 'mpich_numversion') and int(self.mpich_numversion) <= 30004300) and not (hasattr(self, 'isNecMPI')):
@@ -455,9 +471,9 @@ Unable to run hostname to check the network')
     if (hasattr(self, 'mpich_numversion') and int(self.mpich_numversion) > 30004300) or not hasattr(self, 'mpich_numversion'):
       if self.checkLink('#include <mpi.h>\n',
                       'MPI_Comm scomm; MPI_Aint size=128; int disp_unit=8,*baseptr; MPI_Win win;\n\
-                       if (MPI_Comm_split_type(MPI_COMM_WORLD, MPI_COMM_TYPE_SHARED, 0, MPI_INFO_NULL, &scomm));\n\
-                       if (MPI_Win_allocate_shared(size,disp_unit,MPI_INFO_NULL,MPI_COMM_WORLD,&baseptr,&win));\n\
-                       if (MPI_Win_shared_query(win,0,&size,&disp_unit,&baseptr));\n'):
+                       if (MPI_Comm_split_type(MPI_COMM_WORLD, MPI_COMM_TYPE_SHARED, 0, MPI_INFO_NULL, &scomm)) { }\n\
+                       if (MPI_Win_allocate_shared(size,disp_unit,MPI_INFO_NULL,MPI_COMM_WORLD,&baseptr,&win)) { }\n\
+                       if (MPI_Win_shared_query(win,0,&size,&disp_unit,&baseptr)) { }\n'):
         self.addDefine('HAVE_MPI_PROCESS_SHARED_MEMORY', 1)
         self.support_mpi3_shm = 1
     if not any([
@@ -465,9 +481,9 @@ Unable to run hostname to check the network')
         hasattr(self, 'ompi_version') and (4,1,0) <= self.ompi_version < (4,2,0), # dynamic window tests fail unless using --mca btl vader
         ]) and self.checkLink('#include <mpi.h>\n',
                       'MPI_Aint size=128; int disp_unit=8,*baseptr; MPI_Win win;\n\
-                       if (MPI_Win_allocate(size,disp_unit,MPI_INFO_NULL,MPI_COMM_WORLD,&baseptr,&win));\n\
-                       if (MPI_Win_attach(win,baseptr,size));\n\
-                       if (MPI_Win_create_dynamic(MPI_INFO_NULL,MPI_COMM_WORLD,&win));\n'):
+                       if (MPI_Win_allocate(size,disp_unit,MPI_INFO_NULL,MPI_COMM_WORLD,&baseptr,&win)) { }\n\
+                       if (MPI_Win_attach(win,baseptr,size)) { }\n\
+                       if (MPI_Win_create_dynamic(MPI_INFO_NULL,MPI_COMM_WORLD,&win)) { }\n'):
       self.addDefine('HAVE_MPI_FEATURE_DYNAMIC_WINDOW', 1) # Use it to represent a group of MPI3 Win routines
     if self.checkLink('#include <mpi.h>\n',
                       '''
@@ -487,9 +503,9 @@ Unable to run hostname to check the network')
     if self.checkLink('#include <mpi.h>\n',
                       'MPI_Comm distcomm; \n\
                        MPI_Request req; \n\
-                       if (MPI_Dist_graph_create_adjacent(MPI_COMM_WORLD,0,0,MPI_WEIGHTS_EMPTY,0,0,MPI_WEIGHTS_EMPTY,MPI_INFO_NULL,0,&distcomm));\n\
-                       if (MPI_Neighbor_alltoallv(0,0,0,MPI_INT,0,0,0,MPI_INT,distcomm));\n\
-                       if (MPI_Ineighbor_alltoallv(0,0,0,MPI_INT,0,0,0,MPI_INT,distcomm,&req));\n'):
+                       if (MPI_Dist_graph_create_adjacent(MPI_COMM_WORLD,0,0,MPI_WEIGHTS_EMPTY,0,0,MPI_WEIGHTS_EMPTY,MPI_INFO_NULL,0,&distcomm)) { }\n\
+                       if (MPI_Neighbor_alltoallv(0,0,0,MPI_INT,0,0,0,MPI_INT,distcomm)) { }\n\
+                       if (MPI_Ineighbor_alltoallv(0,0,0,MPI_INT,0,0,0,MPI_INT,distcomm,&req)) { }\n'):
       self.addDefine('HAVE_MPI_NEIGHBORHOOD_COLLECTIVES',1)
     cuda_aware = 0
     if hasattr(self, 'ompi_major_version'):
@@ -503,9 +519,9 @@ Unable to run hostname to check the network')
       self.addDefine('HAVE_MPI_GPU_AWARE', 1)
     else:
       self.testoptions = '-use_gpu_aware_mpi 0'
-    if self.checkLink('#include <mpi.h>\n', 'int ptr[1]; MPI_Win win; if (MPI_Get_accumulate(ptr,1,MPI_INT,ptr,1,MPI_INT,0,0,1,MPI_INT,MPI_SUM,win));\n'):
+    if self.checkLink('#include <mpi.h>\n', 'int ptr[1] = {0}; MPI_Win win = 0; if (MPI_Get_accumulate(ptr,1,MPI_INT,ptr,1,MPI_INT,0,0,1,MPI_INT,MPI_SUM,win)) { }\n'):
       self.addDefine('HAVE_MPI_GET_ACCUMULATE', 1)
-    if self.checkLink('#include <mpi.h>\n', 'int ptr[1]; MPI_Win win; MPI_Request req; if (MPI_Rget(ptr,1,MPI_INT,0,1,1,MPI_INT,win,&req));\n'):
+    if self.checkLink('#include <mpi.h>\n', 'int ptr[1]; MPI_Win win = 0; MPI_Request req; if (MPI_Rget(ptr,1,MPI_INT,0,1,1,MPI_INT,win,&req)) { }\n'):
       self.addDefine('HAVE_MPI_RGET', 1)
     self.compilers.CPPFLAGS = oldFlags
     self.compilers.LIBS = oldLibs
@@ -541,6 +557,42 @@ Unable to run hostname to check the network')
     self.logWrite(self.framework.restoreLog())
     return
 
+  def configureMPIX(self):
+    '''Check for experimental functions added by MPICH or OpenMPI as MPIX'''
+    # mpich-4.2 has a bug fix (PR6454). Without it, we could not use MPIX stream
+    if (hasattr(self, 'mpich_numversion') and int(self.mpich_numversion) >= 40200000):
+      oldFlags = self.compilers.CPPFLAGS
+      oldLibs  = self.compilers.LIBS
+      self.compilers.CPPFLAGS += ' '+self.headers.toString(self.include)
+      self.compilers.LIBS = self.libraries.toString(self.lib)+' '+self.compilers.LIBS
+      self.framework.saveLog()
+      if self.checkLink('#include <mpi.h>\n',
+      '''
+        MPI_Info    info ;
+        // cudaStream_t stream;
+        int         stream; // use a fake type instead as we don't want this check to depend on CUDA
+        MPI_Comm    stream_comm ;
+        MPIX_Stream mpi_stream ;
+        MPI_Request req;
+        MPI_Status  stat;
+        int         sbuf[1]={0},rbuf[1]={0},count=1,dest=1,source=0,tag=0;
+
+        MPI_Info_create (&info);
+        MPI_Info_set(info, "type", "cudaStream_t");
+        MPIX_Info_set_hex(info, "value", &stream, sizeof(stream));
+        MPIX_Stream_create(info, &mpi_stream );
+        MPIX_Stream_comm_create(MPI_COMM_WORLD, mpi_stream, &stream_comm);
+        MPIX_Isend_enqueue(sbuf,count,MPI_INT,dest,tag,stream_comm,&req);
+        MPIX_Irecv_enqueue(rbuf,count,MPI_INT,source,tag,stream_comm,&req);
+        MPIX_Allreduce_enqueue(sbuf,rbuf,count,MPI_INT,MPI_SUM,stream_comm);
+        MPIX_Wait_enqueue(&req, &stat);
+      '''):
+        self.addDefine('HAVE_MPIX_STREAM', 1)
+      self.compilers.CPPFLAGS = oldFlags
+      self.compilers.LIBS = oldLibs
+      self.logWrite(self.framework.restoreLog())
+    return
+
   def configureMPITypes(self):
     '''Checking for MPI Datatype handles'''
     oldFlags = self.compilers.CPPFLAGS
@@ -565,6 +617,7 @@ Unable to run hostname to check the network')
     self.mpiexec = '${PETSC_DIR}/lib/petsc/bin/petsc-mpiexec.uni'
     self.mpiexecseq = '${PETSC_DIR}/lib/petsc/bin/petsc-mpiexec.uni'
     self.addMakeMacro('MPIEXEC','${PETSC_DIR}/lib/petsc/bin/petsc-mpiexec.uni')
+    self.executeTest(self.configureMPIEXEC_TAIL)
     self.framework.saveLog()
     self.framework.addDefine('MPI_Type_create_struct(count,lens,displs,types,newtype)', 'MPI_Type_struct((count),(lens),(displs),(types),(newtype))')
     self.framework.addDefine('MPI_Comm_create_errhandler(p_err_fun,p_errhandler)', 'MPI_Errhandler_create((p_err_fun),(p_errhandler))')
@@ -573,6 +626,7 @@ Unable to run hostname to check the network')
     self.commf2c = 1
     self.commc2f = 1
     self.usingMPIUni = 1
+    self.found = 1
     self.version = 'PETSc MPIUNI uniprocessor MPI replacement'
     self.executeTest(self.PetscArchMPICheck)
     return
@@ -605,7 +659,7 @@ Unable to run hostname to check the network')
     self.log.write('Checking for header mpi.h\n')
     # check if MPI_Finalize from c++ exists
     self.log.write('Checking for C++ MPI_Finalize()\n')
-    if not self.libraries.check(self.lib, 'MPI_Finalize', prototype = '#include <mpi.h>', call = 'int ierr;\nierr = MPI_Finalize();', cxxMangle = 1):
+    if not self.libraries.check(self.lib, 'MPI_Finalize', prototype = '#include <mpi.h>', call = 'int ierr;\nierr = MPI_Finalize();\n(void)ierr', cxxMangle = 1):
       raise RuntimeError('C++ error! MPI_Finalize() could not be located!')
     self.compilers.CXXPPFLAGS = oldFlags
     self.libraries.popLanguage()
@@ -643,12 +697,12 @@ Unable to run hostname to check the network')
     oldLibs  = self.compilers.LIBS
     self.compilers.CPPFLAGS += ' '+self.headers.toString(self.include)
     self.compilers.LIBS = self.libraries.toString(self.lib)+' '+self.compilers.LIBS
-    if not self.checkLink('#include <mpi.h>\n', '''MPI_Aint lb, extent;\nif (MPI_Type_get_extent(MPI_INT, &lb, &extent));\n
-                                                 MPI_File fh;\nvoid *buf;\nMPI_Status status;\nif (MPI_File_write_all(fh, buf, 1, MPI_INT, &status));\n
-                                                 if (MPI_File_read_all(fh, buf, 1, MPI_INT, &status));\n
-                                                 MPI_Offset disp;\nMPI_Info info;\nif (MPI_File_set_view(fh, disp, MPI_INT, MPI_INT, "", info));\n
-                                                 if (MPI_File_open(MPI_COMM_SELF, "", 0, info, &fh));\n
-                                                 if (MPI_File_close(&fh));\n'''):
+    if not self.checkLink('#include <mpi.h>\n', '''MPI_Aint lb, extent;\nif (MPI_Type_get_extent(MPI_INT, &lb, &extent)) { }\n
+                                                 MPI_File fh = 0;\nvoid *buf = 0;\nMPI_Status status;\nif (MPI_File_write_all(fh, buf, 1, MPI_INT, &status)) { }\n
+                                                 if (MPI_File_read_all(fh, buf, 1, MPI_INT, &status)) { }\n
+                                                 MPI_Offset disp = 0;\nMPI_Info info = 0;\nif (MPI_File_set_view(fh, disp, MPI_INT, MPI_INT, "", info)) { }\n
+                                                 if (MPI_File_open(MPI_COMM_SELF, "", 0, info, &fh)) { }\n
+                                                 if (MPI_File_close(&fh)) { }\n'''):
       self.compilers.LIBS = oldLibs
       self.compilers.CPPFLAGS = oldFlags
       return
@@ -665,7 +719,7 @@ Unable to run hostname to check the network')
     oldFlags = self.compilers.CPPFLAGS
     self.compilers.CPPFLAGS += ' '+self.headers.toString(self.include)
 
-    # the following packages are all derived orginally from the MPICH implementation
+    # the following packages are all derived originally from the MPICH implementation
     MPI_VER = ''
     # I_MPI_NUMVERSION is broken on Windows and only has a value of 0 so test also for the named version
     MPICHPKG = 'I_MPI'
@@ -673,7 +727,7 @@ Unable to run hostname to check the network')
     if self.checkCompile(mpich_test):
       buf = self.outputPreprocess(mpich_test)
       try:
-        mpich_numversion = re.compile('\nconst char *mpich_ver ='+HASHLINESPACE+'"([\.0-9]+)"'+HASHLINESPACE+';').search(buf).group(1)
+        mpich_numversion = re.compile('\nconst char *mpich_ver ='+HASHLINESPACE+r'"([\.0-9]+)"'+HASHLINESPACE+';').search(buf).group(1)
         self.addDefine('HAVE_'+MPICHPKG+'_VERSION',mpich_numversion)
         MPI_VER  = '  '+MPICHPKG+'_VERSION: '+mpich_numversion
       except:
@@ -734,7 +788,7 @@ Unable to run hostname to check the network')
       msmpi_version = 'unknown'
       self.addDefine('HAVE_MSMPI',1) # flag we have MSMPI since we need to disable broken components
       try:
-        msmpi_version = re.compile('\nchar msmpi_hex\[\] = '+HASHLINESPACE+'\"([a-zA-Z0-9_]*)\"'+HASHLINESPACE+';').search(buf).group(1)
+        msmpi_version = re.compile('\n'+r'char msmpi_hex\[\] = '+HASHLINESPACE+'\"([a-zA-Z0-9_]*)\"'+HASHLINESPACE+';').search(buf).group(1)
         MPI_VER = '  MSMPI_VERSION: '+msmpi_version
         self.addDefine('HAVE_MSMPI_VERSION',msmpi_version)
       except:
@@ -833,7 +887,7 @@ Unable to run hostname to check the network')
   def PetscArchMPICheck(self):
     '''Check that previously configured for MPI include files are not in the PETSC_ARCH directory'''
     import os
-    '''Makes sure incompatable mpi.h is not in the PETSC_ARCH/include directory'''
+    '''Makes sure incompatible mpi.h is not in the PETSC_ARCH/include directory'''
     build_mpi_h_dir = os.path.join(self.petscdir.dir,self.arch,'include')
     build_mpi_h = os.path.join(build_mpi_h_dir,'mpi.h')
     if os.path.isfile(build_mpi_h):
@@ -878,7 +932,9 @@ You may need to set the environmental variable HWLOC_COMPONENTS to -x86 to preve
     self.executeTest(self.configureMPI2) #depends on checkMPIDistro
     self.executeTest(self.configureMPI3) #depends on checkMPIDistro
     self.executeTest(self.configureMPI4)
+    self.executeTest(self.configureMPIX)
     self.executeTest(self.configureMPIEXEC)
+    self.executeTest(self.configureMPIEXEC_TAIL)
     self.executeTest(self.configureMPITypes)
     self.executeTest(self.SGIMPICheck)
     self.executeTest(self.CxxMPICheck)
@@ -890,6 +946,6 @@ You may need to set the environmental variable HWLOC_COMPONENTS to -x86 to preve
     oldFlags = self.compilers.CPPFLAGS # Disgusting save and restore
     self.compilers.CPPFLAGS += ' '+self.headers.toString(self.include)
     for combiner in ['MPI_COMBINER_DUP', 'MPI_COMBINER_CONTIGUOUS', 'MPI_COMBINER_NAMED']:
-      if self.checkCompile('#include <mpi.h>', 'int combiner = %s;' % (combiner,)):
+      if self.checkCompile('#include <mpi.h>', 'int combiner = %s;(void)combiner' % (combiner,)):
         self.addDefine('HAVE_' + combiner,1)
     self.compilers.CPPFLAGS = oldFlags
