@@ -4,9 +4,10 @@ import os
 class Configure(config.package.GNUPackage):
   def __init__(self, framework):
     config.package.GNUPackage.__init__(self, framework)
-    self.version          = '4.0.1'
-    self.download         = ['https://www.mpich.org/static/downloads/'+self.version+'/mpich-'+self.version+'.tar.gz',
-                             'http://ftp.mcs.anl.gov/pub/petsc/externalpackages/mpich-'+self.version+'.tar.gz']
+    self.version          = '4.1.1'
+    self.download         = ['https://github.com/pmodels/mpich/releases/download/v'+self.version+'/mpich-'+self.version+'.tar.gz',
+                             'https://www.mpich.org/static/downloads/'+self.version+'/mpich-'+self.version+'.tar.gz', # does not always work from Python? So add in ftp.mcs URL below
+                             'https://ftp.mcs.anl.gov/pub/petsc/externalpackages'+'/mpich-'+self.version+'.tar.gz']
     self.downloaddirnames = ['mpich']
     self.skippackagewithoptions = 1
     self.isMPI = 1
@@ -16,8 +17,10 @@ class Configure(config.package.GNUPackage):
     config.package.GNUPackage.setupDependencies(self, framework)
     self.compilerFlags   = framework.require('config.compilerFlags',self)
     self.cuda            = framework.require('config.packages.cuda',self)
+    self.hip             = framework.require('config.packages.hip',self)
     self.hwloc           = framework.require('config.packages.hwloc',self)
-    self.odeps           = [self.hwloc]
+    self.python          = framework.require('config.packages.python',self)
+    self.odeps           = [self.cuda, self.hip, self.hwloc]
     return
 
   def setupHelp(self, help):
@@ -38,8 +41,6 @@ class Configure(config.package.GNUPackage):
       self.installDir = self.defaultInstallDir
       self.updateCompilers(self.installDir,'mpicc','mpicxx','mpif77','mpif90')
       return self.installDir
-    if self.cuda.found:
-      self.logPrintBox('***** WARNING: CUDA enabled! Its best to use --download-openmpi instead of --download-mpich as it provides CUDA enabled MPI! ****')
     if self.argDB['download-'+self.downloadname.lower()]:
       return self.getInstallDir()
     return ''
@@ -63,6 +64,16 @@ class Configure(config.package.GNUPackage):
       mpich_device = 'ch3:sock'
     else:
       mpich_device = 'ch3:nemesis'
+    if self.cuda.found:
+      args.append('--with-cuda='+self.cuda.cudaDir)
+      if not (self.cuda.cudaArch == 'all' or self.cuda.cudaArchIsVersionList()):
+        raise RuntimeError('MPICH not known to support cuda arch string '+self.cuda.cudaArch)
+      args.append('--with-cuda-sm='+self.cuda.cudaArch)
+      mpich_device = 'ch4:ucx'
+    elif self.hip.found:
+      args.append('--with-hip='+self.hip.hipDir)
+      mpich_device = 'ch4:ofi' # per https://github.com/pmodels/mpich/wiki/Using-MPICH-on-Crusher@OLCF
+
     if 'download-mpich-device' in self.argDB:
       mpich_device = self.argDB['download-mpich-device']
     args.append('--with-device='+mpich_device)
@@ -76,6 +87,9 @@ class Configure(config.package.GNUPackage):
     # MPICH configure errors out on certain standard configure arguments
     args = self.rmArgs(args,['--disable-f90','--enable-f90'])
     args = self.rmArgsStartsWith(args,['F90=','F90FLAGS='])
+    args.append('PYTHON='+self.python.pyexe)
+    args.append('--disable-maintainer-mode')
+    args.append('--disable-dependency-tracking')
     return args
 
   def Install(self):
@@ -88,4 +102,3 @@ class Configure(config.package.GNUPackage):
 
   def configure(self):
     return config.package.Package.configure(self)
-
