@@ -3,7 +3,8 @@ import config.package
 class Configure(config.package.Package):
   def __init__(self,framework):
     config.package.Package.__init__(self,framework)
-    self.gitcommit              = 'd28da835cc0865b64d9bf8736dd5b10173722e00' # main sep-20-2022
+    # self.version                = '2.2.3'
+    self.gitcommit              = '62414514692d25e0e6785ae806a34974fd7e7183' # main apr-07-2023
     self.download               = ['git://https://github.com/hpddm/hpddm','https://github.com/hpddm/hpddm/archive/'+self.gitcommit+'.tar.gz']
     self.minversion             = '2.2.1'
     self.versionname            = 'HPDDM_VERSION'
@@ -61,30 +62,29 @@ class Configure(config.package.Package):
       self.log.write(output+err)
     except RuntimeError as e:
       raise RuntimeError('Error copying HPDDM: '+str(e))
-    # SLEPc dependency
-    if self.slepc.found:
-      if self.checkSharedLibrariesEnabled():
-        slepcbuilddep = ''
-        ldflags = ' '.join(self.setCompilers.sharedLibraryFlags)
-        cxxflags += ' '+self.headers.toStringNoDupes(self.dinclude+[os.path.join(PETSC_DIR,'include'),incDir])
-        ldflags += ' '+self.libraries.toStringNoDupes(self.dlib+[os.path.join(libDir,'libpetsc.'+self.setCompilers.sharedLibraryExt)])
-        slepcbuilddep = 'slepc-install slepc-build'
-        oldFlags = self.compilers.CXXPPFLAGS
-        self.compilers.CXXPPFLAGS += ' -I'+incDir
-        self.checkVersion()
-        self.compilers.CXXPPFLAGS = oldFlags
-        # check for Windows-specific define
-        if self.sharedLibraries.getMakeMacro('PETSC_DLL_EXPORTS'):
-          cxxflags += ' -Dpetsc_EXPORTS'
+    if self.checkSharedLibrariesEnabled():
+      ldflags = ' '.join(self.setCompilers.sharedLibraryFlags)
+      cxxflags += ' '+self.headers.toStringNoDupes(self.dinclude+[os.path.join(PETSC_DIR,'include'),incDir])
+      ldflags += ' '+self.libraries.toStringNoDupes(self.dlib+[os.path.join(libDir,'libpetsc.'+self.setCompilers.sharedLibraryExt)])
+      slepcbuilddep = 'slepc-install slepc-build'
+      oldFlags = self.compilers.CXXPPFLAGS
+      self.compilers.CXXPPFLAGS += ' -I'+incDir
+      self.checkVersion()
+      self.compilers.CXXPPFLAGS = oldFlags
+      # check for Windows-specific define
+      if self.sharedLibraries.getMakeMacro('PETSC_DLL_EXPORTS'):
+        cxxflags += ' -Dpetsc_EXPORTS'
+      # SLEPc dependency
+      if self.slepc.found:
         self.addMakeRule('hpddmbuild',slepcbuilddep,\
                            ['@echo "*** Building and installing HPDDM ***"',\
-                            '@${RM} -f ${PETSC_ARCH}/lib/petsc/conf/hpddm.errorflg',\
-                            '@'+cxx+' '+cxxflags+' '+os.path.join(self.packageDir,'interface','hpddm_petsc.cpp')+' '+ldflags+' -o '+os.path.join(libDir,'libhpddm_petsc.'+self.setCompilers.sharedLibraryExt)+' > ${PETSC_ARCH}/lib/petsc/conf/hpddm.log 2>&1 || \\\n\
-                 (echo "**************************ERROR*************************************" && \\\n\
-                 echo "Error building HPDDM. Check ${PETSC_ARCH}/lib/petsc/conf/hpddm.log" && \\\n\
-                 echo "********************************************************************" && \\\n\
-                 touch '+os.path.join('${PETSC_ARCH}','lib','petsc','conf','hpddm.errorflg')+' && \\\n\
-                 exit 1)'])
+                            '@${RM} '+os.path.join(self.petscdir.dir,self.arch,'lib','petsc','conf','hpddm.errorflg'),\
+                            '@'+cxx+' '+cxxflags+' '+os.path.join(self.packageDir,'interface','hpddm_petsc.cpp')+' '+ldflags+' -o '+os.path.join(libDir,'libhpddm_petsc.'+self.setCompilers.sharedLibraryExt)+' > '+os.path.join(self.petscdir.dir,self.arch,'lib','petsc','conf','hpddm.log')+' 2>&1 || \\\n\
+            (echo "**************************ERROR*************************************" && \\\n\
+            echo "Error building HPDDM. Check '+os.path.join(self.petscdir.dir,self.arch,'lib','petsc','conf','hpddm.log')+'" && \\\n\
+            echo "********************************************************************" && \\\n\
+            touch '+os.path.join(self.petscdir.dir,self.arch,'lib','petsc','conf','hpddm.errorflg')+' && \\\n\
+            exit 1)'])
         if self.argDB['prefix'] and not 'package-prefix-hash' in self.argDB:
           self.addMakeRule('hpddm-build','')
           self.addMakeRule('hpddm-install','hpddmbuild')
@@ -94,10 +94,10 @@ class Configure(config.package.Package):
           self.addMakeRule('hpddm-install','')
           return self.installDir
       else:
-        self.logPrintWarning('Skipping PCHPDDM installation, remove --with-shared-libraries=0')
+        self.logPrintWarning('Compiling HPDDM without SLEPc, \
+PCHPDDM won\'t be available, unless reconfiguring with --download-slepc or configuring SLEPc with --download-hpddm')
     else:
-      self.logPrintWarning('Compiling HPDDM without SLEPc, \
-PCHPDDM won\'t be available, unless reconfiguring with --download-slepc')
+      self.logPrintWarning('Skipping PCHPDDM installation, remove --with-shared-libraries=0')
     self.addMakeRule('hpddm-build','')
     self.addMakeRule('hpddm-install','')
     return self.installDir
