@@ -3,13 +3,12 @@ import config.package
 class Configure(config.package.Package):
   def __init__(self,framework):
     config.package.Package.__init__(self,framework)
-    self.gitcommit              = '9381c9202197cb3235fa55fcd3f72c173c428188' # main oct-19-2021
+    self.gitcommit              = 'feb9643673371553d8d20b7c5a1a117f5946b47d' # main apr-14-2023
     self.download               = ['git://https://github.com/htool-ddm/htool','https://github.com/htool-ddm/htool/archive/'+self.gitcommit+'.tar.gz']
-    self.minversion             = '0.7.0'
+    self.minversion             = '0.8.0'
     self.versionname            = 'HTOOL_VERSION'
     self.versioninclude         = 'htool/misc/define.hpp'
-    self.minCxxVersion          = 'c++11'
-    self.cxx                    = 1
+    self.buildLanguages         = ['Cxx']
     self.functions              = []
     self.includes               = ['htool/misc/define.hpp'] # no C++11 in this header
     self.skippackagewithoptions = 1
