@@ -4,7 +4,8 @@ class Configure(config.package.Package):
   def __init__(self, framework):
     config.package.Package.__init__(self, framework)
     self.version                = '4.0.0'
-    self.gitcommit              = 'v'+self.version
+    #self.gitcommit              = 'v'+self.version
+    self.gitcommit              = '8af76dc862c74cbe880569ff2ccf6e5e54245430' # mar-27,2023 master
     self.download               = ['git://https://github.com/ecrc/kblas-gpu.git']
     self.buildLanguages         = ['CUDA'] # uses nvcc to compile everything
     self.functionsCxx           = [1,'struct KBlasHandle; typedef struct KBlasHandle *kblasHandle_t;extern "C" int kblasCreate(kblasHandle_t*);','kblasHandle_t h; kblasCreate(&h)']
@@ -67,9 +68,15 @@ class Configure(config.package.Package):
       g.write('_MAGMA_ROOT_ = '+self.magma.directory+'\n')
       g.write('_CUDA_ROOT_ = '+cudaDir+'\n')
       if self.cuda.cudaArch:
-        gencodestr = '-DTARGET_SM='+self.cuda.cudaArch+' -arch sm_'+self.cuda.cudaArch
+        # TARGET_SM is just used to check min version compatibility, so we pass
+        # it the smallest version (or 35 if "all" etc are specified)
+        if self.cuda.cudaArchIsVersionList():
+          gencodestr = '-DTARGET_SM='+str(min(int(v) for v in self.cuda.cudaArchList()))
+        else:
+          gencodestr = '-DTARGET_SM=35'
+        gencodestr += self.cuda.nvccArchFlags()
       else:
-        # kblas as of v4.0.0 uses __ldg intrinsincs, available starting from 35
+        # kblas as of v4.0.0 uses __ldg intrinsics, available starting from 35
         gencodestr = '-DTARGET_SM=35 -arch sm_35'
       g.write('NVCC = '+nvcc+'\n')
       g.write('CC = '+cxx+'\n')
