@@ -9,7 +9,7 @@ class Configure(config.package.Package):
   def __init__(self, framework):
     config.package.Package.__init__(self, framework)
     # disable version check
-    self.version          = '2.6.1'
+    self.version          = '2.7.1'
     #self.minversion       = '2.6.0'
     #self.versionname      = ???
     self.gitcommit        = 'v'+self.version
@@ -20,8 +20,6 @@ class Configure(config.package.Package):
                              ['libmagma_sparse.a','libmagma.a','libpthread.a'],
                              ['libmagma.a'],
                              ['libmagma.a','libpthread.a']]
-    self.hastests         = 0
-    self.hastestsdatafiles= 0
     self.requirec99flag   = 1 #From CMakeLists.txt -> some code may not compile
     self.precisions       = ['single','double']
     self.buildLanguages   = ['Cxx']
@@ -142,7 +140,7 @@ class Configure(config.package.Package):
       if self.argDB['with-magma-gputarget']:
         gputarget = self.argDB['with-magma-gputarget']
       elif self.cuda.found and hasattr(self.cuda,'cudaArch') and self.cuda.cudaArch:
-        gputarget = 'sm_'+self.cuda.cudaArch
+        gputarget = ' '.join('sm_'+a for a in self.cuda.cudaArchList())
       elif self.hip.found and hasattr(self.hip,'hipArch') and self.hip.hipArch:
         gputarget = self.hip.hipArch
       g.write('CC = '+cc+'\n')
