@@ -11,8 +11,8 @@ import config.package
 class Configure(config.package.Package):
   def __init__(self, framework):
     config.package.Package.__init__(self, framework)
-    self.version                = '0.3.10'
-    self.gitcommit              = '63b03efc2af332c88b86d4fd8079d00f4b439adf'
+    self.version                = '0.3.21'
+    self.gitcommit              = 'v'+self.version
     self.versionname            = 'OPENBLAS_VERSION'
     self.download               = ['git://https://github.com/xianyi/OpenBLAS.git','https://github.com/xianyi/OpenBLAS/archive/'+self.gitcommit+'.tar.gz']
     self.optionalincludes       = ['openblas_config.h']
@@ -20,7 +20,6 @@ class Configure(config.package.Package):
     self.liblist                = [['libopenblas.a']]
     self.precisions             = ['single','double']
     self.buildLanguages         = ['C','FC']
-    self.installwithbatch       = 1
     self.usespthreads           = 0
 
   def __str__(self):
@@ -65,7 +64,7 @@ class Configure(config.package.Package):
   def versionToStandardForm(self,ver):
     '''Converts from " OpenBLAS 0.3.6<.dev> " to standard 0.3.6 format'''
     import re
-    ver = re.match("\s*OpenBLAS\s*([0-9\.]+)\s*",ver).group(1)
+    ver = re.match(r"\s*OpenBLAS\s*([0-9\.]+)\s*",ver).group(1)
     if ver.endswith('.'): ver = ver[0:-1]
     return ver
 
