@@ -3,6 +3,7 @@
 
 #include <petscmat.h>    /*I      "petscmat.h"          I*/
 #include <petscdmplex.h> /*I      "petscdmplex.h"    I*/
+#include <petscdmplextransform.h>
 #include <petscbt.h>
 #include <petscsf.h>
 #include <petsc/private/dmimpl.h>
@@ -46,12 +47,14 @@ PETSC_EXTERN PetscLogEvent DMPLEX_BuildFromCellList;
 PETSC_EXTERN PetscLogEvent DMPLEX_BuildCoordinatesFromCellList;
 PETSC_EXTERN PetscLogEvent DMPLEX_LocatePoints;
 PETSC_EXTERN PetscLogEvent DMPLEX_TopologyView;
+PETSC_EXTERN PetscLogEvent DMPLEX_DistributionView;
 PETSC_EXTERN PetscLogEvent DMPLEX_LabelsView;
 PETSC_EXTERN PetscLogEvent DMPLEX_CoordinatesView;
 PETSC_EXTERN PetscLogEvent DMPLEX_SectionView;
 PETSC_EXTERN PetscLogEvent DMPLEX_GlobalVectorView;
 PETSC_EXTERN PetscLogEvent DMPLEX_LocalVectorView;
 PETSC_EXTERN PetscLogEvent DMPLEX_TopologyLoad;
+PETSC_EXTERN PetscLogEvent DMPLEX_DistributionLoad;
 PETSC_EXTERN PetscLogEvent DMPLEX_LabelsLoad;
 PETSC_EXTERN PetscLogEvent DMPLEX_CoordinatesLoad;
 PETSC_EXTERN PetscLogEvent DMPLEX_SectionLoad;
@@ -61,6 +64,7 @@ PETSC_EXTERN PetscLogEvent DMPLEX_MetricEnforceSPD;
 PETSC_EXTERN PetscLogEvent DMPLEX_MetricNormalize;
 PETSC_EXTERN PetscLogEvent DMPLEX_MetricAverage;
 PETSC_EXTERN PetscLogEvent DMPLEX_MetricIntersection;
+PETSC_EXTERN PetscLogEvent DMPLEX_Generate;
 
 PETSC_EXTERN PetscLogEvent DMPLEX_RebalBuildGraph;
 PETSC_EXTERN PetscLogEvent DMPLEX_RebalRewriteSF;
@@ -126,15 +130,16 @@ typedef struct {
 
   PetscSection coneSection;      /* Layout of cones (inedges for DAG) */
   PetscInt    *cones;            /* Cone for each point */
-  PetscInt    *coneOrientations; /* Orientation of each cone point, means cone traveral should start on point 'o', and if negative start on -(o+1) and go in reverse */
+  PetscInt    *coneOrientations; /* Orientation of each cone point, means cone traversal should start on point 'o', and if negative start on -(o+1) and go in reverse */
   PetscSection supportSection;   /* Layout of cones (inedges for DAG) */
   PetscInt    *supports;         /* Cone for each point */
   PetscInt    *facesTmp;         /* Work space for faces operation */
 
   /* Transformation */
-  PetscBool refinementUniform;                                      /* Flag for uniform cell refinement */
-  char     *transformType;                                          /* Type of transform for uniform cell refinement */
-  PetscReal refinementLimit;                                        /* Maximum volume for refined cell */
+  DMPlexTransform tr;                                               /* Type of transform used to define an ephemeral mesh */
+  char           *transformType;                                    /* Type of transform for uniform cell refinement */
+  PetscBool       refinementUniform;                                /* Flag for uniform cell refinement */
+  PetscReal       refinementLimit;                                  /* Maximum volume for refined cell */
   PetscErrorCode (*refinementFunc)(const PetscReal[], PetscReal *); /* Function giving the maximum volume for refined cell */
 
   /* Interpolation */
@@ -198,6 +203,16 @@ typedef struct {
   PetscErrorCode (*useradjacency)(DM, PetscInt, PetscInt *, PetscInt[], void *); /* User callback for adjacency */
   void *useradjacencyctx;                                                        /* User context for callback */
 
+  // Periodicity
+  struct {
+    // Specified by the user
+    PetscScalar transform[4][4]; // geometric transform
+    PetscSF     face_sf;         // root(donor faces) <-- leaf(local faces)
+    // Created eagerly (depends on points)
+    PetscSF composed_sf; // root(non-periodic global points) <-- leaf(local points)
+    IS      periodic_points;
+  } periodic;
+
   /* Projection */
   PetscInt maxProjectionHeight; /* maximum height of cells used in DMPlexProject functions */
   PetscInt activePoint;         /* current active point in iteration */
@@ -335,6 +350,9 @@ PETSC_EXTERN PetscErrorCode DMPlexOrientInterface_Internal(DM);
 /* Applications may use this function */
 PETSC_EXTERN PetscErrorCode DMPlexCreateNumbering_Plex(DM, PetscInt, PetscInt, PetscInt, PetscInt *, PetscSF, IS *);
 
+PETSC_INTERN PetscErrorCode DMPlexInterpolateInPlace_Internal(DM);
+PETSC_INTERN PetscErrorCode DMPlexCreateBoxMesh_Tensor_SFC_Internal(DM, PetscInt, const PetscInt[], const PetscReal[], const PetscReal[], const DMBoundaryType[], PetscBool);
+PETSC_INTERN PetscErrorCode DMPlexMigrateIsoperiodicFaceSF_Internal(DM, DM, PetscSF);
 PETSC_INTERN PetscErrorCode DMPlexCreateCellNumbering_Internal(DM, PetscBool, IS *);
 PETSC_INTERN PetscErrorCode DMPlexCreateVertexNumbering_Internal(DM, PetscBool, IS *);
 PETSC_INTERN PetscErrorCode DMPlexRefine_Internal(DM, Vec, DMLabel, DMLabel, DM *);
@@ -466,9 +484,9 @@ static inline void DMPlex_MultTranspose2D_Internal(const PetscScalar A[], PetscI
 static inline void DMPlex_MultTranspose3D_Internal(const PetscScalar A[], PetscInt ldx, const PetscScalar x[], PetscScalar y[])
 {
   const PetscScalar z[3] = {x[0 * ldx], x[1 * ldx], x[2 * ldx]};
-  y[0 * ldx]             = A[0] * z[0] + A[3] * z[1] + A[6] * z[2];
-  y[1 * ldx]             = A[1] * z[0] + A[4] * z[1] + A[7] * z[2];
-  y[2 * ldx]             = A[2] * z[0] + A[5] * z[1] + A[8] * z[2];
+  y[0 * ldx]             = PetscConj(A[0]) * z[0] + PetscConj(A[3]) * z[1] + PetscConj(A[6]) * z[2];
+  y[1 * ldx]             = PetscConj(A[1]) * z[0] + PetscConj(A[4]) * z[1] + PetscConj(A[7]) * z[2];
+  y[2 * ldx]             = PetscConj(A[2]) * z[0] + PetscConj(A[5]) * z[1] + PetscConj(A[8]) * z[2];
   (void)PetscLogFlops(15.0);
 }
 static inline void DMPlex_Mult2DReal_Internal(const PetscReal A[], PetscInt ldx, const PetscScalar x[], PetscScalar y[])
@@ -767,6 +785,7 @@ PETSC_INTERN PetscErrorCode DMPlexGetPointDualSpaceFEM(DM, PetscInt, PetscInt, P
 PETSC_INTERN PetscErrorCode DMPlexGetIndicesPoint_Internal(PetscSection, PetscBool, PetscInt, PetscInt, PetscInt *, PetscBool, const PetscInt[], const PetscInt[], PetscInt[]);
 PETSC_INTERN PetscErrorCode DMPlexGetIndicesPointFields_Internal(PetscSection, PetscBool, PetscInt, PetscInt, PetscInt[], PetscBool, const PetscInt ***, PetscInt, const PetscInt[], PetscInt[]);
 PETSC_INTERN PetscErrorCode DMPlexGetTransitiveClosure_Internal(DM, PetscInt, PetscInt, PetscBool, PetscInt *, PetscInt *[]);
+PETSC_INTERN PetscErrorCode DMPlexVecGetOrientedClosure_Internal(DM, PetscSection, Vec, PetscInt, PetscInt, PetscInt *, PetscScalar *[]);
 
 PETSC_EXTERN PetscErrorCode DMPlexGetAllCells_Internal(DM, IS *);
 PETSC_EXTERN PetscErrorCode DMSNESGetFEGeom(DMField, IS, PetscQuadrature, PetscBool, PetscFEGeom **);
@@ -780,6 +799,8 @@ PETSC_INTERN PetscErrorCode DMPlexBasisTransformApplyReal_Internal(DM, const Pet
 PETSC_INTERN PetscErrorCode DMPlexBasisTransformApply_Internal(DM, const PetscReal[], PetscBool, PetscInt, const PetscScalar *, PetscScalar *, void *);
 PETSC_INTERN PetscErrorCode DMCreateNeumannOverlap_Plex(DM, IS *, Mat *, PetscErrorCode (**)(Mat, PetscReal, Vec, Vec, PetscReal, IS, void *), void **);
 
+PETSC_INTERN PetscErrorCode DMPeriodicCoordinateSetUp_Internal(DM);
+
 /* Functions in the vtable */
 PETSC_INTERN PetscErrorCode DMCreateInterpolation_Plex(DM dmCoarse, DM dmFine, Mat *interpolation, Vec *scaling);
 PETSC_INTERN PetscErrorCode DMCreateInjection_Plex(DM dmCoarse, DM dmFine, Mat *mat);
