@@ -9,24 +9,24 @@
 /* SUBMANSEC = Sys */
 
 #if defined(PETSC_CLANG_STATIC_ANALYZER)
-  #define PetscDisableStaticAnalyzerForExpressionUnderstandingThatThisIsDangerousAndBugprone(expr)
+  #define PetscDisableStaticAnalyzerForExpressionUnderstandingThatThisIsDangerousAndBugprone(...)
 #else
-  #define PetscDisableStaticAnalyzerForExpressionUnderstandingThatThisIsDangerousAndBugprone(expr) expr
+  #define PetscDisableStaticAnalyzerForExpressionUnderstandingThatThisIsDangerousAndBugprone(...) __VA_ARGS__
 #endif
 
-#if PetscDefined(USE_DEBUG)
+#if PetscDefined(USE_DEBUG) && !PetscDefined(HAVE_THREADSAFETY)
 PETSC_INTERN PetscErrorCode PetscStackSetCheck(PetscBool);
 PETSC_INTERN PetscErrorCode PetscStackView(FILE *);
 PETSC_INTERN PetscErrorCode PetscStackReset(void);
 PETSC_INTERN PetscErrorCode PetscStackCopy(PetscStack *, PetscStack *);
 PETSC_INTERN PetscErrorCode PetscStackPrint(PetscStack *, FILE *);
 #else
-  #define PetscStackSetCheck(check)         0
-  #define PetscStackView(file)              0
-  #define PetscStackReset()                 0
-  #define PetscStackCopy(stackin, stackout) 0
-  #define PetscStackPrint(stack, file)      0
-#endif /* PetscDefined(USE_DEBUG) */
+  #define PetscStackSetCheck(check)         PETSC_SUCCESS
+  #define PetscStackView(file)              PETSC_SUCCESS
+  #define PetscStackReset()                 PETSC_SUCCESS
+  #define PetscStackCopy(stackin, stackout) PETSC_SUCCESS
+  #define PetscStackPrint(stack, file)      PETSC_SUCCESS
+#endif
 
 /* These are used internally by PETSc ASCII IO routines*/
 #include <stdarg.h>
@@ -148,8 +148,11 @@ typedef struct _p_PetscObject {
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode (*PetscObjectDestroyFunction)(PetscObject *); /* force cast in next macro to NEVER use extern "C" style */
 PETSC_EXTERN_TYPEDEF typedef PetscErrorCode (*PetscObjectViewFunction)(PetscObject, PetscViewer);
 
+#define PetscHeaderInitialize_Private(h, classid, class_name, descr, mansec, comm, destroy, view) \
+  ((PetscErrorCode)(PetscHeaderCreate_Private((PetscObject)(h), classid, class_name, descr, mansec, comm, (PetscObjectDestroyFunction)(destroy), (PetscObjectViewFunction)(view)) || PetscLogObjectCreate(h)))
+
 /*MC
-  PetscHeaderCreate - Creates a PETSc object of a particular class
+    PetscHeaderCreate - Creates a PETSc object of a particular class
 
   Synopsis:
   #include <petsc/private/petscimpl.h>
@@ -277,8 +280,7 @@ PETSC_EXTERN_TYPEDEF typedef PetscErrorCode (*PetscObjectViewFunction)(PetscObje
 
 .seealso: `PetscHeaderDestroy()`, `PetscClassIdRegister()`
 M*/
-#define PetscHeaderCreate(h, classid, class_name, descr, mansec, comm, destroy, view) \
-  (PetscNew(&(h)) || PetscHeaderCreate_Private((PetscObject)(h), classid, class_name, descr, mansec, comm, (PetscObjectDestroyFunction)(destroy), (PetscObjectViewFunction)(view)) || PetscLogObjectCreate(h))
+#define PetscHeaderCreate(h, classid, class_name, descr, mansec, comm, destroy, view) ((PetscErrorCode)(PetscNew(&(h)) || PetscHeaderInitialize_Private((h), (classid), (class_name), (descr), (mansec), (comm), (destroy), (view))))
 
 PETSC_EXTERN PetscErrorCode PetscComposedQuantitiesDestroy(PetscObject obj);
 PETSC_EXTERN PetscErrorCode PetscHeaderCreate_Private(PetscObject, PetscClassId, const char[], const char[], const char[], MPI_Comm, PetscObjectDestroyFunction, PetscObjectViewFunction);
@@ -291,7 +293,7 @@ PETSC_INTERN PetscObjectId  PetscObjectNewId_Internal(void);
   #include <petsc/private/petscimpl.h>
   PetscErrorCode PetscHeaderDestroy(PetscObject *obj)
 
-  Input Parameters:
+  Input Parameter:
 . h - A pointer to the header created with `PetscHeaderCreate()`
 
   Notes:
@@ -338,7 +340,7 @@ PETSC_INTERN PetscObjectId  PetscObjectNewId_Internal(void);
 
 .seealso: `PetscHeaderCreate()`
 M*/
-#define PetscHeaderDestroy(h) (PetscHeaderDestroy_Private((PetscObject)(*(h)), PETSC_FALSE) || PetscFree(*(h)))
+#define PetscHeaderDestroy(h) ((PetscErrorCode)(PetscHeaderDestroy_Private((PetscObject)(*(h)), PETSC_FALSE) || PetscFree(*(h))))
 
 PETSC_EXTERN PetscErrorCode                PetscHeaderDestroy_Private(PetscObject, PetscBool);
 PETSC_SINGLE_LIBRARY_INTERN PetscErrorCode PetscHeaderReset_Internal(PetscObject);
@@ -745,13 +747,11 @@ void PetscCheckSorted(PetscInt, T);
 +   obj - the object
 .   name - the name of the method, for example, "KSPGMRESSetRestart_C" for the function `KSPGMRESSetRestart()`
 .   arg_types - the argument types for the method, for example, (KSP,PetscInt)
--   args - the arguements for the method, for example, (ksp,restart))
+-   args - the arguments for the method, for example, (ksp,restart))
 
    Level: developer
 
    Notes:
-   The object is always the implicit first argument of the method and is not listed in arg_types or args
-
    This does not return an error code, it is a macro that returns with an error code on error.
 
    Use `PetscUseTypeMethod()` or `PetscTryTypeMethod()` to call functions that are included in the objects function table, the `ops` array
@@ -777,13 +777,11 @@ M*/
 +   obj - the object
 .   name - the name of the method, for example, "KSPGMRESSetRestart_C" for the function `KSPGMRESSetRestart()`
 .   arg_types - the argument types for the method, for example, (KSP,PetscInt)
--   args - the arguements for the method, for example, (ksp,restart))
+-   args - the arguments for the method, for example, (ksp,restart))
 
    Level: developer
 
    Notes:
-   The object is always the implicit first argument of the method and is not listed in arg_types or args
-
    This does not return an error code, it is a macro that returns with an error code on error.
 
    Use `PetscUseTypeMethod()` or `PetscTryTypeMethod()` to call functions that are included in the objects function table, the `ops` array
@@ -904,6 +902,8 @@ M*/
          cast with a (PetscObject), for example,
          `PetscObjectStateIncrease`((`PetscObject`)mat);
 
+   Level: developer
+
    Notes:
    Object state is a 64 bit integer which gets increased every time
    the object is changed internally. By saving and later querying the object state
@@ -919,14 +919,11 @@ M*/
 
    This routine is logically collective because state equality comparison needs to be possible without communication.
 
-   `Mat` also has `MatGetNonzeroState()` and `MatSetNonzeroState()` for tracking changes to the nonzero structure.
-
-   Level: developer
-
-.seealso: `PetscObjectStateGet()`, `MatSetNonzeroState()`, `PetscObject`
+   `Mat` also has `MatGetNonzeroState()` for tracking changes to the nonzero structure.
 
+.seealso: `PetscObjectStateGet()`, `PetscObject`
 M*/
-#define PetscObjectStateIncrease(obj) ((obj)->state++, 0)
+#define PetscObjectStateIncrease(obj) ((obj)->state++, PETSC_SUCCESS)
 
 PETSC_EXTERN PetscErrorCode PetscObjectStateGet(PetscObject, PetscObjectState *);
 PETSC_EXTERN PetscErrorCode PetscObjectStateSet(PetscObject, PetscObjectState);
@@ -946,26 +943,27 @@ PETSC_EXTERN PetscInt       PetscObjectComposedDataMax;
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataSetInt(PetscObject obj,int id,int data)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object to which data is to be attached
 .  id - the identifier for the data
 -  data - the data to  be attached
 
+   Level: developer
+
    Notes:
-   The data identifier can be created through a call to  `PetscObjectComposedDataRegister()`
+   The `data` identifier can be created through a call to  `PetscObjectComposedDataRegister()`
 
    This allows the efficient composition of a single integer value with a `PetscObject`. Complex data may be
    attached with `PetscObjectCompose()`
 
-   Level: developer
-
 .seealso: `PetscObjectComposedDataGetInt()`, `PetscObjectComposedDataGetReal()`, `PetscObjectComposedDataSetReal()`,
           `PetscObjectComposedDataGetIntstar()`, `PetscObjectComposedDataSetIntstar()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`
 M*/
-#define PetscObjectComposedDataSetInt(obj, id, data) ((((obj)->int_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseInt(obj)) || ((obj)->intcomposeddata[id] = data, (obj)->intcomposedstate[id] = (obj)->state, 0))
+#define PetscObjectComposedDataSetInt(obj, id, data) \
+  ((PetscErrorCode)((((obj)->int_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseInt(obj)) || ((obj)->intcomposeddata[id] = data, (obj)->intcomposedstate[id] = (obj)->state, PETSC_SUCCESS)))
 
 /*MC
    PetscObjectComposedDataGetInt - retrieve integer data attached to an object with `PetscObjectComposedDataSetInt()`
@@ -974,7 +972,7 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataGetInt(PetscObject obj,int id,int data,PetscBool  flag)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object from which data is to be retrieved
@@ -987,7 +985,7 @@ M*/
    Level: developer
 
    Notes:
-   The 'data' and 'flag' variables are inlined, so they are not pointers.
+   The `data` and `flag` variables are inlined, so they are not pointers.
 
    The length of the array accessed must be known.
 
@@ -995,7 +993,7 @@ M*/
           `PetscObjectComposedDataGetIntstar()`, `PetscObjectComposedDataSetIntstar()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`
 M*/
-#define PetscObjectComposedDataGetInt(obj, id, data, flag) (((obj)->intcomposedstate ? (data = (obj)->intcomposeddata[id], flag = (PetscBool)((obj)->intcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), 0)
+#define PetscObjectComposedDataGetInt(obj, id, data, flag) (((obj)->intcomposedstate ? (data = (obj)->intcomposeddata[id], flag = (PetscBool)((obj)->intcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), PETSC_SUCCESS)
 
 /*MC
    PetscObjectComposedDataSetIntstar - attach an integer array data to a `PetscObject` that may be accessed with `PetscObjectComposedDataGetIntstar()`
@@ -1004,26 +1002,26 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataSetIntstar(PetscObject obj,int id,int *data)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object to which data is to be attached
 .  id - the identifier for the data
 -  data - the data to  be attached
 
+   Level: developer
+
    Notes:
-   The data identifier can be determined through a call to `PetscObjectComposedDataRegister()`
+   The `data` identifier can be determined through a call to `PetscObjectComposedDataRegister()`
 
    The length of the array accessed must be known, it is not available through this API.
 
-   Level: developer
-
 .seealso: `PetscObjectComposedDataSetInt()`, `PetscObjectComposedDataGetReal()`, `PetscObjectComposedDataSetReal()`,
           `PetscObjectComposedDataGetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`
 M*/
 #define PetscObjectComposedDataSetIntstar(obj, id, data) \
-  ((((obj)->intstar_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseIntstar(obj)) || ((obj)->intstarcomposeddata[id] = data, (obj)->intstarcomposedstate[id] = (obj)->state, 0))
+  ((PetscErrorCode)((((obj)->intstar_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseIntstar(obj)) || ((obj)->intstarcomposeddata[id] = data, (obj)->intstarcomposedstate[id] = (obj)->state, PETSC_SUCCESS)))
 
 /*MC
    PetscObjectComposedDataGetIntstar - retrieve integer array data attached to an object with `PetscObjectComposedDataSetIntstar()`
@@ -1032,7 +1030,7 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataGetIntstar(PetscObject obj,int id,int *data,PetscBool  flag)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object from which data is to be retrieved
@@ -1042,18 +1040,19 @@ M*/
 +  data - the data to be retrieved
 -  flag - `PETSC_TRUE` if the data item exists and is valid, `PETSC_FALSE` otherwise
 
+   Level: developer
+
    Notes:
-   The 'data' and 'flag' variables are inlined, so they are not pointers.
+   The `data` and `flag` variables are inlined, so they are not pointers.
 
    The length of the array accessed must be known, it is not available through this API.
 
-   Level: developer
-
 .seealso: `PetscObjectComposedDataSetInt()`, `PetscObjectComposedDataGetReal()`, `PetscObjectComposedDataSetReal()`,
           `PetscObjectComposedDataSetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`
 M*/
-#define PetscObjectComposedDataGetIntstar(obj, id, data, flag) (((obj)->intstarcomposedstate ? (data = (obj)->intstarcomposeddata[id], flag = (PetscBool)((obj)->intstarcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), 0)
+#define PetscObjectComposedDataGetIntstar(obj, id, data, flag) \
+  ((PetscErrorCode)(((obj)->intstarcomposedstate ? (data = (obj)->intstarcomposeddata[id], flag = (PetscBool)((obj)->intstarcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), PETSC_SUCCESS))
 
 /*MC
    PetscObjectComposedDataSetReal - attach real data to a `PetscObject` that may be accessed with `PetscObjectComposedDataGetReal()`
@@ -1062,23 +1061,24 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataSetReal(PetscObject obj,int id,PetscReal data)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object to which data is to be attached
 .  id - the identifier for the data
 -  data - the data to  be attached
 
-   Note:
-   The data identifier can be determined through a call to  `PetscObjectComposedDataRegister()`
-
    Level: developer
 
+   Note:
+   The `data` identifier can be determined through a call to  `PetscObjectComposedDataRegister()`
+
 .seealso: `PetscObjectComposedDataSetInt()`, `PetscObjectComposedDataGetReal()`, `PetscObjectComposedDataSetIntstar()`,
           `PetscObjectComposedDataSetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`
 M*/
-#define PetscObjectComposedDataSetReal(obj, id, data) ((((obj)->real_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseReal(obj)) || ((obj)->realcomposeddata[id] = data, (obj)->realcomposedstate[id] = (obj)->state, 0))
+#define PetscObjectComposedDataSetReal(obj, id, data) \
+  ((PetscErrorCode)((((obj)->real_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseReal(obj)) || ((obj)->realcomposeddata[id] = data, (obj)->realcomposedstate[id] = (obj)->state, PETSC_SUCCESS)))
 
 /*MC
    PetscObjectComposedDataGetReal - retrieve real data attached to an object set with `PetscObjectComposedDataSetReal()`
@@ -1087,7 +1087,7 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataGetReal(PetscObject obj,int id,PetscReal data,PetscBool  flag)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object from which data is to be retrieved
@@ -1097,16 +1097,16 @@ M*/
 +  data - the data to be retrieved
 -  flag - `PETSC_TRUE` if the data item exists and is valid, `PETSC_FALSE` otherwise
 
-   Note:
-   The 'data' and 'flag' variables are inlined, so they are not pointers.
-
    Level: developer
 
+   Note:
+   The `data` and `flag` variables are inlined, so they are not pointers.
+
 .seealso: `PetscObjectComposedDataSetInt()`, `PetscObjectComposedDataSetReal()`, `PetscObjectComposedDataSetIntstar()`,
           `PetscObjectComposedDataSetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`
 M*/
-#define PetscObjectComposedDataGetReal(obj, id, data, flag) (((obj)->realcomposedstate ? (data = (obj)->realcomposeddata[id], flag = (PetscBool)((obj)->realcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), 0)
+#define PetscObjectComposedDataGetReal(obj, id, data, flag) ((PetscErrorCode)(((obj)->realcomposedstate ? (data = (obj)->realcomposeddata[id], flag = (PetscBool)((obj)->realcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), PETSC_SUCCESS))
 
 /*MC
    PetscObjectComposedDataSetRealstar - attach real array data to a `PetscObject` that may be retrieved with `PetscObjectComposedDataGetRealstar()`
@@ -1115,26 +1115,26 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataSetRealstar(PetscObject obj,int id,PetscReal *data)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object to which data is to be attached
 .  id - the identifier for the data
 -  data - the data to  be attached
 
+   Level: developer
+
    Notes:
-   The data identifier can be determined through a call to `PetscObjectComposedDataRegister()`
+   The `data` identifier can be determined through a call to `PetscObjectComposedDataRegister()`
 
    The length of the array accessed must be known, it is not available through this API.
 
-   Level: developer
-
 .seealso: `PetscObjectComposedDataSetInt()`, `PetscObjectComposedDataSetReal()`, `PetscObjectComposedDataGetReal()`, `PetscObjectComposedDataSetIntstar()`,
           `PetscObjectComposedDataSetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`, `PetscObjectComposedDataGetRealstar()`
 M*/
 #define PetscObjectComposedDataSetRealstar(obj, id, data) \
-  ((((obj)->realstar_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseRealstar(obj)) || ((obj)->realstarcomposeddata[id] = data, (obj)->realstarcomposedstate[id] = (obj)->state, 0))
+  ((PetscErrorCode)((((obj)->realstar_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseRealstar(obj)) || ((obj)->realstarcomposeddata[id] = data, (obj)->realstarcomposedstate[id] = (obj)->state, PETSC_SUCCESS)))
 
 /*MC
    PetscObjectComposedDataGetRealstar - retrieve real array data attached to an object with `PetscObjectComposedDataSetRealstar()`
@@ -1143,7 +1143,7 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataGetRealstar(PetscObject obj,int id,PetscReal *data,PetscBool  flag)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object from which data is to be retrieved
@@ -1154,17 +1154,18 @@ M*/
 -  flag - `PETSC_TRUE` if the data item exists and is valid, `PETSC_FALSE` otherwise
 
    Notes:
-   The 'data' and 'flag' variables are inlined, so they are not pointers.
+   Level: developer
+
+   The `data` and `flag` variables are inlined, so they are not pointers.
 
    The length of the array accessed must be known, it is not available through this API.
 
-   Level: developer
-
 .seealso: `PetscObjectComposedDataSetInt()`, `PetscObjectComposedDataSetReal()`, `PetscObjectComposedDataGetReal()`, `PetscObjectComposedDataSetIntstar()`,
           `PetscObjectComposedDataSetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`, `PetscObjectComposedDataSetRealstar()`
 M*/
-#define PetscObjectComposedDataGetRealstar(obj, id, data, flag) (((obj)->realstarcomposedstate ? (data = (obj)->realstarcomposeddata[id], flag = (PetscBool)((obj)->realstarcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), 0)
+#define PetscObjectComposedDataGetRealstar(obj, id, data, flag) \
+  ((PetscErrorCode)(((obj)->realstarcomposedstate ? (data = (obj)->realstarcomposeddata[id], flag = (PetscBool)((obj)->realstarcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), PETSC_SUCCESS))
 
 /*MC
    PetscObjectComposedDataSetScalar - attach scalar data to a PetscObject that may be retrieved with `PetscObjectComposedDataGetScalar()`
@@ -1173,24 +1174,25 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataSetScalar(PetscObject obj,int id,PetscScalar data)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object to which data is to be attached
 .  id - the identifier for the data
 -  data - the data to  be attached
 
-   Note:
-   The data identifier can be determined through a call to `PetscObjectComposedDataRegister()`
-
    Level: developer
 
+   Note:
+   The `data` identifier can be determined through a call to `PetscObjectComposedDataRegister()`
+
 .seealso: `PetscObjectComposedDataSetInt()`, `PetscObjectComposedDataSetReal()`, `PetscObjectComposedDataGetReal()`, `PetscObjectComposedDataSetIntstar()`,
           `PetscObjectComposedDataSetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`, `PetscObjectComposedDataSetRealstar()`, `PetscObjectComposedDataGetScalar()`
 M*/
 #if defined(PETSC_USE_COMPLEX)
-  #define PetscObjectComposedDataSetScalar(obj, id, data) ((((obj)->scalar_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseScalar(obj)) || ((obj)->scalarcomposeddata[id] = data, (obj)->scalarcomposedstate[id] = (obj)->state, 0))
+  #define PetscObjectComposedDataSetScalar(obj, id, data) \
+    ((PetscErrorCode)((((obj)->scalar_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseScalar(obj)) || ((obj)->scalarcomposeddata[id] = data, (obj)->scalarcomposedstate[id] = (obj)->state, PETSC_SUCCESS)))
 #else
   #define PetscObjectComposedDataSetScalar(obj, id, data) PetscObjectComposedDataSetReal(obj, id, data)
 #endif
@@ -1201,7 +1203,7 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataGetScalar(PetscObject obj,int id,PetscScalar data,PetscBool  flag)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object from which data is to be retrieved
@@ -1211,17 +1213,18 @@ M*/
 +  data - the data to be retrieved
 -  flag - `PETSC_TRUE` if the data item exists and is valid, `PETSC_FALSE` otherwise
 
-   Note:
-   The 'data' and 'flag' variables are inlined, so they are not pointers.
-
    Level: developer
 
+   Note:
+   The `data` and `flag` variables are inlined, so they are not pointers.
+
 .seealso: `PetscObjectComposedDataSetInt()`, `PetscObjectComposedDataSetReal()`, `PetscObjectComposedDataGetReal()`, `PetscObjectComposedDataSetIntstar()`,
           `PetscObjectComposedDataSetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`, `PetscObjectComposedDataSetRealstar()`, `PetscObjectComposedDataSetScalar()`
 M*/
 #if defined(PETSC_USE_COMPLEX)
-  #define PetscObjectComposedDataGetScalar(obj, id, data, flag) (((obj)->scalarcomposedstate ? (data = (obj)->scalarcomposeddata[id], flag = (PetscBool)((obj)->scalarcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), 0)
+  #define PetscObjectComposedDataGetScalar(obj, id, data, flag) \
+    ((PetscErrorCode)(((obj)->scalarcomposedstate ? (data = (obj)->scalarcomposeddata[id], flag = (PetscBool)((obj)->scalarcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), PETSC_SUCCESS))
 #else
   #define PetscObjectComposedDataGetScalar(obj, id, data, flag) PetscObjectComposedDataGetReal(obj, id, data, flag)
 #endif
@@ -1233,27 +1236,27 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataSetScalarstar(PetscObject obj,int id,PetscScalar *data)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object to which data is to be attached
 .  id - the identifier for the data
 -  data - the data to  be attached
 
+   Level: developer
+
    Notes:
-   The data identifier can be determined through a call to `PetscObjectComposedDataRegister()`
+   The `data` identifier can be determined through a call to `PetscObjectComposedDataRegister()`
 
    The length of the array accessed must be known, it is not available through this API.
 
-   Level: developer
-
 .seealso: `PetscObjectComposedDataSetInt()`, `PetscObjectComposedDataSetReal()`, `PetscObjectComposedDataGetReal()`, `PetscObjectComposedDataSetIntstar()`,
           `PetscObjectComposedDataSetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`, `PetscObjectComposedDataSetRealstar()`, `PetscObjectComposedDataGetScalarstar()`
 M*/
 #if defined(PETSC_USE_COMPLEX)
   #define PetscObjectComposedDataSetScalarstar(obj, id, data) \
-    ((((obj)->scalarstar_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseScalarstar(obj)) || ((obj)->scalarstarcomposeddata[id] = data, (obj)->scalarstarcomposedstate[id] = (obj)->state, 0))
+    ((PetscErrorCode)((((obj)->scalarstar_idmax < PetscObjectComposedDataMax) && PetscObjectComposedDataIncreaseScalarstar(obj)) || ((obj)->scalarstarcomposeddata[id] = data, (obj)->scalarstarcomposedstate[id] = (obj)->state, PETSC_SUCCESS)))
 #else
   #define PetscObjectComposedDataSetScalarstar(obj, id, data) PetscObjectComposedDataSetRealstar(obj, id, data)
 #endif
@@ -1265,7 +1268,7 @@ M*/
    #include "petsc/private/petscimpl.h"
    PetscErrorCode PetscObjectComposedDataGetScalarstar(PetscObject obj,int id,PetscScalar *data,PetscBool  flag)
 
-   Not collective
+   Not Collective
 
    Input parameters:
 +  obj - the object from which data is to be retrieved
@@ -1275,19 +1278,20 @@ M*/
 +  data - the data to be retrieved
 -  flag - `PETSC_TRUE` if the data item exists and is valid, `PETSC_FALSE` otherwise
 
+   Level: developer
+
    Notes:
-   The 'data' and 'flag' variables are inlined, so they are not pointers.
+   The `data` and `flag` variables are inlined, so they are not pointers.
 
    The length of the array accessed must be known, it is not available through this API.
 
-   Level: developer
-
 .seealso: `PetscObjectComposedDataSetInt()`, `PetscObjectComposedDataSetReal()`, `PetscObjectComposedDataGetReal()`, `PetscObjectComposedDataSetIntstar()`,
           `PetscObjectComposedDataSetIntstar()`, `PetscObjectComposedDataGetInt()`, `PetscObject`,
           `PetscObjectCompose()`, `PetscObjectQuery()`, `PetscObjectComposedDataSetRealstar()`, `PetscObjectComposedDataSetScalarstar()`
 M*/
 #if defined(PETSC_USE_COMPLEX)
-  #define PetscObjectComposedDataGetScalarstar(obj, id, data, flag) (((obj)->scalarstarcomposedstate ? (data = (obj)->scalarstarcomposeddata[id], flag = (PetscBool)((obj)->scalarstarcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), 0)
+  #define PetscObjectComposedDataGetScalarstar(obj, id, data, flag) \
+    ((PetscErrorCode)(((obj)->scalarstarcomposedstate ? (data = (obj)->scalarstarcomposeddata[id], flag = (PetscBool)((obj)->scalarstarcomposedstate[id] == (obj)->state)) : (flag = PETSC_FALSE)), PETSC_SUCCESS))
 #else
   #define PetscObjectComposedDataGetScalarstar(obj, id, data, flag) PetscObjectComposedDataGetRealstar(obj, id, data, flag)
 #endif
@@ -1300,6 +1304,9 @@ PETSC_EXTERN PetscMPIInt Petsc_ShmComm_keyval;
 PETSC_EXTERN PetscMPIInt Petsc_CreationIdx_keyval;
 PETSC_EXTERN PetscMPIInt Petsc_Garbage_HMap_keyval;
 
+PETSC_EXTERN PetscMPIInt Petsc_SharedWD_keyval;
+PETSC_EXTERN PetscMPIInt Petsc_SharedTmp_keyval;
+
 struct PetscCommStash {
   struct PetscCommStash *next;
   MPI_Comm               comm;
@@ -1352,79 +1359,122 @@ PETSC_EXTERN PetscErrorCode PetscSplitReductionGet(MPI_Comm, PetscSplitReduction
 PETSC_EXTERN PetscErrorCode PetscSplitReductionEnd(PetscSplitReduction *);
 PETSC_EXTERN PetscErrorCode PetscSplitReductionExtend(PetscSplitReduction *);
 
-#if !defined(PETSC_SKIP_SPINLOCK)
-  #if defined(PETSC_HAVE_THREADSAFETY)
-    #if defined(PETSC_HAVE_CONCURRENCYKIT)
-      #if defined(__cplusplus)
+#if defined(PETSC_HAVE_THREADSAFETY)
+  #if defined(PETSC_HAVE_CONCURRENCYKIT)
+    #if defined(__cplusplus)
 /*  CK does not have extern "C" protection in their include files */
 extern "C" {
-      #endif
-      #include <ck_spinlock.h>
-      #if defined(__cplusplus)
+    #endif
+    #include <ck_spinlock.h>
+    #if defined(__cplusplus)
 }
-      #endif
-typedef ck_spinlock_t        PetscSpinlock;
+    #endif
+typedef ck_spinlock_t PetscSpinlock;
+
 static inline PetscErrorCode PetscSpinlockCreate(PetscSpinlock *ck_spinlock)
 {
   ck_spinlock_init(ck_spinlock);
-  return 0;
+  return PETSC_SUCCESS;
 }
 static inline PetscErrorCode PetscSpinlockLock(PetscSpinlock *ck_spinlock)
 {
   ck_spinlock_lock(ck_spinlock);
-  return 0;
+  return PETSC_SUCCESS;
 }
 static inline PetscErrorCode PetscSpinlockUnlock(PetscSpinlock *ck_spinlock)
 {
   ck_spinlock_unlock(ck_spinlock);
-  return 0;
+  return PETSC_SUCCESS;
 }
 static inline PetscErrorCode PetscSpinlockDestroy(PetscSpinlock *ck_spinlock)
 {
-  return 0;
+  return PETSC_SUCCESS;
 }
-    #elif defined(PETSC_HAVE_OPENMP)
+  #elif (defined(__cplusplus) && defined(PETSC_HAVE_CXX_ATOMIC)) || (!defined(__cplusplus) && defined(PETSC_HAVE_STDATOMIC_H))
+    #if defined(__cplusplus)
+      #include <atomic>
+      #define petsc_atomic_flag                 std::atomic_flag
+      #define petsc_atomic_flag_test_and_set(p) std::atomic_flag_test_and_set_explicit(p, std::memory_order_relaxed)
+      #define petsc_atomic_flag_clear(p)        std::atomic_flag_clear_explicit(p, std::memory_order_relaxed)
+    #else
+      #include <stdatomic.h>
+      #define petsc_atomic_flag                 atomic_flag
+      #define petsc_atomic_flag_test_and_set(p) atomic_flag_test_and_set_explicit(p, memory_order_relaxed)
+      #define petsc_atomic_flag_clear(p)        atomic_flag_clear_explicit(p, memory_order_relaxed)
+    #endif
+
+typedef petsc_atomic_flag PetscSpinlock;
+
+static inline PetscErrorCode PetscSpinlockCreate(PetscSpinlock *spinlock)
+{
+  petsc_atomic_flag_clear(spinlock);
+  return PETSC_SUCCESS;
+}
+static inline PetscErrorCode PetscSpinlockLock(PetscSpinlock *spinlock)
+{
+  do {
+  } while (petsc_atomic_flag_test_and_set(spinlock));
+  return PETSC_SUCCESS;
+}
+static inline PetscErrorCode PetscSpinlockUnlock(PetscSpinlock *spinlock)
+{
+  petsc_atomic_flag_clear(spinlock);
+  return PETSC_SUCCESS;
+}
+static inline PetscErrorCode PetscSpinlockDestroy(PetscSpinlock *spinlock)
+{
+  return PETSC_SUCCESS;
+}
+    #undef petsc_atomic_flag_test_and_set
+    #undef petsc_atomic_flag_clear
+    #undef petsc_atomic_flag
+
+  #elif defined(PETSC_HAVE_OPENMP)
+
+    #include <omp.h>
+typedef omp_lock_t PetscSpinlock;
 
-      #include <omp.h>
-typedef omp_lock_t           PetscSpinlock;
 static inline PetscErrorCode PetscSpinlockCreate(PetscSpinlock *omp_lock)
 {
   omp_init_lock(omp_lock);
-  return 0;
+  return PETSC_SUCCESS;
 }
 static inline PetscErrorCode PetscSpinlockLock(PetscSpinlock *omp_lock)
 {
   omp_set_lock(omp_lock);
-  return 0;
+  return PETSC_SUCCESS;
 }
 static inline PetscErrorCode PetscSpinlockUnlock(PetscSpinlock *omp_lock)
 {
   omp_unset_lock(omp_lock);
-  return 0;
+  return PETSC_SUCCESS;
 }
 static inline PetscErrorCode PetscSpinlockDestroy(PetscSpinlock *omp_lock)
 {
   omp_destroy_lock(omp_lock);
-  return 0;
+  return PETSC_SUCCESS;
 }
-    #else
-      #error "Thread safety requires either --with-openmp or --download-concurrencykit"
-    #endif
-
   #else
-typedef int PetscSpinlock;
-    #define PetscSpinlockCreate(a)  0
-    #define PetscSpinlockLock(a)    0
-    #define PetscSpinlockUnlock(a)  0
-    #define PetscSpinlockDestroy(a) 0
+    #if defined(__cplusplus)
+      #error "Thread safety requires either --download-concurrencykit, std::atomic, or --with-openmp"
+    #else
+      #error "Thread safety requires either --download-concurrencykit, stdatomic.h, or --with-openmp"
+    #endif
   #endif
 
-  #if defined(PETSC_HAVE_THREADSAFETY)
+#else
+typedef int PetscSpinlock;
+  #define PetscSpinlockCreate(a)  PETSC_SUCCESS
+  #define PetscSpinlockLock(a)    PETSC_SUCCESS
+  #define PetscSpinlockUnlock(a)  PETSC_SUCCESS
+  #define PetscSpinlockDestroy(a) PETSC_SUCCESS
+#endif
+
+#if defined(PETSC_HAVE_THREADSAFETY)
 PETSC_INTERN PetscSpinlock PetscViewerASCIISpinLockOpen;
 PETSC_INTERN PetscSpinlock PetscViewerASCIISpinLockStdout;
 PETSC_INTERN PetscSpinlock PetscViewerASCIISpinLockStderr;
 PETSC_INTERN PetscSpinlock PetscCommSpinLock;
-  #endif
 #endif
 
 PETSC_EXTERN PetscLogEvent PETSC_Barrier;
