@@ -8,13 +8,13 @@
 #include <petscfetypes.h>
 #include <petscdstypes.h>
 #include <petscdmlabel.h>
+#include <petscdt.h>
 
 /* SUBMANSEC = DM */
 
 PETSC_EXTERN PetscErrorCode DMInitializePackage(void);
 
 PETSC_EXTERN PetscClassId DM_CLASSID;
-PETSC_EXTERN PetscClassId DMLABEL_CLASSID;
 
 #define DMLOCATEPOINT_POINT_NOT_FOUND -367
 
@@ -23,7 +23,7 @@ PETSC_EXTERN PetscClassId DMLABEL_CLASSID;
 
    Level: beginner
 
-.seealso: `DMSetType()`, `DM`
+.seealso: [](chapter_dmbase), `DMSetType()`, `DMCreate()`, `DM`
 J*/
 typedef const char *DMType;
 #define DMDA        "da"
@@ -44,6 +44,7 @@ typedef const char *DMType;
 
 PETSC_EXTERN const char *const       DMBoundaryTypes[];
 PETSC_EXTERN const char *const       DMBoundaryConditionTypes[];
+PETSC_EXTERN const char *const       DMBlockingTypes[];
 PETSC_EXTERN PetscFunctionList       DMList;
 PETSC_EXTERN DMGeneratorFunctionList DMGenerateList;
 PETSC_EXTERN PetscErrorCode          DMCreate(MPI_Comm, DM *);
@@ -78,6 +79,8 @@ PETSC_EXTERN PetscErrorCode DMCreateMatrix(DM, Mat *);
 PETSC_EXTERN PetscErrorCode DMSetMatrixPreallocateSkip(DM, PetscBool);
 PETSC_EXTERN PetscErrorCode DMSetMatrixPreallocateOnly(DM, PetscBool);
 PETSC_EXTERN PetscErrorCode DMSetMatrixStructureOnly(DM, PetscBool);
+PETSC_EXTERN PetscErrorCode DMSetBlockingType(DM, DMBlockingType);
+PETSC_EXTERN PetscErrorCode DMGetBlockingType(DM, DMBlockingType *);
 PETSC_EXTERN PetscErrorCode DMCreateInterpolation(DM, DM, Mat *, Vec *);
 PETSC_EXTERN PetscErrorCode DMCreateRestriction(DM, DM, Mat *);
 PETSC_EXTERN PetscErrorCode DMCreateInjection(DM, DM, Mat *);
@@ -298,11 +301,11 @@ PETSC_EXTERN PetscErrorCode DMSetBasicAdjacency(DM, PetscBool, PetscBool);
 
 PETSC_EXTERN PetscErrorCode DMGetNumDS(DM, PetscInt *);
 PETSC_EXTERN PetscErrorCode DMGetDS(DM, PetscDS *);
-PETSC_EXTERN PetscErrorCode DMGetCellDS(DM, PetscInt, PetscDS *);
-PETSC_EXTERN PetscErrorCode DMGetRegionDS(DM, DMLabel, IS *, PetscDS *);
-PETSC_EXTERN PetscErrorCode DMSetRegionDS(DM, DMLabel, IS, PetscDS);
-PETSC_EXTERN PetscErrorCode DMGetRegionNumDS(DM, PetscInt, DMLabel *, IS *, PetscDS *);
-PETSC_EXTERN PetscErrorCode DMSetRegionNumDS(DM, PetscInt, DMLabel, IS, PetscDS);
+PETSC_EXTERN PetscErrorCode DMGetCellDS(DM, PetscInt, PetscDS *, PetscDS *);
+PETSC_EXTERN PetscErrorCode DMGetRegionDS(DM, DMLabel, IS *, PetscDS *, PetscDS *);
+PETSC_EXTERN PetscErrorCode DMSetRegionDS(DM, DMLabel, IS, PetscDS, PetscDS);
+PETSC_EXTERN PetscErrorCode DMGetRegionNumDS(DM, PetscInt, DMLabel *, IS *, PetscDS *, PetscDS *);
+PETSC_EXTERN PetscErrorCode DMSetRegionNumDS(DM, PetscInt, DMLabel, IS, PetscDS, PetscDS);
 PETSC_EXTERN PetscErrorCode DMFindRegionNum(DM, PetscDS, PetscInt *);
 PETSC_EXTERN PetscErrorCode DMCreateFEDefault(DM, PetscInt, const char[], PetscInt, PetscFE *);
 PETSC_EXTERN PetscErrorCode DMCreateDS(DM);
@@ -319,8 +322,6 @@ PETSC_EXTERN PetscErrorCode DMCopyAuxiliaryVec(DM, DM);
 /*MC
   DMInterpolationInfo - Structure for holding information about interpolation on a mesh
 
-  Level: intermediate
-
   Synopsis:
     comm   - The communicator
     dim    - The spatial dimension of points
@@ -331,7 +332,9 @@ PETSC_EXTERN PetscErrorCode DMCopyAuxiliaryVec(DM, DM);
     coords - The point coordinates
     dof    - The number of components to interpolate
 
-.seealso: `DMInterpolationCreate()`, `DMInterpolationEvaluate()`, `DMInterpolationAddPoints()`
+  Level: intermediate
+
+.seealso: `DM`, `DMInterpolationCreate()`, `DMInterpolationEvaluate()`, `DMInterpolationAddPoints()`
 M*/
 struct _DMInterpolationInfo {
   MPI_Comm   comm;
@@ -375,12 +378,14 @@ PETSC_EXTERN PetscErrorCode DMGetFirstLabeledPoint(DM, DM, DMLabel, PetscInt, co
 /*E
    DMCopyLabelsMode - Determines how `DMCopyLabels()` behaves when there is a `DMLabel` in the source and destination DMs with the same name
 
+   Values:
++  `DM_COPY_LABELS_REPLACE`  - replace label in destination by label from source
+.  `DM_COPY_LABELS_KEEP`     - keep destination label
+-  `DM_COPY_LABELS_FAIL`     - throw error
+
    Level: advanced
 
-$ DM_COPY_LABELS_REPLACE  - replace label in destination by label from source
-$ DM_COPY_LABELS_KEEP     - keep destination label
-$ DM_COPY_LABELS_FAIL     - throw error
-
+.seealso: `DMLabel`, `DM`, `DMCompareLabels()`, `DMRemoveLabel()`
 E*/
 typedef enum {
   DM_COPY_LABELS_REPLACE,
@@ -750,11 +755,11 @@ static inline const PetscInt *DMPolytopeTypeGetArrangment(DMPolytopeType ct, Pet
   case DM_POLYTOPE_PYRAMID:
     return &pyrArr[(o + 4) * 5 * 2];
   default:
-    return NULL;
+    return PETSC_NULLPTR;
   }
 }
 
-/* A vertex arrangment is a vertex order */
+/* A vertex arrangement is a vertex order */
 static inline const PetscInt *DMPolytopeTypeGetVertexArrangment(DMPolytopeType ct, PetscInt o)
 {
   static const PetscInt pntVerts[1]      = {0};
@@ -921,7 +926,7 @@ static inline const PetscInt *DMPolytopeTypeGetVertexArrangment(DMPolytopeType c
   case DM_POLYTOPE_PYRAMID:
     return &pyrVerts[(o + 4) * 5];
   default:
-    return NULL;
+    return PETSC_NULLPTR;
   }
 }
 
@@ -1092,4 +1097,6 @@ PETSC_EXTERN PetscErrorCode DMPolytopeGetOrientation(DMPolytopeType, const Petsc
 PETSC_EXTERN PetscErrorCode DMPolytopeGetVertexOrientation(DMPolytopeType, const PetscInt[], const PetscInt[], PetscInt *);
 PETSC_EXTERN PetscErrorCode DMPolytopeInCellTest(DMPolytopeType, const PetscReal[], PetscBool *);
 
+PETSC_EXTERN PetscErrorCode PetscDTComputeFaceQuadPermutation(DMPolytopeType, PetscQuadrature, PetscInt *, IS *[]);
+
 #endif
