@@ -12,15 +12,15 @@ PETSC_EXTERN PetscErrorCode KSPInitializePackage(void);
 
 /*S
      KSP - Abstract PETSc object that manages all Krylov methods. This is the object that manages the
-         linear solves in PETSc (even those such as direct solvers that do no use Krylov accelerators).
+         linear solves in PETSc (even those such as direct factorization-based solvers that do no use Krylov accelerators).
 
    Level: beginner
 
    Note:
-    When a direct solver is used, but no Krylov solver is used, the KSP object is still used but with a
-    `KSPType` of `KSPPREONLY`, meaning that only application of the preconditioner is used as the linear solver.
+    When a direct solver is used, but no Krylov solver is used, the `KSP` object is still used but with a
+    `KSPType` of `KSPPREONLY` (or equivalently `KSPNONE`), meaning that only application of the preconditioner is used as the linear solver.
 
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `SNES`, `TS`, `PC`, `KSP`, `KSPDestroy()`, `KSPCG`, `KSPGMRES`
+.seealso: [](doc_linsolve), [](chapter_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `SNES`, `TS`, `PC`, `KSP`, `KSPDestroy()`, `KSPCG`, `KSPGMRES`
 S*/
 typedef struct _p_KSP *KSP;
 
@@ -29,7 +29,7 @@ typedef struct _p_KSP *KSP;
 
    Level: beginner
 
-.seealso: `KSPSetType()`, `KSP`, `KSPRegister()`, `KSPCreate()`, `KSPSetFromOptions()`
+.seealso: [](doc_linsolve), [](chapter_ksp), `KSPSetType()`, `KSP`, `KSPRegister()`, `KSPCreate()`, `KSPSetFromOptions()`
 J*/
 typedef const char *KSPType;
 #define KSPRICHARDSON "richardson"
@@ -98,6 +98,7 @@ PETSC_EXTERN PetscErrorCode KSPSolve(KSP, Vec, Vec);
 PETSC_EXTERN PetscErrorCode KSPSolveTranspose(KSP, Vec, Vec);
 PETSC_EXTERN PetscErrorCode KSPSetUseExplicitTranspose(KSP, PetscBool);
 PETSC_EXTERN PetscErrorCode KSPMatSolve(KSP, Mat, Mat);
+PETSC_EXTERN PetscErrorCode KSPMatSolveTranspose(KSP, Mat, Mat);
 PETSC_EXTERN PetscErrorCode KSPSetMatSolveBatchSize(KSP, PetscInt);
 PETSC_DEPRECATED_FUNCTION("Use KSPSetMatSolveBatchSize() (since version 3.15)") static inline PetscErrorCode KSPSetMatSolveBlockSize(KSP ksp, PetscInt n)
 {
@@ -192,11 +193,31 @@ PETSC_EXTERN PetscErrorCode    PCMGGetCoarseSpaceConstructor(const char[], Petsc
 PETSC_EXTERN PetscErrorCode KSPBuildSolution(KSP, Vec, Vec *);
 PETSC_EXTERN PetscErrorCode KSPBuildResidual(KSP, Vec, Vec, Vec *);
 
+/*E
+  KSPChebyshevKind - Which kind of Chebyshev polynomial to use
+
+  Values:
++ `KSP_CHEBYSHEV_FIRST`      - "classic" first-kind Chebyshev polynomial
+. `KSP_CHEBYSHEV_FOURTH`     - fourth-kind Chebyshev polynomial
+- `KSP_CHEBYSHEV_OPT_FOURTH` - optimized fourth-kind Chebyshev polynomial
+
+  Level: intermediate
+
+.seealso: [](chapter_ksp), `KSPCHEBYSHEV`, `KSPChebyshevSetKind()`, `KSPChebyshevGetKind()`
+E*/
+typedef enum {
+  KSP_CHEBYSHEV_FIRST,
+  KSP_CHEBYSHEV_FOURTH,
+  KSP_CHEBYSHEV_OPT_FOURTH
+} KSPChebyshevKind;
+
 PETSC_EXTERN PetscErrorCode KSPRichardsonSetScale(KSP, PetscReal);
 PETSC_EXTERN PetscErrorCode KSPRichardsonSetSelfScale(KSP, PetscBool);
 PETSC_EXTERN PetscErrorCode KSPChebyshevSetEigenvalues(KSP, PetscReal, PetscReal);
 PETSC_EXTERN PetscErrorCode KSPChebyshevEstEigSet(KSP, PetscReal, PetscReal, PetscReal, PetscReal);
 PETSC_EXTERN PetscErrorCode KSPChebyshevEstEigSetUseNoisy(KSP, PetscBool);
+PETSC_EXTERN PetscErrorCode KSPChebyshevSetKind(KSP, KSPChebyshevKind);
+PETSC_EXTERN PetscErrorCode KSPChebyshevGetKind(KSP, KSPChebyshevKind *);
 PETSC_EXTERN PetscErrorCode KSPChebyshevEstEigGetKSP(KSP, KSP *);
 PETSC_EXTERN PetscErrorCode KSPComputeExtremeSingularValues(KSP, PetscReal *, PetscReal *);
 PETSC_EXTERN PetscErrorCode KSPComputeEigenvalues(KSP, PetscInt, PetscReal[], PetscReal[], PetscInt *);
@@ -208,12 +229,12 @@ PETSC_EXTERN PetscErrorCode KSPComputeRitz(KSP, PetscBool, PetscBool, PetscInt *
   KSPFCDTruncationType - Define how stored directions are used to orthogonalize in flexible conjugate directions (FCD) methods
 
   Values:
-$ `KSP_FCD_TRUNC_TYPE_STANDARD` - uses all (up to mmax) stored directions
-$ `KSP_FCD_TRUNC_TYPE_NOTAY` - uses the last max(1,mod(i,mmax)) stored directions at iteration i=0,1..
++ `KSP_FCD_TRUNC_TYPE_STANDARD` - uses all (up to mmax) stored directions
+- `KSP_FCD_TRUNC_TYPE_NOTAY` - uses the last max(1,mod(i,mmax)) stored directions at iteration i=0,1..
 
    Level: intermediate
 
-.seealso `:` `KSPFCG`, `KSPPIPEFCG`, `KSPPIPEGCR`, `KSPFCGSetTruncationType()`, `KSPFCGGetTruncationType()`
+.seealso: [](chapter_ksp), `KSP`, `KSPFCG`, `KSPPIPEFCG`, `KSPPIPEGCR`, `KSPFCGSetTruncationType()`, `KSPFCGGetTruncationType()`
 E*/
 typedef enum {
   KSP_FCD_TRUNC_TYPE_STANDARD,
@@ -264,6 +285,10 @@ PETSC_EXTERN PetscErrorCode KSPGCRSetRestart(KSP, PetscInt);
 PETSC_EXTERN PetscErrorCode KSPGCRGetRestart(KSP, PetscInt *);
 PETSC_EXTERN PetscErrorCode KSPGCRSetModifyPC(KSP, PetscErrorCode (*)(KSP, PetscInt, PetscReal, void *), void *, PetscErrorCode (*)(void *));
 
+PETSC_EXTERN PetscErrorCode KSPMINRESSetRadius(KSP, PetscReal);
+PETSC_EXTERN PetscErrorCode KSPMINRESGetUseQLP(KSP, PetscBool *);
+PETSC_EXTERN PetscErrorCode KSPMINRESSetUseQLP(KSP, PetscBool);
+
 PETSC_EXTERN PetscErrorCode KSPFETIDPGetInnerBDDC(KSP, PC *);
 PETSC_EXTERN PetscErrorCode KSPFETIDPSetInnerBDDC(KSP, PC);
 PETSC_EXTERN PetscErrorCode KSPFETIDPGetInnerKSP(KSP, KSP *);
@@ -288,19 +313,19 @@ PETSC_DEPRECATED_FUNCTION("Use KSPMatSolve() (since version 3.14)") static inlin
 /*E
     KSPHPDDMType - Type of Krylov method used by `KSPHPDDM`
 
+    Values:
++   `KSP_HPDDM_TYPE_GMRES` (default) - Generalized Minimal Residual method
+.   `KSP_HPDDM_TYPE_BGMRES` - block GMRES
+.   `KSP_HPDDM_TYPE_CG` - Conjugate Gradient
+.   `KSP_HPDDM_TYPE_BCG` - block CG
+.   `KSP_HPDDM_TYPE_GCRODR` - Generalized Conjugate Residual method with inner Orthogonalization and Deflated Restarting
+.   `KSP_HPDDM_TYPE_BGCRODR` - block GCRODR
+.   `KSP_HPDDM_TYPE_BFBCG` - breakdown-free BCG
+-   `KSP_HPDDM_TYPE_PREONLY` - apply the preconditioner only
+
     Level: intermediate
 
-    Values:
-$   `KSP_HPDDM_TYPE_GMRES` (default)
-$   `KSP_HPDDM_TYPE_BGMRES`
-$   `KSP_HPDDM_TYPE_CG`
-$   `KSP_HPDDM_TYPE_BCG`
-$   `KSP_HPDDM_TYPE_GCRODR`
-$   `KSP_HPDDM_TYPE_BGCRODR`
-$   `KSP_HPDDM_TYPE_BFBCG`
-$   `KSP_HPDDM_TYPE_PREONLY`
-
-.seealso: `KSPHPDDM`, `KSPHPDDMSetType()`
+.seealso: [](chapter_ksp), `KSPHPDDM`, `KSPHPDDMSetType()`
 E*/
 typedef enum {
   KSP_HPDDM_TYPE_GMRES   = 0,
@@ -313,18 +338,19 @@ typedef enum {
   KSP_HPDDM_TYPE_PREONLY = 7
 } KSPHPDDMType;
 PETSC_EXTERN const char *const KSPHPDDMTypes[];
+
 /*E
     KSPHPDDMPrecision - Precision of Krylov bases used by `KSPHPDDM`
 
+    Values:
++   `KSP_HPDDM_PRECISION_HALF` - default when PETSc is configured `--with-precision=__fp16`
+.   `KSP_HPDDM_PRECISION_SINGLE` - default when PETSc is configured `--with-precision=single`
+.   `KSP_HPDDM_PRECISION_DOUBLE` - default when PETSc is configured `--with-precision=double`
+-   `KSP_HPDDM_PRECISION_QUADRUPLE` - default when PETSc is configured `--with-precision=__float128`
+
     Level: intermediate
 
-    Values:
-$   `KSP_HPDDM_PRECISION_HALF`
-$   `KSP_HPDDM_PRECISION_SINGLE` (default when PETSc is configured --with-precision=single)
-$   `KSP_HPDDM_PRECISION_DOUBLE` (default when PETSc is configured --with-precision=double)
-$   `KSP_HPDDM_PRECISION_QUADRUPLE` (default when PETSc is configured --with-precision=__float128)
-
-.seealso: `KSPHPDDM`
+.seealso: [](chapter_ksp), `KSP`, `KSPHPDDM`
 E*/
 typedef enum {
   KSP_HPDDM_PRECISION_HALF      = 0,
@@ -336,13 +362,18 @@ PETSC_EXTERN PetscErrorCode KSPHPDDMSetType(KSP, KSPHPDDMType);
 PETSC_EXTERN PetscErrorCode KSPHPDDMGetType(KSP, KSPHPDDMType *);
 
 /*E
-    KSPGMRESCGSRefinementType - How the classical (unmodified) Gram-Schmidt is performed.
+    KSPGMRESCGSRefinementType - How the classical (unmodified) Gram-Schmidt is performed in the GMRES solvers
+
+    Values:
++   `KSP_GMRES_CGS_REFINE_NEVER` - one step of classical Gram-Schmidt
+.   `KSP_GMRES_CGS_REFINE_IFNEEDED` - a second step is performed if the first step does not satisfy some criteria
+-   `KSP_GMRES_CGS_REFINE_ALWAYS` - always perform two steps
 
    Level: advanced
 
-.seealso: `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`, `KSPGMRESGetOrthogonalization()`,
+.seealso: [](chapter_ksp), `KSP`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
+          `KSPGMRESGetOrthogonalization()`,
           `KSPGMRESSetCGSRefinementType()`, `KSPGMRESGetCGSRefinementType()`, `KSPGMRESModifiedGramSchmidtOrthogonalization()`
-
 E*/
 typedef enum {
   KSP_GMRES_CGS_REFINE_NEVER,
@@ -350,6 +381,7 @@ typedef enum {
   KSP_GMRES_CGS_REFINE_ALWAYS
 } KSPGMRESCGSRefinementType;
 PETSC_EXTERN const char *const KSPGMRESCGSRefinementTypes[];
+
 /*MC
     KSP_GMRES_CGS_REFINE_NEVER - Do the classical (unmodified) Gram-Schmidt process
 
@@ -358,7 +390,8 @@ PETSC_EXTERN const char *const KSPGMRESCGSRefinementTypes[];
    Note:
    Possibly unstable, but the fastest to compute
 
-.seealso: `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`, `KSPGMRESGetOrthogonalization()`,
+.seealso: [](chapter_ksp), `KSPGMRESCGSRefinementType`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
+          `KSP`, `KSPGMRESGetOrthogonalization()`,
           `KSPGMRESSetCGSRefinementType()`, `KSPGMRESGetCGSRefinementType()`, `KSP_GMRES_CGS_REFINE_IFNEEDED`, `KSP_GMRES_CGS_REFINE_ALWAYS`,
           `KSPGMRESModifiedGramSchmidtOrthogonalization()`
 M*/
@@ -370,16 +403,18 @@ M*/
 
    Level: advanced
 
-   Note: This is slower than `KSP_GMRES_CGS_REFINE_NEVER` because it requires an extra norm computation to
-     estimate the orthogonality but is more stable.
+   Note:
+   This is slower than `KSP_GMRES_CGS_REFINE_NEVER` because it requires an extra norm computation to
+   estimate the orthogonality but is more stable.
 
-.seealso: `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`, `KSPGMRESGetOrthogonalization()`,
+.seealso: [](chapter_ksp), `KSPGMRESCGSRefinementType`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
+          `KSP`, `KSPGMRESGetOrthogonalization()`,
           `KSPGMRESSetCGSRefinementType()`, `KSPGMRESGetCGSRefinementType()`, `KSP_GMRES_CGS_REFINE_NEVER`, `KSP_GMRES_CGS_REFINE_ALWAYS`,
           `KSPGMRESModifiedGramSchmidtOrthogonalization()`
 M*/
 
 /*MC
-    KSP_GMRES_CGS_REFINE_NEVER - Do two steps of the classical (unmodified) Gram-Schmidt process.
+    KSP_GMRES_CGS_REFINE_ALWAYS - Do two steps of the classical (unmodified) Gram-Schmidt process.
 
    Level: advanced
 
@@ -389,7 +424,8 @@ M*/
 
    You should only use this if you absolutely know that the iterative refinement is needed.
 
-.seealso: `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`, `KSPGMRESGetOrthogonalization()`,
+.seealso: [](chapter_ksp), `KSPGMRESCGSRefinementType`, `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESSetOrthogonalization()`,
+          `KSP`, `KSPGMRESGetOrthogonalization()`,
           `KSPGMRESSetCGSRefinementType()`, `KSPGMRESGetCGSRefinementType()`, `KSP_GMRES_CGS_REFINE_IFNEEDED`, `KSP_GMRES_CGS_REFINE_ALWAYS`,
           `KSPGMRESModifiedGramSchmidtOrthogonalization()`
 M*/
@@ -451,8 +487,10 @@ PETSC_DEPRECATED_FUNCTION("Use KSPMonitorTrueResidualMax() (since version 3.15)"
 }
 
 PETSC_EXTERN PetscErrorCode KSPGMRESMonitorKrylov(KSP, PetscInt, PetscReal, void *);
-PETSC_EXTERN PetscErrorCode KSPMonitorDynamicTolerance(KSP ksp, PetscInt its, PetscReal fnorm, void *dummy);
-PETSC_EXTERN PetscErrorCode KSPMonitorDynamicToleranceDestroy(void **dummy);
+PETSC_EXTERN PetscErrorCode KSPMonitorDynamicTolerance(KSP, PetscInt, PetscReal, void *);
+PETSC_EXTERN PetscErrorCode KSPMonitorDynamicToleranceDestroy(void **);
+PETSC_EXTERN PetscErrorCode KSPMonitorDynamicToleranceCreate(void *);
+PETSC_EXTERN PetscErrorCode KSPMonitorDynamicToleranceSetCoefficient(void *, PetscReal);
 PETSC_EXTERN PetscErrorCode KSPMonitorSAWs(KSP, PetscInt, PetscReal, void *);
 PETSC_EXTERN PetscErrorCode KSPMonitorSAWsCreate(KSP, void **);
 PETSC_EXTERN PetscErrorCode KSPMonitorSAWsDestroy(void **);
@@ -505,18 +543,26 @@ PETSC_EXTERN PetscErrorCode PCRedistributeGetKSP(PC, KSP *);
 PETSC_EXTERN PetscErrorCode PCTelescopeGetKSP(PC, KSP *);
 
 /*E
-    KSPNormType - Norm that is passed in the Krylov convergence
+    KSPNormType - Norm calculated by the `KSP` and passed in the Krylov convergence
        test routines.
 
+    Values:
++   `KSP_NORM_DEFAULT` - use the default for the current `KSPType`
+.   `KSP_NORM_NONE` - use no norm calculation
+.   `KSP_NORM_PRECONDITIONED` - use the preconditioned residual norm
+.   `KSP_NORM_UNPRECONDITIONED` - use the unpreconditioned residual norm
+-   `KSP_NORM_NATURAL` - use the natural norm (the norm induced by the linear operator)
+
    Level: advanced
 
+   Note:
    Each solver only supports a subset of these and some may support different ones
-   depending on left or right preconditioning, see `KSPSetPCSide()`
+   depending on whether left or right preconditioning is used, see `KSPSetPCSide()`
 
    Developer Note:
-    this must match petsc/finclude/petscksp.h
+   This must match the values in petsc/finclude/petscksp.h
 
-.seealso: `KSPSolve()`, `KSPGetConvergedReason()`, `KSPSetNormType()`,
+.seealso: [](chapter_ksp), `KSP`, `PCSide`, `KSPSolve()`, `KSPGetConvergedReason()`, `KSPSetNormType()`,
           `KSPSetConvergenceTest()`, `KSPSetPCSide()`
 E*/
 typedef enum {
@@ -536,9 +582,10 @@ PETSC_EXTERN const char *const *const KSPNormTypes;
 
    Level: advanced
 
-    Note: Some Krylov methods need to compute a residual norm (such as `KPSGMRES`) and then this option is ignored
+    Note:
+    Some Krylov methods need to compute a residual norm (such as `KPSGMRES`) and then this option is ignored
 
-.seealso: `KSPNormType`, `KSPSetNormType()`, `KSP_NORM_PRECONDITIONED`, `KSP_NORM_UNPRECONDITIONED`, `KSP_NORM_NATURAL`
+.seealso: [](chapter_ksp), `KSPNormType`, `KSP`, `KSPSetNormType()`, `KSP_NORM_PRECONDITIONED`, `KSP_NORM_UNPRECONDITIONED`, `KSP_NORM_NATURAL`
 M*/
 
 /*MC
@@ -547,7 +594,7 @@ M*/
 
    Level: advanced
 
-.seealso: `KSPNormType`, `KSPSetNormType()`, `KSP_NORM_NONE`, `KSP_NORM_UNPRECONDITIONED`, `KSP_NORM_NATURAL`, `KSPSetConvergenceTest()`
+.seealso: [](chapter_ksp), `KSPNormType`, `KSP`, `KSPSetNormType()`, `KSP_NORM_NONE`, `KSP_NORM_UNPRECONDITIONED`, `KSP_NORM_NATURAL`, `KSPSetConvergenceTest()`
 M*/
 
 /*MC
@@ -556,7 +603,7 @@ M*/
 
    Level: advanced
 
-.seealso: `KSPNormType`, `KSPSetNormType()`, `KSP_NORM_NONE`, `KSP_NORM_PRECONDITIONED`, `KSP_NORM_NATURAL`, `KSPSetConvergenceTest()`
+.seealso: [](chapter_ksp), `KSPNormType`, `KSP`, `KSPSetNormType()`, `KSP_NORM_NONE`, `KSP_NORM_PRECONDITIONED`, `KSP_NORM_NATURAL`, `KSPSetConvergenceTest()`
 M*/
 
 /*MC
@@ -565,7 +612,7 @@ M*/
 
    Level: advanced
 
-.seealso: `KSPNormType`, `KSPSetNormType()`, `KSP_NORM_NONE`, `KSP_NORM_PRECONDITIONED`, `KSP_NORM_UNPRECONDITIONED`, `KSPSetConvergenceTest()`
+.seealso: [](chapter_ksp), `KSPNormType`, `KSP`, `KSPSetNormType()`, `KSP_NORM_NONE`, `KSP_NORM_PRECONDITIONED`, `KSP_NORM_UNPRECONDITIONED`, `KSPSetConvergenceTest()`
 M*/
 
 PETSC_EXTERN PetscErrorCode KSPSetNormType(KSP, KSPNormType);
@@ -574,33 +621,57 @@ PETSC_EXTERN PetscErrorCode KSPSetSupportedNorm(KSP ksp, KSPNormType, PCSide, Pe
 PETSC_EXTERN PetscErrorCode KSPSetCheckNormIteration(KSP, PetscInt);
 PETSC_EXTERN PetscErrorCode KSPSetLagNorm(KSP, PetscBool);
 
-#define KSP_DIVERGED_PCSETUP_FAILED_DEPRECATED KSP_DIVERGED_PCSETUP_FAILED PETSC_DEPRECATED_ENUM("Use KSP_DIVERGED_PC_FAILED (since version 3.11)")
+#define KSP_CONVERGED_CG_NEG_CURVE_DEPRECATED   KSP_CONVERGED_CG_NEG_CURVE PETSC_DEPRECATED_ENUM("Use KSP_CONVERGED_NEG_CURVE (since version 3.19)")
+#define KSP_CONVERGED_CG_CONSTRAINED_DEPRECATED KSP_CONVERGED_CG_CONSTRAINED PETSC_DEPRECATED_ENUM("Use KSP_CONVERGED_STEP_LENGTH (since version 3.19)")
+#define KSP_DIVERGED_PCSETUP_FAILED_DEPRECATED  KSP_DIVERGED_PCSETUP_FAILED PETSC_DEPRECATED_ENUM("Use KSP_DIVERGED_PC_FAILED (since version 3.11)")
 /*E
-    KSPConvergedReason - reason a Krylov method was said to have converged or diverged
+    KSPConvergedReason - reason a Krylov method was determined to have converged or diverged
+
+   Values:
++  `KSP_CONVERGED_RTOL_NORMAL` - requested decrease in the residual for the normal equations
+.  `KSP_CONVERGED_ATOL_NORMAL` - requested absolute value in the residual for the normal equations
+.  `KSP_CONVERGED_RTOL` - requested decrease in the residual
+.  `KSP_CONVERGED_ATOL` - requested absolute value in the residual
+.  `KSP_CONVERGED_ITS` - requested number of iterations
+.  `KSP_CONVERGED_NEG_CURVE` - see note below
+.  `KSP_CONVERGED_STEP_LENGTH` - see note below
+.  `KSP_CONVERGED_HAPPY_BREAKDOWN` - happy breakdown (meaning early convergence of the `KSPType` occurred.
+.  `KSP_DIVERGED_NULL` - breakdown when solving the Hessenberg system within GMRES
+.  `KSP_DIVERGED_ITS` - requested number of iterations
+.  `KSP_DIVERGED_DTOL` - large increase in the residual norm
+.  `KSP_DIVERGED_BREAKDOWN` - breakdown in the Krylov method
+.  `KSP_DIVERGED_BREAKDOWN_BICG` - breakdown in the `KSPBGCS` Krylov method
+.  `KSP_DIVERGED_NONSYMMETRIC` - the operator or preonditioner was not symmetric for a `KSPType` that requires symmetry
+.  `KSP_DIVERGED_INDEFINITE_PC` - the preconditioner was indefinite for a `KSPType` that requires it be definite
+.  `KSP_DIVERGED_NANORINF` - a not a number of infinity was detected in a vector during the computation
+.  `KSP_DIVERGED_INDEFINITE_MAT` - the operator was indefinite for a `KSPType` that requires it be definite
+-  `KSP_DIVERGED_PC_FAILED` - the action of the preconditioner failed for some reason
 
    Level: beginner
 
-   Notes:
-    See `KSPGetConvergedReason()` for explanation of each value
+   Note:
+   The values  `KSP_CONVERGED_NEG_CURVE`, and `KSP_CONVERGED_STEP_LENGTH` are returned only by the special `KSPNASH`,
+   `KSPSTCG`, and `KSPGLTR` solvers which are used by the `SNESNEWTONTR` (trust region) solver.
 
    Developer Notes:
-   This must match petsc/finclude/petscksp.h
+   This must match the values in petsc/finclude/petscksp.h
 
    The string versions of these are `KSPConvergedReasons`; if you change
    any of the values here also change them that array of names.
 
-.seealso: `KSPSolve()`, `KSPGetConvergedReason()`, `KSPSetTolerances()`, `KSPConvergedReasonView()`
+.seealso: [](chapter_ksp), `KSP`, `KSPSolve()`, `KSPGetConvergedReason()`, `KSPSetTolerances()`, `KSPConvergedReasonView()`
 E*/
 typedef enum { /* converged */
-  KSP_CONVERGED_RTOL_NORMAL     = 1,
-  KSP_CONVERGED_ATOL_NORMAL     = 9,
-  KSP_CONVERGED_RTOL            = 2,
-  KSP_CONVERGED_ATOL            = 3,
-  KSP_CONVERGED_ITS             = 4,
-  KSP_CONVERGED_CG_NEG_CURVE    = 5,
-  KSP_CONVERGED_CG_CONSTRAINED  = 6,
-  KSP_CONVERGED_STEP_LENGTH     = 7,
-  KSP_CONVERGED_HAPPY_BREAKDOWN = 8,
+  KSP_CONVERGED_RTOL_NORMAL               = 1,
+  KSP_CONVERGED_ATOL_NORMAL               = 9,
+  KSP_CONVERGED_RTOL                      = 2,
+  KSP_CONVERGED_ATOL                      = 3,
+  KSP_CONVERGED_ITS                       = 4,
+  KSP_CONVERGED_NEG_CURVE                 = 5,
+  KSP_CONVERGED_CG_NEG_CURVE_DEPRECATED   = 5,
+  KSP_CONVERGED_CG_CONSTRAINED_DEPRECATED = 6,
+  KSP_CONVERGED_STEP_LENGTH               = 6,
+  KSP_CONVERGED_HAPPY_BREAKDOWN           = 7,
   /* diverged */
   KSP_DIVERGED_NULL                      = -2,
   KSP_DIVERGED_ITS                       = -3,
@@ -629,8 +700,7 @@ PETSC_EXTERN const char *const *KSPConvergedReasons;
 
    See also `KSP_CONVERGED_ATOL` which may apply before this tolerance.
 
-.seealso: `KSP_CONVERGED_ATOL`, `KSP_DIVERGED_DTOL`, `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
-
+.seealso: [](chapter_ksp), `KSPNormType`, `KSP_CONVERGED_ATOL`, `KSP_DIVERGED_DTOL`, `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
@@ -644,8 +714,7 @@ M*/
 
    See also `KSP_CONVERGED_RTOL` which may apply before this tolerance.
 
-.seealso: `KSP_CONVERGED_RTOL`, `KSP_DIVERGED_DTOL`, `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
-
+.seealso: [](chapter_ksp), `KSPNormType`, `KSP_CONVERGED_RTOL`, `KSP_DIVERGED_DTOL`, `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
@@ -659,8 +728,7 @@ M*/
 
    Level: beginner
 
-.seealso: `KSP_CONVERGED_ATOL`, `KSP_DIVERGED_RTOL`, `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
-
+.seealso: [](chapter_ksp), `KSPNormType`, `KSP_CONVERGED_ATOL`, `KSP_DIVERGED_RTOL`, `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
@@ -669,8 +737,7 @@ M*/
 
    Level: beginner
 
-.seealso: `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
-
+.seealso: [](chapter_ksp), `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
@@ -680,8 +747,7 @@ M*/
 
    Level: beginner
 
-.seealso: `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
-
+.seealso: [](chapter_ksp), `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
@@ -692,8 +758,7 @@ M*/
 
    Level: beginner
 
-.seealso: `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
-
+.seealso: [](chapter_ksp), `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
@@ -702,8 +767,7 @@ M*/
 
    Level: beginner
 
-.seealso: `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
-
+.seealso: [](chapter_ksp), `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
@@ -712,8 +776,7 @@ M*/
 
    Level: beginner
 
-.seealso: `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
-
+.seealso: [](chapter_ksp), `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
@@ -724,11 +787,10 @@ M*/
    Level: beginner
 
      Note:
-    This can happen with the `PCICC` preconditioner, use -pc_factor_shift_positive_definite to force
+    This can happen with the `PCICC` preconditioner, use the options database option `-pc_factor_shift_positive_definite` to force
   the `PCICC` preconditioner to generate a positive definite preconditioner
 
-.seealso: `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
-
+.seealso: [](chapter_ksp), `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
@@ -738,21 +800,19 @@ M*/
 
    Level: beginner
 
-    Notes:
-    Run with -ksp_error_if_not_converged to stop the program when the error is detected and print an error message with details.
-
-.seealso: `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
+    Note:
+    Run with `-ksp_error_if_not_converged` to stop the program when the error is detected and print an error message with details.
 
+.seealso: [](chapter_ksp), `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 /*MC
-     KSP_CONVERGED_ITERATING - This flag is returned if you call `KSPGetConvergedReason()`
-        while the `KSPSolve()` is still running.
+     KSP_CONVERGED_ITERATING - This flag is returned if `KSPGetConvergedReason()` is called
+        while `KSPSolve()` is still running.
 
    Level: beginner
 
-.seealso: `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
-
+.seealso: [](chapter_ksp), `KSPSolve()`, `KSPGetConvergedReason()`, `KSPConvergedReason`, `KSPSetTolerances()`
 M*/
 
 PETSC_EXTERN PetscErrorCode KSPSetConvergenceTest(KSP, PetscErrorCode (*)(KSP, PetscInt, PetscReal, KSPConvergedReason *, void *), void *, PetscErrorCode (*)(void *));
@@ -770,6 +830,8 @@ PETSC_EXTERN PetscErrorCode KSPConvergedSkip(KSP, PetscInt, PetscReal, KSPConver
 PETSC_EXTERN PetscErrorCode KSPGetConvergedReason(KSP, KSPConvergedReason *);
 PETSC_EXTERN PetscErrorCode KSPGetConvergedReasonString(KSP, const char **);
 PETSC_EXTERN PetscErrorCode KSPComputeConvergenceRate(KSP, PetscReal *, PetscReal *, PetscReal *, PetscReal *);
+PETSC_EXTERN PetscErrorCode KSPSetConvergedNegativeCurvature(KSP, PetscBool);
+PETSC_EXTERN PetscErrorCode KSPGetConvergedNegativeCurvature(KSP, PetscBool *);
 
 PETSC_DEPRECATED_FUNCTION("Use KSPConvergedDefault() (since version 3.5)") static inline void KSPDefaultConverged(void)
 { /* never called */
@@ -799,15 +861,19 @@ PETSC_DEPRECATED_FUNCTION("Use KSPConvergedSkip() (since version 3.5)") static i
 PETSC_EXTERN PetscErrorCode KSPComputeOperator(KSP, MatType, Mat *);
 PETSC_DEPRECATED_FUNCTION("Use KSPComputeOperator() (since version 3.12)") static inline PetscErrorCode KSPComputeExplicitOperator(KSP A, Mat *B)
 {
-  return KSPComputeOperator(A, NULL, B);
+  return KSPComputeOperator(A, PETSC_NULLPTR, B);
 }
 
 /*E
-    KSPCGType - Determines what type of CG to use
+    KSPCGType - Determines what type of `KSPCG` to use
+
+   Values:
+ + `KSP_CG_SYMMETRIC` - the matrix is complex symmetric
+ - `KSP_CG_HERMITIAN` - the matrix is complex Hermitian
 
    Level: beginner
 
-.seealso: `KSPCGSetType()`
+.seealso: [](chapter_ksp), `KSPCG`, `KSP`, `KSPCGSetType()`
 E*/
 typedef enum {
   KSP_CG_SYMMETRIC = 0,
@@ -819,6 +885,7 @@ PETSC_EXTERN PetscErrorCode KSPCGSetType(KSP, KSPCGType);
 PETSC_EXTERN PetscErrorCode KSPCGUseSingleReduction(KSP, PetscBool);
 
 PETSC_EXTERN PetscErrorCode KSPCGSetRadius(KSP, PetscReal);
+PETSC_EXTERN PetscErrorCode KSPCGSetObjectiveTarget(KSP, PetscReal);
 PETSC_EXTERN PetscErrorCode KSPCGGetNormD(KSP, PetscReal *);
 PETSC_EXTERN PetscErrorCode KSPCGGetObjFcn(KSP, PetscReal *);
 
@@ -847,23 +914,29 @@ PETSC_EXTERN PetscErrorCode PCShellSetPreSolve(PC, PetscErrorCode (*)(PC, KSP, V
 PETSC_EXTERN PetscErrorCode PCShellSetPostSolve(PC, PetscErrorCode (*)(PC, KSP, Vec, Vec));
 
 /*S
-     KSPGuess - Abstract PETSc object that manages all initial guess methods in Krylov methods.
+     KSPGuess - Abstract PETSc object that manages all initial guess generation methods for Krylov methods.
 
-   Level: beginner
+   Level: intermediate
 
-.seealso: `KSPCreate()`, `KSPSetGuessType()`, `KSPGuessType`
+.seealso: [](chapter_ksp), `KSPCreate()`, `KSPSetGuessType()`, `KSPGuessType`
 S*/
 typedef struct _p_KSPGuess *KSPGuess;
+
 /*J
     KSPGuessType - String with the name of a PETSc initial guess approach for Krylov methods.
 
-   Level: beginner
+   Values:
+ + `KSPGUESSFISCHER` - methodology developed by Paul Fischer
+ - `KSPGUESSPOD` - methodology based on proper orthogonal decomposition
 
-.seealso: `KSPGuess`
+   Level: intermediate
+
+.seealso: [](chapter_ksp), `KSP`, `KSPGuess`
 J*/
 typedef const char *KSPGuessType;
 #define KSPGUESSFISCHER "fischer"
 #define KSPGUESSPOD     "pod"
+
 PETSC_EXTERN PetscErrorCode KSPGuessRegister(const char[], PetscErrorCode (*)(KSPGuess));
 PETSC_EXTERN PetscErrorCode KSPSetGuess(KSP, KSPGuess);
 PETSC_EXTERN PetscErrorCode KSPGetGuess(KSP, KSPGuess *);
@@ -887,7 +960,8 @@ PETSC_EXTERN PetscErrorCode KSPGetInitialGuessKnoll(KSP, PetscBool *);
 
     Level: intermediate
 
-.seealso: `MatSchurComplementGetAinvType()`, `MatSchurComplementSetAinvType()`, `MatSchurComplementGetPmat()`, `MatGetSchurComplement()`, `MatCreateSchurComplementPmat()`
+.seealso: `MatSchurComplementGetAinvType()`, `MatSchurComplementSetAinvType()`, `MatSchurComplementGetPmat()`, `MatGetSchurComplement()`,
+          `MatCreateSchurComplementPmat()`
 E*/
 typedef enum {
   MAT_SCHUR_COMPLEMENT_AINV_DIAG,
