@@ -9,6 +9,14 @@
 
 /* SUBMANSEC = Sys */
 
+typedef enum {
+  PETSC_OPT_CODE,
+  PETSC_OPT_COMMAND_LINE,
+  PETSC_OPT_FILE,
+  PETSC_OPT_ENVIRONMENT,
+  NUM_PETSC_OPT_SOURCE
+} PetscOptionSource;
+
 #define PETSC_MAX_OPTION_NAME 512
 typedef struct _n_PetscOptions *PetscOptions;
 PETSC_EXTERN PetscErrorCode     PetscOptionsCreate(PetscOptions *);
@@ -66,8 +74,8 @@ PETSC_EXTERN PetscErrorCode PetscOptionsStringToInt(const char[], PetscInt *);
 PETSC_EXTERN PetscErrorCode PetscOptionsStringToReal(const char[], PetscReal *);
 PETSC_EXTERN PetscErrorCode PetscOptionsStringToScalar(const char[], PetscScalar *);
 
-PETSC_EXTERN PetscErrorCode PetscOptionsMonitorSet(PetscErrorCode (*)(const char[], const char[], void *), void *, PetscErrorCode (*)(void **));
-PETSC_EXTERN PetscErrorCode PetscOptionsMonitorDefault(const char[], const char[], void *);
+PETSC_EXTERN PetscErrorCode PetscOptionsMonitorSet(PetscErrorCode (*)(const char[], const char[], PetscOptionSource, void *), void *, PetscErrorCode (*)(void **));
+PETSC_EXTERN PetscErrorCode PetscOptionsMonitorDefault(const char[], const char[], PetscOptionSource, void *);
 
 PETSC_EXTERN PetscErrorCode PetscObjectSetOptions(PetscObject, PetscOptions);
 PETSC_EXTERN PetscErrorCode PetscObjectGetOptions(PetscObject, PetscOptions *);
@@ -95,6 +103,7 @@ typedef enum {
   OPTION_BOOL_ARRAY,
   OPTION_STRING_ARRAY
 } PetscOptionType;
+
 typedef struct _n_PetscOptionItem *PetscOptionItem;
 struct _n_PetscOptionItem {
   char              *option;
@@ -132,7 +141,7 @@ PetscErrorCode           PetscOptionsEnd(void);
   /*MC
     PetscOptionsBegin - Begins a set of queries on the options database that are related and should be
      displayed on the same window of a GUI that allows the user to set the options interactively. Often one should
-     use PetscObjectOptionsBegin() rather than this call.
+     use `PetscObjectOptionsBegin()` rather than this call.
 
    Synopsis:
     #include <petscoptions.h>
@@ -156,17 +165,17 @@ PetscErrorCode           PetscOptionsEnd(void);
     One can add subheadings with `PetscOptionsHeadBegin()`.
 
   Developer Notes:
-      PetscOptionsPublish is set in PetscOptionsCheckInitial_Private() with -saws_options. When PetscOptionsPublish is set the
-      loop between PetscOptionsBegin() and PetscOptionsEnd() is run THREE times with PetscOptionsPublishCount of values -1,0,1.
-      Otherwise the loop is run ONCE with a PetscOptionsPublishCount of 1.
-+      \-1 - PetscOptionsInt() etc. just call PetscOptionsGetInt() etc.
-.      0  - The GUI objects are created in PetscOptionsInt() etc. and displayed in PetscOptionsEnd() and the options
-               database updated with user changes; PetscOptionsGetInt() etc. are also called.
--      1 - PetscOptionsInt() etc. again call PetscOptionsGetInt() etc. (possibly getting new values), in addition the help message and
+      `PetscOptionsPublish` is set in `PetscOptionsCheckInitial_Private()` with `-saws_options`. When `PetscOptionsPublish` is set the
+      loop between `PetscOptionsBegin()` and `PetscOptionsEnd()` is run THREE times with `PetscOptionsPublishCount` of values -1,0,1.
+      Otherwise the loop is run ONCE with a `PetscOptionsPublishCount` of 1.
++      \-1 - `PetscOptionsInt()` etc. just call `PetscOptionsGetInt()` etc.
+.      0  - The GUI objects are created in `PetscOptionsInt()` etc. and displayed in `PetscOptionsEnd()` and the options
+               database updated with user changes; `PetscOptionsGetInt()` etc. are also called.
+-      1 - `PetscOptionsInt()` etc. again call `PetscOptionsGetInt()` etc. (possibly getting new values), in addition the help message and
               default values are printed if -help was given.
-      When PetscOptionsObject.changedmethod is set this causes PetscOptionsPublishCount to be reset to -2 (so in the next loop iteration it is -1)
-      and the whole process is repeated. This is to handle when, for example, the KSPType is changed thus changing the list of
-      options available so they need to be redisplayed so the user can change the. Changing PetscOptionsObjects.changedmethod is never
+      When `PetscOptionsObject.changedmethod` is set this causes `PetscOptionsPublishCount` to be reset to -2 (so in the next loop iteration it is -1)
+      and the whole process is repeated. This is to handle when, for example, the `KSPType` is changed thus changing the list of
+      options available so they need to be redisplayed so the user can change the. Changing `PetscOptionsObjects.changedmethod` is never
       currently set.
 
 .seealso: `PetscOptionsGetReal()`, `PetscOptionsHasName()`, `PetscOptionsGetString()`, `PetscOptionsGetInt()`,
@@ -176,7 +185,6 @@ PetscErrorCode           PetscOptionsEnd(void);
           `PetscOptionsStringArray()`, `PetscOptionsRealArray()`, `PetscOptionsScalar()`,
           `PetscOptionsBoolGroupBegin()`, `PetscOptionsBoolGroup()`, `PetscOptionsBoolGroupEnd()`,
           `PetscOptionsFList()`, `PetscOptionsEList()`, `PetscObjectOptionsBegin()`
-
 M*/
   #define PetscOptionsBegin(comm, prefix, mess, sec) \
     do { \
@@ -194,9 +202,9 @@ M*/
     #include <petscoptions.h>
     PetscErrorCode PetscObjectOptionsBegin(PetscObject obj)
 
-    Collective on obj
+    Collective
 
-  Input Parameters:
+  Input Parameter:
 .   obj - object to set options for
 
   Level: intermediate
@@ -215,7 +223,6 @@ M*/
           `PetscOptionsStringArray()`, `PetscOptionsRealArray()`, `PetscOptionsScalar()`,
           `PetscOptionsBoolGroupBegin()`, `PetscOptionsBoolGroup()`, `PetscOptionsBoolGroupEnd()`,
           `PetscOptionsFList()`, `PetscOptionsEList()`
-
 M*/
   #define PetscObjectOptionsBegin(obj) \
     do { \
@@ -249,7 +256,6 @@ M*/
           `PetscOptionsStringArray()`, `PetscOptionsRealArray()`, `PetscOptionsScalar()`,
           `PetscOptionsBoolGroupBegin()`, `PetscOptionsBoolGroup()`, `PetscOptionsBoolGroupEnd()`,
           `PetscOptionsFList()`, `PetscOptionsEList()`, `PetscObjectOptionsBegin()`
-
 M*/
   #define PetscOptionsEnd() \
     PetscCall(PetscOptionsEnd_Private(PetscOptionsObject)); \
@@ -314,9 +320,9 @@ PetscErrorCode PetscOptionsDeprecatedNoObject(T...);
 #else
   /*MC
      PetscOptionsHeadBegin - Puts a heading before listing any more published options. Used, for example,
-            in KSPSetFromOptions_GMRES().
+            in `KSPSetFromOptions_GMRES()`.
 
-   Logically Collective on the communicator passed in PetscOptionsBegin()
+   Logically Collective on the communicator passed in `PetscOptionsBegin()`
 
    Input Parameter:
 .   head - the heading text
@@ -326,7 +332,7 @@ PetscErrorCode PetscOptionsDeprecatedNoObject(T...);
    Notes:
     Handles errors directly, hence does not return an error code
 
-    Must be between a `PetscOptionsBegin()` and a `PetscOptionsEnd()`, and PetscOptionsObject created in `PetscOptionsBegin()` should be the first argument
+    Must be between a `PetscOptionsBegin()` and a `PetscOptionsEnd()`, and `PetscOptionsObject` created in `PetscOptionsBegin()` should be the first argument
 
     Must be followed by a call to `PetscOptionsHeadEnd()` in the same function.
 
@@ -346,7 +352,7 @@ PetscErrorCode PetscOptionsDeprecatedNoObject(T...);
 
   /*MC
      PetscOptionsHeadEnd - Ends a section of options begun with `PetscOptionsHeadBegin()`
-            See, for example, KSPSetFromOptions_GMRES().
+            See, for example, `KSPSetFromOptions_GMRES()`.
 
     Collective on the comm used in `PetscOptionsBegin()` or obj used in `PetscObjectOptionsBegin()`
 
@@ -362,7 +368,7 @@ PetscErrorCode PetscOptionsDeprecatedNoObject(T...);
     Must be preceded by a call to `PetscOptionsHeadBegin()` in the same function.
 
     This needs to be used only if the code below `PetscOptionsHeadEnd()` can be run ONLY once.
-    See, for example, `PCSetFromOptions_Composite()`. This is a return(0) in it for early exit
+    See, for example, `PCSetFromOptions_Composite()`. This is a `return(0)` in it for early exit
     from the function.
 
           This is only for use with the PETSc options GUI
@@ -376,7 +382,7 @@ PetscErrorCode PetscOptionsDeprecatedNoObject(T...);
 M*/
   #define PetscOptionsHeadEnd() \
     do { \
-      if (PetscOptionsObject->count != 1) PetscFunctionReturn(0); \
+      if (PetscOptionsObject->count != 1) PetscFunctionReturn(PETSC_SUCCESS); \
     } while (0)
 
   #define PetscOptionsTail(...) PETSC_DEPRECATED_MACRO("GCC warning \"Use PetscOptionsHeadEnd() (since version 3.18)\"") PetscOptionsHeadEnd(__VA_ARGS__)
