@@ -8,32 +8,158 @@
 #include <petscconf.h>
 #include <petscconf_poison.h>
 #include <petscfix.h>
+#include <petscmacros.h> // PETSC_NODISCARD, PETSC_CPP_VERSION
 #include <stddef.h>
 
 /* SUBMANSEC = Sys */
 
-/*MC
-    PetscErrorCode - datatype used for return error code from almost all PETSc functions
+#include <limits.h> // INT_MIN, INT_MAX
 
-    Level: beginner
+#if defined(__clang__) || (PETSC_CPP_VERSION >= 17)
+  // clang allows both [[nodiscard]] and __attribute__((warn_unused_result)) on type
+  // definitions. GCC, however, does not, so check that we are using C++17 [[nodiscard]]
+  // instead of __attribute__((warn_unused_result))
+  #define PETSC_ERROR_CODE_NODISCARD PETSC_NODISCARD
+#else
+  #define PETSC_ERROR_CODE_NODISCARD
+#endif
 
-.seealso: `PetscCall()`, `SETERRQ()`
-M*/
+#ifdef PETSC_CLANG_STATIC_ANALYZER
+  #undef PETSC_USE_STRICT_PETSCERRORCODE
+#endif
+
+#ifdef PETSC_USE_STRICT_PETSCERRORCODE
+  #define PETSC_ERROR_CODE_TYPEDEF   typedef
+  #define PETSC_ERROR_CODE_ENUM_NAME PetscErrorCode
+#else
+  #define PETSC_ERROR_CODE_TYPEDEF
+  #define PETSC_ERROR_CODE_ENUM_NAME
+#endif
+
+/*E
+  PetscErrorCode - Datatype used to return PETSc error codes.
+
+  Level: beginner
+
+  Notes:
+  Virtually all PETSc functions return an error code. It is the callers responsibility to check
+  the value of the returned error code after each PETSc call to determine if any errors
+  occurred. A set of convenience macros (e.g. `PetscCall()`, `PetscCallVoid()`) are provided
+  for this purpose. Failing to properly check for errors is not supported, as errors may leave
+  PETSc in an undetermined state.
+
+  One can retrieve the error string corresponding to a particular error code using
+  `PetscErrorMessage()`.
+
+  The user can also configure PETSc with the `--with-strict-petscerrorcode` option to enable
+  compiler warnings when the returned error codes are not captured and checked. Users are
+  *heavily* encouraged to opt-in to this option, as it will become enabled by default in a
+  future release.
+
+  Developer Notes:
+
+  These are the generic error codes. These error codes are used in many different places in the
+  PETSc source code. The C-string versions are at defined in `PetscErrorStrings[]` in
+  `src/sys/error/err.c`, while the Fortran versions are defined in
+  `src/sys/f90-mod/petscerror.h`. Any changes here must also be made in both locations.
+
+.seealso: `PetscErrorMessage()`, `PetscCall()`, `SETERRQ()`
+E*/
+PETSC_ERROR_CODE_TYPEDEF enum PETSC_ERROR_CODE_NODISCARD {
+  PETSC_SUCCESS                   = 0,
+  PETSC_ERR_BOOLEAN_MACRO_FAILURE = 1, /* do not use */
+
+  PETSC_ERR_MIN_VALUE = 54, /* should always be one less then the smallest value */
+
+  PETSC_ERR_MEM            = 55, /* unable to allocate requested memory */
+  PETSC_ERR_SUP            = 56, /* no support for requested operation */
+  PETSC_ERR_SUP_SYS        = 57, /* no support for requested operation on this computer system */
+  PETSC_ERR_ORDER          = 58, /* operation done in wrong order */
+  PETSC_ERR_SIG            = 59, /* signal received */
+  PETSC_ERR_FP             = 72, /* floating point exception */
+  PETSC_ERR_COR            = 74, /* corrupted PETSc object */
+  PETSC_ERR_LIB            = 76, /* error in library called by PETSc */
+  PETSC_ERR_PLIB           = 77, /* PETSc library generated inconsistent data */
+  PETSC_ERR_MEMC           = 78, /* memory corruption */
+  PETSC_ERR_CONV_FAILED    = 82, /* iterative method (KSP or SNES) failed */
+  PETSC_ERR_USER           = 83, /* user has not provided needed function */
+  PETSC_ERR_SYS            = 88, /* error in system call */
+  PETSC_ERR_POINTER        = 70, /* pointer does not point to valid address */
+  PETSC_ERR_MPI_LIB_INCOMP = 87, /* MPI library at runtime is not compatible with MPI user compiled with */
+
+  PETSC_ERR_ARG_SIZ          = 60, /* nonconforming object sizes used in operation */
+  PETSC_ERR_ARG_IDN          = 61, /* two arguments not allowed to be the same */
+  PETSC_ERR_ARG_WRONG        = 62, /* wrong argument (but object probably ok) */
+  PETSC_ERR_ARG_CORRUPT      = 64, /* null or corrupted PETSc object as argument */
+  PETSC_ERR_ARG_OUTOFRANGE   = 63, /* input argument, out of range */
+  PETSC_ERR_ARG_BADPTR       = 68, /* invalid pointer argument */
+  PETSC_ERR_ARG_NOTSAMETYPE  = 69, /* two args must be same object type */
+  PETSC_ERR_ARG_NOTSAMECOMM  = 80, /* two args must be same communicators */
+  PETSC_ERR_ARG_WRONGSTATE   = 73, /* object in argument is in wrong state, e.g. unassembled mat */
+  PETSC_ERR_ARG_TYPENOTSET   = 89, /* the type of the object has not yet been set */
+  PETSC_ERR_ARG_INCOMP       = 75, /* two arguments are incompatible */
+  PETSC_ERR_ARG_NULL         = 85, /* argument is null that should not be */
+  PETSC_ERR_ARG_UNKNOWN_TYPE = 86, /* type name doesn't match any registered type */
+
+  PETSC_ERR_FILE_OPEN       = 65, /* unable to open file */
+  PETSC_ERR_FILE_READ       = 66, /* unable to read from file */
+  PETSC_ERR_FILE_WRITE      = 67, /* unable to write to file */
+  PETSC_ERR_FILE_UNEXPECTED = 79, /* unexpected data in file */
+
+  PETSC_ERR_MAT_LU_ZRPVT = 71, /* detected a zero pivot during LU factorization */
+  PETSC_ERR_MAT_CH_ZRPVT = 81, /* detected a zero pivot during Cholesky factorization */
+
+  PETSC_ERR_INT_OVERFLOW   = 84,
+  PETSC_ERR_FLOP_COUNT     = 90,
+  PETSC_ERR_NOT_CONVERGED  = 91,  /* solver did not converge */
+  PETSC_ERR_MISSING_FACTOR = 92,  /* MatGetFactor() failed */
+  PETSC_ERR_OPT_OVERWRITE  = 93,  /* attempted to over write options which should not be changed */
+  PETSC_ERR_WRONG_MPI_SIZE = 94,  /* example/application run with number of MPI ranks it does not support */
+  PETSC_ERR_USER_INPUT     = 95,  /* missing or incorrect user input */
+  PETSC_ERR_GPU_RESOURCE   = 96,  /* unable to load a GPU resource, for example cuBLAS */
+  PETSC_ERR_GPU            = 97,  /* An error from a GPU call, this may be due to lack of resources on the GPU or a true error in the call */
+  PETSC_ERR_MPI            = 98,  /* general MPI error */
+  PETSC_ERR_RETURN         = 99,  /* PetscError() incorrectly returned an error code of 0 */
+  PETSC_ERR_MAX_VALUE      = 100, /* this is always the one more than the largest error code */
+
+  /*
+    do not use, exist purely to make the enum bounds equal that of a regular int (so conversion
+    to int in main() is not undefined behavior)
+  */
+  PETSC_ERR_MIN_SIGNED_BOUND_DO_NOT_USE = INT_MIN,
+  PETSC_ERR_MAX_SIGNED_BOUND_DO_NOT_USE = INT_MAX
+} PETSC_ERROR_CODE_ENUM_NAME;
+
+#ifndef PETSC_USE_STRICT_PETSCERRORCODE
 typedef int PetscErrorCode;
 
-/*MC
+  /*
+  Needed so that C++ lambdas can deduce the return type as PetscErrorCode from
+  PetscFunctionReturn(PETSC_SUCCESS). Otherwise we get
 
+  error: return type '(unnamed enum at include/petscsystypes.h:50:1)' must match previous
+  return type 'int' when lambda expression has unspecified explicit return type
+  PetscFunctionReturn(PETSC_SUCCESS);
+  ^
+*/
+  #define PETSC_SUCCESS ((PetscErrorCode)0)
+#endif
+
+#undef PETSC_ERROR_CODE_NODISCARD
+#undef PETSC_ERROR_CODE_TYPEDEF
+#undef PETSC_ERROR_CODE_ENUM_NAME
+
+/*MC
     PetscClassId - A unique id used to identify each PETSc class.
 
-    Notes:
+    Level: developer
+
+    Note:
     Use `PetscClassIdRegister()` to obtain a new value for a new class being created. Usually
          XXXInitializePackage() calls it for each class it defines.
 
-    Developer Notes:
-    Internal integer stored in the `_p_PetscObject` data structure.
-         These are all computed by an offset from the lowest one, `PETSC_SMALLEST_CLASSID`.
-
-    Level: developer
+    Developer Note:
+    Internal integer stored in the `_p_PetscObject` data structure. These are all computed by an offset from the lowest one, `PETSC_SMALLEST_CLASSID`.
 
 .seealso: `PetscClassIdRegister()`, `PetscLogEventRegister()`, `PetscHeaderCreate()`
 M*/
@@ -45,27 +171,31 @@ typedef int PetscClassId;
     Level: intermediate
 
     Notes:
-    This is always a 32 bit integer, sometimes it is the same as `PetscInt`, but if PETSc was built with --with-64-bit-indices but
+    This is always a 32 bit integer, sometimes it is the same as `PetscInt`, but if PETSc was built with `--with-64-bit-indices` but
            standard C/Fortran integers are 32 bit then this is NOT the same as `PetscInt`; it remains 32 bit.
 
     `PetscMPIIntCast`(a,&b) checks if the given `PetscInt` a will fit in a `PetscMPIInt`, if not it
       generates a `PETSC_ERR_ARG_OUTOFRANGE` error.
 
 .seealso: `PetscBLASInt`, `PetscInt`, `PetscMPIIntCast()`
-
 M*/
 typedef int PetscMPIInt;
 
+/* Limit MPI to 32-bits */
+enum {
+  PETSC_MPI_INT_MIN = INT_MIN,
+  PETSC_MPI_INT_MAX = INT_MAX
+};
+
 /*MC
-    PetscSizeT - datatype used to represent sizes in memory (like size_t)
+    PetscSizeT - datatype used to represent sizes in memory (like `size_t`)
 
     Level: intermediate
 
     Notes:
-    This is equivalent to size_t, but defined for consistency with Fortran, which lacks a native equivalent of size_t.
+    This is equivalent to `size_t`, but defined for consistency with Fortran, which lacks a native equivalent of `size_t`.
 
 .seealso: `PetscInt`, `PetscInt64`, `PetscCount`
-
 M*/
 typedef size_t PetscSizeT;
 
@@ -75,12 +205,11 @@ typedef size_t PetscSizeT;
     Level: intermediate
 
     Notes:
-    This is equivalent to ptrdiff_t, but defined for consistency with Fortran, which lacks a native equivalent of ptrdiff_t.
+    This is equivalent to `ptrdiff_t`, but defined for consistency with Fortran, which lacks a native equivalent of `ptrdiff_t`.
 
     Use `PetscCount_FMT` to format with `PetscPrintf()`, `printf()`, and related functions.
 
 .seealso: `PetscInt`, `PetscInt64`, `PetscSizeT`
-
 M*/
 typedef ptrdiff_t PetscCount;
 #define PetscCount_FMT "td"
@@ -102,14 +231,14 @@ typedef float PetscFloat;
 
 /*MC
   PetscInt - PETSc type that represents an integer, used primarily to
-      represent size of arrays and indexing into arrays. Its size can be configured with the option --with-64-bit-indices to be either 32-bit (default) or 64-bit.
-
-  Notes:
-  For MPI calls that require datatypes, use `MPIU_INT` as the datatype for `PetscInt`. It will automatically work correctly regardless of the size of PetscInt.
+      represent size of arrays and indexing into arrays. Its size can be configured with the option `--with-64-bit-indices` to be either 32-bit (default) or 64-bit.
 
   Level: beginner
 
-.seealso: `PetscBLASInt`, `PetscMPIInt`, `PetscReal`, `PetscScalar`, `PetscComplex`, `PetscInt`, `MPIU_REAL`, `MPIU_SCALAR`, `MPIU_COMPLEX`, `MPIU_INT`
+  Notes:
+  For MPI calls that require datatypes, use `MPIU_INT` as the datatype for `PetscInt`. It will automatically work correctly regardless of the size of `PetscInt`.
+
+.seealso: `PetscBLASInt`, `PetscMPIInt`, `PetscReal`, `PetscScalar`, `PetscComplex`, `PetscInt`, `MPIU_REAL`, `MPIU_SCALAR`, `MPIU_COMPLEX`, `MPIU_INT`, `PetscIntCast()`
 M*/
 
 #if defined(PETSC_HAVE_STDINT_H)
@@ -127,20 +256,47 @@ M*/
 
 #if defined(PETSC_HAVE_STDINT_H) && defined(PETSC_HAVE_INTTYPES_H) && defined(PETSC_HAVE_MPI_INT64_T) /* MPI_INT64_T is not guaranteed to be a macro */
 typedef int64_t PetscInt64;
+
+  #define PETSC_INT64_MIN INT64_MIN
+  #define PETSC_INT64_MAX INT64_MAX
+
 #elif (PETSC_SIZEOF_LONG_LONG == 8)
 typedef long long PetscInt64;
+
+  #define PETSC_INT64_MIN LLONG_MIN
+  #define PETSC_INT64_MAX LLONG_MAX
+
 #elif defined(PETSC_HAVE___INT64)
 typedef __int64 PetscInt64;
+
+  #define PETSC_INT64_MIN INT64_MIN
+  #define PETSC_INT64_MAX INT64_MAX
+
 #else
   #error "cannot determine PetscInt64 type"
 #endif
 
 #if defined(PETSC_USE_64BIT_INDICES)
 typedef PetscInt64 PetscInt;
+
+  #define PETSC_INT_MIN PETSC_INT64_MIN
+  #define PETSC_INT_MAX PETSC_INT64_MAX
+  #define PetscInt_FMT  PetscInt64_FMT
 #else
 typedef int       PetscInt;
+
+enum {
+  PETSC_INT_MIN = INT_MIN,
+  PETSC_INT_MAX = INT_MAX
+};
+
+  #define PetscInt_FMT "d"
 #endif
 
+#define PETSC_MIN_INT    PETSC_INT_MIN
+#define PETSC_MAX_INT    PETSC_INT_MAX
+#define PETSC_MAX_UINT16 65535
+
 #if defined(PETSC_HAVE_STDINT_H) && defined(PETSC_HAVE_INTTYPES_H) && defined(PETSC_HAVE_MPI_INT64_T) /* MPI_INT64_T is not guaranteed to be a macro */
   #define MPIU_INT64     MPI_INT64_T
   #define PetscInt64_FMT PRId64
@@ -157,75 +313,91 @@ typedef int       PetscInt;
 /*MC
    PetscBLASInt - datatype used to represent 'int' parameters to BLAS/LAPACK functions.
 
-   Notes:
-    Usually this is the same as `PetscIn`t, but if PETSc was built with --with-64-bit-indices but
-           standard C/Fortran integers are 32 bit then this may not be the same as `PetscInt`,
-           except on some BLAS/LAPACK implementations that support 64 bit integers see the notes below.
+   Level: intermediate
 
-    `PetscErrorCode` `PetscBLASIntCast`(a,&b) checks if the given `PetscInt` a will fit in a `PetscBLASInt`, if not it
-      generates a `PETSC_ERR_ARG_OUTOFRANGE` error
+   Notes:
+   Usually this is the same as `PetscInt`, but if PETSc was built with `--with-64-bit-indices` but
+   standard C/Fortran integers are 32 bit then this may not be the same as `PetscInt`,
+   except on some BLAS/LAPACK implementations that support 64 bit integers see the notes below.
+
+   `PetscErrorCode` `PetscBLASIntCast`(a,&b) checks if the given `PetscInt` a will fit in a `PetscBLASInt`, if not it
+    generates a `PETSC_ERR_ARG_OUTOFRANGE` error
 
    Installation Notes:
-    ./configure automatically determines the size of the integers used by BLAS/LAPACK except when --with-batch is used
-    in that situation one must know (by some other means) if the integers used by BLAS/LAPACK are 64 bit and if so pass the flag --known-64-bit-blas-indice
+    ./configure automatically determines the size of the integers used by BLAS/LAPACK except when `--with-batch` is used
+    in that situation one must know (by some other means) if the integers used by BLAS/LAPACK are 64 bit and if so pass the flag `--known-64-bit-blas-indices`
 
     MATLAB ships with BLAS and LAPACK that use 64 bit integers, for example if you run ./configure with, the option
-     --with-blaslapack-lib=[/Applications/MATLAB_R2010b.app/bin/maci64/libmwblas.dylib,/Applications/MATLAB_R2010b.app/bin/maci64/libmwlapack.dylib]
+     `--with-blaslapack-lib`=[/Applications/MATLAB_R2010b.app/bin/maci64/libmwblas.dylib,/Applications/MATLAB_R2010b.app/bin/maci64/libmwlapack.dylib]
 
-    MKL ships with both 32 and 64 bit integer versions of the BLAS and LAPACK. If you pass the flag -with-64-bit-blas-indices PETSc will link
-    against the 64 bit version, otherwise it use the 32 bit version
+    MKL ships with both 32 and 64 bit integer versions of the BLAS and LAPACK. If you pass the flag `-with-64-bit-blas-indices` PETSc will link
+    against the 64 bit version, otherwise it uses the 32 bit version
 
-    OpenBLAS can be built to use 64 bit integers. The ./configure options --download-openblas -with-64-bit-blas-indices will build a 64 bit integer version
+    OpenBLAS can be built to use 64 bit integers. The ./configure options `--download-openblas` `-with-64-bit-blas-indices` will build a 64 bit integer version
 
     External packages such as hypre, ML, SuperLU etc do not provide any support for passing 64 bit integers to BLAS/LAPACK so cannot
     be used with PETSc when PETSc links against 64 bit integer BLAS/LAPACK. ./configure will generate an error if you attempt to link PETSc against any of
     these external libraries while using 64 bit integer BLAS/LAPACK.
 
-   Level: intermediate
-
 .seealso: `PetscMPIInt`, `PetscInt`, `PetscBLASIntCast()`
-
 M*/
 #if defined(PETSC_HAVE_64BIT_BLAS_INDICES)
-  #define PetscBLASInt_FMT PetscInt64_FMT
 typedef PetscInt64 PetscBLASInt;
+
+  #define PETSC_BLAS_INT_MIN PETSC_INT64_MIN
+  #define PETSC_BLAS_INT_MAX PETSC_INT64_MAX
+  #define PetscBLASInt_FMT   PetscInt64_FMT
 #else
+typedef int PetscBLASInt;
+
+enum {
+  PETSC_BLAS_INT_MIN = INT_MIN,
+  PETSC_BLAS_INT_MAX = INT_MAX
+};
+
   #define PetscBLASInt_FMT "d"
-typedef int       PetscBLASInt;
 #endif
 
 /*MC
    PetscCuBLASInt - datatype used to represent 'int' parameters to cuBLAS/cuSOLVER functions.
 
-   Notes:
-    As of this writing PetscCuBLASInt is always the system `int`.
-
-    `PetscErrorCode` `PetscCuBLASIntCast`(a,&b) checks if the given `PetscInt` a will fit in a `PetscCuBLASInt`, if not it
-      generates a `PETSC_ERR_ARG_OUTOFRANGE` error
-
    Level: intermediate
 
-.seealso: `PetscBLASInt`, `PetscMPIInt`, `PetscInt`, `PetscCuBLASIntCast()`
+   Notes:
+   As of this writing `PetscCuBLASInt` is always the system `int`.
 
+  `PetscErrorCode` `PetscCuBLASIntCast`(a,&b) checks if the given `PetscInt` a will fit in a `PetscCuBLASInt`, if not it
+   generates a `PETSC_ERR_ARG_OUTOFRANGE` error
+
+.seealso: `PetscBLASInt`, `PetscMPIInt`, `PetscInt`, `PetscCuBLASIntCast()`
 M*/
 typedef int PetscCuBLASInt;
 
+enum {
+  PETSC_CUBLAS_INT_MIN = INT_MIN,
+  PETSC_CUBLAS_INT_MAX = INT_MAX
+};
+
 /*MC
    PetscHipBLASInt - datatype used to represent 'int' parameters to hipBLAS/hipSOLVER functions.
 
-   Notes:
-    As of this writing PetscHipBLASInt is always the system `int`.
-
-    PetscErrorCode PetscHipBLASIntCast(a,&b) checks if the given PetscInt a will fit in a PetscHipBLASInt, if not it
-      generates a PETSC_ERR_ARG_OUTOFRANGE error
-
    Level: intermediate
 
-.seealso: PetscBLASInt, PetscMPIInt, PetscInt, PetscHipBLASIntCast()
+   Notes:
+   As of this writing `PetscHipBLASInt` is always the system `int`.
 
+   `PetscErrorCode` `PetscHipBLASIntCast`(a,&b) checks if the given `PetscInt` a will fit in a `PetscHipBLASInt`, if not it
+   generates a `PETSC_ERR_ARG_OUTOFRANGE` error
+
+.seealso: PetscBLASInt, PetscMPIInt, PetscInt, PetscHipBLASIntCast()
 M*/
 typedef int PetscHipBLASInt;
 
+enum {
+  PETSC_HIPBLAS_INT_MIN = INT_MIN,
+  PETSC_HIPBLAS_INT_MAX = INT_MAX
+};
+
 /*E
     PetscBool  - Logical variable. Actually an enum in C and a logical in Fortran.
 
@@ -241,6 +413,7 @@ typedef enum {
   PETSC_FALSE,
   PETSC_TRUE
 } PetscBool;
+PETSC_EXTERN const char *const PetscBools[];
 
 /*E
     PetscBool3  - Ternary logical variable. Actually an enum in C and a 4 byte integer in Fortran.
@@ -250,7 +423,7 @@ typedef enum {
    Note:
    Should not be used with the if (flg) or if (!flg) syntax.
 
-.seealso: `PETSC_TRUE`, `PETSC_FALSE`, `PetscNot()`, `PETSC_BOOL3_TRUE`, `PETSC_BOOL3_FALSE`, `PETSC_BOOL3_UKNOWN`
+.seealso: `PETSC_TRUE`, `PETSC_FALSE`, `PetscNot()`, `PETSC_BOOL3_TRUE`, `PETSC_BOOL3_FALSE`, `PETSC_BOOL3_UNKNOWN`
 E*/
 typedef enum {
   PETSC_BOOL3_FALSE,
@@ -264,13 +437,13 @@ typedef enum {
 /*MC
    PetscReal - PETSc type that represents a real number version of `PetscScalar`
 
+   Level: beginner
+
    Notes:
    For MPI calls that require datatypes, use `MPIU_REAL` as the datatype for `PetscReal` and `MPIU_SUM`, `MPIU_MAX`, etc. for operations.
-          They will automatically work correctly regardless of the size of `PetscReal`.
+   They will automatically work correctly regardless of the size of `PetscReal`.
 
-          See `PetscScalar` for details on how to ./configure the size of `PetscReal`.
-
-   Level: beginner
+   See `PetscScalar` for details on how to ./configure the size of `PetscReal`.
 
 .seealso: `PetscScalar`, `PetscComplex`, `PetscInt`, `MPIU_REAL`, `MPIU_SCALAR`, `MPIU_COMPLEX`, `MPIU_INT`
 M*/
@@ -299,23 +472,23 @@ typedef __fp16 PetscReal;
    #include <petscsys.h>
    PetscComplex number = 1. + 2.*PETSC_i;
 
+   Level: beginner
+
    Notes:
    For MPI calls that require datatypes, use `MPIU_COMPLEX` as the datatype for `PetscComplex` and `MPIU_SUM` etc for operations.
           They will automatically work correctly regardless of the size of `PetscComplex`.
 
-          See PetscScalar for details on how to ./configure the size of `PetscReal`
+          See `PetscScalar` for details on how to ./configure the size of `PetscReal`
 
           Complex numbers are automatically available if PETSc was able to find a working complex implementation
 
-    Petsc has a 'fix' for complex numbers to support expressions such as std::complex<PetscReal> + `PetscInt`, which are not supported by the standard
-    C++ library, but are convenient for petsc users. If the C++ compiler is able to compile code in petsccxxcomplexfix.h (This is checked by
-    configure), we include petsccxxcomplexfix.h to provide this convenience.
+    PETSc has a 'fix' for complex numbers to support expressions such as `std::complex<PetscReal>` + `PetscInt`, which are not supported by the standard
+    C++ library, but are convenient for petsc users. If the C++ compiler is able to compile code in `petsccxxcomplexfix.h` (This is checked by
+    configure), we include `petsccxxcomplexfix.h` to provide this convenience.
 
     If the fix causes conflicts, or one really does not want this fix for a particular C++ file, one can define `PETSC_SKIP_CXX_COMPLEX_FIX`
     at the beginning of the C++ file to skip the fix.
 
-   Level: beginner
-
 .seealso: `PetscReal`, `PetscScalar`, `PetscComplex`, `PetscInt`, `MPIU_REAL`, `MPIU_SCALAR`, `MPIU_COMPLEX`, `MPIU_INT`, `PETSC_i`
 M*/
 #if !defined(PETSC_SKIP_COMPLEX)
@@ -384,13 +557,13 @@ typedef __complex128 PetscComplex;
 /*MC
    PetscScalar - PETSc type that represents either a double precision real number, a double precision
        complex number, a single precision real number, a __float128 real or complex or a __fp16 real - if the code is configured
-       with --with-scalar-type=real,complex --with-precision=single,double,__float128,__fp16
-
-   Notes:
-   For MPI calls that require datatypes, use `MPIU_SCALAR` as the datatype for `PetscScalar` and `MPIU_SUM`, etc for operations. They will automatically work correctly regardless of the size of `PetscScalar`.
+       with `--with-scalar-type`=real,complex `--with-precision`=single,double,__float128,__fp16
 
    Level: beginner
 
+   Note:
+   For MPI calls that require datatypes, use `MPIU_SCALAR` as the datatype for `PetscScalar` and `MPIU_SUM`, etc for operations. They will automatically work correctly regardless of the size of `PetscScalar`.
+
 .seealso: `PetscReal`, `PetscComplex`, `PetscInt`, `MPIU_REAL`, `MPIU_SCALAR`, `MPIU_COMPLEX`, `MPIU_INT`, `PetscRealPart()`, `PetscImaginaryPart()`
 M*/
 
@@ -405,25 +578,25 @@ typedef PetscReal PetscScalar;
 
    Level: beginner
 
-   For the array input:
-$   `PETSC_COPY_VALUES` - the array values are copied into new space, the user is free to reuse or delete the passed in array
-$   `PETSC_OWN_POINTER` - the array values are NOT copied, the object takes ownership of the array and will free it later, the user cannot change or
-$                       delete the array. The array MUST have been obtained with PetscMalloc(). Hence this mode cannot be used in Fortran.
-$   `PETSC_USE_POINTER` - the array values are NOT copied, the object uses the array but does NOT take ownership of the array. The user cannot use
-$                       the array but the user must delete the array after the object is destroyed.
-
-   For the PetscObject input:
-$   `PETSC_COPY_VALUES` - the input `PetscObject` is cloned into the aggregate `PetscObject`; the user is free to reuse/modify the input `PetscObject` without side effects.
-$   `PETSC_OWN_POINTER` - the input `PetscObject` is referenced by pointer (with reference count), thus should not be modified by the user. (Modification may cause errors or unintended side-effects in this or a future version of PETSc.)
-   For either case above, the input `PetscObject` should be destroyed by the user when no longer needed (the aggregate object increases its reference count).
-$   `PETSC_USE_POINTER` - invalid for `PetscObject` inputs.
+   Values for array input:
++   `PETSC_COPY_VALUES` - the array values are copied into new space, the user is free to reuse or delete the passed in array
+.   `PETSC_OWN_POINTER` - the array values are NOT copied, the object takes ownership of the array and will free it later, the user cannot change or
+                          delete the array. The array MUST have been obtained with `PetscMalloc()`. Hence this mode cannot be used in Fortran.
+-   `PETSC_USE_POINTER` - the array values are NOT copied, the object uses the array but does NOT take ownership of the array. The user cannot use
+                          the array but the user must delete the array after the object is destroyed.
 
+   Values for PetscObject:
++   `PETSC_COPY_VALUES` - the input `PetscObject` is cloned into the aggregate `PetscObject`; the user is free to reuse/modify the input `PetscObject` without side effects.
+.   `PETSC_OWN_POINTER` - the input `PetscObject` is referenced by pointer (with reference count), thus should not be modified by the user.
+                          increases its reference count).
+-   `PETSC_USE_POINTER` - invalid for `PetscObject` inputs.
 E*/
 typedef enum {
   PETSC_COPY_VALUES,
   PETSC_OWN_POINTER,
   PETSC_USE_POINTER
 } PetscCopyMode;
+PETSC_EXTERN const char *const PetscCopyModes[];
 
 /*MC
     PETSC_FALSE - False value of `PetscBool`
@@ -450,11 +623,11 @@ M*/
 /*MC
     PetscLogDouble - Used for logging times
 
-  Notes:
-  Contains double precision numbers that are not used in the numerical computations, but rather in logging, timing etc.
-
   Level: developer
 
+  Note:
+  Contains double precision numbers that are not used in the numerical computations, but rather in logging, timing etc.
+
 M*/
 typedef double PetscLogDouble;
 
@@ -475,11 +648,11 @@ typedef double PetscLogDouble;
    If you change any values in `PetscDatatype` make sure you update their usage in
    share/petsc/matlab/PetscBagRead.m and share/petsc/matlab/@PetscOpenSocket/read/write.m
 
-   TODO: Add PETSC_INT32 and remove use of improper PETSC_ENUM
+   TODO:
+   Add PETSC_INT32 and remove use of improper `PETSC_ENUM`
 
 .seealso: `PetscBinaryRead()`, `PetscBinaryWrite()`, `PetscDataTypeToMPIDataType()`,
           `PetscDataTypeGetSize()`
-
 E*/
 typedef enum {
   PETSC_DATATYPE_UNKNOWN = 0,
@@ -502,6 +675,7 @@ typedef enum {
   PETSC_INT64            = 17,
   PETSC_COUNT            = 18
 } PetscDataType;
+PETSC_EXTERN const char *const PetscDataTypes[];
 
 #if defined(PETSC_USE_REAL_SINGLE)
   #define PETSC_REAL PETSC_FLOAT
@@ -585,14 +759,15 @@ typedef struct _n_PetscFunctionList *PetscFunctionList;
 /*E
   PetscFileMode - Access mode for a file.
 
-  Level: beginner
+  Values:
++  `FILE_MODE_UNDEFINED` - initial invalid value
+.  `FILE_MODE_READ` - open a file at its beginning for reading
+.  `FILE_MODE_WRITE` - open a file at its beginning for writing (will create if the file does not exist)
+.  `FILE_MODE_APPEND` - open a file at end for writing
+.  `FILE_MODE_UPDATE` - open a file for updating, meaning for reading and writing
+-  `FILE_MODE_APPEND_UPDATE` - open a file for updating, meaning for reading and writing, at the end
 
-$  `FILE_MODE_UNDEFINED` - initial invalid value
-$  `FILE_MODE_READ` - open a file at its beginning for reading
-$  `FILE_MODE_WRITE` - open a file at its beginning for writing (will create if the file does not exist)
-$  `FILE_MODE_APPEND` - open a file at end for writing
-$  `FILE_MODE_UPDATE` - open a file for updating, meaning for reading and writing
-$  `FILE_MODE_APPEND_UPDATE` - open a file for updating, meaning for reading and writing, at the end
+  Level: beginner
 
 .seealso: `PetscViewerFileSetMode()`
 E*/
@@ -604,6 +779,7 @@ typedef enum {
   FILE_MODE_UPDATE,
   FILE_MODE_APPEND_UPDATE
 } PetscFileMode;
+PETSC_EXTERN const char *const PetscFileModes[];
 
 typedef void *PetscDLHandle;
 typedef enum {
@@ -625,9 +801,9 @@ S*/
 typedef struct _n_PetscObjectList *PetscObjectList;
 
 /*S
-     PetscDLLibrary - Linked list of dynamics libraries to search for functions
+     PetscDLLibrary - Linked list of dynamic libraries to search for functions
 
-   Level: advanced
+   Level: developer
 
 .seealso: `PetscDLLibraryOpen()`
 S*/
@@ -670,6 +846,11 @@ typedef struct _p_PetscRandom *PetscRandom;
 /*E
   PetscBinarySeekType - argument to `PetscBinarySeek()`
 
+  Values:
++  `PETSC_BINARY_SEEK_SET` - offset is an absolute location in the file
+.  `PETSC_BINARY_SEEK_CUR` - offset is an offset from the current location of the file pointer
+-  `PETSC_BINARY_SEEK_END` - offset is an offset from the end of the file
+
   Level: advanced
 
 .seealso: `PetscBinarySeek()`, `PetscBinarySynchronizedSeek()`
@@ -681,15 +862,16 @@ typedef enum {
 } PetscBinarySeekType;
 
 /*E
-    PetscBuildTwoSidedType - algorithm for setting up two-sided communication
+    PetscBuildTwoSidedType - algorithm for setting up two-sided communication for use with `PetscSF`
 
-$  `PETSC_BUILDTWOSIDED_ALLREDUCE` - classical algorithm using an MPI_Allreduce with
-$      a buffer of length equal to the communicator size. Not memory-scalable due to
-$      the large reduction size. Requires only MPI-1.
-$  `PETSC_BUILDTWOSIDED_IBARRIER` - nonblocking algorithm based on MPI_Issend and MPI_Ibarrier.
-$      Proved communication-optimal in Hoefler, Siebert, and Lumsdaine (2010). Requires MPI-3.
-$  `PETSC_BUILDTWOSIDED_REDSCATTER` - similar to above, but use more optimized function
-$      that only communicates the part of the reduction that is necessary.  Requires MPI-2.
+   Values:
++  `PETSC_BUILDTWOSIDED_ALLREDUCE` - classical algorithm using an `MPI_Allreduce()` with
+      a buffer of length equal to the communicator size. Not memory-scalable due to
+      the large reduction size. Requires only an MPI-1 implementation.
+.  `PETSC_BUILDTWOSIDED_IBARRIER` - nonblocking algorithm based on `MPI_Issend()` and `MPI_Ibarrier()`.
+      Proved communication-optimal in Hoefler, Siebert, and Lumsdaine (2010). Requires an MPI-3 implementation.
+-  `PETSC_BUILDTWOSIDED_REDSCATTER` - similar to above, but use more optimized function
+      that only communicates the part of the reduction that is necessary.  Requires an MPI-2 implementation.
 
    Level: developer
 
@@ -702,13 +884,31 @@ typedef enum {
   PETSC_BUILDTWOSIDED_REDSCATTER = 2
   /* Updates here must be accompanied by updates in finclude/petscsys.h and the string array in mpits.c */
 } PetscBuildTwoSidedType;
+PETSC_EXTERN const char *const PetscBuildTwoSidedTypes[];
 
 /* NOTE: If you change this, you must also change the values in src/vec/f90-mod/petscvec.h */
 /*E
-  InsertMode - Whether entries are inserted or added into vectors or matrices
+  InsertMode - How the entries are combined with the current values in the vectors or matrices
+
+  Values:
++  `NOT_SET_VALUES` - do not actually use the values
+.  `INSERT_VALUES` - replace the current values with the provided values, unless the index is marked as constrained by the `PetscSection`
+.  `ADD_VALUES` - add the values to the current values, unless the index is marked as constrained by the `PetscSection`
+.  `MAX_VALUES` - use the maximum of each current value and provided value
+.  `MIN_VALUES` - use the minimum of each current value and provided value
+.  `INSERT_ALL_VALUES` - insert, even if indices that are not marked as constrained by the `PetscSection`
+.  `ADD_ALL_VALUES` - add, even if indices that are not marked as constrained by the `PetscSection`
+.  `INSERT_BC_VALUES` - insert, but ignore indices that are not marked as constrained by the `PetscSection`
+-  `ADD_BC_VALUES` - add, but ignore indices that are not marked as constrained by the `PetscSection`
 
   Level: beginner
 
+  Note:
+  The `PetscSection` that determines the effects of the `InsertMode` values can be obtained by the `Vec` object with `VecGetDM()`
+  and `DMGetLocalSection()`.
+
+  Not all options are supported for all operations or PETSc object types.
+
 .seealso: `VecSetValues()`, `MatSetValues()`, `VecSetValue()`, `VecSetValuesBlocked()`,
           `VecSetValuesLocal()`, `VecSetValuesBlockedLocal()`, `MatSetValuesBlocked()`,
           `MatSetValuesBlockedLocal()`, `MatSetValuesLocal()`, `VecScatterBegin()`, `VecScatterEnd()`
@@ -733,7 +933,6 @@ typedef enum {
 .seealso: `InsertMode`, `VecSetValues()`, `MatSetValues()`, `VecSetValue()`, `VecSetValuesBlocked()`,
           `VecSetValuesLocal()`, `VecSetValuesBlockedLocal()`, `MatSetValuesBlocked()`, `ADD_VALUES`,
           `MatSetValuesBlockedLocal()`, `MatSetValuesLocal()`, `VecScatterBegin()`, `VecScatterEnd()`, `MAX_VALUES`
-
 M*/
 
 /*MC
@@ -745,7 +944,6 @@ M*/
 .seealso: `InsertMode`, `VecSetValues()`, `MatSetValues()`, `VecSetValue()`, `VecSetValuesBlocked()`,
           `VecSetValuesLocal()`, `VecSetValuesBlockedLocal()`, `MatSetValuesBlocked()`, `INSERT_VALUES`,
           `MatSetValuesBlockedLocal()`, `MatSetValuesLocal()`, `VecScatterBegin()`, `VecScatterEnd()`, `MAX_VALUES`
-
 M*/
 
 /*MC
@@ -754,7 +952,6 @@ M*/
     Level: beginner
 
 .seealso: `InsertMode`, `VecScatterBegin()`, `VecScatterEnd()`, `ADD_VALUES`, `INSERT_VALUES`
-
 M*/
 
 /*MC
@@ -763,43 +960,46 @@ M*/
     Level: beginner
 
 .seealso: `InsertMode`, `VecScatterBegin()`, `VecScatterEnd()`, `ADD_VALUES`, `INSERT_VALUES`
-
 M*/
 
 /*S
    PetscSubcomm - A decomposition of an MPI communicator into subcommunicators
 
-   Notes:
-   After a call to `PetscSubcommSetType()`, `PetscSubcommSetTypeGeneral()`, or `PetscSubcommSetFromOptions()` one may call
-$     `PetscSubcommChild()` returns the associated subcommunicator on this process
-$     `PetscSubcommContiguousParent()` returns a parent communitor but with all child of the same subcommunicator having contiguous rank
+   Values:
++   `PETSC_SUBCOMM_GENERAL` - similar to `MPI_Comm_split()` each process sets the new communicator (color) they will belong to and the order within that communicator
+.   `PETSC_SUBCOMM_CONTIGUOUS` - each new communicator contains a set of process with contiguous ranks in the original MPI communicator
+-   `PETSC_SUBCOMM_INTERLACED` - each new communictor contains a set of processes equally far apart in rank from the others in that new communicator
 
    Sample Usage:
 .vb
-       `PetscSubcommCreate()`
-       `PetscSubcommSetNumber()`
-       `PetscSubcommSetType`(`PETSC_SUBCOMM_INTERLACED`);
-       ccomm = `PetscSubcommChild()`
-       `PetscSubcommDestroy()`
+       PetscSubcommCreate()
+       PetscSubcommSetNumber()
+       PetscSubcommSetType(PETSC_SUBCOMM_INTERLACED);
+       ccomm = PetscSubcommChild()
+       PetscSubcommDestroy()
+.ve
+
+   Example:
+   Consider a communicator with six processes split into 3 subcommunicators.
+.vb
+   PETSC_SUBCOMM_CONTIGUOUS - the first communicator contains rank 0,1  the second rank 2,3 and the third rank 4,5 in the original ordering of the original communicator
+   PETSC_SUBCOMM_INTERLACED - the first communicator contains rank 0,3, the second 1,4 and the third 2,5
 .ve
 
    Level: advanced
 
-   Notes:
-$   `PETSC_SUBCOMM_GENERAL` - similar to `MPI_Comm_split()` each process sets the new communicator (color) they will belong to and the order within that communicator
-$   `PETSC_SUBCOMM_CONTIGUOUS` - each new communicator contains a set of process with contiguous ranks in the original MPI communicator
-$   `PETSC_SUBCOMM_INTERLACED` - each new communictor contains a set of processes equally far apart in rank from the others in that new communicator
-
-   Example: Consider a communicator with six processes split into 3 subcommunicators.
-$     `PETSC_SUBCOMM_CONTIGUOUS` - the first communicator contains rank 0,1  the second rank 2,3 and the third rank 4,5 in the original ordering of the original communicator
-$     `PETSC_SUBCOMM_INTERLACED` - the first communicator contains rank 0,3, the second 1,4 and the third 2,5
+   Note:
+   After a call to `PetscSubcommSetType()`, `PetscSubcommSetTypeGeneral()`, or `PetscSubcommSetFromOptions()` one may call
+.vb
+     PetscSubcommChild() returns the associated subcommunicator on this process
+     PetscSubcommContiguousParent() returns a parent communitor but with all child of the same subcommunicator having contiguous rank
+.ve
 
    Developer Note:
    This is used in objects such as `PCREDUNDANT` to manage the subcommunicators on which the redundant computations
    are performed.
 
 .seealso: `PetscSubcommCreate()`, `PetscSubcommSetNumber()`, `PetscSubcommSetType()`, `PetscSubcommView()`, `PetscSubcommSetFromOptions()`
-
 S*/
 typedef struct _n_PetscSubcomm *PetscSubcomm;
 typedef enum {
@@ -807,6 +1007,7 @@ typedef enum {
   PETSC_SUBCOMM_CONTIGUOUS = 1,
   PETSC_SUBCOMM_INTERLACED = 2
 } PetscSubcommType;
+PETSC_EXTERN const char *const PetscSubcommTypes[];
 
 /*S
      PetscHeap - A simple class for managing heaps
