@@ -49,7 +49,7 @@ static PetscErrorCode DMView_DA_3d(DM da, PetscViewer viewer)
       PetscCall(PetscFree(nz));
       navg = navg / size;
       PetscCall(PetscViewerASCIIPrintf(viewer, "  Load Balance - Grid Points: Min %" PetscInt_FMT "  avg %" PetscInt_FMT "  max %" PetscInt_FMT "\n", nmin, navg, nmax));
-      PetscFunctionReturn(0);
+      PetscFunctionReturn(PETSC_SUCCESS);
     }
     if (format != PETSC_VIEWER_ASCII_VTK_DEPRECATED && format != PETSC_VIEWER_ASCII_VTK_CELL_DEPRECATED && format != PETSC_VIEWER_ASCII_GLVIS) {
       DMDALocalInfo info;
@@ -84,7 +84,7 @@ static PetscErrorCode DMView_DA_3d(DM da, PetscViewer viewer)
 
     PetscCall(PetscViewerDrawGetDraw(viewer, 0, &draw));
     PetscCall(PetscDrawIsNull(draw, &isnull));
-    if (isnull) PetscFunctionReturn(0);
+    if (isnull) PetscFunctionReturn(PETSC_SUCCESS);
 
     PetscCall(PetscDrawCheckResizedWindow(draw));
     PetscCall(PetscDrawClear(draw));
@@ -158,7 +158,7 @@ static PetscErrorCode DMView_DA_3d(DM da, PetscViewer viewer)
         xmax = (dd->M + 1) * plane * dd->w + dd->M * dd->w;
         for (y = ymin; y < ymax; y++) {
           for (x = xmin + dd->Xs; x < xmin + dd->Xe; x += dd->w) {
-            sprintf(node, "%d", (int)(idx[base]));
+            PetscCall(PetscSNPrintf(node, PETSC_STATIC_ARRAY_LENGTH(node), "%" PetscInt_FMT, idx[base]));
             ycoord = y;
             /*Keep y wrap around points on drawing */
             if (y < 0) ycoord = dd->N + y;
@@ -186,7 +186,7 @@ static PetscErrorCode DMView_DA_3d(DM da, PetscViewer viewer)
     PetscCall(DMView_DA_Matlab(da, viewer));
 #endif
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DMSetUp_DA_3D(DM da)
@@ -1431,7 +1431,7 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
   da->ops->view = DMView_DA_3d;
   dd->ltol      = NULL;
   dd->ao        = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1443,11 +1443,11 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
    Input Parameters:
 +  comm - MPI communicator
 .  bx,by,bz - type of ghost nodes the array have.
-         Use one of DM_BOUNDARY_NONE, DM_BOUNDARY_GHOSTED, DM_BOUNDARY_PERIODIC.
-.  stencil_type - Type of stencil (DMDA_STENCIL_STAR or DMDA_STENCIL_BOX)
+         Use one of `DM_BOUNDARY_NONE`, `DM_BOUNDARY_GHOSTED`, `DM_BOUNDARY_PERIODIC`.
+.  stencil_type - Type of stencil (`DMDA_STENCIL_STAR` or `DMDA_STENCIL_BOX`)
 .  M,N,P - global dimension in each direction of the array
 .  m,n,p - corresponding number of processors in each dimension
-           (or PETSC_DECIDE to have calculated)
+           (or `PETSC_DECIDE` to have calculated)
 .  dof - number of degrees of freedom per node
 .  s - stencil width
 -  lx, ly, lz - arrays containing the number of nodes in each cell along
@@ -1459,8 +1459,8 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
    Output Parameter:
 .  da - the resulting distributed array object
 
-   Options Database Key:
-+  -dm_view - Calls DMView() at the conclusion of DMDACreate3d()
+   Options Database Keys:
++  -dm_view - Calls `DMView()` at the conclusion of `DMDACreate3d()`
 .  -da_grid_x <nx> - number of grid points in x direction
 .  -da_grid_y <ny> - number of grid points in y direction
 .  -da_grid_z <nz> - number of grid points in z direction
@@ -1475,24 +1475,23 @@ PetscErrorCode DMSetUp_DA_3D(DM da)
    Level: beginner
 
    Notes:
-   The stencil type DMDA_STENCIL_STAR with width 1 corresponds to the
-   standard 7-pt stencil, while DMDA_STENCIL_BOX with width 1 denotes
+   The stencil type `DMDA_STENCIL_STAR` with width 1 corresponds to the
+   standard 7-pt stencil, while `DMDA_STENCIL_BOX` with width 1 denotes
    the standard 27-pt stencil.
 
-   The array data itself is NOT stored in the DMDA, it is stored in Vec objects;
-   The appropriate vector objects can be obtained with calls to DMCreateGlobalVector()
-   and DMCreateLocalVector() and calls to VecDuplicate() if more are needed.
+   The array data itself is NOT stored in the `DMDA`, it is stored in `Vec` objects;
+   The appropriate vector objects can be obtained with calls to `DMCreateGlobalVector()`
+   and `DMCreateLocalVector()` and calls to `VecDuplicate()` if more are needed.
 
-   You must call DMSetUp() after this call before using this DM.
+   You must call `DMSetUp()` after this call before using this `DM`.
 
-   If you wish to use the options database to change values in the DMDA call DMSetFromOptions() after this call
-   but before DMSetUp().
+   If you wish to use the options database to change values in the `DMDA` call `DMSetFromOptions()` after this call
+   but before `DMSetUp()`.
 
-.seealso: `DMDestroy()`, `DMView()`, `DMDACreate1d()`, `DMDACreate2d()`, `DMGlobalToLocalBegin()`, `DMDAGetRefinementFactor()`,
+.seealso: `DM`, `DMDA`, `DMDestroy()`, `DMView()`, `DMDACreate1d()`, `DMDACreate2d()`, `DMGlobalToLocalBegin()`, `DMDAGetRefinementFactor()`,
           `DMGlobalToLocalEnd()`, `DMLocalToGlobalBegin()`, `DMLocalToLocalBegin()`, `DMLocalToLocalEnd()`, `DMDASetRefinementFactor()`,
           `DMDAGetInfo()`, `DMCreateGlobalVector()`, `DMCreateLocalVector()`, `DMDACreateNaturalVector()`, `DMLoad()`, `DMDAGetOwnershipRanges()`,
           `DMStagCreate3d()`
-
 @*/
 PetscErrorCode DMDACreate3d(MPI_Comm comm, DMBoundaryType bx, DMBoundaryType by, DMBoundaryType bz, DMDAStencilType stencil_type, PetscInt M, PetscInt N, PetscInt P, PetscInt m, PetscInt n, PetscInt p, PetscInt dof, PetscInt s, const PetscInt lx[], const PetscInt ly[], const PetscInt lz[], DM *da)
 {
@@ -1506,5 +1505,5 @@ PetscErrorCode DMDACreate3d(MPI_Comm comm, DMBoundaryType bx, DMBoundaryType by,
   PetscCall(DMDASetStencilType(*da, stencil_type));
   PetscCall(DMDASetStencilWidth(*da, s));
   PetscCall(DMDASetOwnershipRanges(*da, lx, ly, lz));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
