@@ -1,41 +1,47 @@
 
 #include <petsc/private/dmdaimpl.h> /*I   "petscdmda.h"   I*/
 
+/*MC
+  DMDAVecGetArrayF90 - check Fortran Notes at `DMDAVecGetArray()`
+
+  Level: intermediate
+M*/
+
 /*@C
    DMDAVecGetArray - Returns a multiple dimension array that shares data with
       the underlying vector and is indexed using the global dimensions.
 
-   Logically collective on da
+   Logically Collective
 
    Input Parameters:
 +  da - the distributed array
--  vec - the vector, either a vector the same size as one obtained with DMCreateGlobalVector() or DMCreateLocalVector()
+-  vec - the vector, either a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
    Output Parameter:
 .  array - the array
 
+  Level: intermediate
+
    Notes:
-    Call DMDAVecRestoreArray() once you have finished accessing the vector entries.
+    Call `DMDAVecRestoreArray()` once you have finished accessing the vector entries.
 
     In C, the indexing is "backwards" from what expects: array[k][j][i] NOT array[i][j][k]!
 
     If vec is a local vector (obtained with DMCreateLocalVector() etc) then the ghost point locations are accessible. If it is
     a global vector then the ghost points are not accessible. Of course with the local vector you will have had to do the
 
-    appropriate DMGlobalToLocalBegin() and DMGlobalToLocalEnd() to have correct values in the ghost locations.
+    appropriate `DMGlobalToLocalBegin()` and `DMGlobalToLocalEnd()` to have correct values in the ghost locations.
 
   Fortran Notes:
-    From Fortran use DMDAVecGetArrayF90() and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
-       dimension. For a DMDA created with a dof of 1 use the dimension of the DMDA, for a DMDA created with a dof greater than 1 use one more than the
-       dimension of the DMDA. The order of the indices is array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) (when dof is 1) otherwise
-       array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) where the values are obtained from
-       DMDAGetCorners() for a global array or DMDAGetGhostCorners() for a local array. Include petsc/finclude/petscdmda.h90 to access this routine.
+  Use `DMDAVecGetArrayF90()` and pass for the array type `PetscScalar`,pointer :: array(:,...,:) of the appropriate
+  dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
+  dimension of the `DMDA`.
 
-  Due to bugs in the compiler DMDAVecGetArrayF90() does not work with gfortran versions before 4.5
+  The order of the indices is array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) (when dof is 1) otherwise
+  array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) where the values are obtained from
+  `DMDAGetCorners()` for a global array or `DMDAGetGhostCorners()` for a local array.
 
-  Level: intermediate
-
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecRestoreArrayDOF()`
+.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecRestoreArrayDOF()`
           `DMDAVecGetArrayDOF()`, `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`,
           `DMStagVecGetArray()`
 @*/
@@ -69,26 +75,32 @@ PetscErrorCode DMDAVecGetArray(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecGetArray3d(vec, gzm, gym, gxm * dof, gzs, gys, gxs * dof, (PetscScalar ****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@
-   DMDAVecRestoreArray - Restores a multiple dimension array obtained with DMDAVecGetArray()
+/*MC
+  DMDAVecRestoreArrayF90 - check Fortran Notes at `DMDAVecRestoreArray()`
 
-   Logically collective on da
+  Level: intermediate
+M*/
+
+/*@
+   DMDAVecRestoreArray - Restores a multiple dimension array obtained with `DMDAVecGetArray()`
+
+   Logically Collective
 
    Input Parameters:
 +  da - the distributed array
 .  vec - the vector, either a vector the same size as one obtained with
-         DMCreateGlobalVector() or DMCreateLocalVector()
+         `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 -  array - the array, non-NULL pointer is zeroed
 
   Level: intermediate
 
-  Fortran Notes:
-    From Fortran use DMDAVecRestoreArayF90()
+  Fortran Note:
+  From Fortran use `DMDAVecRestoreArayF90()`
 
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`,
+.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `DMDAVecRestoreArayF90()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`,
           `DMDStagVecRestoreArray()`
 @*/
@@ -122,46 +134,52 @@ PetscErrorCode DMDAVecRestoreArray(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecRestoreArray3d(vec, gzm, gym, gxm * dof, gzs, gys, gxs * dof, (PetscScalar ****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+  DMDAVecGetArrayWriteF90 - check Fortran Notes at `DMDAVecGetArrayWrite()`
+
+  Level: intermediate
+M*/
+
 /*@C
    DMDAVecGetArrayWrite - Returns a multiple dimension array that shares data with
       the underlying vector and is indexed using the global dimensions.
 
-   Logically collective on Vec
+   Logically Collective
 
    Input Parameters:
 +  da - the distributed array
--  vec - the vector, either a vector the same size as one obtained with DMCreateGlobalVector() or DMCreateLocalVector()
+-  vec - the vector, either a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
    Output Parameter:
 .  array - the array
 
+  Level: intermediate
+
    Notes:
-    Call DMDAVecRestoreArray() once you have finished accessing the vector entries.
+    Call `DMDAVecRestoreArray()` once you have finished accessing the vector entries.
 
     In C, the indexing is "backwards" from what expects: array[k][j][i] NOT array[i][j][k]!
 
-    If vec is a local vector (obtained with DMCreateLocalVector() etc) then the ghost point locations are accessible. If it is
+    If vec is a local vector (obtained with `DMCreateLocalVector()` etc) then the ghost point locations are accessible. If it is
     a global vector then the ghost points are not accessible. Of course with the local vector you will have had to do the
+    appropriate `DMGlobalToLocalBegin()` and `DMGlobalToLocalEnd()` to have correct values in the ghost locations.
 
-    appropriate DMGlobalToLocalBegin() and DMGlobalToLocalEnd() to have correct values in the ghost locations.
+   Fortran Notes:
+   From Fortran use `DMDAVecGetArrayWriteF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
+   dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
+   dimension of the `DMDA`.
 
-  Fortran Notes:
-    From Fortran use DMDAVecGetArrayF90() and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
-       dimension. For a DMDA created with a dof of 1 use the dimension of the DMDA, for a DMDA created with a dof greater than 1 use one more than the
-       dimension of the DMDA. The order of the indices is array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) (when dof is 1) otherwise
-       array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) where the values are obtained from
-       DMDAGetCorners() for a global array or DMDAGetGhostCorners() for a local array. Include petsc/finclude/petscdmda.h90 to access this routine.
+   The order of the indices is array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) (when dof is 1) otherwise
+   array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) where the values are obtained from
+   `DMDAGetCorners()` for a global array or `DMDAGetGhostCorners()` for a local array.
 
-  Due to bugs in the compiler DMDAVecGetArrayF90() does not work with gfortran versions before 4.5
+  Developer Note:
+  This has code duplication with `DMDAVecGetArray()` and `DMDAVecGetArrayRead()`
 
-  Level: intermediate
-
-  Developer Notes: This has code duplication with DMDAVecGetArray() and DMDAVecGetArrayRead()
-
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecRestoreArrayDOF()`
+.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecRestoreArrayDOF()`
           `DMDAVecGetArrayDOF()`, `DMDAVecGetArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`
 @*/
 PetscErrorCode DMDAVecGetArrayWrite(DM da, Vec vec, void *array)
@@ -174,7 +192,7 @@ PetscErrorCode DMDAVecGetArrayWrite(DM da, Vec vec, void *array)
   PetscValidPointer(array, 3);
   if (da->localSection) {
     PetscCall(VecGetArrayWrite(vec, (PetscScalar **)array));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCall(DMDAGetCorners(da, &xs, &ys, &zs, &xm, &ym, &zm));
   PetscCall(DMDAGetGhostCorners(da, &gxs, &gys, &gzs, &gxm, &gym, &gzm));
@@ -198,26 +216,32 @@ PetscErrorCode DMDAVecGetArrayWrite(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecGetArray3dWrite(vec, gzm, gym, gxm * dof, gzs, gys, gxs * dof, (PetscScalar ****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@
-   DMDAVecRestoreArrayWrite - Restores a multiple dimension array obtained with DMDAVecGetArrayWrite()
+/*MC
+  DMDAVecRestoreArrayWriteF90 - check Fortran Notes at `DMDAVecRestoreArrayWrite()`
 
-   Logically collective on Vec
+  Level: intermediate
+M*/
+
+/*@
+   DMDAVecRestoreArrayWrite - Restores a multiple dimension array obtained with `DMDAVecGetArrayWrite()`
+
+   Logically Collective
 
    Input Parameters:
 +  da - the distributed array
 .  vec - the vector, either a vector the same size as one obtained with
-         DMCreateGlobalVector() or DMCreateLocalVector()
+         `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 -  array - the array, non-NULL pointer is zeroed
 
   Level: intermediate
 
-  Fortran Notes:
-    From Fortran use DMDAVecRestoreArayF90()
+  Fortran Note:
+  Use `DMDAVecRestoreArayWriteF90()`
 
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArrayWrite()`,
+.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArrayWrite()`,
           `DMDAVecGetArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`
 @*/
 PetscErrorCode DMDAVecRestoreArrayWrite(DM da, Vec vec, void *array)
@@ -230,7 +254,7 @@ PetscErrorCode DMDAVecRestoreArrayWrite(DM da, Vec vec, void *array)
   PetscValidPointer(array, 3);
   if (da->localSection) {
     PetscCall(VecRestoreArray(vec, (PetscScalar **)array));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCall(DMDAGetCorners(da, &xs, &ys, &zs, &xm, &ym, &zm));
   PetscCall(DMDAGetGhostCorners(da, &gxs, &gys, &gzs, &gxm, &gym, &gzm));
@@ -254,34 +278,40 @@ PetscErrorCode DMDAVecRestoreArrayWrite(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecRestoreArray3dWrite(vec, gzm, gym, gxm * dof, gzs, gys, gxs * dof, (PetscScalar ****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    DMDAVecGetArrayDOF - Returns a multiple dimension array that shares data with
       the underlying vector and is indexed using the global dimensions.
 
-   Logically collective
+   Logically Collective
 
    Input Parameters:
 +  da - the distributed array
 -  vec - the vector, either a vector the same size as one obtained with
-         DMCreateGlobalVector() or DMCreateLocalVector()
+         `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
    Output Parameter:
 .  array - the array
 
+  Level: intermediate
+
    Notes:
-    Call DMDAVecRestoreArrayDOF() once you have finished accessing the vector entries.
+    Call `DMDAVecRestoreArrayDOF()` once you have finished accessing the vector entries.
 
     In C, the indexing is "backwards" from what expects: array[k][j][i][DOF] NOT array[i][j][k][DOF]!
 
-    In Fortran 90 you do not need a version of DMDAVecRestoreArrayDOF() just use  DMDAVecRestoreArrayF90() and declare your array with one higher dimension,
-    see src/dm/tutorials/ex11f90.F
+   Fortran Notes:
+    Use `DMDAVecGetArrayF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
+   dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
+   dimension of the `DMDA`.
 
-  Level: intermediate
+   The order of the indices is array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) (when dof is 1) otherwise
+   array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) where the values are obtained from
+   `DMDAGetCorners()` for a global array or `DMDAGetGhostCorners()` for a local array.
 
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecRestoreArrayDOF()`,
+.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecRestoreArrayDOF()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`, `DMDAVecGetArrayDOFRead()`
 @*/
 PetscErrorCode DMDAVecGetArrayDOF(DM da, Vec vec, void *array)
@@ -311,23 +341,26 @@ PetscErrorCode DMDAVecGetArrayDOF(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecGetArray4d(vec, gzm, gym, gxm, dof, gzs, gys, gxs, 0, (PetscScalar *****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   DMDAVecRestoreArrayDOF - Restores a multiple dimension array obtained with DMDAVecGetArrayDOF()
+   DMDAVecRestoreArrayDOF - Restores a multiple dimension array obtained with `DMDAVecGetArrayDOF()`
 
-   Logically collective
+   Logically Collective
 
    Input Parameters:
 +  da - the distributed array
 .  vec - the vector, either a vector the same size as one obtained with
-         DMCreateGlobalVector() or DMCreateLocalVector()
+         `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 -  array - the array
 
   Level: intermediate
 
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
+  Fortran Note:
+  Use `DMDAVecRestoreArayF90()`
+
+.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`
 @*/
 PetscErrorCode DMDAVecRestoreArrayDOF(DM da, Vec vec, void *array)
@@ -357,44 +390,49 @@ PetscErrorCode DMDAVecRestoreArrayDOF(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecRestoreArray4d(vec, gzm, gym, gxm, dof, gzs, gys, gxs, 0, (PetscScalar *****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+  DMDAVecGetArrayReadF90 - check Fortran Notes at `DMDAVecGetArrayRead()`
+
+  Level: intermediate
+M*/
+
 /*@C
    DMDAVecGetArrayRead - Returns a multiple dimension array that shares data with
       the underlying vector and is indexed using the global dimensions.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  da - the distributed array
--  vec - the vector, either a vector the same size as one obtained with DMCreateGlobalVector() or DMCreateLocalVector()
+-  vec - the vector, either a vector the same size as one obtained with `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
    Output Parameter:
 .  array - the array
 
+  Level: intermediate
+
    Notes:
-    Call DMDAVecRestoreArrayRead() once you have finished accessing the vector entries.
+    Call `DMDAVecRestoreArrayRead()` once you have finished accessing the vector entries.
 
     In C, the indexing is "backwards" from what expects: array[k][j][i] NOT array[i][j][k]!
 
-    If vec is a local vector (obtained with DMCreateLocalVector() etc) then the ghost point locations are accessible. If it is
+    If vec is a local vector (obtained with `DMCreateLocalVector()` etc) then the ghost point locations are accessible. If it is
     a global vector then the ghost points are not accessible. Of course with the local vector you will have had to do the
-
-    appropriate DMGlobalToLocalBegin() and DMGlobalToLocalEnd() to have correct values in the ghost locations.
+    appropriate `DMGlobalToLocalBegin()` and `DMGlobalToLocalEnd()` to have correct values in the ghost locations.
 
   Fortran Notes:
-    From Fortran use DMDAVecGetArrayReadF90() and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
-       dimension. For a DMDA created with a dof of 1 use the dimension of the DMDA, for a DMDA created with a dof greater than 1 use one more than the
-       dimension of the DMDA. The order of the indices is array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) (when dof is 1) otherwise
-       array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) where the values are obtained from
-       DMDAGetCorners() for a global array or DMDAGetGhostCorners() for a local array. Include petsc/finclude/petscdmda.h90 to access this routine.
+  Use `DMDAVecGetArrayReadF90()` and pass for the array type `PetscScalar`,pointer :: array(:,...,:) of the appropriate
+  dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
+  dimension of the `DMDA`.
 
-  Due to bugs in the compiler DMDAVecGetArrayReadF90() does not work with gfortran versions before 4.5
+  The order of the indices is array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) (when dof is 1) otherwise
+  array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) where the values are obtained from
+  `DMDAGetCorners()` for a global array or `DMDAGetGhostCorners()` for a local array.
 
-  Level: intermediate
-
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArrayRead()`, `DMDAVecRestoreArrayDOF()`
+.seealso: `DM`, `DMDA`, `DMDAVecGetArrayReadF90()`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArrayRead()`, `DMDAVecRestoreArrayDOF()`
           `DMDAVecGetArrayDOF()`, `DMDAVecGetArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`,
           `DMStagVecGetArrayRead()`
 @*/
@@ -428,26 +466,32 @@ PetscErrorCode DMDAVecGetArrayRead(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecGetArray3dRead(vec, gzm, gym, gxm * dof, gzs, gys, gxs * dof, (PetscScalar ****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*@
-   DMDAVecRestoreArrayRead - Restores a multiple dimension array obtained with DMDAVecGetArrayRead()
+/*MC
+  DMDAVecRestoreArrayReadF90 - check Fortran Notes at `DMDAVecRestoreArrayRead()`
 
-   Not collective
+  Level: intermediate
+M*/
+
+/*@
+   DMDAVecRestoreArrayRead - Restores a multiple dimension array obtained with `DMDAVecGetArrayRead()`
+
+   Not Collective
 
    Input Parameters:
 +  da - the distributed array
 .  vec - the vector, either a vector the same size as one obtained with
-         DMCreateGlobalVector() or DMCreateLocalVector()
+         `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 -  array - the array, non-NULL pointer is zeroed
 
   Level: intermediate
 
-  Fortran Notes:
-    From Fortran use DMDAVecRestoreArrayReadF90()
+  Fortran Note:
+  Use `DMDAVecRestoreArrayReadF90()`
 
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArrayRead()`,
+.seealso: `DM`, `DMDA`, `DMDAVecRestoreArrayReadF90()`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArrayRead()`,
           `DMDAVecGetArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`,
           `DMStagVecRestoreArrayRead()`
 @*/
@@ -481,7 +525,7 @@ PetscErrorCode DMDAVecRestoreArrayRead(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecRestoreArray3dRead(vec, gzm, gym, gxm * dof, gzs, gys, gxs * dof, (PetscScalar ****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -493,22 +537,28 @@ PetscErrorCode DMDAVecRestoreArrayRead(DM da, Vec vec, void *array)
    Input Parameters:
 +  da - the distributed array
 -  vec - the vector, either a vector the same size as one obtained with
-         DMCreateGlobalVector() or DMCreateLocalVector()
+         `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
    Output Parameter:
 .  array - the array
 
-   Notes:
-    Call DMDAVecRestoreArrayDOFRead() once you have finished accessing the vector entries.
-
-    In C, the indexing is "backwards" from what expects: array[k][j][i][DOF] NOT array[i][j][k][DOF]!
-
-    In Fortran 90 you do not need a version of DMDAVecRestoreArrayDOF() just use  DMDAVecRestoreArrayReadF90() and declare your array with one higher dimension,
-    see src/dm/tutorials/ex11f90.F
-
   Level: intermediate
 
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`,
+   Notes:
+   Call `DMDAVecRestoreArrayDOFRead()` once you have finished accessing the vector entries.
+
+   In C, the indexing is "backwards" from what expects: array[k][j][i][DOF] NOT array[i][j][k][DOF]!
+
+   Fortran Note:
+   Use  `DMDAVecGetArrayReadF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
+   dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
+   dimension of the `DMDA`.
+
+   The order of the indices is array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) (when dof is 1) otherwise
+   array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) where the values are obtained from
+   `DMDAGetCorners()` for a global array or `DMDAGetGhostCorners()` for a local array.
+
+.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`
 @*/
 PetscErrorCode DMDAVecGetArrayDOFRead(DM da, Vec vec, void *array)
@@ -538,23 +588,26 @@ PetscErrorCode DMDAVecGetArrayDOFRead(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecGetArray4dRead(vec, gzm, gym, gxm, dof, gzs, gys, gxs, 0, (PetscScalar *****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   DMDAVecRestoreArrayDOFRead - Restores a multiple dimension array obtained with DMDAVecGetArrayDOFRead()
+   DMDAVecRestoreArrayDOFRead - Restores a multiple dimension array obtained with `DMDAVecGetArrayDOFRead()`
 
    Not Collective
 
    Input Parameters:
 +  da - the distributed array
 .  vec - the vector, either a vector the same size as one obtained with
-         DMCreateGlobalVector() or DMCreateLocalVector()
+         `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 -  array - the array
 
   Level: intermediate
 
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
+  Fortran Note:
+  Use `DMDAVecRestoreArrayReadF90()`
+
+.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayRead()`, `DMDAVecRestoreArrayRead()`
 @*/
 PetscErrorCode DMDAVecRestoreArrayDOFRead(DM da, Vec vec, void *array)
@@ -584,7 +637,7 @@ PetscErrorCode DMDAVecRestoreArrayDOFRead(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecRestoreArray4dRead(vec, gzm, gym, gxm, dof, gzs, gys, gxs, 0, (PetscScalar *****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -596,22 +649,28 @@ PetscErrorCode DMDAVecRestoreArrayDOFRead(DM da, Vec vec, void *array)
    Input Parameters:
 +  da - the distributed array
 -  vec - the vector, either a vector the same size as one obtained with
-         DMCreateGlobalVector() or DMCreateLocalVector()
+         `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 
    Output Parameter:
 .  array - the array
 
+   Level: intermediate
+
    Notes:
-    Call DMDAVecRestoreArrayDOFWrite() once you have finished accessing the vector entries.
+    Call `DMDAVecRestoreArrayDOFWrite()` once you have finished accessing the vector entries.
 
     In C, the indexing is "backwards" from what expects: array[k][j][i][DOF] NOT array[i][j][k][DOF]!
 
-    In Fortran 90 you do not need a version of DMDAVecRestoreArrayDOF() just use  DMDAVecRestoreArrayWriteF90() and declare your array with one higher dimension,
-    see src/dm/tutorials/ex11f90.F
+   Fortran Note:
+   Use  `DMDAVecGetArrayWriteF90()` and pass for the array type PetscScalar,pointer :: array(:,...,:) of the appropriate
+   dimension. For a `DMDA` created with a dof of 1 use the dimension of the `DMDA`, for a `DMDA` created with a dof greater than 1 use one more than the
+   dimension of the `DMDA`.
 
-  Level: intermediate
+   The order of the indices is array(xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) (when dof is 1) otherwise
+   array(0:dof-1,xs:xs+xm-1,ys:ys+ym-1,zs:zs+zm-1) where the values are obtained from
+   `DMDAGetCorners()` for a global array or `DMDAGetGhostCorners()` for a local array.
 
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`,
+.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `DMDAVecRestoreArrayWriteF90()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`
 @*/
 PetscErrorCode DMDAVecGetArrayDOFWrite(DM da, Vec vec, void *array)
@@ -641,23 +700,26 @@ PetscErrorCode DMDAVecGetArrayDOFWrite(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecGetArray4dWrite(vec, gzm, gym, gxm, dof, gzs, gys, gxs, 0, (PetscScalar *****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   DMDAVecRestoreArrayDOFWrite - Restores a multiple dimension array obtained with DMDAVecGetArrayDOFWrite()
+   DMDAVecRestoreArrayDOFWrite - Restores a multiple dimension array obtained with `DMDAVecGetArrayDOFWrite()`
 
    Not Collective
 
    Input Parameters:
 +  da - the distributed array
 .  vec - the vector, either a vector the same size as one obtained with
-         DMCreateGlobalVector() or DMCreateLocalVector()
+         `DMCreateGlobalVector()` or `DMCreateLocalVector()`
 -  array - the array
 
   Level: intermediate
 
-.seealso: `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
+  Fortran Note:
+  Use `DMDAVecRestoreArrayWriteF90()`
+
+.seealso: `DM`, `DMDA`, `DMDAGetGhostCorners()`, `DMDAGetCorners()`, `VecGetArray()`, `VecRestoreArray()`, `DMDAVecGetArray()`, `DMDAVecGetArrayDOF()`, `DMDAVecRestoreArrayDOF()`,
           `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`, `DMDAVecGetArrayWrite()`, `DMDAVecRestoreArrayWrite()`
 @*/
 PetscErrorCode DMDAVecRestoreArrayDOFWrite(DM da, Vec vec, void *array)
@@ -687,5 +749,5 @@ PetscErrorCode DMDAVecRestoreArrayDOFWrite(DM da, Vec vec, void *array)
   } else if (dim == 3) {
     PetscCall(VecRestoreArray4dWrite(vec, gzm, gym, gxm, dof, gzs, gys, gxs, 0, (PetscScalar *****)array));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_CORRUPT, "DMDA dimension not 1, 2, or 3, it is %" PetscInt_FMT, dim);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
