@@ -37,7 +37,7 @@ static PetscErrorCode DMPlexCreatePartitionerGraph_Overlap(DM dm, PetscInt heigh
     }
     /* Broken in parallel */
     if (rank) PetscCheck(!*numVertices, PETSC_COMM_SELF, PETSC_ERR_SUP, "Parallel partitioning of uninterpolated meshes not supported");
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   /* Always use FVM adjacency to create partitioner graph */
   PetscCall(DMGetBasicAdjacency(dm, &useCone, &useClosure));
@@ -105,7 +105,7 @@ static PetscErrorCode DMPlexCreatePartitionerGraph_Overlap(DM dm, PetscInt heigh
   if (adjacency) {
     *adjacency = vAdj;
   } else PetscCall(PetscFree(vAdj));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexCreatePartitionerGraph_Native(DM dm, PetscInt height, PetscInt *numVertices, PetscInt **offsets, PetscInt **adjacency, IS *globalNumbering)
@@ -139,7 +139,7 @@ static PetscErrorCode DMPlexCreatePartitionerGraph_Native(DM dm, PetscInt height
     }
     /* Broken in parallel */
     if (rank) PetscCheck(!*numVertices, PETSC_COMM_SELF, PETSC_ERR_SUP, "Parallel partitioning of uninterpolated meshes not supported");
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCall(DMGetPointSF(dm, &sfPoint));
   PetscCall(DMPlexGetHeightStratum(dm, height, &pStart, &pEnd));
@@ -310,7 +310,7 @@ static PetscErrorCode DMPlexCreatePartitionerGraph_Native(DM dm, PetscInt height
   PetscCall(PetscSectionDestroy(&section));
   PetscCall(ISRestoreIndices(cellNumbering, &cellNum));
   PetscCall(ISDestroy(&cellNumbering));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexCreatePartitionerGraph_ViaMat(DM dm, PetscInt height, PetscInt *numVertices, PetscInt **offsets, PetscInt **adjacency, IS *globalNumbering)
@@ -340,7 +340,7 @@ static PetscErrorCode DMPlexCreatePartitionerGraph_ViaMat(DM dm, PetscInt height
     }
     /* Broken in parallel */
     if (rank) PetscCheck(!*numVertices, PETSC_COMM_SELF, PETSC_ERR_SUP, "Parallel partitioning of uninterpolated meshes not supported");
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   /* Interpolated and parallel case */
 
@@ -394,7 +394,7 @@ static PetscErrorCode DMPlexCreatePartitionerGraph_ViaMat(DM dm, PetscInt height
   PetscCall(MatSetSizes(conn, floc, cloc, M, N));
   PetscCall(MatSetType(conn, MATMPIAIJ));
   PetscCall(DMPlexGetMaxSizes(dm, NULL, &lm));
-  PetscCallMPI(MPI_Allreduce(&lm, &m, 1, MPIU_INT, MPI_SUM, PetscObjectComm((PetscObject)dm)));
+  PetscCall(MPIU_Allreduce(&lm, &m, 1, MPIU_INT, MPI_SUM, PetscObjectComm((PetscObject)dm)));
   PetscCall(MatMPIAIJSetPreallocation(conn, m, NULL, m, NULL));
 
   /* Assemble matrix */
@@ -471,14 +471,16 @@ static PetscErrorCode DMPlexCreatePartitionerGraph_ViaMat(DM dm, PetscInt height
   PetscCall(MatRestoreRowIJ(conn, 0, PETSC_FALSE, PETSC_FALSE, &m, &ii, &jj, &flg));
   PetscCheck(flg, PETSC_COMM_SELF, PETSC_ERR_PLIB, "No IJ format");
   PetscCall(MatDestroy(&conn));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMPlexCreatePartitionerGraph - Create a CSR graph of point connections for the partitioner
 
+  Collective
+
   Input Parameters:
-+ dm      - The mesh DM dm
++ dm      - The mesh `DM`
 - height  - Height of the strata from which to construct the graph
 
   Output Parameters:
@@ -487,15 +489,16 @@ static PetscErrorCode DMPlexCreatePartitionerGraph_ViaMat(DM dm, PetscInt height
 . adjacency       - Point connectivity in the graph
 - globalNumbering - A map from the local cell numbering to the global numbering used in "adjacency".  Negative indicates that the cell is a duplicate from another process.
 
-  The user can control the definition of adjacency for the mesh using DMSetAdjacency(). They should choose the combination appropriate for the function
-  representation on the mesh. If requested, globalNumbering needs to be destroyed by the caller; offsets and adjacency need to be freed with PetscFree().
-
-  Options Database Keys:
+  Options Database Key:
 . -dm_plex_csr_alg <mat,graph,overlap> - Choose the algorithm for computing the CSR graph
 
   Level: developer
 
-.seealso: `PetscPartitionerGetType()`, `PetscPartitionerCreate()`, `DMSetAdjacency()`
+  Note:
+  The user can control the definition of adjacency for the mesh using `DMSetAdjacency()`. They should choose the combination appropriate for the function
+  representation on the mesh. If requested, globalNumbering needs to be destroyed by the caller; offsets and adjacency need to be freed with PetscFree().
+
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `PetscPartitionerGetType()`, `PetscPartitionerCreate()`, `DMSetAdjacency()`
 @*/
 PetscErrorCode DMPlexCreatePartitionerGraph(DM dm, PetscInt height, PetscInt *numVertices, PetscInt **offsets, PetscInt **adjacency, IS *globalNumbering)
 {
@@ -514,16 +517,16 @@ PetscErrorCode DMPlexCreatePartitionerGraph(DM dm, PetscInt height, PetscInt *nu
     PetscCall(DMPlexCreatePartitionerGraph_Overlap(dm, height, numVertices, offsets, adjacency, globalNumbering));
     break;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMPlexCreateNeighborCSR - Create a mesh graph (cell-cell adjacency) in parallel CSR format.
 
-  Collective on DM
+  Collective
 
   Input Parameters:
-+ dm - The DMPlex
++ dm - The `DMPLEX`
 - cellHeight - The height of mesh points to treat as cells (default should be 0)
 
   Output Parameters:
@@ -531,11 +534,12 @@ PetscErrorCode DMPlexCreatePartitionerGraph(DM dm, PetscInt height, PetscInt *nu
 . offsets     - The offset to the adjacency list for each cell
 - adjacency   - The adjacency list for all cells
 
-  Note: This is suitable for input to a mesh partitioner like ParMetis.
-
   Level: advanced
 
-.seealso: `DMPlexCreate()`
+  Note:
+  This is suitable for input to a mesh partitioner like ParMetis.
+
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `DMPlexCreate()`
 @*/
 PetscErrorCode DMPlexCreateNeighborCSR(DM dm, PetscInt cellHeight, PetscInt *numVertices, PetscInt **offsets, PetscInt **adjacency)
 {
@@ -556,7 +560,7 @@ PetscErrorCode DMPlexCreateNeighborCSR(DM dm, PetscInt cellHeight, PetscInt *num
     if (numVertices) *numVertices = 0;
     if (offsets) *offsets = NULL;
     if (adjacency) *adjacency = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   numCells  = cEnd - cStart;
   faceDepth = depth - cellHeight;
@@ -611,7 +615,7 @@ PetscErrorCode DMPlexCreateNeighborCSR(DM dm, PetscInt cellHeight, PetscInt *num
     if (numVertices) *numVertices = numCells;
     if (offsets) *offsets = off;
     if (adjacency) *adjacency = adj;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   /* Setup face recognition */
   if (faceDepth == 1) {
@@ -712,30 +716,31 @@ PetscErrorCode DMPlexCreateNeighborCSR(DM dm, PetscInt cellHeight, PetscInt *num
   if (numVertices) *numVertices = numCells;
   if (offsets) *offsets = off;
   if (adjacency) *adjacency = adj;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   PetscPartitionerDMPlexPartition - Create a non-overlapping partition of the cells in the mesh
 
-  Collective on PetscPartitioner
+  Collective
 
   Input Parameters:
-+ part    - The PetscPartitioner
-. targetSection - The PetscSection describing the absolute weight of each partition (can be NULL)
-- dm      - The mesh DM
++ part    - The `PetscPartitioner`
+. targetSection - The `PetscSection` describing the absolute weight of each partition (can be `NULL`)
+- dm      - The mesh `DM`
 
   Output Parameters:
-+ partSection     - The PetscSection giving the division of points by partition
++ partSection     - The `PetscSection` giving the division of points by partition
 - partition       - The list of points by partition
 
-  Notes:
-    If the DM has a local section associated, each point to be partitioned will be weighted by the total number of dofs identified
-    by the section in the transitive closure of the point.
-
   Level: developer
 
-.seealso `DMPlexDistribute()`, `PetscPartitionerCreate()`, `PetscSectionCreate()`, `PetscSectionSetChart()`, `PetscPartitionerPartition()`
+  Note:
+  If the `DM` has a local section associated, each point to be partitioned will be weighted by the total number of dofs identified
+  by the section in the transitive closure of the point.
+
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `PetscPartitioner`, `PetscSection`, `DMPlexDistribute()`, `PetscPartitionerCreate()`, `PetscSectionCreate()`,
+         `PetscSectionSetChart()`, `PetscPartitionerPartition()`
 @*/
 PetscErrorCode PetscPartitionerDMPlexPartition(PetscPartitioner part, DM dm, PetscSection targetSection, PetscSection partSection, IS *partition)
 {
@@ -764,7 +769,7 @@ PetscErrorCode PetscPartitionerDMPlexPartition(PetscPartitioner part, DM dm, Pet
     PetscCall(PetscMalloc1(cEnd - cStart, &points));
     for (c = cStart; c < cEnd; ++c) points[c] = c;
     PetscCall(ISCreateGeneral(PetscObjectComm((PetscObject)part), cEnd - cStart, points, PETSC_OWN_POINTER, partition));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if (part->height == 0) {
     PetscInt  numVertices = 0;
@@ -861,25 +866,26 @@ PetscErrorCode PetscPartitionerDMPlexPartition(PetscPartitioner part, DM dm, Pet
     }
   } else SETERRQ(PetscObjectComm((PetscObject)part), PETSC_ERR_ARG_OUTOFRANGE, "Invalid height %" PetscInt_FMT " for points to partition", part->height);
   PetscCall(PetscSectionDestroy(&vertSection));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMPlexGetPartitioner - Get the mesh partitioner
 
-  Not collective
+  Not Collective
 
   Input Parameter:
-. dm - The DM
+. dm - The `DM`
 
   Output Parameter:
-. part - The PetscPartitioner
+. part - The `PetscPartitioner`
 
   Level: developer
 
-  Note: This gets a borrowed reference, so the user should not destroy this PetscPartitioner.
+  Note:
+  This gets a borrowed reference, so the user should not destroy this `PetscPartitioner`.
 
-.seealso `DMPlexDistribute()`, `DMPlexSetPartitioner()`, `PetscPartitionerDMPlexPartition()`, `PetscPartitionerCreate()`
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `PetscPartitioner`, `PetscSection`, `DMPlexDistribute()`, `DMPlexSetPartitioner()`, `PetscPartitionerDMPlexPartition()`, `PetscPartitionerCreate()`
 @*/
 PetscErrorCode DMPlexGetPartitioner(DM dm, PetscPartitioner *part)
 {
@@ -889,23 +895,24 @@ PetscErrorCode DMPlexGetPartitioner(DM dm, PetscPartitioner *part)
   PetscValidHeaderSpecific(dm, DM_CLASSID, 1);
   PetscValidPointer(part, 2);
   *part = mesh->partitioner;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMPlexSetPartitioner - Set the mesh partitioner
 
-  logically collective on DM
+  logically Collective
 
   Input Parameters:
-+ dm - The DM
++ dm - The `DM`
 - part - The partitioner
 
   Level: developer
 
-  Note: Any existing PetscPartitioner will be destroyed.
+  Note:
+  Any existing `PetscPartitioner` will be destroyed.
 
-.seealso `DMPlexDistribute()`, `DMPlexGetPartitioner()`, `PetscPartitionerCreate()`
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `PetscPartitioner`,`DMPlexDistribute()`, `DMPlexGetPartitioner()`, `PetscPartitionerCreate()`
 @*/
 PetscErrorCode DMPlexSetPartitioner(DM dm, PetscPartitioner part)
 {
@@ -917,7 +924,7 @@ PetscErrorCode DMPlexSetPartitioner(DM dm, PetscPartitioner part)
   PetscCall(PetscObjectReference((PetscObject)part));
   PetscCall(PetscPartitionerDestroy(&mesh->partitioner));
   mesh->partitioner = part;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexAddClosure_Private(DM dm, PetscHSetI ht, PetscInt point)
@@ -933,7 +940,7 @@ static PetscErrorCode DMPlexAddClosure_Private(DM dm, PetscHSetI ht, PetscInt po
     PetscCall(DMPlexGetConeSize(dm, point, &coneSize));
     for (c = 0; c < coneSize; c++) PetscCall(DMPlexAddClosure_Private(dm, ht, cone[c]));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_UNUSED static PetscErrorCode DMPlexAddClosure_Tree(DM dm, PetscHSetI ht, PetscInt point, PetscBool up, PetscBool down)
@@ -972,7 +979,7 @@ PETSC_UNUSED static PetscErrorCode DMPlexAddClosure_Tree(DM dm, PetscHSetI ht, P
       }
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexAddClosureTree_Up_Private(DM dm, PetscHSetI ht, PetscInt point)
@@ -995,7 +1002,7 @@ static PetscErrorCode DMPlexAddClosureTree_Up_Private(DM dm, PetscHSetI ht, Pets
       PetscCall(DMPlexAddClosureTree_Up_Private(dm, ht, cp));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexAddClosureTree_Down_Private(DM dm, PetscHSetI ht, PetscInt point)
@@ -1006,7 +1013,7 @@ static PetscErrorCode DMPlexAddClosureTree_Down_Private(DM dm, PetscHSetI ht, Pe
   PetscFunctionBeginHot;
   PetscCall(DMPlexGetTreeChildren(dm, point, &numChildren, &children));
   for (i = 0; i < numChildren; i++) PetscCall(PetscHSetIAdd(ht, children[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexAddClosureTree_Private(DM dm, PetscHSetI ht, PetscInt point)
@@ -1021,7 +1028,7 @@ static PetscErrorCode DMPlexAddClosureTree_Private(DM dm, PetscHSetI ht, PetscIn
   PetscCall(DMPlexGetCone(dm, point, &cone));
   PetscCall(DMPlexGetConeSize(dm, point, &coneSize));
   for (c = 0; c < coneSize; c++) PetscCall(DMPlexAddClosureTree_Private(dm, ht, cone[c]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DMPlexClosurePoints_Private(DM dm, PetscInt numPoints, const PetscInt points[], IS *closureIS)
@@ -1057,19 +1064,19 @@ PetscErrorCode DMPlexClosurePoints_Private(DM dm, PetscInt numPoints, const Pets
   PetscCall(PetscHSetIDestroy(&ht));
   PetscCall(PetscSortInt(nelems, elems));
   PetscCall(ISCreateGeneral(PETSC_COMM_SELF, nelems, elems, PETSC_OWN_POINTER, closureIS));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMPlexPartitionLabelClosure - Add the closure of all points to the partition label
 
   Input Parameters:
-+ dm     - The DM
-- label  - DMLabel assigning ranks to remote roots
++ dm     - The `DM`
+- label  - `DMLabel` assigning ranks to remote roots
 
   Level: developer
 
-.seealso: `DMPlexPartitionLabelCreateSF()`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `DMLabel`, `DMPlexPartitionLabelCreateSF()`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
 @*/
 PetscErrorCode DMPlexPartitionLabelClosure(DM dm, DMLabel label)
 {
@@ -1094,19 +1101,19 @@ PetscErrorCode DMPlexPartitionLabelClosure(DM dm, DMLabel label)
   }
   PetscCall(ISRestoreIndices(rankIS, &ranks));
   PetscCall(ISDestroy(&rankIS));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMPlexPartitionLabelAdjacency - Add one level of adjacent points to the partition label
 
   Input Parameters:
-+ dm     - The DM
-- label  - DMLabel assigning ranks to remote roots
++ dm     - The `DM`
+- label  - `DMLabel` assigning ranks to remote roots
 
   Level: developer
 
-.seealso: `DMPlexPartitionLabelCreateSF()`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `DMLabel`, `DMPlexPartitionLabelCreateSF()`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
 @*/
 PetscErrorCode DMPlexPartitionLabelAdjacency(DM dm, DMLabel label)
 {
@@ -1136,22 +1143,23 @@ PetscErrorCode DMPlexPartitionLabelAdjacency(DM dm, DMLabel label)
   PetscCall(ISRestoreIndices(rankIS, &ranks));
   PetscCall(ISDestroy(&rankIS));
   PetscCall(PetscFree(adj));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-  DMPlexPartitionLabelPropagate - Propagate points in a partition label over the point SF
+  DMPlexPartitionLabelPropagate - Propagate points in a partition label over the point `PetscSF`
 
   Input Parameters:
-+ dm     - The DM
-- label  - DMLabel assigning ranks to remote roots
++ dm     - The `DM`
+- label  - `DMLabel` assigning ranks to remote roots
 
   Level: developer
 
-  Note: This is required when generating multi-level overlaps to capture
+  Note:
+  This is required when generating multi-level overlaps to capture
   overlap points from non-neighbouring partitions.
 
-.seealso: `DMPlexPartitionLabelCreateSF()`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `DMLabel`, `DMPlexPartitionLabelCreateSF()`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
 @*/
 PetscErrorCode DMPlexPartitionLabelPropagate(DM dm, DMLabel label)
 {
@@ -1197,26 +1205,27 @@ PetscErrorCode DMPlexPartitionLabelPropagate(DM dm, DMLabel label)
   PetscCall(ISRestoreIndices(rankIS, &ranks));
   PetscCall(ISDestroy(&rankIS));
   PetscCall(DMLabelDestroy(&lblRoots));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMPlexPartitionLabelInvert - Create a partition label of remote roots from a local root label
 
   Input Parameters:
-+ dm        - The DM
-. rootLabel - DMLabel assigning ranks to local roots
++ dm        - The `DM`
+. rootLabel - `DMLabel` assigning ranks to local roots
 - processSF - A star forest mapping into the local index on each remote rank
 
   Output Parameter:
-. leafLabel - DMLabel assigning ranks to remote roots
-
-  Note: The rootLabel defines a send pattern by mapping local points to remote target ranks. The
-  resulting leafLabel is a receiver mapping of remote roots to their parent rank.
+. leafLabel - `DMLabel` assigning ranks to remote roots
 
   Level: developer
 
-.seealso: `DMPlexPartitionLabelCreateSF()`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
+  Note:
+  The rootLabel defines a send pattern by mapping local points to remote target ranks. The
+  resulting leafLabel is a receiver mapping of remote roots to their parent rank.
+
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `DMPlexPartitionLabelCreateSF()`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
 @*/
 PetscErrorCode DMPlexPartitionLabelInvert(DM dm, DMLabel rootLabel, PetscSF processSF, DMLabel leafLabel)
 {
@@ -1303,7 +1312,7 @@ PetscErrorCode DMPlexPartitionLabelInvert(DM dm, DMLabel rootLabel, PetscSF proc
       counter += rcounts[r];
     }
     if (counter > PETSC_MPI_INT_MAX) locOverflow = PETSC_TRUE;
-    PetscCallMPI(MPI_Allreduce(&locOverflow, &mpiOverflow, 1, MPIU_BOOL, MPI_LOR, comm));
+    PetscCall(MPIU_Allreduce(&locOverflow, &mpiOverflow, 1, MPIU_BOOL, MPI_LOR, comm));
     if (!mpiOverflow) {
       PetscCall(PetscInfo(dm, "Using Alltoallv for mesh distribution\n"));
       leafSize = (PetscInt)counter;
@@ -1343,24 +1352,25 @@ PetscErrorCode DMPlexPartitionLabelInvert(DM dm, DMLabel rootLabel, PetscSF proc
   PetscCall(PetscFree(rootPoints));
   PetscCall(PetscFree(leafPoints));
   PetscCall(PetscLogEventEnd(DMPLEX_PartLabelInvert, dm, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMPlexPartitionLabelCreateSF - Create a star forest from a label that assigns ranks to points
 
   Input Parameters:
-+ dm    - The DM
-- label - DMLabel assigning ranks to remote roots
++ dm    - The `DM`
+- label - `DMLabel` assigning ranks to remote roots
 
   Output Parameter:
 . sf    - The star forest communication context encapsulating the defined mapping
 
-  Note: The incoming label is a receiver mapping of remote points to their parent rank.
-
   Level: developer
 
-.seealso: `DMPlexDistribute()`, `DMPlexCreateOverlap()`
+  Note:
+  The incoming label is a receiver mapping of remote points to their parent rank.
+
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `DMLabel`, `PetscSF`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
 @*/
 PetscErrorCode DMPlexPartitionLabelCreateSF(DM dm, DMLabel label, PetscSF *sf)
 {
@@ -1426,7 +1436,7 @@ PetscErrorCode DMPlexPartitionLabelCreateSF(DM dm, DMLabel label, PetscSF *sf)
   PetscCall(PetscSFSetUp(*sf));
   PetscCall(ISDestroy(&neighborsIS));
   PetscCall(PetscLogEventEnd(DMPLEX_PartLabelCreateSF, dm, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_HAVE_PARMETIS)
@@ -1439,17 +1449,18 @@ PetscErrorCode DMPlexPartitionLabelCreateSF(DM dm, DMLabel label, PetscSF *sf)
 #if defined(PETSC_HAVE_PARMETIS)
 /*@C
 
-  DMPlexRewriteSF - Rewrites the ownership of the SF of a DM (in place).
+  DMPlexRewriteSF - Rewrites the ownership of the `PetsSF` of a `DM` (in place).
 
   Input parameters:
-+ dm                - The DMPlex object.
++ dm                - The `DMPLEX` object.
 . n                 - The number of points.
-. pointsToRewrite   - The points in the SF whose ownership will change.
+. pointsToRewrite   - The points in the `PetscSF` whose ownership will change.
 . targetOwners      - New owner for each element in pointsToRewrite.
-- degrees           - Degrees of the points in the SF as obtained by PetscSFComputeDegreeBegin/PetscSFComputeDegreeEnd.
+- degrees           - Degrees of the points in the `PetscSF` as obtained by `PetscSFComputeDegreeBegin()`/`PetscSFComputeDegreeEnd()`.
 
   Level: developer
 
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `DMLabel`, `PetscSF`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
 @*/
 static PetscErrorCode DMPlexRewriteSF(DM dm, PetscInt n, PetscInt *pointsToRewrite, PetscInt *targetOwners, const PetscInt *degrees)
 {
@@ -1573,7 +1584,7 @@ static PetscErrorCode DMPlexRewriteSF(DM dm, PetscInt n, PetscInt *pointsToRewri
   PetscCall(PetscFree(newOwners));
   PetscCall(PetscFree(newNumbers));
   PetscCall(PetscFree(isLeaf));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexViewDistribution(MPI_Comm comm, PetscInt n, PetscInt skip, PetscInt *vtxwgt, PetscInt *part, PetscViewer viewer)
@@ -1589,7 +1600,7 @@ static PetscErrorCode DMPlexViewDistribution(MPI_Comm comm, PetscInt n, PetscInt
     if (part) distribution[part[i]] += vtxwgt[skip * i];
     else distribution[rank] += vtxwgt[skip * i];
   }
-  PetscCallMPI(MPI_Allreduce(MPI_IN_PLACE, distribution, size, MPIU_INT, MPI_SUM, comm));
+  PetscCall(MPIU_Allreduce(MPI_IN_PLACE, distribution, size, MPIU_INT, MPI_SUM, comm));
   min = distribution[0];
   max = distribution[0];
   sum = distribution[0];
@@ -1600,33 +1611,32 @@ static PetscErrorCode DMPlexViewDistribution(MPI_Comm comm, PetscInt n, PetscInt
   }
   PetscCall(PetscViewerASCIIPrintf(viewer, "Min: %" PetscInt_FMT ", Avg: %" PetscInt_FMT ", Max: %" PetscInt_FMT ", Balance: %f\n", min, sum / size, max, (max * 1. * size) / sum));
   PetscCall(PetscFree(distribution));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #endif
 
 /*@
-  DMPlexRebalanceSharedPoints - Redistribute points in the plex that are shared in order to achieve better balancing. This routine updates the PointSF of the DM inplace.
+  DMPlexRebalanceSharedPoints - Redistribute points in the plex that are shared in order to achieve better balancing. This routine updates the `PointSF` of the `DM` inplace.
 
   Input parameters:
-+ dm               - The DMPlex object.
++ dm               - The `DMPLEX` object.
 . entityDepth      - depth of the entity to balance (0 -> balance vertices).
 . useInitialGuess  - whether to use the current distribution as initial guess (only used by ParMETIS).
 - parallel         - whether to use ParMETIS and do the partition in parallel or whether to gather the graph onto a single process and use METIS.
 
-  Output parameters:
+  Output parameter:
 . success          - whether the graph partitioning was successful or not, optional. Unsuccessful simply means no change to the partitioning
 
-  Options Database:
+  Options Database Keys:
 +  -dm_plex_rebalance_shared_points_parmetis - Use ParMetis instead of Metis for the partitioner
 .  -dm_plex_rebalance_shared_points_use_initial_guess - Use current partition to bootstrap ParMetis partition
 .  -dm_plex_rebalance_shared_points_use_mat_partitioning - Use the MatPartitioning object to perform the partition, the prefix for those operations is -dm_plex_rebalance_shared_points_
 -  -dm_plex_rebalance_shared_points_monitor - Monitor the shared points rebalance process
 
-  Developer Notes:
-  This should use MatPartitioning to allow the use of any partitioner and not be hardwired to use ParMetis
-
   Level: intermediate
+
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `DMPlexDistribute()`, `DMPlexCreateOverlap()`
 @*/
 PetscErrorCode DMPlexRebalanceSharedPoints(DM dm, PetscInt entityDepth, PetscBool useInitialGuess, PetscBool parallel, PetscBool *success)
 {
@@ -1668,7 +1678,7 @@ PetscErrorCode DMPlexRebalanceSharedPoints(DM dm, PetscInt entityDepth, PetscBoo
   PetscCallMPI(MPI_Comm_size(comm, &size));
   if (size == 1) {
     if (success) *success = PETSC_TRUE;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if (success) *success = PETSC_FALSE;
   PetscCallMPI(MPI_Comm_rank(comm, &rank));
@@ -1786,8 +1796,7 @@ PetscErrorCode DMPlexRebalanceSharedPoints(DM dm, PetscInt entityDepth, PetscBoo
   PetscCall(PetscMalloc1(ncon * nparts, &tpwgts));
   for (i = 0; i < ncon * nparts; i++) tpwgts[i] = 1. / (nparts);
   PetscCall(PetscMalloc1(ncon, &ubvec));
-  ubvec[0] = 1.05;
-  ubvec[1] = 1.05;
+  for (i = 0; i < ncon; i++) ubvec[i] = 1.05;
 
   PetscCall(PetscMalloc1(ncon * (1 + numNonExclusivelyOwned), &vtxwgt));
   if (ncon == 2) {
@@ -1799,7 +1808,7 @@ PetscErrorCode DMPlexRebalanceSharedPoints(DM dm, PetscInt entityDepth, PetscBoo
     }
   } else {
     PetscInt base, ms;
-    PetscCallMPI(MPI_Allreduce(&numExclusivelyOwned, &base, 1, MPIU_INT, MPIU_MAX, PetscObjectComm((PetscObject)dm)));
+    PetscCall(MPIU_Allreduce(&numExclusivelyOwned, &base, 1, MPIU_INT, MPIU_MAX, PetscObjectComm((PetscObject)dm)));
     PetscCall(MatGetSize(A, &ms, NULL));
     ms -= size;
     base      = PetscMax(base, ms);
@@ -1932,9 +1941,9 @@ PetscErrorCode DMPlexRebalanceSharedPoints(DM dm, PetscInt entityDepth, PetscBoo
 
   /* Check if the renumbering worked (this can fail when ParMETIS gives fewer partitions than there are processes) */
   failed = (PetscInt)(part[0] != rank);
-  PetscCallMPI(MPI_Allreduce(&failed, &failedGlobal, 1, MPIU_INT, MPI_SUM, comm));
+  PetscCall(MPIU_Allreduce(&failed, &failedGlobal, 1, MPIU_INT, MPI_SUM, comm));
   if (failedGlobal > 0) {
-    PetscCheck(failedGlobal <= 0, comm, PETSC_ERR_LIB, "Metis/Parmetis returned a bad partion");
+    PetscCheck(failedGlobal <= 0, comm, PETSC_ERR_LIB, "Metis/Parmetis returned a bad partition");
     PetscCall(PetscFree(vtxwgt));
     PetscCall(PetscFree(toBalance));
     PetscCall(PetscFree(isLeaf));
@@ -1949,7 +1958,7 @@ PetscErrorCode DMPlexRebalanceSharedPoints(DM dm, PetscInt entityDepth, PetscBoo
       PetscCall(PetscViewerDestroy(&viewer));
     }
     PetscCall(PetscLogEventEnd(DMPLEX_RebalanceSharedPoints, dm, 0, 0, 0));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   /* Check how well we did distributing points*/
@@ -2012,7 +2021,7 @@ PetscErrorCode DMPlexRebalanceSharedPoints(DM dm, PetscInt entityDepth, PetscBoo
   }
   if (success) *success = PETSC_TRUE;
   PetscCall(PetscLogEventEnd(DMPLEX_RebalanceSharedPoints, dm, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 #else
   SETERRQ(PetscObjectComm((PetscObject)dm), PETSC_ERR_SUP, "Mesh partitioning needs external package support.\nPlease reconfigure with --download-parmetis.");
 #endif
