@@ -148,7 +148,7 @@ static PetscErrorCode DMPlexComputeAnchorAdjacencies(DM dm, PetscBool useCone, P
     PetscCall(PetscSectionSetUp(adjSec));
   }
   *anchorSectionAdj = adjSec;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, PetscSF sfDof, PetscBool useCone, PetscBool useClosure, PetscBool useAnchors, PetscSection *sA, PetscInt **colIdx)
@@ -558,7 +558,7 @@ static PetscErrorCode DMPlexCreateAdjacencySection_Static(DM dm, PetscInt bs, Pe
 
   *sA     = sectionAdj;
   *colIdx = cols;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexUpdateAllocation_Static(DM dm, PetscLayout rLayout, PetscInt bs, PetscInt f, PetscSection sectionAdj, const PetscInt cols[], PetscInt dnz[], PetscInt onz[], PetscInt dnzu[], PetscInt onzu[])
@@ -618,7 +618,7 @@ static PetscErrorCode DMPlexUpdateAllocation_Static(DM dm, PetscLayout rLayout,
       onzu[r] /= bs;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexFillMatrix_Static(DM dm, PetscLayout rLayout, PetscInt bs, PetscInt f, PetscSection sectionAdj, const PetscInt cols[], Mat A)
@@ -659,35 +659,34 @@ static PetscErrorCode DMPlexFillMatrix_Static(DM dm, PetscLayout rLayout, PetscI
     }
   }
   PetscCall(PetscFree(values));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  DMPlexPreallocateOperator - Calculate the matrix nonzero pattern based upon the information in the DM,
-  the PetscDS it contains, and the default PetscSection.
+  DMPlexPreallocateOperator - Calculate the matrix nonzero pattern based upon the information in the `DM`,
+  the `PetscDS` it contains, and the default `PetscSection`.
 
   Collective
 
   Input Parameters:
-+ dm   - The DMPlex
++ dm   - The `DMPLEX`
 . bs   - The matrix blocksize
 . dnz  - An array to hold the number of nonzeros in the diagonal block
 . onz  - An array to hold the number of nonzeros in the off-diagonal block
 . dnzu - An array to hold the number of nonzeros in the upper triangle of the diagonal block
 . onzu - An array to hold the number of nonzeros in the upper triangle of the off-diagonal block
-- fillMatrix - If PETSC_TRUE, fill the matrix with zeros
+- fillMatrix - If `PETSC_TRUE`, fill the matrix with zeros
 
   Output Parameter:
 . A - The preallocated matrix
 
   Level: advanced
 
-.seealso: `DMCreateMatrix()`
+.seealso: [](chapter_unstructured), `DM`, `DMPLEX`, `DMCreateMatrix()`
 @*/
 PetscErrorCode DMPlexPreallocateOperator(DM dm, PetscInt bs, PetscInt dnz[], PetscInt onz[], PetscInt dnzu[], PetscInt onzu[], Mat A, PetscBool fillMatrix)
 {
   MPI_Comm     comm;
-  PetscDS      prob;
   MatType      mtype;
   PetscSF      sf, sfDof;
   PetscSection section;
@@ -707,7 +706,6 @@ PetscErrorCode DMPlexPreallocateOperator(DM dm, PetscInt bs, PetscInt dnz[], Pet
   if (onz) PetscValidIntPointer(onz, 4);
   if (dnzu) PetscValidIntPointer(dnzu, 5);
   if (onzu) PetscValidIntPointer(onzu, 6);
-  PetscCall(DMGetDS(dm, &prob));
   PetscCall(DMGetPointSF(dm, &sf));
   PetscCall(DMGetLocalSection(dm, &section));
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-dm_view_preallocation", &debug, NULL));
@@ -791,7 +789,7 @@ PetscErrorCode DMPlexPreallocateOperator(DM dm, PetscInt bs, PetscInt dnz[], Pet
     PetscCall(PetscFree(cols[idx]));
   }
   PetscCall(PetscLogEventEnd(DMPLEX_Preallocate, dm, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if 0
@@ -838,6 +836,6 @@ PetscErrorCode DMPlexPreallocateOperator_2(DM dm, PetscInt bs, PetscSection sect
 
   PetscCall(PetscSFReduceBegin(sf,MPIU_INT,ldnz,dnz,MPI_SUM));
   PetscCall(PetscSFReduceEnd  (sf,MPIU_INT,lonz,onz,MPI_SUM));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
