@@ -45,7 +45,7 @@ static PetscErrorCode TransferWrite(MPI_Comm comm, PetscViewer viewer, FILE *fp,
     }
     PetscCall(PetscViewerVTKFWrite(viewer, fp, buffer, count, mpidatatype));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMPlexGetVTKConnectivity(DM dm, PetscBool localized, PieceInfo *piece, PetscVTKInt **oconn, PetscVTKInt **ooffsets, PetscVTKType **otypes)
@@ -117,7 +117,7 @@ static PetscErrorCode DMPlexGetVTKConnectivity(DM dm, PetscBool localized, Piece
   *oconn    = conn;
   *ooffsets = offsets;
   *otypes   = types;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -152,7 +152,7 @@ PetscErrorCode DMPlexVTKWriteAll_VTU(DM dm, PetscViewer viewer)
 
   PetscCall(PetscFOpen(comm, vtk->filename, "wb", &fp));
   PetscCall(PetscFPrintf(comm, fp, "<?xml version=\"1.0\"?>\n"));
-  PetscCall(PetscFPrintf(comm, fp, "<VTKFile type=\"UnstructuredGrid\" version=\"0.1\" byte_order=\"%s\">\n", byte_order));
+  PetscCall(PetscFPrintf(comm, fp, "<VTKFile type=\"UnstructuredGrid\" version=\"0.1\" byte_order=\"%s\" header_type=\"UInt64\">\n", byte_order));
   PetscCall(PetscFPrintf(comm, fp, "  <UnstructuredGrid>\n"));
 
   PetscCall(DMGetCoordinateDim(dm, &dimEmbed));
@@ -203,31 +203,31 @@ PetscErrorCode DMPlexVTKWriteAll_VTU(DM dm, PetscViewer viewer)
    * Write file header
    */
   if (rank == 0) {
-    PetscInt boffset = 0;
+    PetscInt64 boffset = 0;
 
     for (r = 0; r < size; r++) {
       PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "    <Piece NumberOfPoints=\"%" PetscInt_FMT "\" NumberOfCells=\"%" PetscInt_FMT "\">\n", gpiece[r].nvertices, gpiece[r].ncells));
       /* Coordinate positions */
       PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "      <Points>\n"));
-      PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "        <DataArray type=\"%s\" Name=\"Position\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, boffset));
-      boffset += gpiece[r].nvertices * 3 * sizeof(PetscVTUReal) + sizeof(int);
+      PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "        <DataArray type=\"%s\" Name=\"Position\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, boffset));
+      boffset += gpiece[r].nvertices * 3 * sizeof(PetscVTUReal) + sizeof(PetscInt64);
       PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "      </Points>\n"));
       /* Cell connectivity */
       PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "      <Cells>\n"));
-      PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "        <DataArray type=\"Int32\" Name=\"connectivity\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", boffset));
-      boffset += gpiece[r].nconn * sizeof(PetscInt) + sizeof(int);
-      PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "        <DataArray type=\"Int32\" Name=\"offsets\"      NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", boffset));
-      boffset += gpiece[r].ncells * sizeof(PetscInt) + sizeof(int);
-      PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "        <DataArray type=\"UInt8\" Name=\"types\"        NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", boffset));
-      boffset += gpiece[r].ncells * sizeof(unsigned char) + sizeof(int);
+      PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "        <DataArray type=\"Int32\" Name=\"connectivity\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", boffset));
+      boffset += gpiece[r].nconn * sizeof(PetscVTKInt) + sizeof(PetscInt64);
+      PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "        <DataArray type=\"Int32\" Name=\"offsets\"      NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", boffset));
+      boffset += gpiece[r].ncells * sizeof(PetscVTKInt) + sizeof(PetscInt64);
+      PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "        <DataArray type=\"UInt8\" Name=\"types\"        NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", boffset));
+      boffset += gpiece[r].ncells * sizeof(unsigned char) + sizeof(PetscInt64);
       PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "      </Cells>\n"));
 
       /*
        * Cell Data headers
        */
       PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "      <CellData>\n"));
-      PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "        <DataArray type=\"Int32\" Name=\"Rank\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", boffset));
-      boffset += gpiece[r].ncells * sizeof(int) + sizeof(int);
+      PetscCall(PetscFPrintf(PETSC_COMM_SELF, fp, "        <DataArray type=\"Int32\" Name=\"Rank\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", boffset));
+      boffset += gpiece[r].ncells * sizeof(PetscVTKInt) + sizeof(PetscInt64);
       /* all the vectors */
       for (link = vtk->link; link; link = link->next) {
         Vec          X       = (Vec)link->vec;
@@ -284,13 +284,13 @@ PetscErrorCode DMPlexVTKWriteAll_VTU(DM dm, PetscViewer viewer)
           }
           if (vector) {
 #if defined(PETSC_USE_COMPLEX)
-            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s.Re\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, vecname, fieldname, boffset));
-            boffset += gpiece[r].ncells * 3 * sizeof(PetscVTUReal) + sizeof(int);
-            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s.Im\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, vecname, fieldname, boffset));
-            boffset += gpiece[r].ncells * 3 * sizeof(PetscVTUReal) + sizeof(int);
+            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s.Re\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, vecname, fieldname, boffset));
+            boffset += gpiece[r].ncells * 3 * sizeof(PetscVTUReal) + sizeof(PetscInt64);
+            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s.Im\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, vecname, fieldname, boffset));
+            boffset += gpiece[r].ncells * 3 * sizeof(PetscVTUReal) + sizeof(PetscInt64);
 #else
-            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, vecname, fieldname, boffset));
-            boffset += gpiece[r].ncells * 3 * sizeof(PetscVTUReal) + sizeof(int);
+            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, vecname, fieldname, boffset));
+            boffset += gpiece[r].ncells * 3 * sizeof(PetscVTUReal) + sizeof(PetscInt64);
 #endif
             i += fbs;
           } else {
@@ -306,13 +306,13 @@ PetscErrorCode DMPlexVTKWriteAll_VTU(DM dm, PetscViewer viewer)
                 PetscCall(PetscSNPrintf(finalname, 255, "%s%s", vecname, fieldname));
               }
 #if defined(PETSC_USE_COMPLEX)
-              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s.Re\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, finalname, boffset));
-              boffset += gpiece[r].ncells * sizeof(PetscVTUReal) + sizeof(int);
-              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s.Im\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, finalname, boffset));
-              boffset += gpiece[r].ncells * sizeof(PetscVTUReal) + sizeof(int);
+              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s.Re\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, finalname, boffset));
+              boffset += gpiece[r].ncells * sizeof(PetscVTUReal) + sizeof(PetscInt64);
+              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s.Im\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, finalname, boffset));
+              boffset += gpiece[r].ncells * sizeof(PetscVTUReal) + sizeof(PetscInt64);
 #else
-              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, finalname, boffset));
-              boffset += gpiece[r].ncells * sizeof(PetscVTUReal) + sizeof(int);
+              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, finalname, boffset));
+              boffset += gpiece[r].ncells * sizeof(PetscVTUReal) + sizeof(PetscInt64);
 #endif
               i++;
             }
@@ -362,13 +362,13 @@ PetscErrorCode DMPlexVTKWriteAll_VTU(DM dm, PetscViewer viewer)
           if (link->ft == PETSC_VTK_POINT_VECTOR_FIELD) {
             PetscCheck(fbs <= 3, PetscObjectComm((PetscObject)viewer), PETSC_ERR_ARG_SIZ, "Point vector fields can have at most 3 components, %" PetscInt_FMT " given", fbs);
 #if defined(PETSC_USE_COMPLEX)
-            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s.Re\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, vecname, fieldname, boffset));
-            boffset += gpiece[r].nvertices * 3 * sizeof(PetscVTUReal) + sizeof(int);
-            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s.Im\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, vecname, fieldname, boffset));
-            boffset += gpiece[r].nvertices * 3 * sizeof(PetscVTUReal) + sizeof(int);
+            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s.Re\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, vecname, fieldname, boffset));
+            boffset += gpiece[r].nvertices * 3 * sizeof(PetscVTUReal) + sizeof(PetscInt64);
+            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s.Im\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, vecname, fieldname, boffset));
+            boffset += gpiece[r].nvertices * 3 * sizeof(PetscVTUReal) + sizeof(PetscInt64);
 #else
-            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, vecname, fieldname, boffset));
-            boffset += gpiece[r].nvertices * 3 * sizeof(PetscVTUReal) + sizeof(int);
+            PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s%s\" NumberOfComponents=\"3\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, vecname, fieldname, boffset));
+            boffset += gpiece[r].nvertices * 3 * sizeof(PetscVTUReal) + sizeof(PetscInt64);
 #endif
           } else {
             for (j = 0; j < fbs; j++) {
@@ -377,13 +377,13 @@ PetscErrorCode DMPlexVTKWriteAll_VTU(DM dm, PetscViewer viewer)
               PetscCall(PetscSectionGetComponentName(section, field, j, &compName));
               PetscCall(PetscSNPrintf(finalname, 255, "%s%s.%s", vecname, fieldname, compName));
 #if defined(PETSC_USE_COMPLEX)
-              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s.Re\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, finalname, boffset));
-              boffset += gpiece[r].nvertices * sizeof(PetscVTUReal) + sizeof(int);
-              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s.Im\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, finalname, boffset));
-              boffset += gpiece[r].nvertices * sizeof(PetscVTUReal) + sizeof(int);
+              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s.Re\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, finalname, boffset));
+              boffset += gpiece[r].nvertices * sizeof(PetscVTUReal) + sizeof(PetscInt64);
+              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s.Im\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, finalname, boffset));
+              boffset += gpiece[r].nvertices * sizeof(PetscVTUReal) + sizeof(PetscInt64);
 #else
-              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt_FMT "\" />\n", precision, finalname, boffset));
-              boffset += gpiece[r].nvertices * sizeof(PetscVTUReal) + sizeof(int);
+              PetscCall(PetscFPrintf(comm, fp, "        <DataArray type=\"%s\" Name=\"%s\" NumberOfComponents=\"1\" format=\"appended\" offset=\"%" PetscInt64_FMT "\" />\n", precision, finalname, boffset));
+              boffset += gpiece[r].nvertices * sizeof(PetscVTUReal) + sizeof(PetscInt64);
 #endif
             }
           }
@@ -824,5 +824,5 @@ PetscErrorCode DMPlexVTKWriteAll_VTU(DM dm, PetscViewer viewer)
   PetscCall(PetscFPrintf(comm, fp, "\n  </AppendedData>\n"));
   PetscCall(PetscFPrintf(comm, fp, "</VTKFile>\n"));
   PetscCall(PetscFClose(comm, fp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
