@@ -1,4 +1,4 @@
-static char help[] = "Test that MatPartitioning and PetscPartitioner interfaces are equivalent when using PETSCPARTITIONERMATPARTITIONING\n\n";
+static char help[]     = "Test that MatPartitioning and PetscPartitioner interfaces are equivalent when using PETSCPARTITIONERMATPARTITIONING\n\n";
 static char FILENAME[] = "ex24.c";
 
 #include <petscdmplex.h>
@@ -6,42 +6,41 @@ static char FILENAME[] = "ex24.c";
 
 #if defined(PETSC_HAVE_PTSCOTCH)
 EXTERN_C_BEGIN
-#include <ptscotch.h>
+  #include <ptscotch.h>
 EXTERN_C_END
 #endif
 
 typedef struct {
-  PetscBool compare_is;                   /* Compare ISs and PetscSections */
-  PetscBool compare_dm;                   /* Compare DM */
-  PetscBool tpw;                          /* Use target partition weights */
+  PetscBool compare_is; /* Compare ISs and PetscSections */
+  PetscBool compare_dm; /* Compare DM */
+  PetscBool tpw;        /* Use target partition weights */
   char      partitioning[64];
   char      repartitioning[64];
 } AppCtx;
 
 static PetscErrorCode ProcessOptions(MPI_Comm comm, AppCtx *options)
 {
-  PetscBool      repartition = PETSC_TRUE;
-  PetscErrorCode ierr;
+  PetscBool repartition = PETSC_TRUE;
 
   PetscFunctionBegin;
   options->compare_is = PETSC_FALSE;
   options->compare_dm = PETSC_FALSE;
 
-  ierr = PetscOptionsBegin(comm, "", "Meshing Interpolation Test Options", "DMPLEX");PetscCall(ierr);
+  PetscOptionsBegin(comm, "", "Meshing Interpolation Test Options", "DMPLEX");
   PetscCall(PetscOptionsBool("-compare_is", "Compare ISs and PetscSections?", FILENAME, options->compare_is, &options->compare_is, NULL));
   PetscCall(PetscOptionsBool("-compare_dm", "Compare DMs?", FILENAME, options->compare_dm, &options->compare_dm, NULL));
-  PetscCall(PetscStrncpy(options->partitioning,MATPARTITIONINGPARMETIS,sizeof(options->partitioning)));
-  PetscCall(PetscOptionsString("-partitioning","The mat partitioning type to test","None",options->partitioning, options->partitioning,sizeof(options->partitioning),NULL));
+  PetscCall(PetscStrncpy(options->partitioning, MATPARTITIONINGPARMETIS, sizeof(options->partitioning)));
+  PetscCall(PetscOptionsString("-partitioning", "The mat partitioning type to test", "None", options->partitioning, options->partitioning, sizeof(options->partitioning), NULL));
   PetscCall(PetscOptionsBool("-repartition", "Partition again after the first partition?", FILENAME, repartition, &repartition, NULL));
   if (repartition) {
-    PetscCall(PetscStrncpy(options->repartitioning,MATPARTITIONINGPARMETIS,64));
-    PetscCall(PetscOptionsString("-repartitioning","The mat partitioning type to test (second partitioning)","None", options->repartitioning, options->repartitioning,sizeof(options->repartitioning),NULL));
+    PetscCall(PetscStrncpy(options->repartitioning, MATPARTITIONINGPARMETIS, 64));
+    PetscCall(PetscOptionsString("-repartitioning", "The mat partitioning type to test (second partitioning)", "None", options->repartitioning, options->repartitioning, sizeof(options->repartitioning), NULL));
   } else {
     options->repartitioning[0] = '\0';
   }
   PetscCall(PetscOptionsBool("-tpweight", "Use target partition weights", FILENAME, options->tpw, &options->tpw, NULL));
-  ierr = PetscOptionsEnd();PetscCall(ierr);
-  PetscFunctionReturn(0);
+  PetscOptionsEnd();
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode ScotchResetRandomSeed()
@@ -50,7 +49,7 @@ static PetscErrorCode ScotchResetRandomSeed()
 #if defined(PETSC_HAVE_PTSCOTCH)
   SCOTCH_randomReset();
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode CreateMesh(MPI_Comm comm, AppCtx *user, DM *dm)
@@ -61,27 +60,28 @@ static PetscErrorCode CreateMesh(MPI_Comm comm, AppCtx *user, DM *dm)
   PetscCall(DMPlexDistributeSetDefault(*dm, PETSC_FALSE));
   PetscCall(DMSetFromOptions(*dm));
   PetscCall(DMViewFromOptions(*dm, NULL, "-dm_view"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 int main(int argc, char **argv)
 {
-  MPI_Comm       comm;
-  DM             dm1, dm2, dmdist1, dmdist2;
+  MPI_Comm               comm;
+  DM                     dm1, dm2, dmdist1, dmdist2;
   DMPlexInterpolatedFlag interp;
-  MatPartitioning mp;
-  PetscPartitioner part1, part2;
-  AppCtx         user;
-  IS             is1=NULL, is2=NULL;
-  IS             is1g, is2g;
-  PetscSection   s1=NULL, s2=NULL, tpws = NULL;
-  PetscInt       i;
-  PetscBool      flg;
-  PetscMPIInt    size;
+  MatPartitioning        mp;
+  PetscPartitioner       part1, part2;
+  AppCtx                 user;
+  IS                     is1 = NULL, is2 = NULL;
+  IS                     is1g, is2g;
+  PetscSection           s1 = NULL, s2 = NULL, tpws = NULL;
+  PetscInt               i;
+  PetscBool              flg;
+  PetscMPIInt            size;
 
-  PetscCall(PetscInitialize(&argc, &argv, NULL,help));
+  PetscFunctionBeginUser;
+  PetscCall(PetscInitialize(&argc, &argv, NULL, help));
   comm = PETSC_COMM_WORLD;
-  PetscCallMPI(MPI_Comm_size(comm,&size));
+  PetscCallMPI(MPI_Comm_size(comm, &size));
   PetscCall(ProcessOptions(comm, &user));
   PetscCall(CreateMesh(comm, &user, &dm1));
   PetscCall(CreateMesh(comm, &user, &dm2));
@@ -89,8 +89,8 @@ int main(int argc, char **argv)
   if (user.tpw) {
     PetscCall(PetscSectionCreate(comm, &tpws));
     PetscCall(PetscSectionSetChart(tpws, 0, size));
-    for (i=0;i<size;i++) {
-      PetscInt tdof = i%2 ? 2*i -1 : i+2;
+    for (i = 0; i < size; i++) {
+      PetscInt tdof = i % 2 ? 2 * i - 1 : i + 2;
       PetscCall(PetscSectionSetDof(tpws, i, tdof));
     }
     if (size > 1) { /* test zero tpw entry */
@@ -102,7 +102,7 @@ int main(int argc, char **argv)
   /* partition dm1 using PETSCPARTITIONERPARMETIS */
   PetscCall(ScotchResetRandomSeed());
   PetscCall(DMPlexGetPartitioner(dm1, &part1));
-  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)part1,"p1_"));
+  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)part1, "p1_"));
   PetscCall(PetscPartitionerSetType(part1, user.partitioning));
   PetscCall(PetscPartitionerSetFromOptions(part1));
   PetscCall(PetscSectionCreate(comm, &s1));
@@ -111,7 +111,7 @@ int main(int argc, char **argv)
   /* partition dm2 using PETSCPARTITIONERMATPARTITIONING with MATPARTITIONINGPARMETIS */
   PetscCall(ScotchResetRandomSeed());
   PetscCall(DMPlexGetPartitioner(dm2, &part2));
-  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)part2,"p2_"));
+  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)part2, "p2_"));
   PetscCall(PetscPartitionerSetType(part2, PETSCPARTITIONERMATPARTITIONING));
   PetscCall(PetscPartitionerMatPartitioningGetMatPartitioning(part2, &mp));
   PetscCall(MatPartitioningSetType(mp, user.partitioning));
@@ -126,7 +126,7 @@ int main(int argc, char **argv)
   /* compare the two ISs */
   if (user.compare_is) {
     PetscCall(ISEqualUnsorted(is1g, is2g, &flg));
-    if (!flg) PetscCall(PetscPrintf(comm, "ISs are not equal with type %s with size %d.\n",user.partitioning,size));
+    if (!flg) PetscCall(PetscPrintf(comm, "ISs are not equal with type %s with size %d.\n", user.partitioning, size));
   }
   PetscCall(ISDestroy(&is1g));
   PetscCall(ISDestroy(&is2g));
@@ -136,7 +136,7 @@ int main(int argc, char **argv)
   PetscCall(PetscSectionViewFromOptions(s2, NULL, "-seq_s2_view"));
   if (user.compare_is) {
     PetscCall(PetscSectionCompare(s1, s2, &flg));
-    if (!flg) PetscCall(PetscPrintf(comm, "PetscSections are not equal with %s with size %d.\n",user.partitioning,size));
+    if (!flg) PetscCall(PetscPrintf(comm, "PetscSections are not equal with %s with size %d.\n", user.partitioning, size));
   }
 
   /* distribute both DMs */
@@ -163,7 +163,7 @@ int main(int argc, char **argv)
   /* compare the two distributed DMs */
   if (user.compare_dm) {
     PetscCall(DMPlexEqual(dmdist1, dmdist2, &flg));
-    if (!flg) PetscCall(PetscPrintf(comm, "Distributed DMs are not equal %s with size %d.\n",user.partitioning,size));
+    if (!flg) PetscCall(PetscPrintf(comm, "Distributed DMs are not equal %s with size %d.\n", user.partitioning, size));
   }
 
   /* if repartitioning is disabled, then quit */
@@ -172,8 +172,8 @@ int main(int argc, char **argv)
   if (user.tpw) {
     PetscCall(PetscSectionCreate(comm, &tpws));
     PetscCall(PetscSectionSetChart(tpws, 0, size));
-    for (i=0;i<size;i++) {
-      PetscInt tdof = i%2 ? i+1 : size - i;
+    for (i = 0; i < size; i++) {
+      PetscInt tdof = i % 2 ? i + 1 : size - i;
       PetscCall(PetscSectionSetDof(tpws, i, tdof));
     }
     PetscCall(PetscSectionSetUp(tpws));
@@ -182,7 +182,7 @@ int main(int argc, char **argv)
   /* repartition distributed DM dmdist1 */
   PetscCall(ScotchResetRandomSeed());
   PetscCall(DMPlexGetPartitioner(dmdist1, &part1));
-  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)part1,"dp1_"));
+  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)part1, "dp1_"));
   PetscCall(PetscPartitionerSetType(part1, user.repartitioning));
   PetscCall(PetscPartitionerSetFromOptions(part1));
   PetscCall(PetscSectionCreate(comm, &s1));
@@ -191,7 +191,7 @@ int main(int argc, char **argv)
   /* repartition distributed DM dmdist2 */
   PetscCall(ScotchResetRandomSeed());
   PetscCall(DMPlexGetPartitioner(dmdist2, &part2));
-  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)part2,"dp2_"));
+  PetscCall(PetscObjectSetOptionsPrefix((PetscObject)part2, "dp2_"));
   PetscCall(PetscPartitionerSetType(part2, PETSCPARTITIONERMATPARTITIONING));
   PetscCall(PetscPartitionerMatPartitioningGetMatPartitioning(part2, &mp));
   PetscCall(MatPartitioningSetType(mp, user.repartitioning));
@@ -206,7 +206,7 @@ int main(int argc, char **argv)
   PetscCall(ISViewFromOptions(is2g, NULL, "-dist_is2_view"));
   if (user.compare_is) {
     PetscCall(ISEqualUnsorted(is1g, is2g, &flg));
-    if (!flg) PetscCall(PetscPrintf(comm, "Distributed ISs are not equal, with %s with size %d.\n",user.repartitioning,size));
+    if (!flg) PetscCall(PetscPrintf(comm, "Distributed ISs are not equal, with %s with size %d.\n", user.repartitioning, size));
   }
   PetscCall(ISDestroy(&is1g));
   PetscCall(ISDestroy(&is2g));
@@ -216,7 +216,7 @@ int main(int argc, char **argv)
   PetscCall(PetscSectionViewFromOptions(s2, NULL, "-dist_s2_view"));
   if (user.compare_is) {
     PetscCall(PetscSectionCompare(s1, s2, &flg));
-    if (!flg) PetscCall(PetscPrintf(comm, "Distributed PetscSections are not equal, with %s with size %d.\n",user.repartitioning,size));
+    if (!flg) PetscCall(PetscPrintf(comm, "Distributed PetscSections are not equal, with %s with size %d.\n", user.repartitioning, size));
   }
 
   /* redistribute both distributed DMs */
@@ -229,7 +229,7 @@ int main(int argc, char **argv)
   PetscCall(DMPlexIsInterpolated(dm1, &interp));
   if (interp == DMPLEX_INTERPOLATED_NONE) {
     PetscCall(DMPlexEqual(dm1, dm2, &flg));
-    if (!flg) PetscCall(PetscPrintf(comm, "Redistributed DMs are not equal, with %s with size %d.\n",user.repartitioning,size));
+    if (!flg) PetscCall(PetscPrintf(comm, "Redistributed DMs are not equal, with %s with size %d.\n", user.repartitioning, size));
   }
 
   /* cleanup */
