@@ -1,7 +1,6 @@
 
 /*
     This file implements flexible BiCGStab (FBiCGStab).
-    Only allow right preconditioning.
 */
 #include <../src/ksp/ksp/impls/bcgs/bcgsimpl.h> /*I  "petscksp.h"  I*/
 
@@ -9,7 +8,7 @@ static PetscErrorCode KSPSetUp_FBCGS(KSP ksp)
 {
   PetscFunctionBegin;
   PetscCall(KSPSetWorkVecs(ksp, 8));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Only need a few hacks from KSPSolve_BCGS */
@@ -36,8 +35,6 @@ static PetscErrorCode KSPSolve_FBCGS(KSP ksp)
   S2 = ksp->work[6];
   P2 = ksp->work[7];
 
-  /* Only supports right preconditioning */
-  PetscCheck(ksp->pc_side == PC_RIGHT, PetscObjectComm((PetscObject)ksp), PETSC_ERR_SUP, "KSP fbcgs does not support %s", PCSides[ksp->pc_side]);
   if (!ksp->guess_zero) {
     if (!bcgs->guess) PetscCall(VecDuplicate(X, &bcgs->guess));
     PetscCall(VecCopy(X, bcgs->guess));
@@ -66,7 +63,7 @@ static PetscErrorCode KSPSolve_FBCGS(KSP ksp)
   PetscCall(KSPLogResidualHistory(ksp, dp));
   PetscCall(KSPMonitor(ksp, 0, dp));
   PetscCall((*ksp->converged)(ksp, 0, dp, &ksp->reason, ksp->cnvP));
-  if (ksp->reason) PetscFunctionReturn(0);
+  if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* Make the initial Rp == R */
   PetscCall(VecCopy(R, RP));
@@ -146,21 +143,25 @@ static PetscErrorCode KSPSolve_FBCGS(KSP ksp)
   } while (i < ksp->max_it);
 
   if (i >= ksp->max_it) ksp->reason = KSP_DIVERGED_ITS;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
-     KSPFBCGS - Implements flexible BiCGStab method.
-
-   Options Database Keys:
-    see KSPSolve()
+     KSPFBCGS - Implements the flexible BiCGStab method. [](sec_flexibleksp)
 
    Level: beginner
 
    Notes:
-    Only allow right preconditioning
+   Flexible BiCGStab, unlike most Krylov methods allows the preconditioner to be nonlinear, that is the action of the preconditioner to a vector need not be linear
+   in the vector entries.
 
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPBICG`, `KSPFBCGSL`, `KSPSetPCSide()`
+   `KSPFBCGSR` provides another variant of this algorithm that requires fewer `MPI_Allreduce()` calls and my converge faster
+
+   See `KSPPIPEBCGS` for a pipelined version of the algorithm
+
+   Only supportst right preconditioning
+
+.seealso: [](chapter_ksp),  [](sec_flexibleksp), `KSPFBCGSR`, `KSPPIPEBCGS`, `KSPBCGSL`, `KSPFBCGS`, `KSPCreate()`, `KSPFGMRES`, `KSPSetType()`, `KSPType`, `KSP`, `KSPBICG`, `KSPSetPCSide()`
 M*/
 PETSC_EXTERN PetscErrorCode KSPCreate_FBCGS(KSP ksp)
 {
@@ -176,11 +177,9 @@ PETSC_EXTERN PetscErrorCode KSPCreate_FBCGS(KSP ksp)
   ksp->ops->reset          = KSPReset_BCGS;
   ksp->ops->buildresidual  = KSPBuildResidualDefault;
   ksp->ops->setfromoptions = KSPSetFromOptions_BCGS;
-  ksp->pc_side             = PC_RIGHT; /* set default PC side */
+  ksp->pc_side             = PC_RIGHT;
 
-  PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_PRECONDITIONED, PC_LEFT, 3));
   PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_UNPRECONDITIONED, PC_RIGHT, 2));
-  PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_NONE, PC_LEFT, 1));
   PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_NONE, PC_RIGHT, 1));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
