@@ -1,7 +1,6 @@
 
 /*
     This file implements FBiCGStab-R.
-    Only allow right preconditioning.
     FBiCGStab-R is a mathematically equivalent variant of FBiCGStab. Differences are:
       (1) There are fewer MPI_Allreduce calls.
       (2) The convergence occasionally is much faster than that of FBiCGStab.
@@ -13,7 +12,7 @@ static PetscErrorCode KSPSetUp_FBCGSR(KSP ksp)
 {
   PetscFunctionBegin;
   PetscCall(KSPSetWorkVecs(ksp, 8));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSolve_FBCGSR(KSP ksp)
@@ -38,7 +37,7 @@ static PetscErrorCode KSPSolve_FBCGSR(KSP ksp)
   B  = ksp->vec_rhs;
   P2 = ksp->work[0];
 
-  /* The followings are involved in modified inner product calculations and vector updates */
+  /* The following are involved in modified inner product calculations and vector updates */
   RP = ksp->work[1];
   PetscCall(VecGetArray(RP, (PetscScalar **)&rp));
   PetscCall(VecRestoreArray(RP, NULL));
@@ -92,7 +91,7 @@ static PetscErrorCode KSPSolve_FBCGSR(KSP ksp)
   PetscCall(KSPLogResidualHistory(ksp, ksp->rnorm));
   PetscCall(KSPMonitor(ksp, 0, ksp->rnorm));
   PetscCall((*ksp->converged)(ksp, 0, ksp->rnorm, &ksp->reason, ksp->cnvP));
-  if (ksp->reason) PetscFunctionReturn(0);
+  if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* Initialize iterates */
   PetscCall(VecCopy(R, RP)); /* rp <- r */
@@ -199,21 +198,25 @@ static PetscErrorCode KSPSolve_FBCGSR(KSP ksp)
   }
 
   if (i >= ksp->max_it) ksp->reason = KSP_DIVERGED_ITS;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
-     KSPFBCGSR - Implements a mathematically equivalent variant of FBiCGSTab.
-
-   Options Database Keys:
-    see KSPSolve()
+     KSPFBCGSR - Implements a mathematically equivalent variant of flexible bi-CG-stab, `KSPFBCGS`. [](sec_flexibleksp)
 
    Level: beginner
 
    Notes:
-    Only allow right preconditioning
+   This implementation requires fewer `MPI_Allreduce()` calls than `KSPFBCGS` and may converge faster
 
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPBICG`, `KSPFBCGSL`, `KSPSetPCSide()`
+   See `KSPPIPEBCGS` for a pipelined version of the algorithm
+
+   Flexible BiCGStab, unlike most Krylov methods, allows the preconditioner to be nonlinear, that is the action of the preconditioner to a vector need not be linear
+   in the vector entries.
+
+   Only supports right preconditioning
+
+.seealso: [](chapter_ksp),  [](sec_flexibleksp), `KSPFBCGSR`, `KSPPIPEBCGS`, `KSPBCGSL`, `KSPBCGS`, `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPBICG`, `KSPFBCGS`, `KSPSetPCSide()`
 M*/
 PETSC_EXTERN PetscErrorCode KSPCreate_FBCGSR(KSP ksp)
 {
@@ -235,5 +238,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_FBCGSR(KSP ksp)
   PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_PRECONDITIONED, PC_LEFT, 3));
   PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_UNPRECONDITIONED, PC_RIGHT, 2));
   PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_NONE, PC_RIGHT, 1));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
