@@ -1,7 +1,6 @@
 
 /*
     This file implements pipelined BiCGStab (pipe-BiCGStab).
-    Only allow right preconditioning.
 */
 #include <../src/ksp/ksp/impls/bcgs/bcgsimpl.h> /*I  "petscksp.h"  I*/
 
@@ -9,7 +8,7 @@ static PetscErrorCode KSPSetUp_PIPEBCGS(KSP ksp)
 {
   PetscFunctionBegin;
   PetscCall(KSPSetWorkVecs(ksp, 15));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Only need a few hacks from KSPSolve_BCGS */
@@ -42,8 +41,6 @@ static PetscErrorCode KSPSolve_PIPEBCGS(KSP ksp)
   T  = ksp->work[13];
   V  = ksp->work[14];
 
-  /* Only supports right preconditioning */
-  PetscCheck(ksp->pc_side == PC_RIGHT, PetscObjectComm((PetscObject)ksp), PETSC_ERR_SUP, "KSP pipebcgs does not support %s", PCSides[ksp->pc_side]);
   if (!ksp->guess_zero) {
     if (!bcgs->guess) PetscCall(VecDuplicate(X, &bcgs->guess));
     PetscCall(VecCopy(X, bcgs->guess));
@@ -73,7 +70,7 @@ static PetscErrorCode KSPSolve_PIPEBCGS(KSP ksp)
   PetscCall(KSPLogResidualHistory(ksp, dp));
   PetscCall(KSPMonitor(ksp, 0, dp));
   PetscCall((*ksp->converged)(ksp, 0, dp, &ksp->reason, ksp->cnvP));
-  if (ksp->reason) PetscFunctionReturn(0);
+  if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* Initialize */
   PetscCall(VecCopy(R, RP)); /* rp <- r */
@@ -200,37 +197,36 @@ static PetscErrorCode KSPSolve_PIPEBCGS(KSP ksp)
   } while (i < ksp->max_it);
 
   if (i >= ksp->max_it) ksp->reason = KSP_DIVERGED_ITS;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
-    KSPPIPEBCGS - Implements the pipelined BiCGStab method.
+    KSPPIPEBCGS - Implements a pipelined BiCGStab method. [](sec_pipelineksp)
 
+    Level: intermediate
+
+    Notes:
     This method has only two non-blocking reductions per iteration, compared to 3 blocking for standard FBCGS.  The
     non-blocking reductions are overlapped by matrix-vector products and preconditioner applications.
 
     Periodic residual replacement may be used to increase robustness and maximal attainable accuracy.
 
-    Options Database Keys:
-    see KSPSolve()
+    Like `KSPFBCGS`, the `KSPPIPEBCGS` implementation only allows for right preconditioning.
 
-    Level: intermediate
-
-    Notes:
-    Like KSPFBCGS, the KSPPIPEBCGS implementation only allows for right preconditioning.
     MPI configuration may be necessary for reductions to make asynchronous progress, which is important for
-    performance of pipelined methods. See the FAQ on the PETSc website for details.
+    performance of pipelined methods. See [](doc_faq_pipelined)
 
     Contributed by:
     Siegfried Cools, Universiteit Antwerpen,
     EXA2CT European Project on EXascale Algorithms and Advanced Computational Techniques, 2016.
 
     Reference:
-    S. Cools and W. Vanroose,
+.   * - S. Cools and W. Vanroose,
     "The communication-hiding pipelined BiCGStab method for the parallel solution of large unsymmetric linear systems",
     Parallel Computing, 65:1-20, 2017.
 
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPBICG`, `KSPFBCGS`, `KSPFBCGSL`, `KSPSetPCSide()`
+.seealso: [](chapter_ksp), `KSPFBCGS`, `KSPFBCGSR`, `KSPBCGS`, `KSPBCGSL`, `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPBICG`, `KSPFBCGS`, `KSPSetPCSide()`,
+           [](sec_pipelineksp), [](doc_faq_pipelined)
 M*/
 PETSC_EXTERN PetscErrorCode KSPCreate_PIPEBCGS(KSP ksp)
 {
@@ -249,5 +245,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_PIPEBCGS(KSP ksp)
 
   PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_UNPRECONDITIONED, PC_RIGHT, 2));
   PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_NONE, PC_RIGHT, 1));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
