@@ -5,7 +5,7 @@ static PetscErrorCode KSPSetUp_BiCG(KSP ksp)
 {
   PetscFunctionBegin;
   PetscCall(KSPSetWorkVecs(ksp, 6));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSolve_BiCG(KSP ksp)
@@ -55,7 +55,7 @@ static PetscErrorCode KSPSolve_BiCG(KSP ksp)
   PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
   PetscCall(KSPLogResidualHistory(ksp, dp));
   PetscCall((*ksp->converged)(ksp, 0, dp, &ksp->reason, ksp->cnvP));
-  if (ksp->reason) PetscFunctionReturn(0);
+  if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   i = 0;
   do {
@@ -64,7 +64,7 @@ static PetscErrorCode KSPSolve_BiCG(KSP ksp)
     if (!i) {
       if (beta == 0.0) {
         ksp->reason = KSP_DIVERGED_BREAKDOWN_BICG;
-        PetscFunctionReturn(0);
+        PetscFunctionReturn(PETSC_SUCCESS);
       }
       PetscCall(VecCopy(Zr, Pr)); /*     p <- z          */
       PetscCall(VecCopy(Zl, Pl));
@@ -109,28 +109,26 @@ static PetscErrorCode KSPSolve_BiCG(KSP ksp)
     i++;
   } while (i < ksp->max_it);
   if (i >= ksp->max_it) ksp->reason = KSP_DIVERGED_ITS;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
      KSPBICG - Implements the Biconjugate gradient method (similar to running the conjugate
          gradient on the normal equations).
 
-   Options Database Keys:
-   see KSPSolve()
-
    Level: beginner
 
    Notes:
-    this method requires that one be apply to apply the transpose of the preconditioner and operator
-         as well as the operator and preconditioner.
-         Supports only left preconditioning
+   This method requires that one be apply to apply the transpose of the preconditioner and operator
+   as well as the operator and preconditioner.
 
-         See KSPCGNE for code that EXACTLY runs the preconditioned conjugate gradient method on the
-         normal equations
+   Supports only left preconditioning
 
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPBCGS`, `KSPCGNE`
+   See `KSPCGNE` for code that EXACTLY runs the preconditioned conjugate gradient method on the normal equations
 
+   See `KSPBCGS` for the famous stabilized variant of this algorithm
+
+.seealso: [](chapter_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPBCGS`, `KSPCGNE`
 M*/
 PETSC_EXTERN PetscErrorCode KSPCreate_BiCG(KSP ksp)
 {
@@ -146,5 +144,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_BiCG(KSP ksp)
   ksp->ops->setfromoptions = NULL;
   ksp->ops->buildsolution  = KSPBuildSolutionDefault;
   ksp->ops->buildresidual  = KSPBuildResidualDefault;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
