@@ -45,6 +45,24 @@
 extern PetscErrorCode KSPComputeExtremeSingularValues_CG(KSP, PetscReal *, PetscReal *);
 extern PetscErrorCode KSPComputeEigenvalues_CG(KSP, PetscInt, PetscReal *, PetscReal *, PetscInt *);
 
+static PetscErrorCode KSPCGSetObjectiveTarget_CG(KSP ksp, PetscReal obj_min)
+{
+  KSP_CG *cg = (KSP_CG *)ksp->data;
+
+  PetscFunctionBegin;
+  cg->obj_min = obj_min;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+static PetscErrorCode KSPCGSetRadius_CG(KSP ksp, PetscReal radius)
+{
+  KSP_CG *cg = (KSP_CG *)ksp->data;
+
+  PetscFunctionBegin;
+  cg->radius = radius;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
 /*
      KSPSetUp_CG - Sets up the workspace needed by the CG method.
 
@@ -72,7 +90,7 @@ static PetscErrorCode KSPSetUp_CG(KSP ksp)
     ksp->ops->computeextremesingularvalues = KSPComputeExtremeSingularValues_CG;
     ksp->ops->computeeigenvalues           = KSPComputeEigenvalues_CG;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -95,10 +113,11 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
   PetscInt    i, stored_max_it, eigs;
   PetscScalar dpi = 0.0, a = 1.0, beta, betaold = 1.0, b = 0, *e = NULL, *d = NULL, dpiold;
   PetscReal   dp = 0.0;
+  PetscReal   r2, norm_p, norm_d, dMp;
   Vec         X, B, Z, R, P, W;
   KSP_CG     *cg;
   Mat         Amat, Pmat;
-  PetscBool   diagonalscale;
+  PetscBool   diagonalscale, testobj;
 
   PetscFunctionBegin;
   PetscCall(PCGetDiagonalScale(ksp->pc, &diagonalscale));
@@ -113,6 +132,7 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
   Z             = ksp->work[1];
   P             = ksp->work[2];
   W             = Z;
+  r2            = PetscSqr(cg->radius);
 
   if (eigs) {
     e    = cg->e;
@@ -124,9 +144,15 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
   ksp->its = 0;
   if (!ksp->guess_zero) {
     PetscCall(KSP_MatMult(ksp, Amat, X, R)); /*    r <- b - Ax                       */
+
     PetscCall(VecAYPX(R, -1.0, B));
+    if (cg->radius) { /* XXX direction? */
+      PetscCall(VecNorm(X, NORM_2, &norm_d));
+      norm_d *= norm_d;
+    }
   } else {
     PetscCall(VecCopy(B, R)); /*    r <- b (x is 0)                   */
+    norm_d = 0.0;
   }
   /* This may be true only on a subset of MPI ranks; setting it here so it will be detected by the first norm computation below */
   if (ksp->reason == KSP_DIVERGED_PC_FAILED) PetscCall(VecSetInf(R));
@@ -153,12 +179,28 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
   default:
     SETERRQ(PetscObjectComm((PetscObject)ksp), PETSC_ERR_SUP, "%s", KSPNormTypes[ksp->normtype]);
   }
+
+  /* Initialize objective function
+     obj = 1/2 x^T A x - x^T b */
+  testobj = (PetscBool)(cg->obj_min < 0.0);
+  PetscCall(VecXDot(R, X, &a));
+  cg->obj = 0.5 * PetscRealPart(a);
+  PetscCall(VecXDot(B, X, &a));
+  cg->obj -= 0.5 * PetscRealPart(a);
+
+  PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " obj %g\n", ksp->its, (double)cg->obj));
   PetscCall(KSPLogResidualHistory(ksp, dp));
-  PetscCall(KSPMonitor(ksp, 0, dp));
+  PetscCall(KSPMonitor(ksp, ksp->its, dp));
   ksp->rnorm = dp;
 
-  PetscCall((*ksp->converged)(ksp, 0, dp, &ksp->reason, ksp->cnvP)); /* test for convergence */
-  if (ksp->reason) PetscFunctionReturn(0);
+  PetscCall((*ksp->converged)(ksp, ksp->its, dp, &ksp->reason, ksp->cnvP)); /* test for convergence */
+
+  if (!ksp->reason && testobj && cg->obj <= cg->obj_min) {
+    PetscCall(PetscInfo(ksp, "converged to objective target minimum\n"));
+    ksp->reason = KSP_CONVERGED_ATOL;
+  }
+
+  if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   if (ksp->normtype != KSP_NORM_PRECONDITIONED && (ksp->normtype != KSP_NORM_NATURAL)) { PetscCall(KSP_PCApply(ksp, R, Z)); /*     z <- Br                           */ }
   if (ksp->normtype != KSP_NORM_NATURAL) {
@@ -183,6 +225,12 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
     }
     if (!i) {
       PetscCall(VecCopy(Z, P)); /*     p <- z                           */
+      if (cg->radius) {
+        PetscCall(VecNorm(P, NORM_2, &norm_p));
+        norm_p *= norm_p;
+        dMp = 0.0;
+        if (!ksp->guess_zero) { PetscCall(VecDotRealPart(X, P, &dMp)); }
+      }
       b = 0.0;
     } else {
       b = beta / betaold;
@@ -191,6 +239,11 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
         e[i] = PetscSqrtReal(PetscAbsScalar(b)) / a;
       }
       PetscCall(VecAYPX(P, b, Z)); /*     p <- z + b* p                    */
+      if (cg->radius) {
+        PetscCall(VecDotRealPart(X, P, &dMp));
+        PetscCall(VecNorm(P, NORM_2, &norm_p));
+        norm_p *= norm_p;
+      }
     }
     dpiold = dpi;
     PetscCall(KSP_MatMult(ksp, Amat, P, W)); /*     w <- Ap                          */
@@ -199,13 +252,48 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
     betaold = beta;
 
     if ((dpi == 0.0) || ((i > 0) && ((PetscSign(PetscRealPart(dpi)) * PetscSign(PetscRealPart(dpiold))) < 0.0))) {
-      PetscCheck(!ksp->errorifnotconverged, PetscObjectComm((PetscObject)ksp), PETSC_ERR_NOT_CONVERGED, "Diverged due to indefinite matrix, dpi %g, dpiold %g", (double)PetscRealPart(dpi), (double)PetscRealPart(dpiold));
-      ksp->reason = KSP_DIVERGED_INDEFINITE_MAT;
-      PetscCall(PetscInfo(ksp, "diverging due to indefinite or negative definite matrix\n"));
+      if (cg->radius) {
+        a = 0.0;
+        if (i == 0) {
+          if (norm_p > 0.0) {
+            a = PetscSqrtReal(r2 / norm_p);
+          } else {
+            PetscCall(VecNorm(R, NORM_2, &dp));
+            a = cg->radius > dp ? 1.0 : cg->radius / dp;
+          }
+        } else if (norm_p > 0.0) {
+          a = (PetscSqrtReal(dMp * dMp + norm_p * (r2 - norm_d)) - dMp) / norm_p;
+        }
+        PetscCall(VecAXPY(X, a, P)); /*     x <- x + ap                      */
+        cg->obj += PetscRealPart(a * (0.5 * a * dpi - betaold));
+      }
+      PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " N obj %g\n", i + 1, (double)cg->obj));
+      if (ksp->converged_neg_curve) {
+        PetscCall(PetscInfo(ksp, "converged due to negative curvature: %g\n", (double)(PetscRealPart(dpi))));
+        ksp->reason = KSP_CONVERGED_NEG_CURVE;
+      } else {
+        PetscCheck(!ksp->errorifnotconverged, PetscObjectComm((PetscObject)ksp), PETSC_ERR_NOT_CONVERGED, "Diverged due to indefinite matrix, dpi %g, dpiold %g", (double)PetscRealPart(dpi), (double)PetscRealPart(dpiold));
+        ksp->reason = KSP_DIVERGED_INDEFINITE_MAT;
+        PetscCall(PetscInfo(ksp, "diverging due to indefinite matrix\n"));
+      }
       break;
     }
     a = beta / dpi; /*     a = beta/p'w                     */
     if (eigs) d[i] = PetscSqrtReal(PetscAbsScalar(b)) * e[i] + 1.0 / a;
+    if (cg->radius) { /* Steihaugh-Toint */
+      PetscReal norm_dp1 = norm_d + PetscRealPart(a) * (2.0 * dMp + PetscRealPart(a) * norm_p);
+      if (norm_dp1 > r2) {
+        ksp->reason = KSP_CONVERGED_STEP_LENGTH;
+        PetscCall(PetscInfo(ksp, "converged to the trust region radius %g\n", (double)cg->radius));
+        if (norm_p > 0.0) {
+          dp = (PetscSqrtReal(dMp * dMp + norm_p * (r2 - norm_d)) - dMp) / norm_p;
+          PetscCall(VecAXPY(X, dp, P)); /*     x <- x + ap                      */
+          cg->obj += PetscRealPart(dp * (0.5 * dp * dpi - beta));
+        }
+        PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " R obj %g\n", i + 1, (double)cg->obj));
+        break;
+      }
+    }
     PetscCall(VecAXPY(X, a, P));  /*     x <- x + ap                      */
     PetscCall(VecAXPY(R, -a, W)); /*     r <- r - aw                      */
     if (ksp->normtype == KSP_NORM_PRECONDITIONED && ksp->chknorm < i + 2) {
@@ -223,12 +311,26 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
     } else {
       dp = 0.0;
     }
+    cg->obj -= PetscRealPart(0.5 * a * betaold);
+    PetscCall(PetscInfo(ksp, "it %" PetscInt_FMT " obj %g\n", i + 1, (double)cg->obj));
+
     ksp->rnorm = dp;
     PetscCall(KSPLogResidualHistory(ksp, dp));
     PetscCall(KSPMonitor(ksp, i + 1, dp));
     PetscCall((*ksp->converged)(ksp, i + 1, dp, &ksp->reason, ksp->cnvP));
+
+    if (!ksp->reason && testobj && cg->obj <= cg->obj_min) {
+      PetscCall(PetscInfo(ksp, "converged to objective target minimum\n"));
+      ksp->reason = KSP_CONVERGED_ATOL;
+    }
+
     if (ksp->reason) break;
 
+    if (cg->radius) {
+      PetscCall(VecNorm(X, NORM_2, &norm_d));
+      norm_d *= norm_d;
+    }
+
     if ((ksp->normtype != KSP_NORM_PRECONDITIONED && (ksp->normtype != KSP_NORM_NATURAL)) || (ksp->chknorm >= i + 2)) { PetscCall(KSP_PCApply(ksp, R, Z)); /*     z <- Br                          */ }
     if ((ksp->normtype != KSP_NORM_NATURAL) || (ksp->chknorm >= i + 2)) {
       PetscCall(VecXDot(Z, R, &beta)); /*     beta <- z'*r                     */
@@ -238,7 +340,7 @@ static PetscErrorCode KSPSolve_CG(KSP ksp)
     i++;
   } while (i < ksp->max_it);
   if (i >= ksp->max_it) ksp->reason = KSP_DIVERGED_ITS;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -320,7 +422,7 @@ static PetscErrorCode KSPSolve_CG_SingleReduction(KSP ksp)
   ksp->rnorm = dp;
 
   PetscCall((*ksp->converged)(ksp, 0, dp, &ksp->reason, ksp->cnvP)); /* test for convergence */
-  if (ksp->reason) PetscFunctionReturn(0);
+  if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   if (ksp->normtype != KSP_NORM_PRECONDITIONED && (ksp->normtype != KSP_NORM_NATURAL)) { PetscCall(KSP_PCApply(ksp, R, Z)); /*    z <- Br                           */ }
   if (ksp->normtype != KSP_NORM_NATURAL) {
@@ -420,7 +522,7 @@ static PetscErrorCode KSPSolve_CG_SingleReduction(KSP ksp)
     i++;
   } while (i < ksp->max_it);
   if (i >= ksp->max_it) ksp->reason = KSP_DIVERGED_ITS;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -436,9 +538,11 @@ PetscErrorCode KSPDestroy_CG(KSP ksp)
   PetscFunctionBegin;
   PetscCall(PetscFree4(cg->e, cg->d, cg->ee, cg->dd));
   PetscCall(KSPDestroyDefault(ksp));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPCGSetObjectiveTarget_C", NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPCGSetRadius_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPCGSetType_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPCGUseSingleReduction_C", NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -459,7 +563,7 @@ PetscErrorCode KSPView_CG(KSP ksp, PetscViewer viewer)
 #endif
     if (cg->singlereduction) PetscCall(PetscViewerASCIIPrintf(viewer, "  using single-reduction variant\n"));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -479,7 +583,7 @@ PetscErrorCode KSPSetFromOptions_CG(KSP ksp, PetscOptionItems *PetscOptionsObjec
   PetscCall(PetscOptionsBool("-ksp_cg_single_reduction", "Merge inner products into single MPI_Allreduce()", "KSPCGUseSingleReduction", cg->singlereduction, &cg->singlereduction, &flg));
   if (flg) PetscCall(KSPCGUseSingleReduction(ksp, cg->singlereduction));
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -493,7 +597,7 @@ PetscErrorCode KSPCGSetType_CG(KSP ksp, KSPCGType type)
 
   PetscFunctionBegin;
   cg->type = type;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -514,7 +618,7 @@ static PetscErrorCode KSPCGUseSingleReduction_CG(KSP ksp, PetscBool flg)
   } else {
     ksp->ops->solve = KSPSolve_CG;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_INTERN PetscErrorCode KSPBuildResidual_CG(KSP ksp, Vec t, Vec v, Vec *V)
@@ -522,22 +626,16 @@ PETSC_INTERN PetscErrorCode KSPBuildResidual_CG(KSP ksp, Vec t, Vec v, Vec *V)
   PetscFunctionBegin;
   PetscCall(VecCopy(ksp->work[0], v));
   *V = v;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*
-    KSPCreate_CG - Creates the data structure for the Krylov method CG and sets the
-       function pointers for all the routines it needs to call (KSPSolve_CG() etc)
-
-    It must be labeled as PETSC_EXTERN to be dynamically linkable in C++
-*/
 /*MC
      KSPCG - The Preconditioned Conjugate Gradient (PCG) iterative method
 
    Options Database Keys:
-+   -ksp_cg_type Hermitian - (for complex matrices only) indicates the matrix is Hermitian, see KSPCGSetType()
++   -ksp_cg_type Hermitian - (for complex matrices only) indicates the matrix is Hermitian, see `KSPCGSetType()`
 .   -ksp_cg_type symmetric - (for complex matrices only) indicates the matrix is symmetric
--   -ksp_cg_single_reduction - performs both inner products needed in the algorithm with a single MPI_Allreduce() call, see KSPCGUseSingleReduction()
+-   -ksp_cg_single_reduction - performs both inner products needed in the algorithm with a single `MPI_Allreduce()` call, see `KSPCGUseSingleReduction()`
 
    Level: beginner
 
@@ -553,11 +651,13 @@ PETSC_INTERN PetscErrorCode KSPBuildResidual_CG(KSP ksp, Vec t, Vec v, Vec *V)
 .n  In all cases, the resulting algorithm only requires application of B to vectors.
 
    For complex numbers there are two different CG methods, one for Hermitian symmetric matrices and one for non-Hermitian symmetric matrices. Use
-   KSPCGSetType() to indicate which type you are using.
+   `KSPCGSetType()` to indicate which type you are using.
+
+   One can use `KSPSetComputeEigenvalues()` and `KSPComputeEigenvalues()` to compute the eigenvalues of the (preconditioned) operator
 
    Developer Notes:
     KSPSolve_CG() should actually query the matrix to determine if it is Hermitian symmetric or not and NOT require the user to
-   indicate it to the KSP object.
+   indicate it to the `KSP` object.
 
    References:
 +  * - Magnus R. Hestenes and Eduard Stiefel, Methods of Conjugate Gradients for Solving Linear Systems,
@@ -565,10 +665,16 @@ PETSC_INTERN PetscErrorCode KSPBuildResidual_CG(KSP ksp, Vec t, Vec v, Vec *V)
 -  * - Josef Malek and Zdenek Strakos, Preconditioning and the Conjugate Gradient Method in the Context of Solving PDEs,
     SIAM, 2014.
 
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`,
+.seealso: [](chapter_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPSetComputeEigenvalues()`, `KSPComputeEigenvalues()`
           `KSPCGSetType()`, `KSPCGUseSingleReduction()`, `KSPPIPECG`, `KSPGROPPCG`
-
 M*/
+
+/*
+    KSPCreate_CG - Creates the data structure for the Krylov method CG and sets the
+       function pointers for all the routines it needs to call (KSPSolve_CG() etc)
+
+    It must be labeled as PETSC_EXTERN to be dynamically linkable in C++
+*/
 PETSC_EXTERN PetscErrorCode KSPCreate_CG(KSP ksp)
 {
   KSP_CG *cg;
@@ -580,7 +686,8 @@ PETSC_EXTERN PetscErrorCode KSPCreate_CG(KSP ksp)
 #else
   cg->type = KSP_CG_HERMITIAN;
 #endif
-  ksp->data = (void *)cg;
+  cg->obj_min = 0.0;
+  ksp->data   = (void *)cg;
 
   PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_PRECONDITIONED, PC_LEFT, 3));
   PetscCall(KSPSetSupportedNorm(ksp, KSP_NORM_UNPRECONDITIONED, PC_LEFT, 2));
@@ -606,5 +713,7 @@ PETSC_EXTERN PetscErrorCode KSPCreate_CG(KSP ksp)
   */
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPCGSetType_C", KSPCGSetType_CG));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPCGUseSingleReduction_C", KSPCGUseSingleReduction_CG));
-  PetscFunctionReturn(0);
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPCGSetRadius_C", KSPCGSetRadius_CG));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPCGSetObjectiveTarget_C", KSPCGSetObjectiveTarget_CG));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
