@@ -6,7 +6,7 @@
     use for solving a linear system with a complex coefficient matrix.
     This option is irrelevant when solving a real system.
 
-    Logically Collective on ksp
+    Logically Collective
 
     Input Parameters:
 +   ksp - the iterative context
@@ -16,12 +16,12 @@
       KSP_CG_SYMMETRIC - complex, symmetric matrix
 .ve
 
-    Level: intermediate
-
     Options Database Keys:
 +   -ksp_cg_hermitian - Indicates Hermitian matrix
 -   -ksp_cg_symmetric - Indicates symmetric matrix
 
+    Level: intermediate
+
     Note:
     By default, the matrix is assumed to be complex, Hermitian.
 
@@ -32,13 +32,13 @@ PetscErrorCode KSPCGSetType(KSP ksp, KSPCGType type)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscTryMethod(ksp, "KSPCGSetType_C", (KSP, KSPCGType), (ksp, type));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     KSPCGUseSingleReduction - Merge the two inner products needed in `KSPCG` into a single `MPI_Allreduce()` call.
 
-    Logically Collective on ksp
+    Logically Collective
 
     Input Parameters:
 +   ksp - the iterative context
@@ -68,20 +68,23 @@ PetscErrorCode KSPCGUseSingleReduction(KSP ksp, PetscBool flg)
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscValidLogicalCollectiveBool(ksp, flg, 2);
   PetscTryMethod(ksp, "KSPCGUseSingleReduction_C", (KSP, PetscBool), (ksp, flg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-    KSPCGSetRadius - Sets the radius of the trust region when the solver is used inside `SNESNEWTONTR`
+    KSPCGSetRadius - Sets the radius of the trust region
 
-    Logically Collective on ksp
+    Logically Collective
 
     Input Parameters:
 +   ksp    - the iterative context
--   radius - the trust region radius (Infinity is the default)
+-   radius - the trust region radius (0 is the default that disable the use of the radius)
 
     Level: advanced
 
+    Note:
+    When radius is greater then 0, the Steihaugh-Toint trick is used
+
 .seealso: [](chapter_ksp), `KSP`, `KSPCG`, `KSPNASH`, `KSPSTCG`, `KSPGLTR`
 @*/
 PetscErrorCode KSPCGSetRadius(KSP ksp, PetscReal radius)
@@ -90,13 +93,40 @@ PetscErrorCode KSPCGSetRadius(KSP ksp, PetscReal radius)
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscValidLogicalCollectiveReal(ksp, radius, 2);
   PetscTryMethod(ksp, "KSPCGSetRadius_C", (KSP, PetscReal), (ksp, radius));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@
+    KSPCGSetObjectiveTarget - Sets the target value for the quadratic model reduction
+
+    Logically Collective
+
+    Input Parameters:
++   ksp - the iterative context
+-   obj - the objective value (0 is the default)
+
+    Level: advanced
+
+    Note:
+    The CG process will stop when the current objective function
+           1/2 x_k * A * x_k - b * x_k is smaller than obj if obj is negative.
+           Otherwise the test is ignored.
+
+.seealso: [](chapter_ksp), `KSP`, `KSPCG`, `KSPNASH`, `KSPSTCG`, `KSPGLTR`
+@*/
+PetscErrorCode KSPCGSetObjectiveTarget(KSP ksp, PetscReal obj)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
+  PetscValidLogicalCollectiveReal(ksp, obj, 2);
+  PetscTryMethod(ksp, "KSPCGSetObjectiveTarget_C", (KSP, PetscReal), (ksp, obj));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     KSPCGGetNormD - Got norm of the direction when the solver is used inside `SNESNEWTONTR`
 
-    Collective on ksp
+    Collective
 
     Input Parameters:
 +   ksp    - the iterative context
@@ -111,13 +141,13 @@ PetscErrorCode KSPCGGetNormD(KSP ksp, PetscReal *norm_d)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscUseMethod(ksp, "KSPCGGetNormD_C", (KSP, PetscReal *), (ksp, norm_d));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     KSPCGGetObjFcn - Get objective function value when the solver is used inside `SNESNEWTONTR`
 
-    Collective on ksp
+    Collective
 
     Input Parameters:
 +   ksp   - the iterative context
@@ -132,5 +162,5 @@ PetscErrorCode KSPCGGetObjFcn(KSP ksp, PetscReal *o_fcn)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscUseMethod(ksp, "KSPCGGetObjFcn_C", (KSP, PetscReal *), (ksp, o_fcn));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
