@@ -12,7 +12,7 @@ static PetscErrorCode KSPSetUp_PIPECG(KSP ksp)
   PetscFunctionBegin;
   /* get work vectors needed by PIPECG */
   PetscCall(KSPSetWorkVecs(ksp, 9));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -87,7 +87,7 @@ static PetscErrorCode KSPSolve_PIPECG(KSP ksp)
   PetscCall(KSPMonitor(ksp, 0, dp));
   ksp->rnorm = dp;
   PetscCall((*ksp->converged)(ksp, 0, dp, &ksp->reason, ksp->cnvP)); /* test for convergence */
-  if (ksp->reason) PetscFunctionReturn(0);
+  if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   i = 0;
   do {
@@ -119,7 +119,7 @@ static PetscErrorCode KSPSolve_PIPECG(KSP ksp)
       PetscCall(KSPLogResidualHistory(ksp, dp));
       PetscCall(KSPMonitor(ksp, i, dp));
       PetscCall((*ksp->converged)(ksp, i, dp, &ksp->reason, ksp->cnvP));
-      if (ksp->reason) PetscFunctionReturn(0);
+      if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
     }
 
     if (i == 0) {
@@ -153,24 +153,24 @@ static PetscErrorCode KSPSolve_PIPECG(KSP ksp)
 
   } while (i <= ksp->max_it);
   if (!ksp->reason) ksp->reason = KSP_DIVERGED_ITS;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_INTERN PetscErrorCode KSPBuildResidual_CG(KSP, Vec, Vec, Vec *);
 
 /*MC
-   KSPPIPECG - Pipelined conjugate gradient method.
-
-   This method has only a single non-blocking reduction per iteration, compared to 2 blocking for standard CG.  The
-   non-blocking reduction is overlapped by the matrix-vector product and preconditioner application.
-
-   See also KSPPIPECR, where the reduction is only overlapped with the matrix-vector product.
+   KSPPIPECG - Pipelined conjugate gradient method. [](sec_pipelineksp)
 
    Level: intermediate
 
    Notes:
+   This method has only a single non-blocking reduction per iteration, compared to 2 blocking for standard CG.  The
+   non-blocking reduction is overlapped by the matrix-vector product and preconditioner application.
+
+   See also `KSPPIPECR`, where the reduction is only overlapped with the matrix-vector product and `KSPGROPPCG`
+
    MPI configuration may be necessary for reductions to make asynchronous progress, which is important for performance of pipelined methods.
-   See the FAQ on the PETSc website for details.
+   See [](doc_faq_pipelined)
 
    Contributed by:
    Pieter Ghysels, Universiteit Antwerpen, Intel Exascience lab Flanders
@@ -179,7 +179,7 @@ PETSC_INTERN PetscErrorCode KSPBuildResidual_CG(KSP, Vec, Vec, Vec *);
    P. Ghysels and W. Vanroose, "Hiding global synchronization latency in the preconditioned Conjugate Gradient algorithm",
    Submitted to Parallel Computing, 2012.
 
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPPIPECR`, `KSPGROPPCG`, `KSPPGMRES`, `KSPCG`, `KSPCGUseSingleReduction()`
+.seealso: [](chapter_ksp), [](doc_faq_pipelined), [](sec_pipelineksp), `KSPCreate()`, `KSPSetType()`, `KSPPIPECG2`, `KSPPIPECR`, `KSPGROPPCG`, `KSPPGMRES`, `KSPCG`, `KSPCGUseSingleReduction()`
 M*/
 PETSC_EXTERN PetscErrorCode KSPCreate_PIPECG(KSP ksp)
 {
@@ -196,5 +196,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_PIPECG(KSP ksp)
   ksp->ops->setfromoptions = NULL;
   ksp->ops->buildsolution  = KSPBuildSolutionDefault;
   ksp->ops->buildresidual  = KSPBuildResidual_CG;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
