@@ -55,7 +55,7 @@ static PetscErrorCode KSPSetUp_PIPELCG(KSP ksp)
   PetscCall(PetscCalloc1(2, &plcg->alpha));
   PetscCall(PetscCalloc1(l, &plcg->sigma));
 
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPReset_PIPELCG(KSP ksp)
@@ -70,7 +70,7 @@ static PetscErrorCode KSPReset_PIPELCG(KSP ksp)
   PetscCall(VecDestroyVecs(3, &plcg->U));
   PetscCall(VecDestroyVecs(3, &plcg->V));
   PetscCall(VecDestroyVecs(3 * (l - 1) + 1, &plcg->Q));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPDestroy_PIPELCG(KSP ksp)
@@ -78,7 +78,7 @@ static PetscErrorCode KSPDestroy_PIPELCG(KSP ksp)
   PetscFunctionBegin;
   PetscCall(KSPReset_PIPELCG(ksp));
   PetscCall(KSPDestroyDefault(ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSetFromOptions_PIPELCG(KSP ksp, PetscOptionItems *PetscOptionsObject)
@@ -97,7 +97,7 @@ static PetscErrorCode KSPSetFromOptions_PIPELCG(KSP ksp, PetscOptionItems *Petsc
   PetscCall(PetscOptionsBool("-ksp_pipelcg_monitor", "Output information on restarts when they occur? (default: 0)", "", plcg->show_rstrt, &plcg->show_rstrt, &flag));
   if (!flag) plcg->show_rstrt = PETSC_FALSE;
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MPIPetsc_Iallreduce(void *sendbuf, void *recvbuf, PetscMPIInt count, MPI_Datatype datatype, MPI_Op op, MPI_Comm comm, MPI_Request *request)
@@ -109,7 +109,7 @@ static PetscErrorCode MPIPetsc_Iallreduce(void *sendbuf, void *recvbuf, PetscMPI
   PetscCall(MPIU_Allreduce(sendbuf, recvbuf, count, datatype, op, comm));
   *request = MPI_REQUEST_NULL;
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPView_PIPELCG(KSP ksp, PetscViewer viewer)
@@ -129,7 +129,7 @@ static PetscErrorCode KSPView_PIPELCG(KSP ksp, PetscViewer viewer)
     PetscCall(PetscViewerStringSPrintf(viewer, "  Minimal eigenvalue estimate %g\n", (double)plcg->lmin));
     PetscCall(PetscViewerStringSPrintf(viewer, "  Maximal eigenvalue estimate %g\n", (double)plcg->lmax));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSolve_InnerLoop_PIPELCG(KSP ksp)
@@ -346,7 +346,7 @@ static PetscErrorCode KSPSolve_InnerLoop_PIPELCG(KSP ksp)
       }
     }
   } /* End inner for loop */
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSolve_ReInitData_PIPELCG(KSP ksp)
@@ -364,7 +364,7 @@ static PetscErrorCode KSPSolve_ReInitData_PIPELCG(KSP ksp)
     delta(j) = 0.0;
     for (i = 0; i < (2 * l + 1); ++i) G_noshift(i, j) = 0.0;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -434,14 +434,14 @@ static PetscErrorCode KSPSolve_PIPELCG(KSP ksp)
   PetscCall(PetscFree(plcg->gamma));
   PetscCall(PetscFree(plcg->delta));
   PetscCall(PetscFree(plcg->req));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
     KSPPIPELCG - Deep pipelined (length l) Conjugate Gradient method. This method has only a single non-blocking global
-    reduction per iteration, compared to 2 blocking reductions for standard CG. The reduction is overlapped by the
+    reduction per iteration, compared to 2 blocking reductions for standard `KSPCG`. The reduction is overlapped by the
     matrix-vector product and preconditioner application of the next l iterations. The pipeline length l is a parameter
-    of the method.
+    of the method. [](sec_pipelineksp)
 
     Options Database Keys:
 +   -ksp_pipelcg_pipel - pipelined length
@@ -449,25 +449,25 @@ static PetscErrorCode KSPSolve_PIPELCG(KSP ksp)
 .   -ksp_pipelcg_lmax - approximation to the largest eigenvalue of the preconditioned operator (default: 0.0)
 -   -ksp_pipelcg_monitor - output where/why the method restarts when a sqrt breakdown occurs
 
-   see KSPSolve() for additional options
-
     Level: advanced
 
     Notes:
     MPI configuration may be necessary for reductions to make asynchronous progress, which is important for
-    performance of pipelined methods. See the FAQ on the PETSc website for details.
+    performance of pipelined methods. See [](doc_faq_pipelined)
 
     Contributed by:
     Siegfried Cools, University of Antwerp, Dept. Mathematics and Computer Science,
     funded by Flemish Research Foundation (FWO) grant number 12H4617N.
 
     Example usage:
-    [*] KSP ex2, no preconditioner, pipel = 2, lmin = 0.0, lmax = 8.0 :
+.vb
+    KSP tutorials ex2, no preconditioner, pipel = 2, lmin = 0.0, lmax = 8.0 :
         $mpiexec -n 14 ./ex2 -m 1000 -n 1000 -ksp_type pipelcg -pc_type none -ksp_norm_type natural
-        -ksp_rtol 1e-10 -ksp_max_it 1000 -ksp_pipelcg_pipel 2 -ksp_pipelcg_lmin 0.0 -ksp_pipelcg_lmax 8.0 -log_view
-    [*] SNES ex48, bjacobi preconditioner, pipel = 3, lmin = 0.0, lmax = 2.0, show restart information :
+           -ksp_rtol 1e-10 -ksp_max_it 1000 -ksp_pipelcg_pipel 2 -ksp_pipelcg_lmin 0.0 -ksp_pipelcg_lmax 8.0 -log_view
+    SNES tutorials ex48, bjacobi preconditioner, pipel = 3, lmin = 0.0, lmax = 2.0, show restart information :
         $mpiexec -n 14 ./ex48 -M 150 -P 100 -ksp_type pipelcg -pc_type bjacobi -ksp_rtol 1e-10 -ksp_pipelcg_pipel 3
-        -ksp_pipelcg_lmin 0.0 -ksp_pipelcg_lmax 2.0 -ksp_pipelcg_monitor -log_view
+           -ksp_pipelcg_lmin 0.0 -ksp_pipelcg_lmax 2.0 -ksp_pipelcg_monitor -log_view
+.ve
 
     References:
 +   * - J. Cornelis, S. Cools and W. Vanroose,
@@ -477,8 +477,8 @@ static PetscErrorCode KSPSolve_PIPELCG(KSP ksp)
         "Numerically Stable Recurrence Relations for the Communication Hiding Pipelined Conjugate Gradient Method"
         Submitted to IEEE Transactions on Parallel and Distributed Systems, 2019.
 
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSPCG`, `KSPPIPECG`, `KSPPIPECGRR`, `KSPPGMRES`,
-          `KSPPIPEBCGS`, `KSPSetPCSide()`
+.seealso: [](chapter_ksp), [](sec_pipelineksp), [](doc_faq_pipelined), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSPCG`, `KSPPIPECG`, `KSPPIPECGRR`, `KSPPGMRES`,
+          `KSPPIPEBCGS`, `KSPSetPCSide()`, `KSPGROPPCG`
 M*/
 PETSC_EXTERN PetscErrorCode KSPCreate_PIPELCG(KSP ksp)
 {
@@ -499,5 +499,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_PIPELCG(KSP ksp)
   ksp->ops->setfromoptions = KSPSetFromOptions_PIPELCG;
   ksp->ops->buildsolution  = KSPBuildSolutionDefault;
   ksp->ops->buildresidual  = KSPBuildResidualDefault;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
