@@ -1,6 +1,5 @@
 
 /*
-
     Note that for the complex numbers version, the VecDot() arguments
     within the code MUST remain in the order given for correct computation
     of inner products.
@@ -11,7 +10,7 @@ static PetscErrorCode KSPSetUp_CGS(KSP ksp)
 {
   PetscFunctionBegin;
   PetscCall(KSPSetWorkVecs(ksp, 7));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSolve_CGS(KSP ksp)
@@ -56,7 +55,7 @@ static PetscErrorCode KSPSolve_CGS(KSP ksp)
   PetscCall(KSPLogResidualHistory(ksp, dp));
   PetscCall(KSPMonitor(ksp, 0, dp));
   PetscCall((*ksp->converged)(ksp, 0, dp, &ksp->reason, ksp->cnvP));
-  if (ksp->reason) PetscFunctionReturn(0);
+  if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* Make the initial Rp == R */
   PetscCall(VecCopy(R, RP));
@@ -124,29 +123,27 @@ static PetscErrorCode KSPSolve_CGS(KSP ksp)
   if (i >= ksp->max_it) ksp->reason = KSP_DIVERGED_ITS;
 
   PetscCall(KSPUnwindPreconditioner(ksp, X, T));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
      KSPCGS - This code implements the CGS (Conjugate Gradient Squared) method.
 
-   Options Database Keys:
-    see KSPSolve()
-
    Level: beginner
 
+   Notes:
+   Does not require a symmetric matrix. Does not apply transpose of the matrix.
+
+   Supports left and right preconditioning, but not symmetric.
+
+   Developer Note:
+   Has this weird support for doing the convergence test with the natural norm, I assume this works only with
+   no preconditioning and symmetric positive definite operator.
+
    References:
 .  * - Sonneveld, 1989.
 
-   Notes:
-    Does not require a symmetric matrix. Does not apply transpose of the matrix.
-        Supports left and right preconditioning, but not symmetric.
-
-   Developer Notes:
-    Has this weird support for doing the convergence test with the natural norm, I assume this works only with
-      no preconditioning and symmetric positive definite operator.
-
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPBCGS`, `KSPSetPCSide()`
+.seealso: [](chapter_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPBCGS`, `KSPSetPCSide()`
 M*/
 PETSC_EXTERN PetscErrorCode KSPCreate_CGS(KSP ksp)
 {
@@ -167,5 +164,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_CGS(KSP ksp)
   ksp->ops->buildresidual  = KSPBuildResidualDefault;
   ksp->ops->setfromoptions = NULL;
   ksp->ops->view           = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
