@@ -1,13 +1,15 @@
-
+#include "chebyshevimpl.h"
 #include <../src/ksp/ksp/impls/cheby/chebyshevimpl.h> /*I "petscksp.h" I*/
 
+static const char *const KSPChebyshevKinds[] = {"FIRST", "FOURTH", "OPT_FOURTH", "KSPChebyshevKinds", "KSP_CHEBYSHEV_", NULL};
+
 static PetscErrorCode KSPReset_Chebyshev(KSP ksp)
 {
   KSP_Chebyshev *cheb = (KSP_Chebyshev *)ksp->data;
 
   PetscFunctionBegin;
   if (cheb->kspest) PetscCall(KSPReset(cheb->kspest));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -31,101 +33,7 @@ static PetscErrorCode KSPChebyshevComputeExtremeEigenvalues_Private(KSP kspest,
   PetscCall(PetscFree2(re, im));
   *emax = max;
   *emin = min;
-  PetscFunctionReturn(0);
-}
-
-static PetscErrorCode KSPSetUp_Chebyshev(KSP ksp)
-{
-  KSP_Chebyshev   *cheb = (KSP_Chebyshev *)ksp->data;
-  PetscBool        isset, flg;
-  Mat              Pmat, Amat;
-  PetscObjectId    amatid, pmatid;
-  PetscObjectState amatstate, pmatstate;
-
-  PetscFunctionBegin;
-  PetscCall(KSPSetWorkVecs(ksp, 3));
-  if (cheb->emin == 0. || cheb->emax == 0.) { // User did not specify eigenvalues
-    PC pc;
-    PetscCall(KSPGetPC(ksp, &pc));
-    PetscCall(PetscObjectTypeCompare((PetscObject)pc, PCJACOBI, &flg));
-    if (!flg) { // Provided estimates are only relevant for Jacobi
-      cheb->emax_provided = 0;
-      cheb->emin_provided = 0;
-    }
-    if (!cheb->kspest) { /* We need to estimate eigenvalues */
-      PetscCall(KSPChebyshevEstEigSet(ksp, PETSC_DECIDE, PETSC_DECIDE, PETSC_DECIDE, PETSC_DECIDE));
-    }
-  }
-  if (cheb->kspest) {
-    PetscCall(KSPGetOperators(ksp, &Amat, &Pmat));
-    PetscCall(MatIsSPDKnown(Pmat, &isset, &flg));
-    if (isset && flg) {
-      const char *prefix;
-      PetscCall(KSPGetOptionsPrefix(cheb->kspest, &prefix));
-      PetscCall(PetscOptionsHasName(NULL, prefix, "-ksp_type", &flg));
-      if (!flg) PetscCall(KSPSetType(cheb->kspest, KSPCG));
-    }
-    PetscCall(PetscObjectGetId((PetscObject)Amat, &amatid));
-    PetscCall(PetscObjectGetId((PetscObject)Pmat, &pmatid));
-    PetscCall(PetscObjectStateGet((PetscObject)Amat, &amatstate));
-    PetscCall(PetscObjectStateGet((PetscObject)Pmat, &pmatstate));
-    if (amatid != cheb->amatid || pmatid != cheb->pmatid || amatstate != cheb->amatstate || pmatstate != cheb->pmatstate) {
-      PetscReal          max = 0.0, min = 0.0;
-      Vec                B;
-      KSPConvergedReason reason;
-      PetscCall(KSPSetPC(cheb->kspest, ksp->pc));
-      if (cheb->usenoisy) {
-        B = ksp->work[1];
-        PetscCall(KSPSetNoisy_Private(B));
-      } else {
-        PetscBool change;
-
-        PetscCheck(ksp->vec_rhs, PetscObjectComm((PetscObject)ksp), PETSC_ERR_SUP, "Chebyshev must use a noisy right hand side to estimate the eigenvalues when no right hand side is available");
-        PetscCall(PCPreSolveChangeRHS(ksp->pc, &change));
-        if (change) {
-          B = ksp->work[1];
-          PetscCall(VecCopy(ksp->vec_rhs, B));
-        } else B = ksp->vec_rhs;
-      }
-      PetscCall(KSPSolve(cheb->kspest, B, ksp->work[0]));
-      PetscCall(KSPGetConvergedReason(cheb->kspest, &reason));
-      if (reason == KSP_DIVERGED_ITS) {
-        PetscCall(PetscInfo(ksp, "Eigen estimator ran for prescribed number of iterations\n"));
-      } else if (reason == KSP_DIVERGED_PC_FAILED) {
-        PetscInt       its;
-        PCFailedReason pcreason;
-
-        PetscCall(KSPGetIterationNumber(cheb->kspest, &its));
-        if (ksp->normtype == KSP_NORM_NONE) {
-          PetscInt sendbuf, recvbuf;
-          PetscCall(PCGetFailedReasonRank(ksp->pc, &pcreason));
-          sendbuf = (PetscInt)pcreason;
-          PetscCallMPI(MPI_Allreduce(&sendbuf, &recvbuf, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)ksp)));
-          PetscCall(PCSetFailedReason(ksp->pc, (PCFailedReason)recvbuf));
-        }
-        PetscCall(PCGetFailedReason(ksp->pc, &pcreason));
-        ksp->reason = KSP_DIVERGED_PC_FAILED;
-        PetscCall(PetscInfo(ksp, "Eigen estimator failed: %s %s at iteration %" PetscInt_FMT, KSPConvergedReasons[reason], PCFailedReasons[pcreason], its));
-        PetscFunctionReturn(0);
-      } else if (reason == KSP_CONVERGED_RTOL || reason == KSP_CONVERGED_ATOL) {
-        PetscCall(PetscInfo(ksp, "Eigen estimator converged prematurely. Should not happen except for small or low rank problem\n"));
-      } else if (reason < 0) {
-        PetscCall(PetscInfo(ksp, "Eigen estimator failed %s, using estimates anyway\n", KSPConvergedReasons[reason]));
-      }
-
-      PetscCall(KSPChebyshevComputeExtremeEigenvalues_Private(cheb->kspest, &min, &max));
-      PetscCall(KSPSetPC(cheb->kspest, NULL));
-
-      cheb->emin_computed = min;
-      cheb->emax_computed = max;
-
-      cheb->amatid    = amatid;
-      cheb->pmatid    = pmatid;
-      cheb->amatstate = amatstate;
-      cheb->pmatstate = pmatstate;
-    }
-  }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPChebyshevGetEigenvalues_Chebyshev(KSP ksp, PetscReal *emax, PetscReal *emin)
@@ -149,7 +57,7 @@ static PetscErrorCode KSPChebyshevGetEigenvalues_Chebyshev(KSP ksp, PetscReal *e
   } else if (cheb->emin_provided != 0.) {
     *emin = cheb->tform[0] * cheb->emin_provided + cheb->tform[1] * cheb->emax_provided;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPChebyshevSetEigenvalues_Chebyshev(KSP ksp, PetscReal emax, PetscReal emin)
@@ -163,7 +71,7 @@ static PetscErrorCode KSPChebyshevSetEigenvalues_Chebyshev(KSP ksp, PetscReal em
   chebyshevP->emin = emin;
 
   PetscCall(KSPChebyshevEstEigSet(ksp, 0., 0., 0., 0.)); /* Destroy any estimation setup */
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPChebyshevEstEigSet_Chebyshev(KSP ksp, PetscReal a, PetscReal b, PetscReal c, PetscReal d)
@@ -197,7 +105,7 @@ static PetscErrorCode KSPChebyshevEstEigSet_Chebyshev(KSP ksp, PetscReal a, Pets
   } else {
     PetscCall(KSPDestroy(&cheb->kspest));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPChebyshevEstEigSetUseNoisy_Chebyshev(KSP ksp, PetscBool use)
@@ -206,18 +114,36 @@ static PetscErrorCode KSPChebyshevEstEigSetUseNoisy_Chebyshev(KSP ksp, PetscBool
 
   PetscFunctionBegin;
   cheb->usenoisy = use;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+static PetscErrorCode KSPChebyshevSetKind_Chebyshev(KSP ksp, KSPChebyshevKind kind)
+{
+  KSP_Chebyshev *cheb = (KSP_Chebyshev *)ksp->data;
+
+  PetscFunctionBegin;
+  cheb->chebykind = kind;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+static PetscErrorCode KSPChebyshevGetKind_Chebyshev(KSP ksp, KSPChebyshevKind *kind)
+{
+  KSP_Chebyshev *cheb = (KSP_Chebyshev *)ksp->data;
+
+  PetscFunctionBegin;
+  *kind = cheb->chebykind;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
 /*@
    KSPChebyshevSetEigenvalues - Sets estimates for the extreme eigenvalues
    of the preconditioned problem.
 
-   Logically Collective on ksp
+   Logically Collective
 
    Input Parameters:
 +  ksp - the Krylov space context
--  emax, emin - the eigenvalue estimates
+   emax - the eigenvalue maximum estimate
+-  emin - the eigenvalue minimum estimate
 
   Options Database Key:
 .  -ksp_chebyshev_eigenvalues emin,emax - extreme eigenvalues
@@ -242,13 +168,13 @@ PetscErrorCode KSPChebyshevSetEigenvalues(KSP ksp, PetscReal emax, PetscReal emi
   PetscValidLogicalCollectiveReal(ksp, emax, 2);
   PetscValidLogicalCollectiveReal(ksp, emin, 3);
   PetscTryMethod(ksp, "KSPChebyshevSetEigenvalues_C", (KSP, PetscReal, PetscReal), (ksp, emax, emin));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    KSPChebyshevEstEigSet - Automatically estimate the eigenvalues to use for Chebyshev
 
-   Logically Collective on ksp
+   Logically Collective
 
    Input Parameters:
 +  ksp - the Krylov space context
@@ -288,7 +214,7 @@ PetscErrorCode KSPChebyshevEstEigSet(KSP ksp, PetscReal a, PetscReal b, PetscRea
   PetscValidLogicalCollectiveReal(ksp, c, 4);
   PetscValidLogicalCollectiveReal(ksp, d, 5);
   PetscTryMethod(ksp, "KSPChebyshevEstEigSet_C", (KSP, PetscReal, PetscReal, PetscReal, PetscReal), (ksp, a, b, c, d));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -314,8 +240,9 @@ PetscErrorCode KSPChebyshevEstEigSetUseNoisy(KSP ksp, PetscBool use)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
+  PetscValidLogicalCollectiveBool(ksp, use, 2);
   PetscTryMethod(ksp, "KSPChebyshevEstEigSetUseNoisy_C", (KSP, PetscBool), (ksp, use));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -323,10 +250,10 @@ PetscErrorCode KSPChebyshevEstEigSetUseNoisy(KSP ksp, PetscBool use)
   a Krylov method is not being used for this purpose, NULL is returned.  The reference count of the returned `KSP` is
   not incremented: it should not be destroyed by the user.
 
-  Input Parameters:
+  Input Parameter:
 . ksp - the Krylov space context
 
-  Output Parameters:
+  Output Parameter:
 . kspest - the eigenvalue estimation Krylov space context
 
   Level: advanced
@@ -340,7 +267,65 @@ PetscErrorCode KSPChebyshevEstEigGetKSP(KSP ksp, KSP *kspest)
   PetscValidPointer(kspest, 2);
   *kspest = NULL;
   PetscTryMethod(ksp, "KSPChebyshevEstEigGetKSP_C", (KSP, KSP *), (ksp, kspest));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@
+  KSPChebyshevSetKind - set the kind of Chebyshev polynomial to use
+
+  Logically Collective
+
+  Input Parameters:
++ ksp  - Linear solver context
+- kind - The kind of Chebyshev polynomial to use
+
+  Options Database Key:
+. -ksp_chebyshev_kind <kind> - which kind of Chebyshev polynomial to use
+
+  Level: intermediate
+
+  Note:
+  When using multigrid methods for problems with a poor quality coarse space (e.g., due to anisotropy or aggressive
+  coarsening), it is necessary for the smoother to handle smaller eigenvalues. With first-kind Chebyshev smoothing, this
+  requires using higher degree Chebyhev polynomials and reducing the lower end of the target spectrum, at which point
+  the whole target spectrum experiences about the same damping. Fourth kind Chebyshev polynomials (and the "optimized"
+  fourth kind) avoid the ad-hoc choice of lower bound and extend smoothing to smaller eigenvalues while preferentially
+  smoothing higher modes faster as needed to minimize the energy norm of the error.
+
+  References:
++  * - Malachi Phillips and Paul Fischer, Optimal Chebyshev Smoothers and One-sided V-cycles, https://arxiv.org/abs/2210.03179.
+-  * - James Lottes, Optimal Polynomial Smoothers for Multigrid V-cycles, https://arxiv.org/abs/2202.08830.
+
+.seealso: [](chapter_ksp), `KSPCHEBYSHEV` `KSPChebyshevKind`, `KSPChebyshevGetKind()`
+@*/
+PetscErrorCode KSPChebyshevSetKind(KSP ksp, KSPChebyshevKind kind)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
+  PetscValidLogicalCollectiveEnum(ksp, kind, 2);
+  PetscUseMethod(ksp, "KSPChebyshevSetKind_C", (KSP, KSPChebyshevKind), (ksp, kind));
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@
+  KSPChebyshevGetKind - get the kind of Chebyshev polynomial to use
+
+  Logically Collective
+
+  Input Parameters:
++ ksp  - Linear solver context
+- kind - The kind of Chebyshev polynomial to use
+
+  Level: intermediate
+
+.seealso: [](chapter_ksp), `KSPCHEBYSHEV` `KSPChebyshevKind`, `KSPChebyshevSetKind()`
+@*/
+PetscErrorCode KSPChebyshevGetKind(KSP ksp, KSPChebyshevKind *kind)
+{
+  PetscFunctionBegin;
+  PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
+  PetscUseMethod(ksp, "KSPChebyshevGetKind_C", (KSP, KSPChebyshevKind *), (ksp, kind));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPChebyshevEstEigGetKSP_Chebyshev(KSP ksp, KSP *kspest)
@@ -349,7 +334,7 @@ static PetscErrorCode KSPChebyshevEstEigGetKSP_Chebyshev(KSP ksp, KSP *kspest)
 
   PetscFunctionBegin;
   *kspest = cheb->kspest;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSetFromOptions_Chebyshev(KSP ksp, PetscOptionItems *PetscOptionsObject)
@@ -385,6 +370,9 @@ static PetscErrorCode KSPSetFromOptions_Chebyshev(KSP ksp, PetscOptionItems *Pet
     }
   }
 
+  cheb->chebykind = KSP_CHEBYSHEV_FIRST; /* Default to 1st-kind Chebyshev polynomial */
+  PetscCall(PetscOptionsEnum("-ksp_chebyshev_kind", "Type of Chebyshev polynomial", "KSPChebyshevKind", KSPChebyshevKinds, (PetscEnum)cheb->chebykind, (PetscEnum *)&cheb->chebykind, NULL));
+
   /* We need to estimate eigenvalues; need to set this here so that KSPSetFromOptions() is called on the estimator */
   if ((cheb->emin == 0. || cheb->emax == 0.) && !cheb->kspest) PetscCall(KSPChebyshevEstEigSet(ksp, PETSC_DECIDE, PETSC_DECIDE, PETSC_DECIDE, PETSC_DECIDE));
 
@@ -393,10 +381,10 @@ static PetscErrorCode KSPSetFromOptions_Chebyshev(KSP ksp, PetscOptionItems *Pet
     PetscCall(KSPSetFromOptions(cheb->kspest));
   }
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode KSPSolve_Chebyshev(KSP ksp)
+static PetscErrorCode KSPSolve_Chebyshev_FirstKind(KSP ksp)
 {
   PetscInt    k, kp1, km1, ktmp, i;
   PetscScalar alpha, omegaprod, mu, omega, Gamma, c[3], scale;
@@ -469,7 +457,7 @@ static PetscErrorCode KSPSolve_Chebyshev(KSP ksp)
   } else ksp->reason = KSP_CONVERGED_ITERATING;
   if (ksp->reason || ksp->max_it == 0) {
     if (ksp->max_it == 0) ksp->reason = KSP_DIVERGED_ITS; /* This for a V(0,x) cycle */
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if (ksp->normtype != KSP_NORM_PRECONDITIONED) { PetscCall(KSP_PCApply(ksp, r, p[k])); /* p[k] = B^{-1}r */ }
   PetscCall(VecAYPX(p[k], scale, p[km1])); /* p[k] = scale B^{-1}r + p[km1] */
@@ -561,7 +549,161 @@ static PetscErrorCode KSPSolve_Chebyshev(KSP ksp)
   ksp->vec_sol = sol_orig;
   if (k) PetscCall(VecCopy(p[k], sol_orig));
   if (ksp->reason == KSP_CONVERGED_ITS) PetscCall(KSPLogErrorHistory(ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+static PetscErrorCode KSPSolve_Chebyshev_FourthKind(KSP ksp)
+{
+  KSP_Chebyshev *cheb = (KSP_Chebyshev *)ksp->data;
+  PetscInt       i;
+  PetscScalar    scale, rScale, dScale;
+  PetscReal      rnorm = 0.0, emax, emin;
+  Vec            x, b, d, r, Br;
+  Mat            Amat, Pmat;
+  PetscBool      diagonalscale;
+  PetscReal     *betas = cheb->betas;
+
+  PetscFunctionBegin;
+  PetscCall(PCGetDiagonalScale(ksp->pc, &diagonalscale));
+  PetscCheck(!diagonalscale, PetscObjectComm((PetscObject)ksp), PETSC_ERR_SUP, "Krylov method %s does not support diagonal scaling", ((PetscObject)ksp)->type_name);
+
+  PetscCall(PCGetOperators(ksp->pc, &Amat, &Pmat));
+  PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
+  ksp->its = 0;
+  PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
+
+  x  = ksp->vec_sol;
+  b  = ksp->vec_rhs;
+  r  = ksp->work[0];
+  d  = ksp->work[1];
+  Br = ksp->work[2];
+
+  PetscCall(KSPChebyshevGetEigenvalues_Chebyshev(ksp, &emax, &emin));
+  /* use scale*B as our preconditioner */
+  scale = 1.0 / emax;
+
+  if (!ksp->guess_zero) {
+    PetscCall(KSP_MatMult(ksp, Amat, x, r)); /*  r = b - A*x */
+    PetscCall(VecAYPX(r, -1.0, b));
+  } else {
+    PetscCall(VecCopy(b, r));
+  }
+
+  /* calculate residual norm if requested, we have done one iteration */
+  if (ksp->normtype) {
+    switch (ksp->normtype) {
+    case KSP_NORM_PRECONDITIONED:
+      PetscCall(KSP_PCApply(ksp, r, Br)); /* Br = B^{-1}r */
+      PetscCall(VecNorm(Br, NORM_2, &rnorm));
+      break;
+    case KSP_NORM_UNPRECONDITIONED:
+    case KSP_NORM_NATURAL:
+      PetscCall(VecNorm(r, NORM_2, &rnorm));
+      break;
+    default:
+      SETERRQ(PetscObjectComm((PetscObject)ksp), PETSC_ERR_SUP, "%s", KSPNormTypes[ksp->normtype]);
+    }
+    PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
+    ksp->rnorm = rnorm;
+    PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
+    PetscCall(KSPLogResidualHistory(ksp, rnorm));
+    PetscCall(KSPLogErrorHistory(ksp));
+    PetscCall(KSPMonitor(ksp, 0, rnorm));
+    PetscCall((*ksp->converged)(ksp, 0, rnorm, &ksp->reason, ksp->cnvP));
+  } else ksp->reason = KSP_CONVERGED_ITERATING;
+  if (ksp->reason || ksp->max_it == 0) {
+    if (ksp->max_it == 0) ksp->reason = KSP_DIVERGED_ITS; /* This for a V(0,x) cycle */
+    PetscFunctionReturn(PETSC_SUCCESS);
+  }
+  if (ksp->normtype != KSP_NORM_PRECONDITIONED) { PetscCall(KSP_PCApply(ksp, r, Br)); /* Br = B^{-1}r */ }
+  PetscCall(VecAXPBY(d, 4.0 / 3.0 * scale, 0.0, Br)); /* d = 4/3 * scale B^{-1}r */
+  PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
+  ksp->its = 1;
+  PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
+
+  for (i = 1; i < ksp->max_it; i++) {
+    PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
+    ksp->its++;
+    PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
+
+    PetscCall(VecAXPBY(x, betas[i - 1], 1.0, d)); /* x = x + \beta_k d */
+
+    PetscCall(KSP_MatMult(ksp, Amat, d, Br)); /*  r = r - Ad */
+    PetscCall(VecAXPBY(r, -1.0, 1.0, Br));
+
+    /* calculate residual norm if requested */
+    if (ksp->normtype) {
+      switch (ksp->normtype) {
+      case KSP_NORM_PRECONDITIONED:
+        PetscCall(KSP_PCApply(ksp, r, Br)); /*  Br = B^{-1}r  */
+        PetscCall(VecNorm(Br, NORM_2, &rnorm));
+        break;
+      case KSP_NORM_UNPRECONDITIONED:
+      case KSP_NORM_NATURAL:
+        PetscCall(VecNorm(r, NORM_2, &rnorm));
+        break;
+      default:
+        rnorm = 0.0;
+        break;
+      }
+      KSPCheckNorm(ksp, rnorm);
+      PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
+      ksp->rnorm = rnorm;
+      PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
+      PetscCall(KSPLogResidualHistory(ksp, rnorm));
+      PetscCall(KSPMonitor(ksp, i, rnorm));
+      PetscCall((*ksp->converged)(ksp, i, rnorm, &ksp->reason, ksp->cnvP));
+      if (ksp->reason) break;
+      if (ksp->normtype != KSP_NORM_PRECONDITIONED) { PetscCall(KSP_PCApply(ksp, r, Br)); /*  Br = B^{-1}r  */ }
+    } else {
+      PetscCall(KSP_PCApply(ksp, r, Br)); /*  Br = B^{-1}r  */
+    }
+    PetscCall(KSPLogErrorHistory(ksp));
+
+    rScale = scale * (8.0 * i + 4.0) / (2.0 * i + 3.0);
+    dScale = (2.0 * i - 1.0) / (2.0 * i + 3.0);
+
+    /* d_k+1 = \dfrac{2k-1}{2k+3} d_k + \dfrac{8k+4}{2k+3} \dfrac{1}{\rho(SA)} Br */
+    PetscCall(VecAXPBY(d, rScale, dScale, Br));
+  }
+
+  /* on last pass, update solution vector */
+  PetscCall(VecAXPBY(x, betas[ksp->max_it - 1], 1.0, d)); /* x = x + d */
+
+  if (!ksp->reason) {
+    if (ksp->normtype) {
+      PetscCall(KSP_MatMult(ksp, Amat, x, r)); /*  r = b - Ax    */
+      PetscCall(VecAYPX(r, -1.0, b));
+      switch (ksp->normtype) {
+      case KSP_NORM_PRECONDITIONED:
+        PetscCall(KSP_PCApply(ksp, r, Br)); /* Br= B^{-1}r */
+        PetscCall(VecNorm(Br, NORM_2, &rnorm));
+        break;
+      case KSP_NORM_UNPRECONDITIONED:
+      case KSP_NORM_NATURAL:
+        PetscCall(VecNorm(r, NORM_2, &rnorm));
+        break;
+      default:
+        rnorm = 0.0;
+        break;
+      }
+      KSPCheckNorm(ksp, rnorm);
+      PetscCall(PetscObjectSAWsTakeAccess((PetscObject)ksp));
+      ksp->rnorm = rnorm;
+      PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
+      PetscCall(KSPLogResidualHistory(ksp, rnorm));
+      PetscCall(KSPMonitor(ksp, i, rnorm));
+    }
+    if (ksp->its >= ksp->max_it) {
+      if (ksp->normtype != KSP_NORM_NONE) {
+        PetscCall((*ksp->converged)(ksp, i, rnorm, &ksp->reason, ksp->cnvP));
+        if (!ksp->reason) ksp->reason = KSP_DIVERGED_ITS;
+      } else ksp->reason = KSP_CONVERGED_ITS;
+    }
+  }
+
+  if (ksp->reason == KSP_CONVERGED_ITS) PetscCall(KSPLogErrorHistory(ksp));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPView_Chebyshev(KSP ksp, PetscViewer viewer)
@@ -572,6 +714,17 @@ static PetscErrorCode KSPView_Chebyshev(KSP ksp, PetscViewer viewer)
   PetscFunctionBegin;
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
   if (iascii) {
+    switch (cheb->chebykind) {
+    case KSP_CHEBYSHEV_FIRST:
+      PetscCall(PetscViewerASCIIPrintf(viewer, "  Chebyshev polynomial of first kind\n"));
+      break;
+    case KSP_CHEBYSHEV_FOURTH:
+      PetscCall(PetscViewerASCIIPrintf(viewer, "  Chebyshev polynomial of fourth kind\n"));
+      break;
+    case KSP_CHEBYSHEV_OPT_FOURTH:
+      PetscCall(PetscViewerASCIIPrintf(viewer, "  Chebyshev polynomial of opt. fourth kind\n"));
+      break;
+    }
     PetscReal emax, emin;
     PetscCall(KSPChebyshevGetEigenvalues_Chebyshev(ksp, &emax, &emin));
     PetscCall(PetscViewerASCIIPrintf(viewer, "  eigenvalue targets used: min %g, max %g\n", (double)emin, (double)emax));
@@ -587,7 +740,126 @@ static PetscErrorCode KSPView_Chebyshev(KSP ksp, PetscViewer viewer)
                                        (double)cheb->tform[3]));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+static PetscErrorCode KSPSetUp_Chebyshev(KSP ksp)
+{
+  KSP_Chebyshev   *cheb = (KSP_Chebyshev *)ksp->data;
+  PetscBool        isset, flg;
+  Mat              Pmat, Amat;
+  PetscObjectId    amatid, pmatid;
+  PetscObjectState amatstate, pmatstate;
+
+  PetscFunctionBegin;
+  switch (cheb->chebykind) {
+  case KSP_CHEBYSHEV_FIRST:
+    ksp->ops->solve = KSPSolve_Chebyshev_FirstKind;
+    break;
+  case KSP_CHEBYSHEV_FOURTH:
+  case KSP_CHEBYSHEV_OPT_FOURTH:
+    ksp->ops->solve = KSPSolve_Chebyshev_FourthKind;
+    break;
+  }
+
+  if (ksp->max_it > cheb->num_betas_alloc) {
+    PetscCall(PetscFree(cheb->betas));
+    PetscCall(PetscMalloc1(ksp->max_it, &cheb->betas));
+    cheb->num_betas_alloc = ksp->max_it;
+  }
+
+  // coefficients for 4th-kind Chebyshev
+  for (PetscInt i = 0; i < ksp->max_it; i++) cheb->betas[i] = 1.0;
+
+  // coefficients for optimized 4th-kind Chebyshev
+  if (cheb->chebykind == KSP_CHEBYSHEV_OPT_FOURTH) PetscCall(KSPChebyshevGetBetas_Private(ksp));
+
+  PetscCall(KSPSetWorkVecs(ksp, 3));
+  if (cheb->emin == 0. || cheb->emax == 0.) { // User did not specify eigenvalues
+    PC pc;
+
+    PetscCall(KSPGetPC(ksp, &pc));
+    PetscCall(PetscObjectTypeCompare((PetscObject)pc, PCJACOBI, &flg));
+    if (!flg) { // Provided estimates are only relevant for Jacobi
+      cheb->emax_provided = 0;
+      cheb->emin_provided = 0;
+    }
+    /* We need to estimate eigenvalues */
+    if (!cheb->kspest) PetscCall(KSPChebyshevEstEigSet(ksp, PETSC_DECIDE, PETSC_DECIDE, PETSC_DECIDE, PETSC_DECIDE));
+  }
+  if (cheb->kspest) {
+    PetscCall(KSPGetOperators(ksp, &Amat, &Pmat));
+    PetscCall(MatIsSPDKnown(Pmat, &isset, &flg));
+    if (isset && flg) {
+      const char *prefix;
+
+      PetscCall(KSPGetOptionsPrefix(cheb->kspest, &prefix));
+      PetscCall(PetscOptionsHasName(NULL, prefix, "-ksp_type", &flg));
+      if (!flg) PetscCall(KSPSetType(cheb->kspest, KSPCG));
+    }
+    PetscCall(PetscObjectGetId((PetscObject)Amat, &amatid));
+    PetscCall(PetscObjectGetId((PetscObject)Pmat, &pmatid));
+    PetscCall(PetscObjectStateGet((PetscObject)Amat, &amatstate));
+    PetscCall(PetscObjectStateGet((PetscObject)Pmat, &pmatstate));
+    if (amatid != cheb->amatid || pmatid != cheb->pmatid || amatstate != cheb->amatstate || pmatstate != cheb->pmatstate) {
+      PetscReal          max = 0.0, min = 0.0;
+      Vec                B;
+      KSPConvergedReason reason;
+
+      PetscCall(KSPSetPC(cheb->kspest, ksp->pc));
+      if (cheb->usenoisy) {
+        B = ksp->work[1];
+        PetscCall(KSPSetNoisy_Private(B));
+      } else {
+        PetscBool change;
+
+        PetscCheck(ksp->vec_rhs, PetscObjectComm((PetscObject)ksp), PETSC_ERR_SUP, "Chebyshev must use a noisy right hand side to estimate the eigenvalues when no right hand side is available");
+        PetscCall(PCPreSolveChangeRHS(ksp->pc, &change));
+        if (change) {
+          B = ksp->work[1];
+          PetscCall(VecCopy(ksp->vec_rhs, B));
+        } else B = ksp->vec_rhs;
+      }
+      PetscCall(KSPSolve(cheb->kspest, B, ksp->work[0]));
+      PetscCall(KSPGetConvergedReason(cheb->kspest, &reason));
+      if (reason == KSP_DIVERGED_ITS) {
+        PetscCall(PetscInfo(ksp, "Eigen estimator ran for prescribed number of iterations\n"));
+      } else if (reason == KSP_DIVERGED_PC_FAILED) {
+        PetscInt       its;
+        PCFailedReason pcreason;
+
+        PetscCall(KSPGetIterationNumber(cheb->kspest, &its));
+        if (ksp->normtype == KSP_NORM_NONE) {
+          PetscInt sendbuf, recvbuf;
+
+          PetscCall(PCGetFailedReasonRank(ksp->pc, &pcreason));
+          sendbuf = (PetscInt)pcreason;
+          PetscCall(MPIU_Allreduce(&sendbuf, &recvbuf, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)ksp)));
+          PetscCall(PCSetFailedReason(ksp->pc, (PCFailedReason)recvbuf));
+        }
+        PetscCall(PCGetFailedReason(ksp->pc, &pcreason));
+        ksp->reason = KSP_DIVERGED_PC_FAILED;
+        PetscCall(PetscInfo(ksp, "Eigen estimator failed: %s %s at iteration %" PetscInt_FMT, KSPConvergedReasons[reason], PCFailedReasons[pcreason], its));
+        PetscFunctionReturn(PETSC_SUCCESS);
+      } else if (reason == KSP_CONVERGED_RTOL || reason == KSP_CONVERGED_ATOL) {
+        PetscCall(PetscInfo(ksp, "Eigen estimator converged prematurely. Should not happen except for small or low rank problem\n"));
+      } else if (reason < 0) {
+        PetscCall(PetscInfo(ksp, "Eigen estimator failed %s, using estimates anyway\n", KSPConvergedReasons[reason]));
+      }
+
+      PetscCall(KSPChebyshevComputeExtremeEigenvalues_Private(cheb->kspest, &min, &max));
+      PetscCall(KSPSetPC(cheb->kspest, NULL));
+
+      cheb->emin_computed = min;
+      cheb->emax_computed = max;
+
+      cheb->amatid    = amatid;
+      cheb->pmatid    = pmatid;
+      cheb->amatstate = amatstate;
+      cheb->pmatstate = pmatstate;
+    }
+  }
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPDestroy_Chebyshev(KSP ksp)
@@ -595,13 +867,16 @@ static PetscErrorCode KSPDestroy_Chebyshev(KSP ksp)
   KSP_Chebyshev *cheb = (KSP_Chebyshev *)ksp->data;
 
   PetscFunctionBegin;
+  PetscCall(PetscFree(cheb->betas));
   PetscCall(KSPDestroy(&cheb->kspest));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevSetEigenvalues_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevEstEigSet_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevEstEigSetUseNoisy_C", NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevSetKind_C", NULL));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevGetKind_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevEstEigGetKSP_C", NULL));
   PetscCall(KSPDestroyDefault(ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -622,7 +897,7 @@ static PetscErrorCode KSPDestroy_Chebyshev(KSP ksp)
 
    Only support for left preconditioning.
 
-   Chebyshev is configured as a smoother by default, targetting the "upper" part of the spectrum.
+   Chebyshev is configured as a smoother by default, targeting the "upper" part of the spectrum.
 
    The user should call `KSPChebyshevSetEigenvalues()` to get eigenvalue estimates.
 
@@ -656,7 +931,6 @@ PETSC_EXTERN PetscErrorCode KSPCreate_Chebyshev(KSP ksp)
   ksp->setupnewmatrix  = PETSC_TRUE;
 
   ksp->ops->setup          = KSPSetUp_Chebyshev;
-  ksp->ops->solve          = KSPSolve_Chebyshev;
   ksp->ops->destroy        = KSPDestroy_Chebyshev;
   ksp->ops->buildsolution  = KSPBuildSolutionDefault;
   ksp->ops->buildresidual  = KSPBuildResidualDefault;
@@ -667,6 +941,8 @@ PETSC_EXTERN PetscErrorCode KSPCreate_Chebyshev(KSP ksp)
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevSetEigenvalues_C", KSPChebyshevSetEigenvalues_Chebyshev));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevEstEigSet_C", KSPChebyshevEstEigSet_Chebyshev));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevEstEigSetUseNoisy_C", KSPChebyshevEstEigSetUseNoisy_Chebyshev));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevSetKind_C", KSPChebyshevSetKind_Chebyshev));
+  PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevGetKind_C", KSPChebyshevGetKind_Chebyshev));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPChebyshevEstEigGetKSP_C", KSPChebyshevEstEigGetKSP_Chebyshev));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
