@@ -58,7 +58,7 @@ static PetscErrorCode KSPSetUp_AGMRES(KSP ksp)
   /* Init the ring of processors for the roddec orthogonalization */
   PetscCall(KSPAGMRESRoddecInitNeighboor(ksp));
 
-  if (agmres->neig < 1) PetscFunctionReturn(0);
+  if (agmres->neig < 1) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* Allocate space for the deflation */
   PetscCall(PetscMalloc1(N, &agmres->select));
@@ -67,7 +67,7 @@ static PetscErrorCode KSPSetUp_AGMRES(KSP ksp)
   /*  PetscCall(PetscMalloc6(N*N, &agmres->Q, N*N, &agmres->Z, N, &agmres->wr, N, &agmres->wi, N, &agmres->beta, N, &agmres->modul)); */
   PetscCall(PetscMalloc3(N * N, &agmres->Q, N * N, &agmres->Z, N, &agmres->beta));
   PetscCall(PetscMalloc2((N + 1), &agmres->perm, (2 * neig * N), &agmres->iwork));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -88,7 +88,7 @@ static PetscErrorCode KSPBuildSolution_AGMRES(KSP ksp, Vec ptr, Vec *result)
     PetscCall(VecCopy(ksp->vec_sol, ptr));
   }
   if (result) *result = ptr;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Computes the shifts  needed to generate stable basis vectors (through the Newton polynomials)
@@ -138,7 +138,7 @@ PetscErrorCode KSPComputeShifts_GMRES(KSP ksp)
   ksp->its        = kspgmres->its;
   if (kspgmres->reason == KSP_CONVERGED_RTOL) {
     ksp->reason = KSP_CONVERGED_RTOL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   } else ksp->reason = KSP_CONVERGED_ITERATING;
   /* Now, compute the Shifts values */
   PetscCall(PetscMalloc2(max_k, &Rshift, max_k, &Ishift));
@@ -149,7 +149,7 @@ PetscErrorCode KSPComputeShifts_GMRES(KSP ksp)
   agmres->HasShifts = PETSC_TRUE;
   /* Restore KSP view options */
   if (flg) PetscCall(PetscOptionsSetValue(NULL, "-ksp_view", ""));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Computes the shift values (Ritz values) needed to generate stable basis vectors
@@ -182,7 +182,7 @@ static PetscErrorCode KSPComputeShifts_DGMRES(KSP ksp)
   ksp->guess_zero = PETSC_FALSE;
   if (ksp->reason == KSP_CONVERGED_RTOL) {
     PetscCall(PetscLogEventEnd(KSP_AGMRESComputeShifts, ksp, 0, 0, 0));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   } else ksp->reason = KSP_CONVERGED_ITERATING;
 
   if ((agmres->r == 0) && (agmres->neig > 0)) { /* Compute the eigenvalues for the shifts and the eigenvectors (to augment the Newton basis) */
@@ -209,7 +209,7 @@ static PetscErrorCode KSPComputeShifts_DGMRES(KSP ksp)
     PetscCall(KSPSolve_DGMRES(ksp));
 
     ksp->guess_zero = PETSC_FALSE;
-    if (ksp->reason == KSP_CONVERGED_RTOL) PetscFunctionReturn(0);
+    if (ksp->reason == KSP_CONVERGED_RTOL) PetscFunctionReturn(PETSC_SUCCESS);
     else ksp->reason = KSP_CONVERGED_ITERATING;
     if (agmres->neig > 0) { /* Compute the eigenvalues for the shifts) and the eigenvectors (to augment the Newton basis */
       agmres->HasSchur = PETSC_FALSE;
@@ -236,7 +236,7 @@ static PetscErrorCode KSPComputeShifts_DGMRES(KSP ksp)
   agmres->HasShifts = PETSC_TRUE;
   ksp->max_it       = max_it;
   PetscCall(PetscLogEventEnd(KSP_AGMRESComputeShifts, ksp, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -345,7 +345,7 @@ static PetscErrorCode KSPAGMRESBuildBasis(KSP ksp)
     j++;
   }
   PetscCall(PetscLogEventEnd(KSP_AGMRESBuildBasis, ksp, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -390,7 +390,7 @@ static PetscErrorCode KSPAGMRESBuildHessenberg(KSP ksp)
   for (j = max_k; j < KspSize; j++) { /* take into account the norm of the augmented vectors */
     for (i = 0; i <= j + 1; i++) *H(i, j) = *RLOC(i, j + 1) / Scale[j];
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -444,7 +444,7 @@ static PetscErrorCode KSPAGMRESBuildSoln(KSP ksp, PetscInt it)
   PetscCall(KSPUnwindPreconditioner(ksp, VEC_TMP, VEC_TMP_MATOP));
   /* add the solution to the previous one */
   PetscCall(VecAXPY(ksp->vec_sol, 1.0, VEC_TMP));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -473,7 +473,7 @@ static PetscErrorCode KSPAGMRESCycle(PetscInt *itcount, KSP ksp)
     if (itcount) *itcount = 0;
     ksp->reason = KSP_CONVERGED_ATOL;
     PetscCall(PetscInfo(ksp, "Converged due to zero residual norm on entry\n"));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCall((*ksp->converged)(ksp, ksp->its, res, &ksp->reason, ksp->cnvP));
   /* Build the Krylov basis with Newton polynomials */
@@ -495,7 +495,7 @@ static PetscErrorCode KSPAGMRESCycle(PetscInt *itcount, KSP ksp)
   PetscCall(KSPMonitor(ksp, ksp->its, res));
 
   *itcount = KspSize;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSolve_AGMRES(KSP ksp)
@@ -547,7 +547,7 @@ static PetscErrorCode KSPSolve_AGMRES(KSP ksp)
     ksp->guess_zero = PETSC_FALSE; /* every future call to KSPInitialResidual() will have nonzero guess */
   }
   ksp->guess_zero = guess_zero; /* restore if user has provided nonzero initial guess */
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPDestroy_AGMRES(KSP ksp)
@@ -575,14 +575,13 @@ static PetscErrorCode KSPDestroy_AGMRES(KSP ksp)
     PetscCall(PetscFree(agmres->beta));
   }
   PetscCall(KSPDestroy_DGMRES(ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPView_AGMRES(KSP ksp, PetscViewer viewer)
 {
   KSP_AGMRES *agmres = (KSP_AGMRES *)ksp->data;
   const char *cstr   = "RODDEC ORTHOGONOLIZATION";
-  char        ritzvec[25];
   PetscBool   iascii, isstring;
 #if defined(KSP_AGMRES_NONORM)
   const char *Nstr = "SCALING FACTORS : NO";
@@ -598,25 +597,22 @@ static PetscErrorCode KSPView_AGMRES(KSP ksp, PetscViewer viewer)
     PetscCall(PetscViewerASCIIPrintf(viewer, " restart=%" PetscInt_FMT " using %s\n", agmres->max_k, cstr));
     PetscCall(PetscViewerASCIIPrintf(viewer, " %s\n", Nstr));
     PetscCall(PetscViewerASCIIPrintf(viewer, " Number of matvecs : %" PetscInt_FMT "\n", agmres->matvecs));
-    if (agmres->force) PetscCall(PetscViewerASCIIPrintf(viewer, " Adaptive strategy is used: FALSE\n"));
-    else PetscViewerASCIIPrintf(viewer, " Adaptive strategy is used: TRUE\n");
+    PetscCall(PetscViewerASCIIPrintf(viewer, " Adaptive strategy is used: %s\n", PetscBools[agmres->force]));
     if (agmres->DeflPrecond) {
       PetscCall(PetscViewerASCIIPrintf(viewer, " STRATEGY OF DEFLATION: PRECONDITIONER \n"));
       PetscCall(PetscViewerASCIIPrintf(viewer, "  Frequency of extracted eigenvalues = %" PetscInt_FMT "\n", agmres->neig));
       PetscCall(PetscViewerASCIIPrintf(viewer, "  Total number of extracted eigenvalues = %" PetscInt_FMT "\n", agmres->r));
       PetscCall(PetscViewerASCIIPrintf(viewer, "  Maximum number of eigenvalues set to be extracted = %" PetscInt_FMT "\n", agmres->max_neig));
     } else {
-      if (agmres->ritz) sprintf(ritzvec, "Ritz vectors");
-      else sprintf(ritzvec, "Harmonic Ritz vectors");
       PetscCall(PetscViewerASCIIPrintf(viewer, " STRATEGY OF DEFLATION: AUGMENT\n"));
-      PetscCall(PetscViewerASCIIPrintf(viewer, " augmented vectors  %" PetscInt_FMT " at frequency %" PetscInt_FMT " with %s\n", agmres->r, agmres->neig, ritzvec));
+      PetscCall(PetscViewerASCIIPrintf(viewer, " augmented vectors  %" PetscInt_FMT " at frequency %" PetscInt_FMT " with %sRitz vectors\n", agmres->r, agmres->neig, agmres->ritz ? "" : "Harmonic "));
     }
     PetscCall(PetscViewerASCIIPrintf(viewer, " Minimum relaxation parameter for the adaptive strategy(smv)  = %g\n", (double)agmres->smv));
     PetscCall(PetscViewerASCIIPrintf(viewer, " Maximum relaxation parameter for the adaptive strategy(bgv)  = %g\n", (double)agmres->bgv));
   } else if (isstring) {
     PetscCall(PetscViewerStringSPrintf(viewer, "%s restart %" PetscInt_FMT, cstr, agmres->max_k));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSetFromOptions_AGMRES(KSP ksp, PetscOptionItems *PetscOptionsObject)
@@ -641,7 +637,7 @@ static PetscErrorCode KSPSetFromOptions_AGMRES(KSP ksp, PetscOptionItems *PetscO
   PetscCall(PetscOptionsReal("-ksp_agmres_MinRatio", "Relaxation parameter in the adaptive strategy; smallest multiple of the remaining number of steps allowed", "KSPGMRESSetMinRatio", agmres->smv, &agmres->smv, NULL));
   PetscCall(PetscOptionsReal("-ksp_agmres_MaxRatio", "Relaxation parameter in the adaptive strategy; Largest multiple of the remaining number of steps allowed", "KSPGMRESSetMaxRatio", agmres->bgv, &agmres->bgv, &flg));
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -657,19 +653,19 @@ There are  many ongoing work that aim at avoiding (or minimizing) the communicat
  .   -ksp_agmres_maxeigen <max_neig> - Maximum number of eigenvalues to deflate
  .   -ksp_agmres_MinRatio <1> - Relaxation parameter in the adaptive strategy; smallest multiple of the remaining number of steps allowed
  .   -ksp_agmres_MaxRatio <1> - Relaxation parameter in the adaptive strategy; Largest multiple of the remaining number of steps allowed
- .   -ksp_agmres_DeflPrecond - Apply deflation as a preconditioner, this is similar to DGMRES but it rather builds a Newton basis.  This is an experimental option.
+ .   -ksp_agmres_DeflPrecond - Apply deflation as a preconditioner, this is similar to `KSPDGMRES` but it rather builds a Newton basis.  This is an experimental option.
  -   -ksp_dgmres_force <0, 1> - Force the deflation at each restart.
 
- Level: beginner
+ Level: intermediate
 
- Notes:
+ Note:
     Left and right preconditioning are supported, but not symmetric preconditioning. Complex arithmetic is not supported
 
- Developer Notes:
-    This object is subclassed off of KSPDGMRES
+ Developer Note:
+    This object is subclassed off of `KSPDGMRES`
 
- Contributed by Desire NUENTSA WAKAM, INRIA <desire.nuentsa_wakam@inria.fr>
- Inputs from Guy Atenekeng <atenekeng@yahoo.com> and R.B. Sidje <roger.b.sidje@ua.edu>
+ Contributed by:
+ Desire NUENTSA WAKAM, INRIA <desire.nuentsa_wakam@inria.fr> with inputs from Guy Atenekeng <atenekeng@yahoo.com> and R.B. Sidje <roger.b.sidje@ua.edu>
 
  References :
  +   [1] D. Nuentsa Wakam and J. Erhel, Parallelism and robustness in GMRES with the Newton basis and the deflated restarting. Research report INRIA RR-7787, November 2011,https://hal.inria.fr/inria-00638247/en,  in revision for ETNA.
@@ -680,7 +676,7 @@ Mathematics, 62(9), pp. 1171-1186, 2012
  .  [5] M. Mohiyuddin, M. Hoemmen, J. Demmel, and K. Yelick, Minimizing communication in sparse matrix solvers, in SC '09: Proceedings of the Conference on High Performance Computing Networking, Storage and Analysis, New York, NY, USA, 2009, ACM, pp. 1154-1171.
  .    Sidje, Roger B. Alternatives for parallel Krylov subspace basis computation. Numer. Linear Algebra Appl. 4 (1997), no. 4, 305-331
 
- .seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPDGMRES`, `KSPPGMRES`,
+.seealso: [](chapter_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPDGMRES`, `KSPPGMRES`,
            `KSPGMRESSetRestart()`, `KSPGMRESSetHapTol()`, `KSPGMRESSetPreAllocateVectors()`, `KSPGMRESSetOrthogonalization()`, `KSPGMRESGetOrthogonalization()`,
            `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESModifiedGramSchmidtOrthogonalization()`,
            `KSPGMRESCGSRefinementType`, `KSPGMRESSetCGSRefinementType()`, `KSPGMRESGetCGSRefinementType()`, `KSPGMRESMonitorKrylov()`, `KSPSetPCSide()`
@@ -748,5 +744,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_AGMRES(KSP ksp)
   agmres->HasSchur    = PETSC_FALSE;
   agmres->DeflPrecond = PETSC_FALSE;
   PetscCall(PetscObjectGetNewTag((PetscObject)ksp, &agmres->tag));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
