@@ -12,7 +12,7 @@
      KSPGMRESModifiedGramSchmidtOrthogonalization -  This is the basic orthogonalization routine
                 using modified Gram-Schmidt.
 
-     Collective on ksp
+     Collective
 
   Input Parameters:
 +   ksp - KSP object, must be associated with `KSPGMRES`, `KSPFGMRES`, or `KSPLGMRES` Krylov method
@@ -49,5 +49,5 @@ PetscErrorCode KSPGMRESModifiedGramSchmidtOrthogonalization(KSP ksp, PetscInt it
     PetscCall(VecAXPY(VEC_VV(it + 1), -(*hh++), VEC_VV(j)));
   }
   PetscCall(PetscLogEventEnd(KSP_GMRESOrthogonalization, ksp, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
