@@ -4,7 +4,7 @@
 /*@C
    KSPFGMRESSetModifyPC - Sets the routine used by `KSPFGMRES` to modify the preconditioner. [](sec_flexibleksp)
 
-   Logically Collective on ksp
+   Logically Collective
 
    Input Parameters:
 +  ksp - iterative context obtained from `KSPCreate()`
@@ -12,14 +12,17 @@
 .  ctx - optional context
 -  d - optional context destroy routine
 
-   Calling Sequence of function:
-    PetscErrorCode fcn(KSP ksp,PetscInt total_its,PetscInt loc_its,PetscReal res_norm,void*ctx);
+   Calling Sequence of `function`:
+$    PetscErrorCode fcn(KSP ksp, PetscInt total_its, PetscInt loc_its, PetscReal res_norm, void *ctx);
 +    ksp - the ksp context being used.
 .    total_its     - the total number of FGMRES iterations that have occurred.
 .    loc_its       - the number of FGMRES iterations since last restart.
 .    res_norm      - the current residual norm.
 -    ctx           - optional context variable
 
+   Calling Sequence of `d`:
+$ PetscErrorCode d(void *ctx)
+
    Options Database Keys:
 +   -ksp_fgmres_modifypcnochange - do not change the `PC`
 -   -ksp_fgmres_modifypcksp - changes the inner KSP solver tolerances
@@ -36,7 +39,7 @@ PetscErrorCode KSPFGMRESSetModifyPC(KSP ksp, PetscErrorCode (*fcn)(KSP, PetscInt
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscTryMethod(ksp, "KSPFGMRESSetModifyPC_C", (KSP, PetscErrorCode(*)(KSP, PetscInt, PetscInt, PetscReal, void *), void *, PetscErrorCode (*)(void *)), (ksp, fcn, ctx, d));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -57,7 +60,7 @@ PetscErrorCode KSPFGMRESSetModifyPC(KSP ksp, PetscErrorCode (*fcn)(KSP, PetscInt
 PetscErrorCode KSPFGMRESModifyPCNoChange(KSP ksp, PetscInt total_its, PetscInt loc_its, PetscReal res_norm, void *dummy)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -102,5 +105,5 @@ PetscErrorCode KSPFGMRESModifyPCKSP(KSP ksp, PetscInt total_its, PetscInt loc_it
     else rtol *= .9;
     PetscCall(KSPSetTolerances(sub_ksp, rtol, abstol, dtol, maxits));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
