@@ -6,7 +6,7 @@
     needed work vectors at initial setup rather than the default, which
     is to allocate them in chunks when needed.
 
-    Logically Collective on ksp
+    Logically Collective
 
     Input Parameter:
 .   ksp   - iterative context obtained from KSPCreate
@@ -22,5 +22,5 @@ PetscErrorCode KSPGMRESSetPreAllocateVectors(KSP ksp)
 {
   PetscFunctionBegin;
   PetscTryMethod(ksp, "KSPGMRESSetPreAllocateVectors_C", (KSP), (ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
