@@ -12,14 +12,14 @@ PetscErrorCode KSPLGMRESSetAugDim(KSP ksp, PetscInt dim)
 {
   PetscFunctionBegin;
   PetscTryMethod((ksp), "KSPLGMRESSetAugDim_C", (KSP, PetscInt), (ksp, dim));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode KSPLGMRESSetConstant(KSP ksp)
 {
   PetscFunctionBegin;
   PetscTryMethod((ksp), "KSPLGMRESSetConstant_C", (KSP), (ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -55,11 +55,10 @@ PetscErrorCode KSPSetUp_LGMRES(KSP ksp)
   PetscCall(KSPCreateVecs(ksp, lgmres->aug_vv_allocated, &lgmres->augvecs_user_work[0], 0, NULL));
   PetscCall(PetscMalloc1(max_k + 1, &lgmres->hwork));
   for (k = 0; k < lgmres->aug_vv_allocated; k++) lgmres->augvecs[k] = lgmres->augvecs_user_work[0][k];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
-
     KSPLGMRESCycle - Run lgmres, possibly with restart.  Return residual
                   history if requested.
 
@@ -77,7 +76,6 @@ PetscErrorCode KSPSetUp_LGMRES(KSP ksp)
     Notes:
     On entry, the value in vector VEC_VV(0) should be
     the initial residual.
-
  */
 PetscErrorCode KSPLGMRESCycle(PetscInt *itcount, KSP ksp)
 {
@@ -128,7 +126,7 @@ PetscErrorCode KSPLGMRESCycle(PetscInt *itcount, KSP ksp)
     if (itcount) *itcount = 0;
     ksp->reason = KSP_CONVERGED_ATOL;
     PetscCall(PetscInfo(ksp, "Converged due to zero residual norm on entry\n"));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   /* scale VEC_VV (the initial residual) */
@@ -274,7 +272,7 @@ PetscErrorCode KSPLGMRESCycle(PetscInt *itcount, KSP ksp)
     for (ii = 0; ii < aug_dim; ii++) AUG_ORDER(ii)++;
     AUG_ORDER(spot) = 1;
 
-    /*now add the A*aug vector to A_AUGVEC(spot)  - this is independ. of preconditioning type*/
+    /*now add the A*aug vector to A_AUGVEC(spot) - this is independent of preconditioning type*/
     /* want V*H*y - y is in GRS, V is in VEC_VV and H is in HES */
 
     /* first do H+*y */
@@ -292,7 +290,7 @@ PetscErrorCode KSPLGMRESCycle(PetscInt *itcount, KSP ksp)
     PetscCall(VecCopy(VEC_TEMP, A_AUGVEC(spot)));
     PetscCall(VecScale(A_AUGVEC(spot), inv_tmp_norm));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -305,7 +303,6 @@ PetscErrorCode KSPLGMRESCycle(PetscInt *itcount, KSP ksp)
 .     outits - number of iterations used
 
 */
-
 PetscErrorCode KSPSolve_LGMRES(KSP ksp)
 {
   PetscInt    cycle_its; /* iterations done in a call to KSPLGMRESCycle */
@@ -342,13 +339,11 @@ PetscErrorCode KSPSolve_LGMRES(KSP ksp)
     ksp->guess_zero = PETSC_FALSE; /* every future call to KSPInitialResidual() will have nonzero guess */
   }
   ksp->guess_zero = guess_zero; /* restore if user provided nonzero initial guess */
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
-
    KSPDestroy_LGMRES - Frees all memory space used by the Krylov method.
-
 */
 PetscErrorCode KSPDestroy_LGMRES(KSP ksp)
 {
@@ -363,7 +358,7 @@ PetscErrorCode KSPDestroy_LGMRES(KSP ksp)
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPLGMRESSetConstant_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ksp, "KSPLGMRESSetAugDim_C", NULL));
   PetscCall(KSPDestroy_GMRES(ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -394,7 +389,7 @@ static PetscErrorCode KSPLGMRESBuildSoln(PetscScalar *nrs, Vec vguess, Vec vdest
   /* If it is < 0, no lgmres steps have been performed */
   if (it < 0) {
     PetscCall(VecCopy(vguess, vdest)); /* VecCopy() is smart, exists immediately if vguess == vdest */
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   /* so (it+1) lgmres steps HAVE been performed */
@@ -464,11 +459,10 @@ static PetscErrorCode KSPLGMRESBuildSoln(PetscScalar *nrs, Vec vguess, Vec vdest
   /* put updated solution into vdest.*/
   PetscCall(VecCopy(vguess, vdest));
   PetscCall(VecAXPY(vdest, 1.0, VEC_TEMP));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
-
     KSPLGMRESUpdateHessenberg - Do the scalar work for the orthogonalization.
                             Return new residual.
 
@@ -523,7 +517,7 @@ static PetscErrorCode KSPLGMRESUpdateHessenberg(KSP ksp, PetscInt it, PetscBool
     tt = PetscSqrtScalar(PetscConj(*hh) * *hh + PetscConj(*(hh + 1)) * *(hh + 1));
     if (tt == 0.0) {
       ksp->reason = KSP_DIVERGED_NULL;
-      PetscFunctionReturn(0);
+      PetscFunctionReturn(PETSC_SUCCESS);
     }
     *cc = *hh / tt;       /* new cosine value */
     *ss = *(hh + 1) / tt; /* new sine value */
@@ -545,7 +539,7 @@ static PetscErrorCode KSPLGMRESUpdateHessenberg(KSP ksp, PetscInt it, PetscBool
 
     *res = 0.0;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -568,7 +562,7 @@ static PetscErrorCode KSPLGMRESGetNewVectors(KSP ksp, PetscInt it)
   /* Adjust the number to allocate to make sure that we don't exceed the
      number of available slots (lgmres->vecs_allocated)*/
   if (it + VEC_OFFSET + nalloc >= lgmres->vecs_allocated) nalloc = lgmres->vecs_allocated - it - VEC_OFFSET;
-  if (!nalloc) PetscFunctionReturn(0);
+  if (!nalloc) PetscFunctionReturn(PETSC_SUCCESS);
 
   lgmres->vv_allocated += nalloc; /* vv_allocated is the number of vectors allocated */
 
@@ -583,11 +577,10 @@ static PetscErrorCode KSPLGMRESGetNewVectors(KSP ksp, PetscInt it)
 
   /* increment the number of work vector chunks */
   lgmres->nwork_alloc++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
-
    KSPBuildSolution_LGMRES
 
      Input Parameter:
@@ -607,7 +600,7 @@ PetscErrorCode KSPBuildSolution_LGMRES(KSP ksp, Vec ptr, Vec *result)
 
   PetscFunctionBegin;
   if (!ptr) {
-    if (!lgmres->sol_temp) { PetscCall(VecDuplicate(ksp->vec_sol, &lgmres->sol_temp)); }
+    if (!lgmres->sol_temp) PetscCall(VecDuplicate(ksp->vec_sol, &lgmres->sol_temp));
     ptr = lgmres->sol_temp;
   }
   if (!lgmres->nrs) {
@@ -617,7 +610,7 @@ PetscErrorCode KSPBuildSolution_LGMRES(KSP ksp, Vec ptr, Vec *result)
 
   PetscCall(KSPLGMRESBuildSoln(lgmres->nrs, ksp->vec_sol, ptr, ksp, lgmres->it));
   if (result) *result = ptr;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode KSPView_LGMRES(KSP ksp, PetscViewer viewer)
@@ -634,7 +627,7 @@ PetscErrorCode KSPView_LGMRES(KSP ksp, PetscViewer viewer)
     if (lgmres->approx_constant) PetscCall(PetscViewerASCIIPrintf(viewer, "  approx. space size was kept constant.\n"));
     PetscCall(PetscViewerASCIIPrintf(viewer, "  number of matvecs=%" PetscInt_FMT "\n", lgmres->matvecs));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode KSPSetFromOptions_LGMRES(KSP ksp, PetscOptionItems *PetscOptionsObject)
@@ -650,7 +643,7 @@ PetscErrorCode KSPSetFromOptions_LGMRES(KSP ksp, PetscOptionItems *PetscOptionsO
   PetscCall(PetscOptionsInt("-ksp_lgmres_augment", "Number of error approximations to augment the Krylov space with", "KSPLGMRESSetAugDim", lgmres->aug_dim, &aug, &flg));
   if (flg) PetscCall(KSPLGMRESSetAugDim(ksp, aug));
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*functions for extra lgmres options here*/
@@ -660,7 +653,7 @@ static PetscErrorCode KSPLGMRESSetConstant_LGMRES(KSP ksp)
 
   PetscFunctionBegin;
   lgmres->approx_constant = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPLGMRESSetAugDim_LGMRES(KSP ksp, PetscInt aug_dim)
@@ -671,11 +664,9 @@ static PetscErrorCode KSPLGMRESSetAugDim_LGMRES(KSP ksp, PetscInt aug_dim)
   PetscCheck(aug_dim >= 0, PetscObjectComm((PetscObject)ksp), PETSC_ERR_ARG_OUTOFRANGE, "Augmentation dimension must be positive");
   PetscCheck(aug_dim <= (lgmres->max_k - 1), PetscObjectComm((PetscObject)ksp), PETSC_ERR_ARG_OUTOFRANGE, "Augmentation dimension must be <= (restart size-1)");
   lgmres->aug_dim = aug_dim;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* end new lgmres functions */
-
 /*MC
     KSPLGMRES - Augments the standard GMRES approximation space with approximations to
                 the error from previous restart cycles.
@@ -693,29 +684,29 @@ static PetscErrorCode KSPLGMRESSetAugDim_LGMRES(KSP ksp, PetscInt aug_dim)
 .   -ksp_lgmres_augment <k> - number of error approximations to augment the Krylov space with
 -   -ksp_lgmres_constant - use a constant approx. space size (only affects restart cycles < num. error approx.(k), i.e. the first k restarts)
 
-    To run LGMRES(m, k) as described in the above paper, use:
+    To run LGMRES(m, k) as described in [1], use:
        -ksp_gmres_restart <m+k>
        -ksp_lgmres_augment <k>
 
   Level: beginner
 
-   Notes:
+   Note:
     Supports both left and right preconditioning, but not symmetric.
 
+  Developer Note:
+    This object is subclassed off of `KSPGMRES`
+
+  Contributed by:
+  Allison Baker
+
    References:
-.  * - A. H. Baker, E.R. Jessup, and T.A. Manteuffel. A technique for accelerating the convergence of restarted GMRES. SIAM Journal on Matrix Analysis and Applications, 26 (2005).
+.  [1] - A. H. Baker, E.R. Jessup, and T.A. Manteuffel. A technique for accelerating the convergence of restarted GMRES. SIAM Journal on Matrix Analysis and Applications, 26 (2005).
 
-  Developer Notes:
-    This object is subclassed off of KSPGMRES
-
-  Contributed by: Allison Baker
-
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPFGMRES`, `KSPGMRES`,
+.seealso: [](chapter_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPFGMRES`, `KSPGMRES`,
           `KSPGMRESSetRestart()`, `KSPGMRESSetHapTol()`, `KSPGMRESSetPreAllocateVectors()`, `KSPGMRESSetOrthogonalization()`, `KSPGMRESGetOrthogonalization()`,
           `KSPGMRESClassicalGramSchmidtOrthogonalization()`, `KSPGMRESModifiedGramSchmidtOrthogonalization()`,
           `KSPGMRESCGSRefinementType`, `KSPGMRESSetCGSRefinementType()`, `KSPGMRESGetCGSRefinementType()`, `KSPGMRESMonitorKrylov()`, `KSPLGMRESSetAugDim()`,
           `KSPGMRESSetConstant()`
-
 M*/
 
 PETSC_EXTERN PetscErrorCode KSPCreate_LGMRES(KSP ksp)
@@ -770,5 +761,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_LGMRES(KSP ksp)
   lgmres->aug_ct          = 0; /* start with no aug vectors */
   lgmres->approx_constant = PETSC_FALSE;
   lgmres->matvecs         = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
