@@ -4,7 +4,7 @@
 static PetscErrorCode KSPSetUp_PREONLY(KSP ksp)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSolve_PREONLY(KSP ksp)
@@ -43,7 +43,7 @@ static PetscErrorCode KSPSolve_PREONLY(KSP ksp)
     PetscCall(VecDestroy(&v));
     PetscCall(KSPMonitor(ksp, 1, norm));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPMatSolve_PREONLY(KSP ksp, Mat B, Mat X)
@@ -57,7 +57,7 @@ static PetscErrorCode KSPMatSolve_PREONLY(KSP ksp, Mat B, Mat X)
   PetscCheck(ksp->guess_zero, PetscObjectComm((PetscObject)ksp), PETSC_ERR_USER, "Running KSP of preonly doesn't make sense with nonzero initial guess\n\
                you probably want a KSP type of Richardson");
   ksp->its = 0;
-  PetscCall(PCMatApply(ksp->pc, B, X));
+  PetscCall(KSP_PCMatApply(ksp, B, X));
   PetscCall(PCGetFailedReason(ksp->pc, &pcreason));
   /* Note: only some ranks may have this set; this may lead to problems if the caller assumes ksp->reason is set on all processes or just uses the result */
   if (pcreason) {
@@ -67,33 +67,32 @@ static PetscErrorCode KSPMatSolve_PREONLY(KSP ksp, Mat B, Mat X)
     ksp->its    = 1;
     ksp->reason = KSP_CONVERGED_ITS;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
      KSPPREONLY - This implements a method that applies ONLY the preconditioner exactly once.
                   This may be used in inner iterations, where it is desired to
                   allow multiple iterations as well as the "0-iteration" case. It is
-                  commonly used with the direct solver preconditioners like PCLU and PCCHOLESKY.
-                  There is an alias of KSPNONE.
+                  commonly used with the direct solver preconditioners like `PCLU` and `PCCHOLESKY`.
+                  There is an alias of `KSPNONE`.
 
-   Options Database Keys:
+   Options Database Key:
 .   -ksp_type preonly - use preconditioner only
 
    Level: beginner
 
    Notes:
-    Since this does not involve an iteration the basic KSP parameters such as tolerances and iteration counts
-          do not apply
+   Since this does not involve an iteration the basic `KSP` parameters such as tolerances and iteration counts
+   do not apply
 
-    To apply multiple preconditioners in a simple iteration use KSPRICHARDSON
+   To apply multiple preconditioners in a simple iteration use `KSPRICHARDSON`
 
-   Developer Notes:
-    Even though this method does not use any norms, the user is allowed to set the KSPNormType to any value.
-    This is so the users does not have to change KSPNormType options when they switch from other KSP methods to this one.
-
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPRICHARDSON`, `KSPCHEBYSHEV`
+   Developer Note:
+   Even though this method does not use any norms, the user is allowed to set the `KSPNormType` to any value.
+   This is so the users does not have to change `KSPNormType` options when they switch from other `KSP` methods to this one.
 
+.seealso: [](chapter_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPRICHARDSON`, `KSPCHEBYSHEV`
 M*/
 
 PETSC_EXTERN PetscErrorCode KSPCreate_PREONLY(KSP ksp)
@@ -116,5 +115,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_PREONLY(KSP ksp)
   ksp->ops->buildresidual  = KSPBuildResidualDefault;
   ksp->ops->setfromoptions = NULL;
   ksp->ops->view           = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
