@@ -3,7 +3,7 @@
 /*@C
    KSPPythonSetType - Initialize a `KSP` object to a type implemented in Python.
 
-   Collective on ksp
+   Collective
 
    Input Parameters:
 +  ksp - the linear solver `KSP` context.
@@ -22,13 +22,13 @@ PetscErrorCode KSPPythonSetType(KSP ksp, const char pyname[])
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscValidCharPointer(pyname, 2);
   PetscTryMethod(ksp, "KSPPythonSetType_C", (KSP, const char[]), (ksp, pyname));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    KSPPythonGetType - Get the type of a `KSP` object implemented in Python.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  ksp - the linear solver `KSP` context.
@@ -46,5 +46,5 @@ PetscErrorCode KSPPythonGetType(KSP ksp, const char *pyname[])
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscValidPointer(pyname, 2);
   PetscUseMethod(ksp, "KSPPythonGetType_C", (KSP, const char *[]), (ksp, pyname));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
