@@ -5,18 +5,18 @@
     KSPRichardsonSetScale - Set the damping factor; if this routine is not called, the factor
     defaults to 1.0.
 
-    Logically Collective on ksp
+    Logically Collective
 
     Input Parameters:
 +   ksp - the iterative context
 -   scale - the damping factor
 
-    Options Database Keys:
-. -ksp_richardson_self <scale> - Set the scale factor
+    Options Database Key:
+. -ksp_richardson_scale <scale> - Set the scale factor
 
     Level: intermediate
 
- .seealso: [](chapter_ksp), `KSPRICHARDSON`, `KSPRichardsonSetSelfScale()`
+.seealso: [](chapter_ksp), `KSPRICHARDSON`, `KSPRichardsonSetSelfScale()`
 @*/
 PetscErrorCode KSPRichardsonSetScale(KSP ksp, PetscReal scale)
 {
@@ -24,20 +24,20 @@ PetscErrorCode KSPRichardsonSetScale(KSP ksp, PetscReal scale)
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscValidLogicalCollectiveReal(ksp, scale, 2);
   PetscTryMethod(ksp, "KSPRichardsonSetScale_C", (KSP, PetscReal), (ksp, scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     KSPRichardsonSetSelfScale - Sets Richardson to automatically determine optimal scaling at each iteration to minimize the 2-norm of the
        preconditioned residual
 
-    Logically Collective on ksp
+    Logically Collective
 
     Input Parameters:
 +   ksp - the iterative context
 -   scale - `PETSC_TRUE` or the default of `PETSC_FALSE`
 
-    Options Database Keys:
+    Options Database Key:
 . -ksp_richardson_self_scale - Use self-scaling
 
     Level: intermediate
@@ -56,5 +56,5 @@ PetscErrorCode KSPRichardsonSetSelfScale(KSP ksp, PetscBool scale)
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscValidLogicalCollectiveBool(ksp, scale, 2);
   PetscTryMethod(ksp, "KSPRichardsonSetSelfScale_C", (KSP, PetscBool), (ksp, scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
