@@ -24,7 +24,7 @@ static PetscErrorCode KSPSolve_TCQMR(KSP ksp)
   if (ksp->normtype != KSP_NORM_NONE) ksp->rnorm = rnorm0;
   else ksp->rnorm = 0;
   PetscCall((*ksp->converged)(ksp, 0, ksp->rnorm, &ksp->reason, ksp->cnvP));
-  if (ksp->reason) PetscFunctionReturn(0);
+  if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(VecSet(um1, 0.0));
   PetscCall(VecCopy(r, u));
@@ -147,37 +147,33 @@ static PetscErrorCode KSPSolve_TCQMR(KSP ksp)
   }
   PetscCall(KSPMonitor(ksp, ksp->its, ksp->rnorm));
   PetscCall(KSPUnwindPreconditioner(ksp, x, vtmp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSetUp_TCQMR(KSP ksp)
 {
   PetscFunctionBegin;
   PetscCall(KSPSetWorkVecs(ksp, TCQMR_VECS));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
-     KSPTCQMR - A variant of QMR (quasi minimal residual) developed by Tony Chan
-
-   Options Database Keys:
-    see KSPSolve()
+     KSPTCQMR - A variant of QMR (quasi minimal residual) [1]
 
    Level: beginner
 
   Notes:
-    Supports either left or right preconditioning, but not symmetric
+  Supports either left or right preconditioning, but not symmetric
 
-          The "residual norm" computed in this algorithm is actually just an upper bound on the actual residual norm.
-          That is for left preconditioning it is a bound on the preconditioned residual and for right preconditioning
-          it is a bound on the true residual.
+  The "residual norm" computed in this algorithm is actually just an upper bound on the actual residual norm.
+  That is for left preconditioning it is a bound on the preconditioned residual and for right preconditioning
+  it is a bound on the true residual.
 
   References:
-. * - Tony F. Chan, Lisette de Pillis, and Henk van der Vorst, Transpose free formulations of Lanczos type methods for nonsymmetric linear systems,
+. [1] - Tony F. Chan, Lisette de Pillis, and Henk van der Vorst, Transpose free formulations of Lanczos type methods for nonsymmetric linear systems,
   Numerical Algorithms, Volume 17, 1998.
 
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPTFQMR`
-
+.seealso: [](chapter_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPTFQMR`
 M*/
 
 PETSC_EXTERN PetscErrorCode KSPCreate_TCQMR(KSP ksp)
@@ -195,5 +191,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_TCQMR(KSP ksp)
   ksp->ops->destroy        = KSPDestroyDefault;
   ksp->ops->setfromoptions = NULL;
   ksp->ops->view           = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
