@@ -6,7 +6,7 @@ static PetscErrorCode KSPSetUp_TFQMR(KSP ksp)
   PetscFunctionBegin;
   PetscCheck(ksp->pc_side != PC_SYMMETRIC, PetscObjectComm((PetscObject)ksp), PETSC_ERR_SUP, "no symmetric preconditioning for KSPTFQMR");
   PetscCall(KSPSetWorkVecs(ksp, 9));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode KSPSolve_TFQMR(KSP ksp)
@@ -43,7 +43,7 @@ static PetscErrorCode KSPSolve_TFQMR(KSP ksp)
   PetscCall(PetscObjectSAWsGrantAccess((PetscObject)ksp));
   PetscCall(KSPMonitor(ksp, 0, ksp->rnorm));
   PetscCall((*ksp->converged)(ksp, 0, ksp->rnorm, &ksp->reason, ksp->cnvP));
-  if (ksp->reason) PetscFunctionReturn(0);
+  if (ksp->reason) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* Make the initial Rp == R */
   PetscCall(VecCopy(R, RP));
@@ -119,28 +119,25 @@ static PetscErrorCode KSPSolve_TFQMR(KSP ksp)
   if (i >= ksp->max_it) ksp->reason = KSP_DIVERGED_ITS;
 
   PetscCall(KSPUnwindPreconditioner(ksp, X, T));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
      KSPTFQMR - A transpose free QMR (quasi minimal residual),
 
-   Options Database Keys:
-   see KSPSolve()
-
    Level: beginner
 
    Notes:
-    Supports left and right preconditioning, but not symmetric
+   Supports left and right preconditioning, but not symmetric
 
-          The "residual norm" computed in this algorithm is actually just an upper bound on the actual residual norm.
-          That is for left preconditioning it is a bound on the preconditioned residual and for right preconditioning
-          it is a bound on the true residual.
+   The "residual norm" computed in this algorithm is actually just an upper bound on the actual residual norm.
+   That is for left preconditioning it is a bound on the preconditioned residual and for right preconditioning
+   it is a bound on the true residual.
 
    References:
 .  * - Freund, 1993
 
-.seealso: `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPTCQMR`
+.seealso: [](chapter_ksp), `KSPCreate()`, `KSPSetType()`, `KSPType`, `KSP`, `KSPTCQMR`
 M*/
 PETSC_EXTERN PetscErrorCode KSPCreate_TFQMR(KSP ksp)
 {
@@ -158,5 +155,5 @@ PETSC_EXTERN PetscErrorCode KSPCreate_TFQMR(KSP ksp)
   ksp->ops->buildresidual  = KSPBuildResidualDefault;
   ksp->ops->setfromoptions = NULL;
   ksp->ops->view           = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
