@@ -10,7 +10,7 @@
    KSPSetOptionsPrefix - Sets the prefix used for searching for all
    `KSP` options in the database.
 
-   Logically Collective on ksp
+   Logically Collective
 
    Input Parameters:
 +  ksp - the Krylov context
@@ -45,14 +45,14 @@ PetscErrorCode KSPSetOptionsPrefix(KSP ksp, const char prefix[])
   if (!ksp->pc) PetscCall(KSPGetPC(ksp, &ksp->pc));
   PetscCall(PCSetOptionsPrefix(ksp->pc, prefix));
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)ksp, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    KSPAppendOptionsPrefix - Appends to the prefix used for searching for all
    `KSP` options in the database.
 
-   Logically Collective on ksp
+   Logically Collective
 
    Input Parameters:
 +  ksp - the Krylov context
@@ -73,13 +73,13 @@ PetscErrorCode KSPAppendOptionsPrefix(KSP ksp, const char prefix[])
   if (!ksp->pc) PetscCall(KSPGetPC(ksp, &ksp->pc));
   PetscCall(PCAppendOptionsPrefix(ksp->pc, prefix));
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)ksp, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    KSPSetUseFischerGuess - Use the Paul Fischer algorithm or its variants to compute initial guesses for a set of solves with related right hand sides
 
-   Logically Collective on ksp
+   Logically Collective
 
    Input Parameters:
 +  ksp - the Krylov context
@@ -104,13 +104,13 @@ PetscErrorCode KSPSetUseFischerGuess(KSP ksp, PetscInt model, PetscInt size)
   PetscCall(KSPGetGuess(ksp, &guess));
   PetscCall(KSPGuessSetType(guess, KSPGUESSFISCHER));
   PetscCall(KSPGuessFischerSetModel(guess, model, size));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    KSPSetGuess - Set the initial guess object
 
-   Logically Collective on ksp
+   Logically Collective
 
    Input Parameters:
 +  ksp - the Krylov context
@@ -136,7 +136,7 @@ PetscErrorCode KSPSetGuess(KSP ksp, KSPGuess guess)
   PetscCall(KSPGuessDestroy(&ksp->guess));
   ksp->guess      = guess;
   ksp->guess->ksp = ksp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -144,10 +144,10 @@ PetscErrorCode KSPSetGuess(KSP ksp, KSPGuess guess)
 
    Not Collective
 
-   Input Parameters:
+   Input Parameter:
 .  ksp - the Krylov context
 
-   Output Parameters:
+   Output Parameter:
 .   guess - the object
 
    Level: developer
@@ -168,7 +168,7 @@ PetscErrorCode KSPGetGuess(KSP ksp, KSPGuess *guess)
     ksp->guess->ksp = ksp;
   }
   *guess = ksp->guess;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -177,10 +177,10 @@ PetscErrorCode KSPGetGuess(KSP ksp, KSPGuess *guess)
 
    Not Collective
 
-   Input Parameters:
+   Input Parameter:
 .  ksp - the Krylov context
 
-   Output Parameters:
+   Output Parameter:
 .  prefix - pointer to the prefix string used is returned
 
    Notes:
@@ -196,7 +196,7 @@ PetscErrorCode KSPGetOptionsPrefix(KSP ksp, const char *prefix[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 1);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)ksp, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PetscViewerAndFormatCreate_Internal(PetscViewer viewer, PetscViewerFormat format, void *ctx, PetscViewerAndFormat **vf)
@@ -204,13 +204,13 @@ static PetscErrorCode PetscViewerAndFormatCreate_Internal(PetscViewer viewer, Pe
   PetscFunctionBegin;
   PetscCall(PetscViewerAndFormatCreate(viewer, format, vf));
   (*vf)->data = ctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    KSPMonitorSetFromOptions - Sets a monitor function and viewer appropriate for the type indicated by the user in the options database
 
-   Collective on ksp
+   Collective
 
    Input Parameters:
 +  ksp  - `KSP` object you wish to monitor
@@ -245,7 +245,7 @@ PetscErrorCode KSPMonitorSetFromOptions(KSP ksp, const char opt[], const char na
   PetscCall(PetscStrcmp(opt, "-all_ksp_monitor", &all));
   if (!all) PetscCall(PetscObjectGetOptionsPrefix((PetscObject)ksp, &prefix));
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)ksp), ((PetscObject)ksp)->options, prefix, opt, &viewer, &format, &flg));
-  if (!flg) PetscFunctionReturn(0);
+  if (!flg) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscViewerGetType(viewer, &vtype));
   PetscCall(KSPMonitorMakeKey_Internal(name, vtype, format, key));
@@ -258,7 +258,7 @@ PetscErrorCode KSPMonitorSetFromOptions(KSP ksp, const char opt[], const char na
   PetscCall((*cfunc)(viewer, format, ctx, &vf));
   PetscCall(PetscObjectDereference((PetscObject)viewer));
   PetscCall(KSPMonitorSet(ksp, mfunc, vf, (PetscErrorCode(*)(void **))dfunc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -266,7 +266,7 @@ PetscErrorCode KSPMonitorSetFromOptions(KSP ksp, const char opt[], const char na
    This routine must be called before `KSPSetUp()` if the user is to be
    allowed to set the Krylov type.
 
-   Collective on ksp
+   Collective
 
    Input Parameter:
 .  ksp - the Krylov space context
@@ -408,6 +408,9 @@ PetscErrorCode KSPSetFromOptions(KSP ksp)
   if (set && flag) PetscCall(KSPConvergedDefaultSetUMIRNorm(ksp));
   PetscCall(PetscOptionsBool("-ksp_converged_maxits", "Declare convergence if the maximum number of iterations is reached", "KSPConvergedDefaultSetConvergedMaxits", PETSC_FALSE, &flag, &set));
   if (set) PetscCall(KSPConvergedDefaultSetConvergedMaxits(ksp, flag));
+  PetscCall(KSPGetConvergedNegativeCurvature(ksp, &flag));
+  PetscCall(PetscOptionsBool("-ksp_converged_neg_curve", "Declare convergence if negative curvature is detected", "KSPConvergedNegativeCurvature", flag, &flag, &set));
+  if (set) PetscCall(KSPSetConvergedNegativeCurvature(ksp, flag));
   PetscCall(KSPGetReusePreconditioner(ksp, &reuse));
   PetscCall(PetscOptionsBool("-ksp_reuse_preconditioner", "Use initial preconditioner and don't ever compute a new one", "KSPReusePreconditioner", reuse, &reuse, NULL));
   PetscCall(KSPSetReusePreconditioner(ksp, reuse));
@@ -468,10 +471,9 @@ PetscErrorCode KSPSetFromOptions(KSP ksp)
 
     PetscCall(MatNullSpaceCreate(comm, PETSC_TRUE, 0, NULL, &nsp));
     if (ksp->pc) PetscCall(PCGetOperators(ksp->pc, &Amat, NULL));
-    if (Amat) {
-      PetscCall(MatSetNullSpace(Amat, nsp));
-      PetscCall(MatNullSpaceDestroy(&nsp));
-    } else SETERRQ(comm, PETSC_ERR_ARG_WRONGSTATE, "Cannot set nullspace, matrix has not yet been provided");
+    PetscCheck(Amat, comm, PETSC_ERR_ARG_WRONGSTATE, "Cannot set nullspace, matrix has not yet been provided");
+    PetscCall(MatSetNullSpace(Amat, nsp));
+    PetscCall(MatNullSpaceDestroy(&nsp));
   }
 
   flg = PETSC_FALSE;
@@ -482,14 +484,15 @@ PetscErrorCode KSPSetFromOptions(KSP ksp)
   }
 
   if (flg) {
-    /* A hack for using dynamic tolerance in preconditioner */
-    PetscCall(PetscOptionsString("-sub_ksp_dynamic_tolerance", "Use dynamic tolerance for PC if PC is a KSP", "KSPMonitorDynamicTolerance", "stdout", monfilename, sizeof(monfilename), &flg));
+    /* Using dynamic tolerance in preconditioner */
+    PetscCall(PetscOptionsString("-sub_ksp_dynamic_tolerance", "Use dynamic tolerance for inner PC", "KSPMonitorDynamicTolerance", "stdout", monfilename, sizeof(monfilename), &flg));
     if (flg) {
-      KSPDynTolCtx *scale;
-      PetscCall(PetscMalloc1(1, &scale));
-      scale->bnrm = -1.0;
-      scale->coef = 1.0;
-      PetscCall(PetscOptionsReal("-sub_ksp_dynamic_tolerance_param", "Parameter of dynamic tolerance for inner PCKSP", "KSPMonitorDynamicToleranceParam", scale->coef, &scale->coef, &flg));
+      void     *scale;
+      PetscReal coeff = 1.0;
+
+      PetscCall(KSPMonitorDynamicToleranceCreate(&scale));
+      PetscCall(PetscOptionsReal("-sub_ksp_dynamic_tolerance", "Coefficient of dynamic tolerance for inner PC", "KSPMonitorDynamicTolerance", coeff, &coeff, &flg));
+      if (flg) PetscCall(KSPMonitorDynamicToleranceSetCoefficient(scale, coeff));
       PetscCall(KSPMonitorSet(ksp, KSPMonitorDynamicTolerance, scale, KSPMonitorDynamicToleranceDestroy));
     }
   }
@@ -627,13 +630,13 @@ skipoptions:
   PetscCall(PetscObjectProcessOptionsHandlers((PetscObject)ksp, PetscOptionsObject));
   PetscOptionsEnd();
   ksp->setfromoptionscalled++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    KSPResetFromOptions - Sets `KSP` parameters from user options ONLY if the `KSP` was previously set from options
 
-   Collective on ksp
+   Collective
 
    Input Parameter:
 .  ksp - the `KSP` context
@@ -646,5 +649,5 @@ PetscErrorCode KSPResetFromOptions(KSP ksp)
 {
   PetscFunctionBegin;
   if (ksp->setfromoptionscalled) PetscCall(KSPSetFromOptions(ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
