@@ -13,7 +13,7 @@
 .  vt1, vt2 - temporary work vectors
 -  vb       - right-hand-side vector
 
-   Output Parameters:
+   Output Parameter:
 .  vres     - calculated residual
 
    Level: developer
@@ -67,9 +67,9 @@ PetscErrorCode KSPInitialResidual(KSP ksp, Vec vsoln, Vec vt1, Vec vt2, Vec vres
       PetscCall(PCApplySymmetricLeft(ksp->pc, vb, vres));
     } else SETERRQ(PetscObjectComm((PetscObject)ksp), PETSC_ERR_SUP, "Invalid preconditioning side %d", (int)ksp->pc_side);
   }
-  /* This may be true only on a subset of MPI ranks; setting it here so it will be detected by the first norm computaion in the Krylov method */
+  /* This may be true only on a subset of MPI ranks; setting it here so it will be detected by the first norm computation in the Krylov method */
   if (ksp->reason == KSP_DIVERGED_PC_FAILED) PetscCall(VecSetInf(vres));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -111,5 +111,5 @@ PetscErrorCode KSPUnwindPreconditioner(KSP ksp, Vec vsoln, Vec vt1)
   } else {
     PetscCall(PCDiagonalScaleRight(ksp->pc, vsoln, vsoln));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
