@@ -1,4 +1,5 @@
 #include <petscksp.h>
+#include "petsc/private/petscimpl.h"
 
 static char help[] = "Solves a linear system using PCHPDDM.\n\n";
 
@@ -12,10 +13,10 @@ int main(int argc, char **args)
   const PetscInt *idx;
   PetscMPIInt     rank, size;
   PetscInt        m, N = 1;
-  const char     *deft = MATAIJ;
   PetscViewer     viewer;
   char            dir[PETSC_MAX_PATH_LEN], name[PETSC_MAX_PATH_LEN], type[256];
-  PetscBool       flg;
+  PetscBool3      share = PETSC_BOOL3_UNKNOWN;
+  PetscBool       flg, set;
 #if defined(PETSC_USE_LOG)
   PetscLogEvent event;
 #endif
@@ -31,7 +32,7 @@ int main(int argc, char **args)
   PetscCall(MatCreate(PETSC_COMM_WORLD, &A));
   PetscCall(MatCreate(PETSC_COMM_SELF, &aux));
   PetscCall(ISCreate(PETSC_COMM_SELF, &is));
-  PetscCall(PetscStrcpy(dir, "."));
+  PetscCall(PetscStrncpy(dir, ".", sizeof(dir)));
   PetscCall(PetscOptionsGetString(NULL, NULL, "-load_dir", dir, sizeof(dir), NULL));
   /* loading matrices */
   PetscCall(PetscSNPrintf(name, sizeof(name), "%s/sizes_%d_%d.dat", dir, rank, size));
@@ -40,10 +41,10 @@ int main(int argc, char **args)
   PetscCall(ISLoad(sizes, viewer));
   PetscCall(ISGetIndices(sizes, &idx));
   PetscCall(MatSetSizes(A, idx[0], idx[1], idx[2], idx[3]));
+  PetscCall(MatSetUp(A));
   PetscCall(ISRestoreIndices(sizes, &idx));
   PetscCall(ISDestroy(&sizes));
   PetscCall(PetscViewerDestroy(&viewer));
-  PetscCall(MatSetUp(A));
   PetscCall(PetscSNPrintf(name, sizeof(name), "%s/A.dat", dir));
   PetscCall(PetscViewerBinaryOpen(PETSC_COMM_WORLD, name, FILE_MODE_READ, &viewer));
   PetscCall(MatLoad(A, viewer));
@@ -51,41 +52,47 @@ int main(int argc, char **args)
   PetscCall(PetscSNPrintf(name, sizeof(name), "%s/is_%d_%d.dat", dir, rank, size));
   PetscCall(PetscViewerBinaryOpen(PETSC_COMM_SELF, name, FILE_MODE_READ, &viewer));
   PetscCall(ISLoad(is, viewer));
+  PetscCall(ISSetBlockSize(is, 2));
   PetscCall(PetscViewerDestroy(&viewer));
   PetscCall(PetscSNPrintf(name, sizeof(name), "%s/Neumann_%d_%d.dat", dir, rank, size));
   PetscCall(PetscViewerBinaryOpen(PETSC_COMM_SELF, name, FILE_MODE_READ, &viewer));
   PetscCall(MatLoad(aux, viewer));
   PetscCall(PetscViewerDestroy(&viewer));
   flg = PETSC_FALSE;
-  PetscCall(PetscOptionsGetBool(NULL, NULL, "-pc_hpddm_levels_1_st_share_sub_ksp", &flg, NULL));
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-pc_hpddm_levels_1_st_share_sub_ksp", &flg, &set));
   if (flg) { /* PETSc LU/Cholesky is struggling numerically for bs > 1          */
              /* only set the proper bs for the geneo_share_* tests, 1 otherwise */
     PetscCall(MatSetBlockSizesFromMats(aux, A, A));
-  }
+    share = PETSC_BOOL3_TRUE;
+  } else if (set) share = PETSC_BOOL3_FALSE;
   PetscCall(MatSetOption(A, MAT_SYMMETRIC, PETSC_TRUE));
   PetscCall(MatSetOption(aux, MAT_SYMMETRIC, PETSC_TRUE));
   /* ready for testing */
   PetscOptionsBegin(PETSC_COMM_WORLD, "", "", "");
-  PetscCall(PetscOptionsFList("-mat_type", "Matrix type", "MatSetType", MatList, deft, type, 256, &flg));
+  PetscCall(PetscStrncpy(type, MATAIJ, sizeof(type)));
+  PetscCall(PetscOptionsFList("-mat_type", "Matrix type", "MatSetType", MatList, type, type, 256, &flg));
   PetscOptionsEnd();
-  if (flg) {
-    PetscCall(MatConvert(A, type, MAT_INPLACE_MATRIX, &A));
-    PetscCall(MatConvert(aux, type, MAT_INPLACE_MATRIX, &aux));
-  }
+  PetscCall(MatConvert(A, type, MAT_INPLACE_MATRIX, &A));
+  PetscCall(MatConvert(aux, type, MAT_INPLACE_MATRIX, &aux));
   PetscCall(KSPCreate(PETSC_COMM_WORLD, &ksp));
   PetscCall(KSPSetOperators(ksp, A, A));
   PetscCall(KSPGetPC(ksp, &pc));
   PetscCall(PCSetType(pc, PCHPDDM));
 #if defined(PETSC_HAVE_HPDDM) && defined(PETSC_HAVE_DYNAMIC_LIBRARIES) && defined(PETSC_USE_SHARED_LIBRARIES)
   flg = PETSC_FALSE;
-  PetscCall(PetscOptionsGetBool(NULL, NULL, "-pc_hpddm_block_splitting", &flg, NULL));
-  if (!flg) {
-    PetscCall(PCHPDDMSetAuxiliaryMat(pc, is, aux, NULL, NULL));
-    PetscCall(PCHPDDMHasNeumannMat(pc, PETSC_FALSE)); /* PETSC_TRUE is fine as well, just testing */
+  PetscCall(PetscOptionsGetBool(NULL, NULL, "-reset", &flg, NULL));
+  if (flg) {
+    PetscCall(PetscOptionsSetValue(NULL, "-pc_hpddm_block_splitting", "true"));
+    PetscCall(PCSetFromOptions(pc));
+    PetscCall(PCSetUp(pc));
+    PetscCall(PetscOptionsClearValue(NULL, "-pc_hpddm_block_splitting"));
   }
+  PetscCall(PCHPDDMSetAuxiliaryMat(pc, is, aux, NULL, NULL));
+  PetscCall(PCHPDDMHasNeumannMat(pc, PETSC_FALSE)); /* PETSC_TRUE is fine as well, just testing */
+  if (share == PETSC_BOOL3_UNKNOWN) PetscCall(PCHPDDMSetSTShareSubKSP(pc, PetscBool3ToBool(share)));
   flg = PETSC_FALSE;
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-set_rhs", &flg, NULL));
-  if (flg) {          /* user-provided RHS for concurrent generalized eigenvalue problems                                 */
+  if (flg) {          /* user-provided RHS for concurrent generalized eigenvalue problems                          */
     Mat      a, c, P; /* usually assembled automatically in PCHPDDM, this is solely for testing PCHPDDMSetRHSMat() */
     PetscInt rstart, rend, location;
     PetscCall(MatDuplicate(aux, MAT_DO_NOT_COPY_VALUES, &B)); /* duplicate so that MatStructure is SAME_NONZERO_PATTERN */
@@ -113,6 +120,8 @@ int main(int argc, char **args)
     PetscCall(PCHPDDMSetRHSMat(pc, B));
     PetscCall(MatDestroy(&B));
   }
+#else
+  (void)share;
 #endif
   PetscCall(MatDestroy(&aux));
   PetscCall(KSPSetFromOptions(ksp));
@@ -182,6 +191,58 @@ int main(int argc, char **args)
       PetscCheck(info2.count > info1.count, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Cholesky numerical factorization (%d) not called more times than Cholesky symbolic factorization (%d), broken -pc_hpddm_levels_1_st_share_sub_ksp", info2.count, info1.count);
     } else PetscCheck(info2.count > info1.count, PETSC_COMM_SELF, PETSC_ERR_PLIB, "LU numerical factorization (%d) not called more times than LU symbolic factorization (%d), broken -pc_hpddm_levels_1_st_share_sub_ksp", info2.count, info1.count);
   }
+#if defined(PETSC_HAVE_HPDDM) && defined(PETSC_HAVE_DYNAMIC_LIBRARIES) && defined(PETSC_USE_SHARED_LIBRARIES)
+  if (N == 1) {
+    flg = PETSC_FALSE;
+    PetscCall(PetscOptionsGetBool(NULL, NULL, "-successive_solves", &flg, NULL));
+    if (flg) {
+      KSPConvergedReason reason[2];
+      PetscInt           iterations[3];
+      PetscCall(KSPGetConvergedReason(ksp, reason));
+      PetscCall(KSPGetTotalIterations(ksp, iterations));
+      PetscCall(PetscOptionsClearValue(NULL, "-ksp_converged_reason"));
+      flg = PETSC_FALSE;
+      PetscCall(PetscOptionsGetBool(NULL, NULL, "-pc_hpddm_block_splitting", &flg, NULL));
+      if (!flg) {
+        PetscCall(MatCreate(PETSC_COMM_SELF, &aux));
+        PetscCall(ISCreate(PETSC_COMM_SELF, &is));
+        PetscCall(PetscSNPrintf(name, sizeof(name), "%s/is_%d_%d.dat", dir, rank, size));
+        PetscCall(PetscViewerBinaryOpen(PETSC_COMM_SELF, name, FILE_MODE_READ, &viewer));
+        PetscCall(ISLoad(is, viewer));
+        PetscCall(ISSetBlockSize(is, 2));
+        PetscCall(PetscViewerDestroy(&viewer));
+        PetscCall(PetscSNPrintf(name, sizeof(name), "%s/Neumann_%d_%d.dat", dir, rank, size));
+        PetscCall(PetscViewerBinaryOpen(PETSC_COMM_SELF, name, FILE_MODE_READ, &viewer));
+        PetscCall(MatLoad(aux, viewer));
+        PetscCall(PetscViewerDestroy(&viewer));
+        PetscCall(MatSetBlockSizesFromMats(aux, A, A));
+        PetscCall(MatSetOption(aux, MAT_SYMMETRIC, PETSC_TRUE));
+        PetscCall(MatConvert(aux, type, MAT_INPLACE_MATRIX, &aux));
+      }
+      PetscCall(MatCreateVecs(A, NULL, &b));
+      PetscCall(PetscObjectStateIncrease((PetscObject)A));
+      if (!flg) PetscCall(PCHPDDMSetAuxiliaryMat(pc, NULL, aux, NULL, NULL));
+      PetscCall(VecSet(b, 1.0));
+      PetscCall(KSPSolve(ksp, b, b));
+      PetscCall(KSPGetConvergedReason(ksp, reason + 1));
+      PetscCall(KSPGetTotalIterations(ksp, iterations + 1));
+      iterations[1] -= iterations[0];
+      PetscCheck(reason[0] == reason[1] && PetscAbs(iterations[0] - iterations[1]) <= 3, PetscObjectComm((PetscObject)ksp), PETSC_ERR_PLIB, "Successive calls to KSPSolve() did not converge for the same reason (%s v. %s) or with the same number of iterations (+/- 3, %" PetscInt_FMT " v. %" PetscInt_FMT ")", KSPConvergedReasons[reason[0]], KSPConvergedReasons[reason[1]], iterations[0], iterations[1]);
+      PetscCall(PetscObjectStateIncrease((PetscObject)A));
+      if (!flg) PetscCall(PCHPDDMSetAuxiliaryMat(pc, is, aux, NULL, NULL));
+      PetscCall(PCSetFromOptions(pc));
+      PetscCall(VecSet(b, 1.0));
+      PetscCall(KSPSolve(ksp, b, b));
+      PetscCall(KSPGetConvergedReason(ksp, reason + 1));
+      PetscCall(KSPGetTotalIterations(ksp, iterations + 2));
+      iterations[2] -= iterations[0] + iterations[1];
+      PetscCheck(reason[0] == reason[1] && PetscAbs(iterations[0] - iterations[2]) <= 3, PetscObjectComm((PetscObject)ksp), PETSC_ERR_PLIB, "Successive calls to KSPSolve() did not converge for the same reason (%s v. %s) or with the same number of iterations (+/- 3, %" PetscInt_FMT " v. %" PetscInt_FMT ")", KSPConvergedReasons[reason[0]], KSPConvergedReasons[reason[1]], iterations[0], iterations[2]);
+      PetscCall(VecDestroy(&b));
+      PetscCall(ISDestroy(&is));
+      PetscCall(MatDestroy(&aux));
+    }
+  }
+#endif
   PetscCall(KSPDestroy(&ksp));
   PetscCall(MatDestroy(&A));
   PetscCall(PetscFinalize());
@@ -212,11 +273,11 @@ int main(int argc, char **args)
         suffix: geneo_block_splitting
         output_file: output/ex76_geneo_pc_hpddm_levels_1_eps_nev-15.out
         filter: sed -e "s/Linear solve converged due to CONVERGED_RTOL iterations 1[6-9]/Linear solve converged due to CONVERGED_RTOL iterations 11/g"
-        args: -pc_hpddm_coarse_p 2 -pc_hpddm_levels_1_eps_nev 15 -pc_hpddm_block_splitting -pc_hpddm_levels_1_st_pc_type lu -pc_hpddm_levels_1_eps_gen_non_hermitian -mat_type {{aij baij}shared output}
+        args: -pc_hpddm_coarse_p 2 -pc_hpddm_levels_1_eps_nev 15 -pc_hpddm_block_splitting -pc_hpddm_levels_1_st_pc_type lu -pc_hpddm_levels_1_eps_gen_non_hermitian -mat_type {{aij baij}shared output} -successive_solves
       test:
         suffix: geneo_share
         output_file: output/ex76_geneo_pc_hpddm_levels_1_eps_nev-5.out
-        args: -pc_hpddm_levels_1_st_pc_type cholesky -pc_hpddm_levels_1_eps_nev 5 -pc_hpddm_levels_1_st_share_sub_ksp
+        args: -pc_hpddm_levels_1_st_pc_type cholesky -pc_hpddm_levels_1_eps_nev 5 -pc_hpddm_levels_1_st_share_sub_ksp -reset {{false true}shared output}
 
    testset:
       requires: hpddm slepc datafilespath double !complex !defined(PETSC_USE_64BIT_INDICES) defined(PETSC_HAVE_DYNAMIC_LIBRARIES) defined(PETSC_USE_SHARED_LIBRARIES)
@@ -226,7 +287,7 @@ int main(int argc, char **args)
         suffix: geneo_share_cholesky
         output_file: output/ex76_geneo_share.out
         # extra -pc_hpddm_levels_1_eps_gen_non_hermitian needed to avoid failures with PETSc Cholesky
-        args: -pc_hpddm_levels_1_sub_pc_type cholesky -pc_hpddm_levels_1_st_pc_type cholesky -mat_type {{aij baij sbaij}shared output} -pc_hpddm_levels_1_eps_gen_non_hermitian -pc_hpddm_has_neumann -pc_hpddm_levels_1_st_share_sub_ksp {{false true}shared output}
+        args: -pc_hpddm_levels_1_sub_pc_type cholesky -pc_hpddm_levels_1_st_pc_type cholesky -mat_type {{aij sbaij}shared output} -pc_hpddm_levels_1_eps_gen_non_hermitian -pc_hpddm_has_neumann -pc_hpddm_levels_1_st_share_sub_ksp {{false true}shared output} -successive_solves
       test:
         suffix: geneo_share_cholesky_matstructure
         output_file: output/ex76_geneo_share.out
@@ -243,12 +304,12 @@ int main(int argc, char **args)
         suffix: geneo_share_lu_matstructure
         output_file: output/ex76_geneo_share.out
         # extra -pc_factor_mat_solver_type mumps needed to avoid failures with PETSc LU
-        args: -pc_hpddm_levels_1_sub_pc_type lu -mat_type baij -pc_hpddm_levels_1_sub_pc_factor_mat_solver_type mumps -pc_hpddm_levels_1_st_share_sub_ksp -pc_hpddm_levels_1_st_matstructure {{same different}shared output} -pc_hpddm_levels_1_st_pc_type lu -pc_hpddm_levels_1_st_pc_factor_mat_solver_type mumps
+        args: -pc_hpddm_levels_1_sub_pc_type lu -mat_type aij -pc_hpddm_levels_1_sub_pc_factor_mat_solver_type mumps -pc_hpddm_levels_1_st_share_sub_ksp -pc_hpddm_levels_1_st_matstructure {{same different}shared output} -pc_hpddm_levels_1_st_pc_type lu -pc_hpddm_levels_1_st_pc_factor_mat_solver_type mumps -successive_solves -pc_hpddm_levels_1_eps_target 1e-5
       test:
         suffix: geneo_share_not_asm
         output_file: output/ex76_geneo_pc_hpddm_levels_1_eps_nev-5.out
         # extra -pc_hpddm_levels_1_eps_gen_non_hermitian needed to avoid failures with PETSc Cholesky
-        args: -pc_hpddm_levels_1_sub_pc_type cholesky -pc_hpddm_levels_1_st_pc_type cholesky -pc_hpddm_levels_1_eps_gen_non_hermitian -pc_hpddm_has_neumann -pc_hpddm_levels_1_st_share_sub_ksp true -pc_hpddm_levels_1_pc_type gasm
+        args: -pc_hpddm_levels_1_sub_pc_type cholesky -pc_hpddm_levels_1_st_pc_type cholesky -pc_hpddm_levels_1_eps_gen_non_hermitian -pc_hpddm_has_neumann -pc_hpddm_levels_1_st_share_sub_ksp true -pc_hpddm_levels_1_pc_type gasm -successive_solves
 
    test:
       requires: hpddm slepc datafilespath double !complex !defined(PETSC_USE_64BIT_INDICES) defined(PETSC_HAVE_DYNAMIC_LIBRARIES) defined(PETSC_USE_SHARED_LIBRARIES)
@@ -289,7 +350,21 @@ int main(int argc, char **args)
       test:
         suffix: geneo_mumps_use_omp_threads_2
         output_file: output/ex76_geneo_mumps_use_omp_threads.out
-        args: -pc_hpddm_coarse_mat_type aij -pc_hpddm_levels_1_eps_threshold 0.3 -pc_hpddm_coarse_pc_type cholesky
+        args: -pc_hpddm_coarse_mat_type aij -pc_hpddm_levels_1_eps_threshold 0.3 -pc_hpddm_coarse_pc_type cholesky -pc_hpddm_coarse_mat_chop 1e-12
+
+   testset: # converge really poorly because of a tiny -pc_hpddm_levels_1_eps_threshold, but needed for proper code coverage where some subdomains don't call EPSSolve()
+      requires: hpddm slepc datafilespath double !complex !defined(PETSC_USE_64BIT_INDICES) defined(PETSC_HAVE_DYNAMIC_LIBRARIES) defined(PETSC_USE_SHARED_LIBRARIES)
+      nsize: 4
+      args: -ksp_converged_reason -pc_type hpddm -pc_hpddm_levels_1_sub_pc_type cholesky -pc_hpddm_levels_1_eps_threshold 0.005 -pc_hpddm_levels_1_eps_use_inertia -load_dir ${DATAFILESPATH}/matrices/hpddm/GENEO -pc_hpddm_coarse_pc_type cholesky -pc_hpddm_levels_1_st_share_sub_ksp -pc_hpddm_define_subdomains -pc_hpddm_has_neumann -ksp_rtol 0.9
+      filter: sed -e "s/Linear solve converged due to CONVERGED_RTOL iterations 1/Linear solve converged due to CONVERGED_RTOL iterations 141/g"
+      test:
+        suffix: inertia_petsc
+        output_file: output/ex76_1.out
+        args: -pc_hpddm_levels_1_sub_pc_factor_mat_solver_type petsc
+      test:
+        suffix: inertia_mumps
+        output_file: output/ex76_1.out
+        requires: mumps
 
    test:
       requires: hpddm slepc datafilespath double !complex !defined(PETSC_USE_64BIT_INDICES) defined(PETSC_HAVE_DYNAMIC_LIBRARIES) defined(PETSC_USE_SHARED_LIBRARIES)
