@@ -28,7 +28,7 @@ PetscErrorCode MatMult_GlobalToLocalNormal(Mat CtC, Vec x, Vec y)
   PetscCall(DMLocalToGlobalBegin(dm, local, ADD_VALUES, y));
   PetscCall(DMLocalToGlobalEnd(dm, local, ADD_VALUES, y));
   PetscCall(DMRestoreLocalVector(dm, &local));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMGlobalToLocalSolve_project1(PetscInt dim, PetscReal time, const PetscReal x[], PetscInt Nf, PetscScalar u[], void *ctx)
@@ -37,7 +37,7 @@ static PetscErrorCode DMGlobalToLocalSolve_project1(PetscInt dim, PetscReal time
 
   PetscFunctionBegin;
   for (f = 0; f < Nf; f++) u[f] = 1.;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -46,14 +46,14 @@ static PetscErrorCode DMGlobalToLocalSolve_project1(PetscInt dim, PetscReal time
   a least-squares solution.  It is also assumed that `DMLocalToGlobalBegin()`/`DMLocalToGlobalEnd()` with mode = `ADD_VALUES` is the adjoint of the
   global-to-local map, so that the least-squares solution may be found by the normal equations.
 
-  collective
+  Collective
 
   Input Parameters:
 + dm - The `DM` object
 . x - The local vector
 - y - The global vector: the input value of globalVec is used as an initial guess
 
-  Output Parameters:
+  Output Parameter:
 . y - The least-squares solution
 
   Level: advanced
@@ -147,13 +147,13 @@ PetscErrorCode DMGlobalToLocalSolve(DM dm, Vec x, Vec y)
     PetscCall(DMRestoreNamedLocalVector(dm, "_DMGlobalToLocalSolve_mask", &mask));
   }
 
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMProjectField - This projects the given function of the input fields into the function space provided, putting the coefficients in a global vector.
 
-  Collective on dm
+  Collective
 
   Input Parameters:
 + dm      - The `DM`
@@ -165,26 +165,25 @@ PetscErrorCode DMGlobalToLocalSolve(DM dm, Vec x, Vec y)
   Output Parameter:
 . X       - The output vector
 
-   Calling sequence of func:
+   Calling sequence of `func`:
 .vb
-    func(PetscInt dim, PetscInt Nf, PetscInt NfAux,
-         const PetscInt uOff[], const PetscInt uOff_x[], const PetscScalar u[], const PetscScalar u_t[], const PetscScalar u_x[],
-         const PetscInt aOff[], const PetscInt aOff_x[], const PetscScalar a[], const PetscScalar a_t[], const PetscScalar a_x[],
-         PetscReal t, const PetscReal x[], PetscInt numConstants, const PetscScalar constants[], PetscScalar f[]);
+   void funcs(PetscInt dim, PetscInt Nf, PetscInt NfAux,
+              const PetscInt uOff[], const PetscInt uOff_x[], const PetscScalar u[], const PetscScalar u_t[], const PetscScalar u_x[],
+              const PetscInt aOff[], const PetscInt aOff_x[], const PetscScalar a[], const PetscScalar a_t[], const PetscScalar a_x[],
+              PetscReal t, const PetscReal x[], PetscInt numConstants, const PetscScalar constants[], PetscScalar f[]);
 .ve
-
 +  dim          - The spatial dimension
 .  Nf           - The number of input fields
 .  NfAux        - The number of input auxiliary fields
 .  uOff         - The offset of each field in u[]
 .  uOff_x       - The offset of each field in u_x[]
 .  u            - The field values at this point in space
-.  u_t          - The field time derivative at this point in space (or NULL)
+.  u_t          - The field time derivative at this point in space (or `NULL`)
 .  u_x          - The field derivatives at this point in space
 .  aOff         - The offset of each auxiliary field in u[]
 .  aOff_x       - The offset of each auxiliary field in u_x[]
 .  a            - The auxiliary field values at this point in space
-.  a_t          - The auxiliary field time derivative at this point in space (or NULL)
+.  a_t          - The auxiliary field time derivative at this point in space (or `NULL`)
 .  a_x          - The auxiliary field derivatives at this point in space
 .  t            - The current time
 .  x            - The coordinates of this point
@@ -231,7 +230,7 @@ PetscErrorCode DMProjectField(DM dm, PetscReal time, Vec U, void (**funcs)(Petsc
   }
   PetscCall(DMRestoreLocalVector(dm, &localX));
   if (U != X) PetscCall(DMRestoreLocalVector(dmIn, &localU));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /********************* Adaptive Interpolation **************************/
@@ -265,7 +264,7 @@ PetscErrorCode DMAdaptInterpolator(DM dmc, DM dmf, Mat In, KSP smoother, Mat MF,
     PetscCall(MatRestoreRow(In, r, &ncols, NULL, NULL));
   }
 #endif
-  if (Nc < maxcols) PetscPrintf(PETSC_COMM_SELF, "The number of input vectors %" PetscInt_FMT " < %" PetscInt_FMT " the maximum number of column entries\n", Nc, maxcols);
+  if (Nc < maxcols) PetscCall(PetscPrintf(PETSC_COMM_SELF, "The number of input vectors %" PetscInt_FMT " < %" PetscInt_FMT " the maximum number of column entries\n", Nc, maxcols));
   for (k = 0; k < Nc && debug; ++k) {
     char        name[PETSC_MAX_PATH_LEN];
     const char *prefix;
@@ -400,7 +399,7 @@ PetscErrorCode DMAdaptInterpolator(DM dmc, DM dmf, Mat In, KSP smoother, Mat MF,
   PetscCall(MatAssemblyBegin(*InAdapt, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(*InAdapt, MAT_FINAL_ASSEMBLY));
   PetscCall(PetscLogEventEnd(DM_AdaptInterpolator, dmc, dmf, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DMCheckInterpolator(DM dmf, Mat In, Mat MC, Mat MF, PetscReal tol)
@@ -433,5 +432,5 @@ PetscErrorCode DMCheckInterpolator(DM dmf, Mat In, Mat MC, Mat MF, PetscReal tol
   }
   PetscCall(DMRestoreGlobalVector(dmf, &tmp));
   PetscCheck(maxnorm2 <= tol, PetscObjectComm((PetscObject)dmf), PETSC_ERR_ARG_WRONG, "max_k ||vf_k - P vc_k||_2 %g > tol %g", (double)maxnorm2, (double)tol);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
