@@ -5,18 +5,18 @@
 static PetscBool KSPMatRegisterAllCalled = PETSC_FALSE;
 
 /*@C
-  KSPMatRegisterAll - Registers all matrix implementations in the KSP package.
+  KSPMatRegisterAll - Registers all matrix implementations in the `KSP` package.
 
   Not Collective
 
   Level: advanced
 
-.seealso: `MatRegisterAll()`, `KSPInitializePackage()`
+.seealso: [](chapter_ksp), `Mat`, `MatRegister()`, `MatRegisterAll()`, `KSPInitializePackage()`
 @*/
 PetscErrorCode KSPMatRegisterAll(void)
 {
   PetscFunctionBegin;
-  if (KSPMatRegisterAllCalled) PetscFunctionReturn(0);
+  if (KSPMatRegisterAllCalled) PetscFunctionReturn(PETSC_SUCCESS);
   KSPMatRegisterAllCalled = PETSC_TRUE;
   PetscCall(MatRegister(MATSCHURCOMPLEMENT, MatCreate_SchurComplement));
   PetscCall(MatRegister(MATLMVMDFP, MatCreate_LMVMDFP));
@@ -27,5 +27,5 @@ PetscErrorCode KSPMatRegisterAll(void)
   PetscCall(MatRegister(MATLMVMSYMBROYDEN, MatCreate_LMVMSymBrdn));
   PetscCall(MatRegister(MATLMVMSYMBADBROYDEN, MatCreate_LMVMSymBadBrdn));
   PetscCall(MatRegister(MATLMVMDIAGBROYDEN, MatCreate_LMVMDiagBrdn));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
