@@ -1,12 +1,12 @@
 #include <../src/ksp/ksp/utils/lmvm/lmvm.h> /*I "petscksp.h" I*/
 
 /*@
-   MatLMVMUpdate - Adds (X-Xprev) and (F-Fprev) updates to an LMVM matrix.
-   The first time the function is called for an LMVM matrix, no update is
+   MatLMVMUpdate - Adds (X-Xprev) and (F-Fprev) updates to an LMVM-type matrix.
+   The first time the function is called for an LMVM-type matrix, no update is
    applied, but the given X and F vectors are stored for use as Xprev and
    Fprev in the next update.
 
-   If the user has provided another LMVM matrix in place of J0, the J0
+   If the user has provided another LMVM-type matrix in place of J0, the J0
    matrix is also updated recursively.
 
    Input Parameters:
@@ -16,7 +16,7 @@
 
    Level: intermediate
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMReset()`, `MatLMVMAllocate()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMReset()`, `MatLMVMAllocate()`
 @*/
 PetscErrorCode MatLMVMUpdate(Mat B, Vec X, Vec F)
 {
@@ -28,7 +28,7 @@ PetscErrorCode MatLMVMUpdate(Mat B, Vec X, Vec F)
   PetscValidHeaderSpecific(X, VEC_CLASSID, 2);
   PetscValidHeaderSpecific(F, VEC_CLASSID, 3);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
   if (!lmvm->allocated) {
     PetscCall(MatLMVMAllocate(B, X, F));
   } else {
@@ -40,30 +40,29 @@ PetscErrorCode MatLMVMUpdate(Mat B, Vec X, Vec F)
     if (same) PetscCall(MatLMVMUpdate(lmvm->J0, X, F));
   }
   PetscCall((*lmvm->ops->update)(B, X, F));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatLMVMClearJ0 - Removes all definitions of J0 and reverts to
    an identity matrix (scale = 1.0).
 
-   Input Parameters:
+   Input Parameter:
 .  B - An LMVM-type matrix
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0()`
 @*/
 PetscErrorCode MatLMVMClearJ0(Mat B)
 {
   Mat_LMVM *lmvm = (Mat_LMVM *)B->data;
   PetscBool same;
-  MPI_Comm  comm = PetscObjectComm((PetscObject)B);
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, comm, PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
   lmvm->user_pc    = PETSC_FALSE;
   lmvm->user_ksp   = PETSC_FALSE;
   lmvm->user_scale = PETSC_FALSE;
@@ -71,7 +70,7 @@ PetscErrorCode MatLMVMClearJ0(Mat B)
   PetscCall(VecDestroy(&lmvm->J0diag));
   PetscCall(MatDestroy(&lmvm->J0));
   PetscCall(PCDestroy(&lmvm->J0pc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -84,23 +83,22 @@ PetscErrorCode MatLMVMClearJ0(Mat B)
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetDiagScale()`, `MatLMVMSetJ0()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetDiagScale()`, `MatLMVMSetJ0()`
 @*/
 PetscErrorCode MatLMVMSetJ0Scale(Mat B, PetscReal scale)
 {
   Mat_LMVM *lmvm = (Mat_LMVM *)B->data;
   PetscBool same;
-  MPI_Comm  comm = PetscObjectComm((PetscObject)B);
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, comm, PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
-  PetscCheck(lmvm->square, comm, PETSC_ERR_SUP, "Scaling is available only for square LMVM matrices");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
+  PetscCheck(lmvm->square, PetscObjectComm((PetscObject)B), PETSC_ERR_SUP, "Scaling is available only for square LMVM matrices");
   PetscCall(MatLMVMClearJ0(B));
   lmvm->J0scalar   = scale;
   lmvm->user_scale = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -113,7 +111,7 @@ PetscErrorCode MatLMVMSetJ0Scale(Mat B, PetscReal scale)
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetScale()`, `MatLMVMSetJ0()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetScale()`, `MatLMVMSetJ0()`
 @*/
 PetscErrorCode MatLMVMSetJ0Diag(Mat B, Vec V)
 {
@@ -125,7 +123,7 @@ PetscErrorCode MatLMVMSetJ0Diag(Mat B, Vec V)
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscValidHeaderSpecific(V, VEC_CLASSID, 2);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, comm, PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheck(lmvm->allocated, comm, PETSC_ERR_ORDER, "Matrix must be allocated before setting diagonal scaling");
   PetscCheck(lmvm->square, comm, PETSC_ERR_SUP, "Diagonal scaling is available only for square LMVM matrices");
   VecCheckSameSize(V, 2, lmvm->Fprev, 3);
@@ -134,22 +132,22 @@ PetscErrorCode MatLMVMSetJ0Diag(Mat B, Vec V)
   if (!lmvm->J0diag) PetscCall(VecDuplicate(V, &lmvm->J0diag));
   PetscCall(VecCopy(V, lmvm->J0diag));
   lmvm->user_scale = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatLMVMSetJ0 - Allows the user to define the initial
-   Jacobian matrix from which the LMVM approximation is
+   Jacobian matrix from which the LMVM-type approximation is
    built up. Inverse of this initial Jacobian is applied
-   using an internal KSP solver, which defaults to GMRES.
-   This internal KSP solver has the "mat_lmvm_" option
+   using an internal `KSP` solver, which defaults to `KSPGMRES`.
+   This internal `KSP` solver has the "mat_lmvm_" option
    prefix.
 
-   Note that another LMVM matrix can be used in place of
-   J0, in which case updating the outer LMVM matrix will
-   also trigger the update for the inner LMVM matrix. This
+   Note that another LMVM-type matrix can be used in place of
+   J0, in which case updating the outer LMVM-type matrix will
+   also trigger the update for the inner LMVM-type matrix. This
    is useful in cases where a full-memory diagonal approximation
-   such as MATLMVMDIAGBRDN is used in place of J0.
+   such as `MATLMVMDIAGBRDN` is used in place of J0.
 
    Input Parameters:
 +  B - An LMVM-type matrix
@@ -157,42 +155,41 @@ PetscErrorCode MatLMVMSetJ0Diag(Mat B, Vec V)
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0PC()`, `MatLMVMSetJ0KSP()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0PC()`, `MatLMVMSetJ0KSP()`
 @*/
 PetscErrorCode MatLMVMSetJ0(Mat B, Mat J0)
 {
   Mat_LMVM *lmvm = (Mat_LMVM *)B->data;
   PetscBool same;
-  MPI_Comm  comm = PetscObjectComm((PetscObject)B);
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscValidHeaderSpecific(J0, MAT_CLASSID, 2);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, comm, PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(MatLMVMClearJ0(B));
   PetscCall(MatDestroy(&lmvm->J0));
   PetscCall(PetscObjectReference((PetscObject)J0));
   lmvm->J0 = J0;
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)lmvm->J0, MATLMVM, &same));
   if (!same && lmvm->square) PetscCall(KSPSetOperators(lmvm->J0ksp, lmvm->J0, lmvm->J0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   MatLMVMSetJ0PC - Allows the user to define a PC object that
-   acts as the initial inverse-Jacobian matrix. This PC should
+   MatLMVMSetJ0PC - Allows the user to define a `PC` object that
+   acts as the initial inverse-Jacobian matrix. This `PC` should
    already contain all the operators necessary for its application.
-   The LMVM matrix only calls PCApply() without changing any other
+   The LMVM-type matrix only calls `PCApply()` without changing any other
    options.
 
    Input Parameters:
 +  B - An LMVM-type matrix
--  J0pc - PC object where PCApply defines an inverse application for J0
+-  J0pc - `PC` object where `PCApply()` defines an inverse application for J0
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMGetJ0PC()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMGetJ0PC()`
 @*/
 PetscErrorCode MatLMVMSetJ0PC(Mat B, PC J0pc)
 {
@@ -204,29 +201,29 @@ PetscErrorCode MatLMVMSetJ0PC(Mat B, PC J0pc)
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscValidHeaderSpecific(J0pc, PC_CLASSID, 2);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, comm, PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheck(lmvm->square, comm, PETSC_ERR_SUP, "Inverse J0 can be defined only for square LMVM matrices");
   PetscCall(MatLMVMClearJ0(B));
   PetscCall(PetscObjectReference((PetscObject)J0pc));
   lmvm->J0pc    = J0pc;
   lmvm->user_pc = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatLMVMSetJ0KSP - Allows the user to provide a pre-configured
    KSP solver for the initial inverse-Jacobian approximation.
-   This KSP solver should already contain all the operators
-   necessary to perform the inversion. The LMVM matrix only
-   calls KSPSolve() without changing any other options.
+   This `KSP` solver should already contain all the operators
+   necessary to perform the inversion. The LMVM-type matrix only
+   calls `KSPSolve()` without changing any other options.
 
    Input Parameters:
 +  B - An LMVM-type matrix
--  J0ksp - KSP solver for the initial inverse-Jacobian application
+-  J0ksp - `KSP` solver for the initial inverse-Jacobian application
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMGetJ0KSP()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMGetJ0KSP()`
 @*/
 PetscErrorCode MatLMVMSetJ0KSP(Mat B, KSP J0ksp)
 {
@@ -238,14 +235,14 @@ PetscErrorCode MatLMVMSetJ0KSP(Mat B, KSP J0ksp)
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscValidHeaderSpecific(J0ksp, KSP_CLASSID, 2);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, comm, PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheck(lmvm->square, comm, PETSC_ERR_SUP, "Inverse J0 can be defined only for square LMVM matrices");
   PetscCall(MatLMVMClearJ0(B));
   PetscCall(KSPDestroy(&lmvm->J0ksp));
   PetscCall(PetscObjectReference((PetscObject)J0ksp));
   lmvm->J0ksp    = J0ksp;
   lmvm->user_ksp = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -255,11 +252,11 @@ PetscErrorCode MatLMVMSetJ0KSP(Mat B, KSP J0ksp)
 .  B - An LMVM-type matrix
 
    Output Parameter:
-.  J0 - Mat object for defining the initial Jacobian
+.  J0 - `Mat` object for defining the initial Jacobian
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0()`
 @*/
 PetscErrorCode MatLMVMGetJ0(Mat B, Mat *J0)
 {
@@ -271,22 +268,22 @@ PetscErrorCode MatLMVMGetJ0(Mat B, Mat *J0)
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
   PetscCheck(same, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
   *J0 = lmvm->J0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   MatLMVMGetJ0PC - Returns a pointer to the internal PC object
+   MatLMVMGetJ0PC - Returns a pointer to the internal `PC` object
    associated with the initial Jacobian.
 
-   Input Parameters:
+   Input Parameter:
 .  B - An LMVM-type matrix
 
    Output Parameter:
-.  J0pc - PC object for defining the initial inverse-Jacobian
+.  J0pc - `PC` object for defining the initial inverse-Jacobian
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0PC()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0PC()`
 @*/
 PetscErrorCode MatLMVMGetJ0PC(Mat B, PC *J0pc)
 {
@@ -302,22 +299,22 @@ PetscErrorCode MatLMVMGetJ0PC(Mat B, PC *J0pc)
   } else {
     PetscCall(KSPGetPC(lmvm->J0ksp, J0pc));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   MatLMVMGetJ0KSP - Returns a pointer to the internal KSP solver
+   MatLMVMGetJ0KSP - Returns a pointer to the internal `KSP` solver
    associated with the initial Jacobian.
 
-   Input Parameters:
+   Input Parameter:
 .  B - An LMVM-type matrix
 
    Output Parameter:
-.  J0ksp - KSP solver for defining the initial inverse-Jacobian
+.  J0ksp - `KSP` solver for defining the initial inverse-Jacobian
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0KSP()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0KSP()`
 @*/
 PetscErrorCode MatLMVMGetJ0KSP(Mat B, KSP *J0ksp)
 {
@@ -329,7 +326,7 @@ PetscErrorCode MatLMVMGetJ0KSP(Mat B, KSP *J0ksp)
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
   PetscCheck(same, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
   *J0ksp = lmvm->J0ksp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -345,7 +342,7 @@ PetscErrorCode MatLMVMGetJ0KSP(Mat B, KSP *J0ksp)
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0()`, `MatLMVMSetJ0Scale()`, `MatLMVMSetJ0ScaleDiag()`,
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0()`, `MatLMVMSetJ0Scale()`, `MatLMVMSetJ0ScaleDiag()`,
           `MatLMVMSetJ0PC()`, `MatLMVMSetJ0KSP()`, `MatLMVMApplyJ0Inv()`
 @*/
 PetscErrorCode MatLMVMApplyJ0Fwd(Mat B, Vec X, Vec Y)
@@ -386,21 +383,20 @@ PetscErrorCode MatLMVMApplyJ0Fwd(Mat B, Vec X, Vec Y)
       PetscCall(VecPointwiseMult(X, lmvm->J0diag, Y));
     } else {
       /* User has defined a scalar value for J0 */
-      PetscCall(VecCopy(X, Y));
-      PetscCall(VecScale(Y, lmvm->J0scalar));
+      PetscCall(VecAXPBY(Y, lmvm->J0scalar, 0.0, X));
     }
   } else {
     /* There is no J0 representation so just apply an identity matrix */
     PetscCall(VecCopy(X, Y));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatLMVMApplyJ0Inv - Applies some estimation of the initial Jacobian
    inverse to the given vector. The specific form of the application
    depends on whether the user provided a scaling factor, a J0 matrix,
-   a J0 PC, or a J0 KSP object. If no form of the initial Jacobian is
+   a J0 `PC`, or a J0 `KSP` object. If no form of the initial Jacobian is
    provided, the function simply does an identity matrix application
    (vector copy).
 
@@ -413,7 +409,7 @@ PetscErrorCode MatLMVMApplyJ0Fwd(Mat B, Vec X, Vec Y)
 
    Level: advanced
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0()`, `MatLMVMSetJ0Scale()`, `MatLMVMSetJ0ScaleDiag()`,
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMSetJ0()`, `MatLMVMSetJ0Scale()`, `MatLMVMSetJ0ScaleDiag()`,
           `MatLMVMSetJ0PC()`, `MatLMVMSetJ0KSP()`, `MatLMVMApplyJ0Fwd()`
 @*/
 PetscErrorCode MatLMVMApplyJ0Inv(Mat B, Vec X, Vec Y)
@@ -449,29 +445,28 @@ PetscErrorCode MatLMVMApplyJ0Inv(Mat B, Vec X, Vec Y)
     if (lmvm->J0diag) {
       PetscCall(VecPointwiseDivide(X, Y, lmvm->J0diag));
     } else {
-      PetscCall(VecCopy(X, Y));
-      PetscCall(VecScale(Y, 1.0 / lmvm->J0scalar));
+      PetscCall(VecAXPBY(Y, 1.0 / lmvm->J0scalar, 0.0, X));
     }
   } else {
     /* There is no J0 representation so just apply an identity matrix */
     PetscCall(VecCopy(X, Y));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatLMVMIsAllocated - Returns a boolean flag that shows whether
    the necessary data structures for the underlying matrix is allocated.
 
-   Input Parameters:
+   Input Parameter:
 .  B - An LMVM-type matrix
 
    Output Parameter:
-.  flg - PETSC_TRUE if allocated, PETSC_FALSE otherwise
+.  flg - `PETSC_TRUE` if allocated, `PETSC_FALSE` otherwise
 
    Level: intermediate
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMAllocate()`, `MatLMVMReset()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMAllocate()`, `MatLMVMReset()`
 @*/
 
 PetscErrorCode MatLMVMIsAllocated(Mat B, PetscBool *flg)
@@ -485,14 +480,14 @@ PetscErrorCode MatLMVMIsAllocated(Mat B, PetscBool *flg)
   PetscCheck(same, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
   *flg = PETSC_FALSE;
   if (lmvm->allocated && B->preallocated && B->assembled) *flg = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatLMVMAllocate - Produces all necessary common memory for
    LMVM approximations based on the solution and function vectors
-   provided. If MatSetSizes() and MatSetUp() have not been called
-   before MatLMVMAllocate(), the allocation will read sizes from
+   provided. If `MatSetSizes()` and `MatSetUp()` have not been called
+   before `MatLMVMAllocate()`, the allocation will read sizes from
    the provided vectors and update the matrix.
 
    Input Parameters:
@@ -502,36 +497,39 @@ PetscErrorCode MatLMVMIsAllocated(Mat B, PetscBool *flg)
 
    Level: intermediate
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMReset()`, `MatLMVMUpdate()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMReset()`, `MatLMVMUpdate()`
 @*/
 PetscErrorCode MatLMVMAllocate(Mat B, Vec X, Vec F)
 {
   Mat_LMVM *lmvm = (Mat_LMVM *)B->data;
   PetscBool same;
+  VecType   vtype;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscValidHeaderSpecific(X, VEC_CLASSID, 2);
   PetscValidHeaderSpecific(F, VEC_CLASSID, 3);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
+  PetscCall(VecGetType(X, &vtype));
+  PetscCall(MatSetVecType(B, vtype));
   PetscCall((*lmvm->ops->allocate)(B, X, F));
   if (lmvm->J0) {
     PetscCall(PetscObjectBaseTypeCompare((PetscObject)lmvm->J0, MATLMVM, &same));
     if (same) PetscCall(MatLMVMAllocate(lmvm->J0, X, F));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatLMVMResetShift - Zero the shift factor.
 
-   Input Parameters:
+   Input Parameter:
 .  B - An LMVM-type matrix
 
    Level: intermediate
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMAllocate()`, `MatLMVMUpdate()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMAllocate()`, `MatLMVMUpdate()`
 @*/
 PetscErrorCode MatLMVMResetShift(Mat B)
 {
@@ -541,9 +539,9 @@ PetscErrorCode MatLMVMResetShift(Mat B)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
   lmvm->shift = 0.0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -551,7 +549,7 @@ PetscErrorCode MatLMVMResetShift(Mat B)
    the LMVM approximation. In practice, this will not actually
    destroy the data associated with the updates. It simply resets
    counters, which leads to existing data being overwritten, and
-   MatSolve() being applied as if there are no updates. A boolean
+   `MatSolve()` being applied as if there are no updates. A boolean
    flag is available to force destruction of the update vectors.
 
    If the user has provided another LMVM matrix as J0, the J0
@@ -563,7 +561,7 @@ PetscErrorCode MatLMVMResetShift(Mat B)
 
    Level: intermediate
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMAllocate()`, `MatLMVMUpdate()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMAllocate()`, `MatLMVMUpdate()`
 @*/
 PetscErrorCode MatLMVMReset(Mat B, PetscBool destructive)
 {
@@ -573,13 +571,13 @@ PetscErrorCode MatLMVMReset(Mat B, PetscBool destructive)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall((*lmvm->ops->reset)(B, destructive));
   if (lmvm->J0) {
     PetscCall(PetscObjectBaseTypeCompare((PetscObject)lmvm->J0, MATLMVM, &same));
     if (same) PetscCall(MatLMVMReset(lmvm->J0, destructive));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -590,12 +588,12 @@ PetscErrorCode MatLMVMReset(Mat B, PetscBool destructive)
 +  B - An LMVM-type matrix
 -  hist_size - number of past iterates (default 5)
 
-   Options Database:
+   Options Database Key:
 .  -mat_lmvm_hist_size <m> - set number of past iterates
 
    Level: beginner
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMGetUpdateCount()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMGetUpdateCount()`
 @*/
 PetscErrorCode MatLMVMSetHistorySize(Mat B, PetscInt hist_size)
 {
@@ -606,7 +604,7 @@ PetscErrorCode MatLMVMSetHistorySize(Mat B, PetscInt hist_size)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
-  PetscCheck(same, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
+  if (!same) PetscFunctionReturn(PETSC_SUCCESS);
   if (hist_size > 0) {
     lmvm->m = hist_size;
     if (lmvm->allocated && lmvm->m != lmvm->m_old) {
@@ -618,16 +616,16 @@ PetscErrorCode MatLMVMSetHistorySize(Mat B, PetscInt hist_size)
       PetscCall(VecDestroy(&F));
     }
   } else PetscCheck(hist_size >= 0, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "QN history size must be a non-negative integer.");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatLMVMGetUpdateCount - Returns the number of accepted updates.
    This number may be greater than the total number of update vectors
-   stored in the matrix. The counters are reset when MatLMVMReset()
+   stored in the matrix. The counters are reset when `MatLMVMReset()`
    is called.
 
-   Input Parameters:
+   Input Parameter:
 .  B - An LMVM-type matrix
 
    Output Parameter:
@@ -635,7 +633,7 @@ PetscErrorCode MatLMVMSetHistorySize(Mat B, PetscInt hist_size)
 
    Level: intermediate
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMGetRejectCount()`, `MatLMVMReset()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMGetRejectCount()`, `MatLMVMReset()`
 @*/
 PetscErrorCode MatLMVMGetUpdateCount(Mat B, PetscInt *nupdates)
 {
@@ -647,14 +645,14 @@ PetscErrorCode MatLMVMGetUpdateCount(Mat B, PetscInt *nupdates)
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
   PetscCheck(same, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
   *nupdates = lmvm->nupdates;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatLMVMGetRejectCount - Returns the number of rejected updates.
-   The counters are reset when MatLMVMReset() is called.
+   The counters are reset when `MatLMVMReset()` is called.
 
-   Input Parameters:
+   Input Parameter:
 .  B - An LMVM-type matrix
 
    Output Parameter:
@@ -662,7 +660,7 @@ PetscErrorCode MatLMVMGetUpdateCount(Mat B, PetscInt *nupdates)
 
    Level: intermediate
 
-.seealso: [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMGetRejectCount()`, `MatLMVMReset()`
+.seealso: [](chapter_ksp), [LMVM Matrices](sec_matlmvm), `MATLMVM`, `MatLMVMGetRejectCount()`, `MatLMVMReset()`
 @*/
 PetscErrorCode MatLMVMGetRejectCount(Mat B, PetscInt *nrejects)
 {
@@ -674,5 +672,5 @@ PetscErrorCode MatLMVMGetRejectCount(Mat B, PetscInt *nrejects)
   PetscCall(PetscObjectBaseTypeCompare((PetscObject)B, MATLMVM, &same));
   PetscCheck(same, PetscObjectComm((PetscObject)B), PETSC_ERR_ARG_WRONG, "Matrix must be an LMVM-type.");
   *nrejects = lmvm->nrejects;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
