@@ -9,11 +9,11 @@ PetscErrorCode MatCreateVecs_SchurComplement(Mat N, Vec *right, Vec *left)
   PetscFunctionBegin;
   if (Na->D) {
     PetscCall(MatCreateVecs(Na->D, right, left));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if (right) PetscCall(MatCreateVecs(Na->B, right, NULL));
   if (left) PetscCall(MatCreateVecs(Na->C, NULL, left));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatView_SchurComplement(Mat N, PetscViewer viewer)
@@ -42,7 +42,7 @@ PetscErrorCode MatView_SchurComplement(Mat N, PetscViewer viewer)
   PetscCall(PetscViewerASCIIPushTab(viewer));
   PetscCall(MatView(Na->B, viewer));
   PetscCall(PetscViewerASCIIPopTab(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -60,7 +60,7 @@ PetscErrorCode MatMultTranspose_SchurComplement(Mat N, Vec x, Vec y)
   PetscCall(MatMultTranspose(Na->B, Na->work2, y));
   PetscCall(VecScale(y, -1.0));
   if (Na->D) PetscCall(MatMultTransposeAdd(Na->D, x, y, y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -78,7 +78,7 @@ PetscErrorCode MatMult_SchurComplement(Mat N, Vec x, Vec y)
   PetscCall(MatMult(Na->C, Na->work2, y));
   PetscCall(VecScale(y, -1.0));
   if (Na->D) PetscCall(MatMultAdd(Na->D, x, y, y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -101,7 +101,7 @@ PetscErrorCode MatMultAdd_SchurComplement(Mat N, Vec x, Vec y, Vec z)
     PetscCall(VecAYPX(z, -1.0, y));
   }
   if (Na->D) PetscCall(MatMultAdd(Na->D, x, z, z));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSetFromOptions_SchurComplement(Mat N, PetscOptionItems *PetscOptionsObject)
@@ -115,7 +115,7 @@ PetscErrorCode MatSetFromOptions_SchurComplement(Mat N, PetscOptionItems *PetscO
                              (PetscEnum *)&Na->ainvtype, NULL));
   PetscOptionsHeadEnd();
   PetscCall(KSPSetFromOptions(Na->ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDestroy_SchurComplement(Mat N)
@@ -134,17 +134,20 @@ PetscErrorCode MatDestroy_SchurComplement(Mat N)
   PetscCall(PetscFree(N->data));
   PetscCall(PetscObjectComposeFunction((PetscObject)N, "MatProductSetFromOptions_schurcomplement_seqdense_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)N, "MatProductSetFromOptions_schurcomplement_mpidense_C", NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
       MatCreateSchurComplement - Creates a new `Mat` that behaves like the Schur complement of a matrix
 
-   Collective on A00
+   Collective
 
    Input Parameters:
-+   A00,A01,A10,A11  - the four parts of the original matrix A = [A00 A01; A10 A11] (A11 is optional)
--   Ap00             - preconditioning matrix for use in ksp(A00,Ap00) to approximate the action of A^{-1}
++   A00  - the upper-left block of the original matrix A = [A00 A01; A10 A11]
+.   Ap00 - preconditioning matrix for use in ksp(A00,Ap00) to approximate the action of A00^{-1}
+.   A01  - the upper-right block of the original matrix A = [A00 A01; A10 A11]
+.   A10  - the lower-left block of the original matrix A = [A00 A01; A10 A11]
+-   A11  - (optional) the lower-right block of the original matrix A = [A00 A01; A10 A11]
 
    Output Parameter:
 .   S - the matrix that behaves as the Schur complement S = A11 - A10 ksp(A00,Ap00) A01
@@ -158,7 +161,7 @@ PetscErrorCode MatDestroy_SchurComplement(Mat N)
 
     All four matrices must have the same MPI communicator.
 
-    A00 and  A11 must be square matrices.
+    `A00` and  `A11` must be square matrices.
 
     `MatGetSchurComplement()` takes as arguments the index sets for the submatrices and returns both the virtual Schur complement (what this returns) plus
     a sparse approximation to the Schur complement (useful for building a preconditioner for the Schur complement) which can be obtained from this
@@ -178,18 +181,21 @@ PetscErrorCode MatCreateSchurComplement(Mat A00, Mat Ap00, Mat A01, Mat A10, Mat
   PetscCall(MatCreate(PetscObjectComm((PetscObject)A00), S));
   PetscCall(MatSetType(*S, MATSCHURCOMPLEMENT));
   PetscCall(MatSchurComplementSetSubMatrices(*S, A00, Ap00, A01, A10, A11));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
       MatSchurComplementSetSubMatrices - Sets the matrices that define the Schur complement
 
-   Collective on S
+   Collective
 
    Input Parameters:
 +   S                - matrix obtained with `MatSetType`(S,`MATSCHURCOMPLEMENT`)
-.   A00,A01,A10,A11  - the four parts of A = [A00 A01; A10 A11] (A11 is optional)
--   Ap00             - preconditioning matrix for use in ksp(A00,Ap00) to approximate the action of A^{-1}.
++   A00  - the upper-left block of the original matrix A = [A00 A01; A10 A11]
+.   Ap00 - preconditioning matrix for use in ksp(A00,Ap00) to approximate the action of A00^{-1}
+.   A01  - the upper-right block of the original matrix A = [A00 A01; A10 A11]
+.   A10  - the lower-left block of the original matrix A = [A00 A01; A10 A11]
+-   A11  - (optional) the lower-right block of the original matrix A = [A00 A01; A10 A11]
 
    Level: intermediate
 
@@ -199,7 +205,7 @@ PetscErrorCode MatCreateSchurComplement(Mat A00, Mat Ap00, Mat A01, Mat A10, Mat
 
      All four matrices must have the same MPI communicator.
 
-     A00 and A11 must be square matrices.
+     `A00` and `A11` must be square matrices.
 
      This is to be used in the context of code such as
 .vb
@@ -217,7 +223,7 @@ PetscErrorCode MatSchurComplementSetSubMatrices(Mat S, Mat A00, Mat Ap00, Mat A0
 
   PetscFunctionBegin;
   PetscCall(PetscObjectTypeCompare((PetscObject)S, MATSCHURCOMPLEMENT, &isschur));
-  if (!isschur) PetscFunctionReturn(0);
+  if (!isschur) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheck(!S->assembled, PetscObjectComm((PetscObject)S), PETSC_ERR_ARG_WRONGSTATE, "Use MatSchurComplementUpdateSubMatrices() for already used matrix");
   PetscValidHeaderSpecific(A00, MAT_CLASSID, 2);
   PetscValidHeaderSpecific(Ap00, MAT_CLASSID, 3);
@@ -251,7 +257,7 @@ PetscErrorCode MatSchurComplementSetSubMatrices(Mat S, Mat A00, Mat Ap00, Mat A0
   PetscCall(MatSetUp(S));
   PetscCall(KSPSetOperators(Na->ksp, A00, Ap00));
   S->assembled = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -266,7 +272,7 @@ PetscErrorCode MatSchurComplementSetSubMatrices(Mat S, Mat A00, Mat Ap00, Mat A0
 . ksp - the linear solver object
 
   Options Database Key:
-. -fieldsplit_<splitname_0>_XXX sets KSP and PC options for the 0-split solver inside the Schur complement used in PCFieldSplit; default <splitname_0> is 0.
+. -fieldsplit_<splitname_0>_XXX sets KSP and PC options for the 0-split solver inside the Schur complement used in `PCFIELDSPLIT`; default <splitname_0> is 0.
 
   Level: intermediate
 
@@ -284,7 +290,7 @@ PetscErrorCode MatSchurComplementGetKSP(Mat S, KSP *ksp)
   PetscValidPointer(ksp, 2);
   Na   = (Mat_SchurComplement *)S->data;
   *ksp = Na->ksp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -312,32 +318,35 @@ PetscErrorCode MatSchurComplementSetKSP(Mat S, KSP ksp)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(S, MAT_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)S, MATSCHURCOMPLEMENT, &isschur));
-  if (!isschur) PetscFunctionReturn(0);
+  if (!isschur) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(ksp, KSP_CLASSID, 2);
   Na = (Mat_SchurComplement *)S->data;
   PetscCall(PetscObjectReference((PetscObject)ksp));
   PetscCall(KSPDestroy(&Na->ksp));
   Na->ksp = ksp;
   PetscCall(KSPSetOperators(Na->ksp, Na->A, Na->Ap));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
       MatSchurComplementUpdateSubMatrices - Updates the Schur complement matrix object with new submatrices
 
-   Collective on S
+   Collective
 
    Input Parameters:
 +   S                - matrix obtained with `MatCreateSchurComplement()` (or `MatSchurSetSubMatrices()`) and implementing the action of A11 - A10 ksp(A00,Ap00) A01
-.   A00,A01,A10,A11  - the four parts of A = [A00 A01; A10 A11] (A11 is optional)
--   Ap00             - preconditioning matrix for use in ksp(A00,Ap00) to approximate the action of A^{-1}.
+.   A00  - the upper-left block of the original matrix A = [A00 A01; A10 A11]
+.   Ap00 - preconditioning matrix for use in ksp(A00,Ap00) to approximate the action of A00^{-1}
+.   A01  - the upper-right block of the original matrix A = [A00 A01; A10 A11]
+.   A10  - the lower-left block of the original matrix A = [A00 A01; A10 A11]
+-   A11  - (optional) the lower-right block of the original matrix A = [A00 A01; A10 A11]
 
    Level: intermediate
 
    Notes:
      All four matrices must have the same MPI communicator
 
-     A00 and  A11 must be square matrices
+     `A00` and  `A11` must be square matrices
 
      All of the matrices provided must have the same sizes as was used with `MatCreateSchurComplement()` or `MatSchurComplementSetSubMatrices()`
      though they need not be the same matrices.
@@ -357,7 +366,7 @@ PetscErrorCode MatSchurComplementUpdateSubMatrices(Mat S, Mat A00, Mat Ap00, Mat
   PetscFunctionBegin;
   PetscValidHeaderSpecific(S, MAT_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)S, MATSCHURCOMPLEMENT, &isschur));
-  if (!isschur) PetscFunctionReturn(0);
+  if (!isschur) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheck(S->assembled, PetscObjectComm((PetscObject)S), PETSC_ERR_ARG_WRONGSTATE, "Use MatSchurComplementSetSubMatrices() for a new matrix");
   PetscValidHeaderSpecific(A00, MAT_CLASSID, 2);
   PetscValidHeaderSpecific(Ap00, MAT_CLASSID, 3);
@@ -396,13 +405,13 @@ PetscErrorCode MatSchurComplementUpdateSubMatrices(Mat S, Mat A00, Mat Ap00, Mat
   Na->D  = A11;
 
   PetscCall(KSPSetOperators(Na->ksp, A00, Ap00));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   MatSchurComplementGetSubMatrices - Get the individual submatrices in the Schur complement
 
-  Collective on S
+  Collective
 
   Input Parameter:
 . S    - matrix obtained with `MatCreateSchurComplement()` (or equivalent) and implementing the action of A11 - A10 ksp(A00,Ap00) A01
@@ -417,7 +426,9 @@ PetscErrorCode MatSchurComplementUpdateSubMatrices(Mat S, Mat A00, Mat Ap00, Mat
   Level: intermediate
 
   Note:
-  A11 is optional, and thus can be NULL.  The reference counts of the submatrices are not increased before they are returned and the matrices should not be modified or destroyed.
+  `A11` is optional, and thus can be `NULL`.
+
+  The reference counts of the submatrices are not increased before they are returned and the matrices should not be modified or destroyed.
 
 .seealso: [](chapter_ksp), `MatCreateNormal()`, `MatMult()`, `MatCreate()`, `MatSchurComplementGetKSP()`, `MatCreateSchurComplement()`, `MatSchurComplementUpdateSubMatrices()`
 @*/
@@ -435,7 +446,7 @@ PetscErrorCode MatSchurComplementGetSubMatrices(Mat S, Mat *A00, Mat *Ap00, Mat
   if (A01) *A01 = Na->B;
   if (A10) *A10 = Na->C;
   if (A11) *A11 = Na->D;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #include <petsc/private/kspimpl.h>
@@ -443,7 +454,7 @@ PetscErrorCode MatSchurComplementGetSubMatrices(Mat S, Mat *A00, Mat *Ap00, Mat
 /*@
   MatSchurComplementComputeExplicitOperator - Compute the Schur complement matrix explicitly
 
-  Collective on A
+  Collective
 
   Input Parameter:
 . M - the matrix obtained with `MatCreateSchurComplement()`
@@ -494,7 +505,7 @@ PetscErrorCode MatSchurComplementComputeExplicitOperator(Mat A, Mat *S)
   PetscCall(MatConvert(*S, !E && flg ? MATSBAIJ : MATAIJ, MAT_INPLACE_MATRIX, S)); /* if A is symmetric and the (1,1) block is a MatSBAIJ, return S as a MatSBAIJ */
   PetscCall(MatScale(*S, -1.0));
   PetscCall(MatDestroy(&E));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Developer Notes:
@@ -514,7 +525,7 @@ PetscErrorCode MatGetSchurComplement_Basic(Mat mat, IS isrow0, IS iscol0, IS isr
   PetscValidLogicalCollectiveEnum(mat, mreuse, 6);
   PetscValidLogicalCollectiveEnum(mat, ainvtype, 8);
   PetscValidLogicalCollectiveEnum(mat, preuse, 9);
-  if (mreuse == MAT_IGNORE_MATRIX && preuse == MAT_IGNORE_MATRIX) PetscFunctionReturn(0);
+  if (mreuse == MAT_IGNORE_MATRIX && preuse == MAT_IGNORE_MATRIX) PetscFunctionReturn(PETSC_SUCCESS);
   if (mreuse == MAT_REUSE_MATRIX) PetscValidHeaderSpecific(*S, MAT_CLASSID, 7);
   if (preuse == MAT_REUSE_MATRIX) PetscValidHeaderSpecific(*Sp, MAT_CLASSID, 10);
 
@@ -547,13 +558,13 @@ PetscErrorCode MatGetSchurComplement_Basic(Mat mat, IS isrow0, IS iscol0, IS isr
   PetscCall(MatDestroy(&B));
   PetscCall(MatDestroy(&C));
   PetscCall(MatDestroy(&D));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatGetSchurComplement - Obtain the Schur complement from eliminating part of the matrix in another part.
 
-    Collective on A
+    Collective
 
     Input Parameters:
 +   A      - matrix in which the complement is to be taken
@@ -616,13 +627,13 @@ PetscErrorCode MatGetSchurComplement(Mat A, IS isrow0, IS iscol0, IS isrow1, IS
   }
   if (f) PetscCall((*f)(A, isrow0, iscol0, isrow1, iscol1, mreuse, S, preuse, Sp));
   else PetscCall(MatGetSchurComplement_Basic(A, isrow0, iscol0, isrow1, iscol1, mreuse, S, ainvtype, preuse, Sp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatSchurComplementSetAinvType - set the type of approximation used for the inverse of the (0,0) block used in forming Sp in `MatSchurComplementGetPmat()`
 
-    Not collective.
+    Not Collective
 
     Input Parameters:
 +   S        - matrix obtained with `MatCreateSchurComplement()` (or equivalent) and implementing the action of A11 - A10 ksp(A00,Ap00) A01
@@ -644,18 +655,18 @@ PetscErrorCode MatSchurComplementSetAinvType(Mat S, MatSchurComplementAinvType a
   PetscFunctionBegin;
   PetscValidHeaderSpecific(S, MAT_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)S, MATSCHURCOMPLEMENT, &isschur));
-  if (!isschur) PetscFunctionReturn(0);
+  if (!isschur) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidLogicalCollectiveEnum(S, ainvtype, 2);
   schur = (Mat_SchurComplement *)S->data;
   PetscCheck(ainvtype == MAT_SCHUR_COMPLEMENT_AINV_DIAG || ainvtype == MAT_SCHUR_COMPLEMENT_AINV_LUMP || ainvtype == MAT_SCHUR_COMPLEMENT_AINV_BLOCK_DIAG || ainvtype == MAT_SCHUR_COMPLEMENT_AINV_FULL, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONG, "Unknown MatSchurComplementAinvType: %d", (int)ainvtype);
   schur->ainvtype = ainvtype;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatSchurComplementGetAinvType - get the type of approximation for the inverse of the (0,0) block used in forming Sp in `MatSchurComplementGetPmat()`
 
-    Not collective.
+    Not Collective
 
     Input Parameter:
 .   S      - matrix obtained with `MatCreateSchurComplement()` (or equivalent) and implementing the action of A11 - A10 ksp(A00,Ap00) A01
@@ -679,14 +690,14 @@ PetscErrorCode MatSchurComplementGetAinvType(Mat S, MatSchurComplementAinvType *
   PetscCheck(isschur, PetscObjectComm((PetscObject)S), PETSC_ERR_ARG_WRONG, "Not for type %s", ((PetscObject)S)->type_name);
   schur = (Mat_SchurComplement *)S->data;
   if (ainvtype) *ainvtype = schur->ainvtype;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatCreateSchurComplementPmat - create a preconditioning matrix for the Schur complement by explicitly assembling the sparse matrix
         Sp = A11 - A10 inv(DIAGFORM(A00)) A01
 
-    Collective on A00
+    Collective
 
     Input Parameters:
 +   A00      - the upper-left part of the original matrix A = [A00 A01; A10 A11]
@@ -711,7 +722,7 @@ PetscErrorCode MatCreateSchurComplementPmat(Mat A00, Mat A01, Mat A10, Mat A11,
   /* Use an appropriate approximate inverse of A00 to form A11 - A10 inv(DIAGFORM(A00)) A01; a NULL A01, A10 or A11 indicates a zero matrix. */
   /* TODO: Perhaps should create an appropriately-sized zero matrix of the same type as A00? */
   PetscValidLogicalCollectiveEnum(A11, preuse, 6);
-  if (preuse == MAT_IGNORE_MATRIX) PetscFunctionReturn(0);
+  if (preuse == MAT_IGNORE_MATRIX) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* A zero size A00 or empty A01 or A10 imply S = A11. */
   PetscCall(MatGetSize(A00, &N00, NULL));
@@ -762,7 +773,7 @@ PetscErrorCode MatCreateSchurComplementPmat(Mat A00, Mat A01, Mat A10, Mat A11,
     }
     PetscCall(MatDestroy(&AdB));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSchurComplementGetPmat_Basic(Mat S, MatReuse preuse, Mat *Sp)
@@ -771,7 +782,7 @@ PetscErrorCode MatSchurComplementGetPmat_Basic(Mat S, MatReuse preuse, Mat *Sp)
   Mat_SchurComplement *schur = (Mat_SchurComplement *)S->data;
 
   PetscFunctionBegin;
-  if (preuse == MAT_IGNORE_MATRIX) PetscFunctionReturn(0);
+  if (preuse == MAT_IGNORE_MATRIX) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(MatSchurComplementGetSubMatrices(S, &A, NULL, &B, &C, &D));
   PetscCheck(A, PetscObjectComm((PetscObject)S), PETSC_ERR_ARG_WRONGSTATE, "Schur complement component matrices unset");
   if (schur->ainvtype != MAT_SCHUR_COMPLEMENT_AINV_FULL) PetscCall(MatCreateSchurComplementPmat(A, B, C, D, schur->ainvtype, preuse, Sp));
@@ -779,13 +790,13 @@ PetscErrorCode MatSchurComplementGetPmat_Basic(Mat S, MatReuse preuse, Mat *Sp)
     if (preuse == MAT_REUSE_MATRIX) PetscCall(MatDestroy(Sp));
     PetscCall(MatSchurComplementComputeExplicitOperator(S, Sp));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatSchurComplementGetPmat - Obtain a preconditioning matrix for the Schur complement by assembling Sp = A11 - A10 inv(DIAGFORM(A00)) A01
 
-    Collective on S
+    Collective
 
     Input Parameters:
 +   S      - matrix obtained with MatCreateSchurComplement() (or equivalent) that implements the action of A11 - A10 ksp(A00,Ap00) A01
@@ -832,7 +843,7 @@ PetscErrorCode MatSchurComplementGetPmat(Mat S, MatReuse preuse, Mat *Sp)
   PetscCall(PetscObjectQueryFunction((PetscObject)S, "MatSchurComplementGetPmat_C", &f));
   if (f) PetscCall((*f)(S, preuse, Sp));
   else PetscCall(MatSchurComplementGetPmat_Basic(S, preuse, Sp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatProductNumeric_SchurComplement_Dense(Mat C)
@@ -861,7 +872,7 @@ static PetscErrorCode MatProductNumeric_SchurComplement_Dense(Mat C)
     PetscCall(MatAYPX(C, -1.0, work1, SAME_NONZERO_PATTERN));
     PetscCall(MatDestroy(&work1));
   } else PetscCall(MatScale(C, -1.0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatProductSymbolic_SchurComplement_Dense(Mat C)
@@ -880,14 +891,14 @@ static PetscErrorCode MatProductSymbolic_SchurComplement_Dense(Mat C)
   }
   PetscCall(MatSetUp(C));
   C->ops->productnumeric = MatProductNumeric_SchurComplement_Dense;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatProductSetFromOptions_Dense_AB(Mat C)
 {
   PetscFunctionBegin;
   C->ops->productsymbolic = MatProductSymbolic_SchurComplement_Dense;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatProductSetFromOptions_SchurComplement_Dense(Mat C)
@@ -897,9 +908,17 @@ static PetscErrorCode MatProductSetFromOptions_SchurComplement_Dense(Mat C)
   PetscFunctionBegin;
   PetscCheck(product->type == MATPRODUCT_AB, PetscObjectComm((PetscObject)C), PETSC_ERR_PLIB, "Not for product type %s", MatProductTypes[product->type]);
   PetscCall(MatProductSetFromOptions_Dense_AB(C));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+  MATSCHURCOMPLEMENT -  "schurcomplement" - Matrix type that behaves like the Schur complement of a matrix.
+
+  Level: intermediate
+
+.seealso: [](chapter_matrices), `Mat`, `MatCreate()`, `MatType`, `MatCreateSchurComplement()`, `MatSchurComplementComputeExplicitOperator()`,
+          `MatSchurComplementGetSubMatrices()`, `MatSchurComplementGetKSP()`
+M*/
 PETSC_EXTERN PetscErrorCode MatCreate_SchurComplement(Mat N)
 {
   Mat_SchurComplement *Na;
@@ -922,5 +941,5 @@ PETSC_EXTERN PetscErrorCode MatCreate_SchurComplement(Mat N)
   PetscCall(PetscObjectChangeTypeName((PetscObject)N, MATSCHURCOMPLEMENT));
   PetscCall(PetscObjectComposeFunction((PetscObject)N, "MatProductSetFromOptions_schurcomplement_seqdense_C", MatProductSetFromOptions_SchurComplement_Dense));
   PetscCall(PetscObjectComposeFunction((PetscObject)N, "MatProductSetFromOptions_schurcomplement_mpidense_C", MatProductSetFromOptions_SchurComplement_Dense));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
