@@ -39,7 +39,7 @@ PetscErrorCode PCReset_GAMG(PC pc)
   }
   pc_gamg->emin = 0;
   pc_gamg->emax = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -101,7 +101,7 @@ static PetscErrorCode PCGAMGCreateLevel_GAMG(PC pc, Mat Amat_fine, PetscInt cr_b
     PetscCall(PetscShmCommGetMpiShmComm(pshmcomm, &loccomm));
     PetscCallMPI(MPI_Comm_rank(loccomm, &locrank));
     s_nnodes = !locrank;
-    PetscCallMPI(MPI_Allreduce(&s_nnodes, &r_nnodes, 1, MPIU_INT, MPI_SUM, comm));
+    PetscCall(MPIU_Allreduce(&s_nnodes, &r_nnodes, 1, MPIU_INT, MPI_SUM, comm));
     PetscCheck((size % r_nnodes) == 0, PETSC_COMM_SELF, PETSC_ERR_PLIB, "odd number of nodes np=%d nnodes%" PetscInt_FMT, size, r_nnodes);
     devCount = 0;
     cerr     = cudaGetDeviceCount(&devCount);
@@ -131,7 +131,7 @@ static PetscErrorCode PCGAMGCreateLevel_GAMG(PC pc, Mat Amat_fine, PetscInt cr_b
 #endif
     PetscCall(MatGetSize(Cmat, &ncrs_eq_glob, NULL));
     new_size = (PetscMPIInt)((float)ncrs_eq_glob / (float)pc_gamg->min_eq_proc + 0.5); /* hardwire min. number of eq/proc */
-    if (!new_size) new_size = 1;                                                       /* not likely, posible? */
+    if (!new_size) new_size = 1;                                                       /* not likely, possible? */
     else if (new_size >= nactive) new_size = nactive;                                  /* no change, rare */
     PetscCall(PetscInfo(pc, "%s: Coarse grid reduction from %d to %d active processes\n", ((PetscObject)pc)->prefix, nactive, new_size));
   }
@@ -179,7 +179,7 @@ static PetscErrorCode PCGAMGCreateLevel_GAMG(PC pc, Mat Amat_fine, PetscInt cr_b
         *a_Amat_crs = Cmat;
         PetscCall(PetscInfo(pc, "%s: Finding factorable processor set stopped reduction: new_size=%d, neq(loc)=%" PetscInt_FMT "\n", ((PetscObject)pc)->prefix, new_size, ncrs_eq));
         PetscCall(PetscLogEventEnd(petsc_gamg_setup_events[GAMG_REDUCE], 0, 0, 0, 0));
-        PetscFunctionReturn(0);
+        PetscFunctionReturn(PETSC_SUCCESS);
       }
     }
     /* make 'is_eq_newproc' */
@@ -238,7 +238,7 @@ static PetscErrorCode PCGAMGCreateLevel_GAMG(PC pc, Mat Amat_fine, PetscInt cr_b
           PetscViewer viewer;
           char        fname[32];
           PetscCall(PetscSNPrintf(fname, sizeof(fname), "part_mat_%" PetscInt_FMT ".mat", llev));
-          PetscViewerBinaryOpen(comm, fname, FILE_MODE_WRITE, &viewer);
+          PetscCall(PetscViewerBinaryOpen(comm, fname, FILE_MODE_WRITE, &viewer));
           PetscCall(MatView(tMat, viewer));
           PetscCall(PetscViewerDestroy(&viewer));
         }
@@ -459,7 +459,7 @@ static PetscErrorCode PCGAMGCreateLevel_GAMG(PC pc, Mat Amat_fine, PetscInt cr_b
     }
     PetscCall(PetscLogEventEnd(petsc_gamg_setup_events[GAMG_REDUCE], 0, 0, 0, 0));
   } // processor reduce
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 // used in GEO
@@ -490,7 +490,7 @@ PetscErrorCode PCGAMGSquareGraph_GAMG(PC a_pc, Mat Gmat1, Mat *Gmat2)
   PetscCall(MatProductClear(*Gmat2));
   /* we only need the sparsity, cheat and tell PETSc the matrix has been assembled */
   (*Gmat2)->assembled = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -503,17 +503,19 @@ PetscErrorCode PCGAMGSquareGraph_GAMG(PC a_pc, Mat Gmat1, Mat *Gmat2)
 */
 PetscErrorCode PCSetUp_GAMG(PC pc)
 {
-  PC_MG         *mg      = (PC_MG *)pc->data;
-  PC_GAMG       *pc_gamg = (PC_GAMG *)mg->innerctx;
-  Mat            Pmat    = pc->pmat;
-  PetscInt       fine_level, level, level1, bs, M, N, qq, lidx, nASMBlocksArr[PETSC_MG_MAXLEVELS];
-  MPI_Comm       comm;
-  PetscMPIInt    rank, size, nactivepe;
-  Mat            Aarr[PETSC_MG_MAXLEVELS], Parr[PETSC_MG_MAXLEVELS];
-  IS            *ASMLocalIDsArr[PETSC_MG_MAXLEVELS];
+  PC_MG      *mg      = (PC_MG *)pc->data;
+  PC_GAMG    *pc_gamg = (PC_GAMG *)mg->innerctx;
+  Mat         Pmat    = pc->pmat;
+  PetscInt    fine_level, level, level1, bs, M, N, qq, lidx, nASMBlocksArr[PETSC_MG_MAXLEVELS];
+  MPI_Comm    comm;
+  PetscMPIInt rank, size, nactivepe;
+  Mat         Aarr[PETSC_MG_MAXLEVELS], Parr[PETSC_MG_MAXLEVELS];
+  IS         *ASMLocalIDsArr[PETSC_MG_MAXLEVELS];
+  PetscBool   is_last = PETSC_FALSE;
+#if defined(PETSC_USE_INFO)
   PetscLogDouble nnz0 = 0., nnztot = 0.;
   MatInfo        info;
-  PetscBool      is_last = PETSC_FALSE;
+#endif
 
   PetscFunctionBegin;
   PetscCall(PetscObjectGetComm((PetscObject)pc, &comm));
@@ -566,7 +568,7 @@ PetscErrorCode PCSetUp_GAMG(PC pc)
 
       PetscCall(PCSetUp_MG(pc));
       PetscCall(PetscLogEventEnd(petsc_gamg_setup_events[GAMG_SETUP], 0, 0, 0, 0));
-      PetscFunctionReturn(0);
+      PetscFunctionReturn(PETSC_SUCCESS);
     }
   }
 
@@ -599,9 +601,11 @@ PetscErrorCode PCSetUp_GAMG(PC pc)
   PetscCall(MatGetBlockSize(Pmat, &bs));
   PetscCall(MatGetSize(Pmat, &M, &N));
 
+#if defined(PETSC_USE_INFO)
   PetscCall(MatGetInfo(Pmat, MAT_GLOBAL_SUM, &info)); /* global reduction */
   nnz0   = info.nz_used;
   nnztot = info.nz_used;
+#endif
   PetscCall(PetscInfo(pc, "%s: level %d) N=%" PetscInt_FMT ", n data rows=%" PetscInt_FMT ", n data cols=%" PetscInt_FMT ", nnz/row (ave)=%" PetscInt_FMT ", np=%d\n", ((PetscObject)pc)->prefix, 0, M, pc_gamg->data_cell_rows, pc_gamg->data_cell_cols, (PetscInt)(nnz0 / (PetscReal)M + 0.5), size));
 
   /* Get A_i and R_i */
@@ -612,7 +616,7 @@ PetscErrorCode PCSetUp_GAMG(PC pc)
 #if defined(GAMG_STAGES)
     if (!gamg_stages[level]) {
       char str[32];
-      sprintf(str, "GAMG Level %d", (int)level);
+      PetscCall(PetscSNPrintf(str, PETSC_STATIC_ARRAY_LENGTH(str), "GAMG Level %d", (int)level));
       PetscCall(PetscLogStageRegister(str, &gamg_stages[level]));
     }
     PetscCall(PetscLogStagePush(gamg_stages[level]));
@@ -676,8 +680,10 @@ PetscErrorCode PCSetUp_GAMG(PC pc)
     PetscCall(PetscLogEventEnd(petsc_gamg_setup_events[GAMG_LEVEL], 0, 0, 0, 0));
 
     PetscCall(MatGetSize(Aarr[level1], &M, &N)); /* M is loop test variables */
+#if defined(PETSC_USE_INFO)
     PetscCall(MatGetInfo(Aarr[level1], MAT_GLOBAL_SUM, &info));
     nnztot += info.nz_used;
+#endif
     PetscCall(PetscInfo(pc, "%s: %d) N=%" PetscInt_FMT ", n data cols=%" PetscInt_FMT ", nnz/row (ave)=%" PetscInt_FMT ", %d active pes\n", ((PetscObject)pc)->prefix, (int)level1, M, pc_gamg->data_cell_cols, (PetscInt)(info.nz_used / (PetscReal)M), nactivepe));
 
 #if defined(GAMG_STAGES)
@@ -732,7 +738,7 @@ PetscErrorCode PCSetUp_GAMG(PC pc)
           PetscCall(ISDestroy(&is));
         } else {
           PetscInt kk;
-          PetscCall(PCASMSetLocalSubdomains(subpc, sz, NULL, iss));
+          PetscCall(PCASMSetLocalSubdomains(subpc, sz, iss, NULL));
           for (kk = 0; kk < sz; kk++) PetscCall(ISDestroy(&iss[kk]));
           PetscCall(PetscFree(iss));
         }
@@ -817,7 +823,7 @@ PetscErrorCode PCSetUp_GAMG(PC pc)
     PetscCall(PCSetUp_MG(pc));
   }
   PetscCall(PetscLogEventEnd(petsc_gamg_setup_events[GAMG_SETUP], 0, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -857,13 +863,13 @@ PetscErrorCode PCDestroy_GAMG(PC pc)
   PetscCall(PetscObjectComposeFunction((PetscObject)pc, "PCGAMGGetType_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)pc, "PCGAMGSetNlevels_C", NULL));
   PetscCall(PCDestroy_MG(pc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetProcEqLim - Set number of equations to aim for per process on the coarse grids via processor reduction in `PCGAMG`
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -872,12 +878,12 @@ PetscErrorCode PCDestroy_GAMG(PC pc)
    Options Database Key:
 .  -pc_gamg_process_eq_limit <limit> - set the limit
 
+   Level: intermediate
+
    Note:
    `PCGAMG` will reduce the number of MPI processes used directly on the coarse grids so that there are around <limit> equations on each process
    that has degrees of freedom
 
-   Level: intermediate
-
 .seealso: `PCGAMG`, `PCGAMGSetCoarseEqLim()`, `PCGAMGSetRankReductionFactors()`, `PCGAMGSetRepartition()`
 @*/
 PetscErrorCode PCGAMGSetProcEqLim(PC pc, PetscInt n)
@@ -885,7 +891,7 @@ PetscErrorCode PCGAMGSetProcEqLim(PC pc, PetscInt n)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetProcEqLim_C", (PC, PetscInt), (pc, n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetProcEqLim_GAMG(PC pc, PetscInt n)
@@ -895,13 +901,13 @@ static PetscErrorCode PCGAMGSetProcEqLim_GAMG(PC pc, PetscInt n)
 
   PetscFunctionBegin;
   if (n > 0) pc_gamg->min_eq_proc = n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetCoarseEqLim - Set maximum number of equations on the coarsest grid of `PCGAMG`
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -910,12 +916,12 @@ static PetscErrorCode PCGAMGSetProcEqLim_GAMG(PC pc, PetscInt n)
    Options Database Key:
 .  -pc_gamg_coarse_eq_limit <limit> - set the limit
 
+   Level: intermediate
+
    Note:
    For example -pc_gamg_coarse_eq_limit 1000 will stop coarsening once the coarse grid
    has less than 1000 unknowns.
 
-   Level: intermediate
-
 .seealso: `PCGAMG`, `PCGAMGSetProcEqLim()`, `PCGAMGSetRankReductionFactors()`, `PCGAMGSetRepartition()`
 @*/
 PetscErrorCode PCGAMGSetCoarseEqLim(PC pc, PetscInt n)
@@ -923,7 +929,7 @@ PetscErrorCode PCGAMGSetCoarseEqLim(PC pc, PetscInt n)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetCoarseEqLim_C", (PC, PetscInt), (pc, n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetCoarseEqLim_GAMG(PC pc, PetscInt n)
@@ -933,13 +939,13 @@ static PetscErrorCode PCGAMGSetCoarseEqLim_GAMG(PC pc, PetscInt n)
 
   PetscFunctionBegin;
   if (n > 0) pc_gamg->coarse_eq_limit = n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetRepartition - Repartition the degrees of freedom across the processors on the coarser grids when reducing the number of MPI ranks to use
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -948,11 +954,11 @@ static PetscErrorCode PCGAMGSetCoarseEqLim_GAMG(PC pc, PetscInt n)
    Options Database Key:
 .  -pc_gamg_repartition <true,false> - turn on the repartitioning
 
+   Level: intermediate
+
    Note:
    This will generally improve the loading balancing of the work on each level
 
-   Level: intermediate
-
 .seealso: `PCGAMG`, `PCGAMGSetProcEqLim()`, `PCGAMGSetRankReductionFactors()`
 @*/
 PetscErrorCode PCGAMGSetRepartition(PC pc, PetscBool n)
@@ -960,7 +966,7 @@ PetscErrorCode PCGAMGSetRepartition(PC pc, PetscBool n)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetRepartition_C", (PC, PetscBool), (pc, n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetRepartition_GAMG(PC pc, PetscBool n)
@@ -970,13 +976,13 @@ static PetscErrorCode PCGAMGSetRepartition_GAMG(PC pc, PetscBool n)
 
   PetscFunctionBegin;
   pc_gamg->repart = n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetUseSAEstEig - Use the eigen estimate from smoothed aggregation for the Chebyshev smoother during the solution process
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -985,6 +991,8 @@ static PetscErrorCode PCGAMGSetRepartition_GAMG(PC pc, PetscBool n)
    Options Database Key:
 .  -pc_gamg_use_sa_esteig <true,false> - use the eigen estimate
 
+   Level: advanced
+
    Notes:
    Smoothed aggregation constructs the smoothed prolongator $P = (I - \omega D^{-1} A) T$ where $T$ is the tentative prolongator and $D$ is the diagonal of $A$.
    Eigenvalue estimates (based on a few `PCCG` or `PCGMRES` iterations) are computed to choose $\omega$ so that this is a stable smoothing operation.
@@ -992,8 +1000,6 @@ static PetscErrorCode PCGAMGSetRepartition_GAMG(PC pc, PetscBool n)
    This option is only used when the smoother uses Jacobi, and should be turned off if a different `PCJacobiType` is used.
    It became default in PETSc 3.17.
 
-   Level: advanced
-
 .seealso: `PCGAMG`, `KSPChebyshevSetEigenvalues()`, `KSPChebyshevEstEigSet()`
 @*/
 PetscErrorCode PCGAMGSetUseSAEstEig(PC pc, PetscBool n)
@@ -1001,7 +1007,7 @@ PetscErrorCode PCGAMGSetUseSAEstEig(PC pc, PetscBool n)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetUseSAEstEig_C", (PC, PetscBool), (pc, n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetUseSAEstEig_GAMG(PC pc, PetscBool n)
@@ -1011,13 +1017,13 @@ static PetscErrorCode PCGAMGSetUseSAEstEig_GAMG(PC pc, PetscBool n)
 
   PetscFunctionBegin;
   pc_gamg->use_sa_esteig = n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetEigenvalues - Set WHAT eigenvalues WHY?
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1036,7 +1042,7 @@ PetscErrorCode PCGAMGSetEigenvalues(PC pc, PetscReal emax, PetscReal emin)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetEigenvalues_C", (PC, PetscReal, PetscReal), (pc, emax, emin));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetEigenvalues_GAMG(PC pc, PetscReal emax, PetscReal emin)
@@ -1049,13 +1055,13 @@ static PetscErrorCode PCGAMGSetEigenvalues_GAMG(PC pc, PetscReal emax, PetscReal
   PetscCheck(emax * emin > 0.0, PetscObjectComm((PetscObject)pc), PETSC_ERR_ARG_INCOMP, "Both eigenvalues must be of the same sign: max %g min %g", (double)emax, (double)emin);
   pc_gamg->emax = emax;
   pc_gamg->emin = emin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetReuseInterpolation - Reuse prolongation when rebuilding a `PCGAMG` algebraic multigrid preconditioner
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1077,7 +1083,7 @@ PetscErrorCode PCGAMGSetReuseInterpolation(PC pc, PetscBool n)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetReuseInterpolation_C", (PC, PetscBool), (pc, n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetReuseInterpolation_GAMG(PC pc, PetscBool n)
@@ -1087,14 +1093,14 @@ static PetscErrorCode PCGAMGSetReuseInterpolation_GAMG(PC pc, PetscBool n)
 
   PetscFunctionBegin;
   pc_gamg->reuse_prol = n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGASMSetUseAggs - Have the `PCGAMG` smoother on each level use the aggregates defined by the coarsening process as the subdomains for the additive Schwarz preconditioner
    used as the smoother
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1112,7 +1118,7 @@ PetscErrorCode PCGAMGASMSetUseAggs(PC pc, PetscBool flg)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGASMSetUseAggs_C", (PC, PetscBool), (pc, flg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGASMSetUseAggs_GAMG(PC pc, PetscBool flg)
@@ -1122,13 +1128,13 @@ static PetscErrorCode PCGAMGASMSetUseAggs_GAMG(PC pc, PetscBool flg)
 
   PetscFunctionBegin;
   pc_gamg->use_aggs_in_asm = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetUseParallelCoarseGridSolve - allow a parallel coarse grid solver
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1146,7 +1152,7 @@ PetscErrorCode PCGAMGSetUseParallelCoarseGridSolve(PC pc, PetscBool flg)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetUseParallelCoarseGridSolve_C", (PC, PetscBool), (pc, flg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetUseParallelCoarseGridSolve_GAMG(PC pc, PetscBool flg)
@@ -1156,13 +1162,13 @@ static PetscErrorCode PCGAMGSetUseParallelCoarseGridSolve_GAMG(PC pc, PetscBool
 
   PetscFunctionBegin;
   pc_gamg->use_parallel_coarse_grid_solver = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetCpuPinCoarseGrids - pin the coarse grids created in `PCGAMG` to run only on the CPU since the problems may be too small to run efficiently on the GPUs
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1180,7 +1186,7 @@ PetscErrorCode PCGAMGSetCpuPinCoarseGrids(PC pc, PetscBool flg)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetCpuPinCoarseGrids_C", (PC, PetscBool), (pc, flg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetCpuPinCoarseGrids_GAMG(PC pc, PetscBool flg)
@@ -1190,13 +1196,13 @@ static PetscErrorCode PCGAMGSetCpuPinCoarseGrids_GAMG(PC pc, PetscBool flg)
 
   PetscFunctionBegin;
   pc_gamg->cpu_pin_coarse_grids = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetCoarseGridLayoutType - place coarse grids on processors with natural order (compact type)
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1214,7 +1220,7 @@ PetscErrorCode PCGAMGSetCoarseGridLayoutType(PC pc, PCGAMGLayoutType flg)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetCoarseGridLayoutType_C", (PC, PCGAMGLayoutType), (pc, flg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetCoarseGridLayoutType_GAMG(PC pc, PCGAMGLayoutType flg)
@@ -1224,13 +1230,13 @@ static PetscErrorCode PCGAMGSetCoarseGridLayoutType_GAMG(PC pc, PCGAMGLayoutType
 
   PetscFunctionBegin;
   pc_gamg->layout_type = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetNlevels -  Sets the maximum number of levels `PCGAMG` will use
 
-   Not collective on pc
+   Not Collective
 
    Input Parameters:
 +  pc - the preconditioner
@@ -1251,7 +1257,7 @@ PetscErrorCode PCGAMGSetNlevels(PC pc, PetscInt n)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetNlevels_C", (PC, PetscInt), (pc, n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetNlevels_GAMG(PC pc, PetscInt n)
@@ -1261,13 +1267,13 @@ static PetscErrorCode PCGAMGSetNlevels_GAMG(PC pc, PetscInt n)
 
   PetscFunctionBegin;
   pc_gamg->Nlevels = n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetThreshold - Relative threshold to use for dropping edges in aggregation graph
 
-   Not collective on pc
+   Not Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1277,17 +1283,17 @@ static PetscErrorCode PCGAMGSetNlevels_GAMG(PC pc, PetscInt n)
    Options Database Key:
 .  -pc_gamg_threshold <threshold> - the threshold to drop edges
 
+   Level: intermediate
+
    Notes:
     Increasing the threshold decreases the rate of coarsening. Conversely reducing the threshold increases the rate of coarsening (aggressive coarsening) and thereby reduces the complexity of the coarse grids, and generally results in slower solver converge rates. Reducing coarse grid complexity reduced the complexity of Galerkin coarse grid construction considerably.
     Before coarsening or aggregating the graph, `PCGAMG` removes small values from the graph with this threshold, and thus reducing the coupling in the graph and a different (perhaps better) coarser set of points.
 
-    If n is less than the total number of coarsenings (see `PCGAMGSetNlevels()`), then threshold scaling (see `PCGAMGSetThresholdScale()`) is used for each successive coarsening.
+    If `n` is less than the total number of coarsenings (see `PCGAMGSetNlevels()`), then threshold scaling (see `PCGAMGSetThresholdScale()`) is used for each successive coarsening.
     In this case, `PCGAMGSetThresholdScale()` must be called before `PCGAMGSetThreshold()`.
-    If n is greater than the total number of levels, the excess entries in threshold will not be used.
+    If `n` is greater than the total number of levels, the excess entries in threshold will not be used.
 
-   Level: intermediate
-
-.seealso: `PCGAMG`, `PCGAMGFilterGraph()`, `PCGAMGSetAggressiveLevels()`, `PCGAMGSetThresholdScale()`
+.seealso: `PCGAMG`, `PCGAMGSetAggressiveLevels()`, `PCGAMGSetThresholdScale()`
 @*/
 PetscErrorCode PCGAMGSetThreshold(PC pc, PetscReal v[], PetscInt n)
 {
@@ -1295,7 +1301,7 @@ PetscErrorCode PCGAMGSetThreshold(PC pc, PetscReal v[], PetscInt n)
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   if (n) PetscValidRealPointer(v, 2);
   PetscTryMethod(pc, "PCGAMGSetThreshold_C", (PC, PetscReal[], PetscInt), (pc, v, n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetThreshold_GAMG(PC pc, PetscReal v[], PetscInt n)
@@ -1306,13 +1312,13 @@ static PetscErrorCode PCGAMGSetThreshold_GAMG(PC pc, PetscReal v[], PetscInt n)
   PetscFunctionBegin;
   for (i = 0; i < PetscMin(n, PETSC_MG_MAXLEVELS); i++) pc_gamg->threshold[i] = v[i];
   for (; i < PETSC_MG_MAXLEVELS; i++) pc_gamg->threshold[i] = pc_gamg->threshold[i - 1] * pc_gamg->threshold_scale;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetRankReductionFactors - Set a manual schedule for MPI rank reduction on coarse grids
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1332,7 +1338,7 @@ PetscErrorCode PCGAMGSetRankReductionFactors(PC pc, PetscInt v[], PetscInt n)
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   if (n) PetscValidIntPointer(v, 2);
   PetscTryMethod(pc, "PCGAMGSetRankReductionFactors_C", (PC, PetscInt[], PetscInt), (pc, v, n));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetRankReductionFactors_GAMG(PC pc, PetscInt v[], PetscInt n)
@@ -1343,13 +1349,13 @@ static PetscErrorCode PCGAMGSetRankReductionFactors_GAMG(PC pc, PetscInt v[], Pe
   PetscFunctionBegin;
   for (i = 0; i < PetscMin(n, PETSC_MG_MAXLEVELS); i++) pc_gamg->level_reduction_factors[i] = v[i];
   for (; i < PETSC_MG_MAXLEVELS; i++) pc_gamg->level_reduction_factors[i] = -1; /* 0 stop putting one process/device on first level */
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGAMGSetThresholdScale - Relative threshold reduction at each level
 
-   Not collective on pc
+   Not Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1358,12 +1364,12 @@ static PetscErrorCode PCGAMGSetRankReductionFactors_GAMG(PC pc, PetscInt v[], Pe
    Options Database Key:
 .  -pc_gamg_threshold_scale <v> - set the relative threshold reduction on each level
 
+   Level: advanced
+
    Note:
    The initial threshold (for an arbitrary number of levels starting from the finest) can be set with `PCGAMGSetThreshold()`.
    This scaling is used for each subsequent coarsening, but must be called before `PCGAMGSetThreshold()`.
 
-   Level: advanced
-
 .seealso: `PCGAMG`, `PCGAMGSetThreshold()`
 @*/
 PetscErrorCode PCGAMGSetThresholdScale(PC pc, PetscReal v)
@@ -1371,7 +1377,7 @@ PetscErrorCode PCGAMGSetThresholdScale(PC pc, PetscReal v)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetThresholdScale_C", (PC, PetscReal), (pc, v));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetThresholdScale_GAMG(PC pc, PetscReal v)
@@ -1380,13 +1386,13 @@ static PetscErrorCode PCGAMGSetThresholdScale_GAMG(PC pc, PetscReal v)
   PC_GAMG *pc_gamg = (PC_GAMG *)mg->innerctx;
   PetscFunctionBegin;
   pc_gamg->threshold_scale = v;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PCGAMGSetType - Set the type of algorithm `PCGAMG` should use
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1404,13 +1410,13 @@ PetscErrorCode PCGAMGSetType(PC pc, PCGAMGType type)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscTryMethod(pc, "PCGAMGSetType_C", (PC, PCGAMGType), (pc, type));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PCGAMGGetType - Get the type of algorithm `PCGAMG` will use
 
-   Collective on pc
+   Collective
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -1427,7 +1433,7 @@ PetscErrorCode PCGAMGGetType(PC pc, PCGAMGType *type)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscUseMethod(pc, "PCGAMGGetType_C", (PC, PCGAMGType *), (pc, type));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGGetType_GAMG(PC pc, PCGAMGType *type)
@@ -1437,7 +1443,7 @@ static PetscErrorCode PCGAMGGetType_GAMG(PC pc, PCGAMGType *type)
 
   PetscFunctionBegin;
   *type = pc_gamg->type;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCGAMGSetType_GAMG(PC pc, PCGAMGType type)
@@ -1454,7 +1460,7 @@ static PetscErrorCode PCGAMGSetType_GAMG(PC pc, PCGAMGType type)
     PetscCall((*pc_gamg->ops->destroy)(pc));
     PetscCall(PetscMemzero(pc_gamg->ops, sizeof(struct _PCGAMGOps)));
     pc_gamg->ops->createlevel = PCGAMGCreateLevel_GAMG;
-    /* cleaning up common data in pc_gamg - this should disapear someday */
+    /* cleaning up common data in pc_gamg - this should disappear someday */
     pc_gamg->data_cell_cols      = 0;
     pc_gamg->data_cell_rows      = 0;
     pc_gamg->orig_data_cell_cols = 0;
@@ -1465,7 +1471,7 @@ static PetscErrorCode PCGAMGSetType_GAMG(PC pc, PCGAMGType type)
   PetscCall(PetscFree(pc_gamg->gamg_type_name));
   PetscCall(PetscStrallocpy(type, &pc_gamg->gamg_type_name));
   PetscCall((*r)(pc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PCView_GAMG(PC pc, PetscViewer viewer)
@@ -1485,7 +1491,7 @@ static PetscErrorCode PCView_GAMG(PC pc, PetscViewer viewer)
   if (pc_gamg->ops->view) PetscCall((*pc_gamg->ops->view)(pc, viewer));
   PetscCall(PCMGGetGridComplexity(pc, &gc, &oc));
   PetscCall(PetscViewerASCIIPrintf(viewer, "      Complexity:    grid = %g    operator = %g\n", (double)gc, (double)oc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PCSetFromOptions_GAMG(PC pc, PetscOptionItems *PetscOptionsObject)
@@ -1546,7 +1552,7 @@ PetscErrorCode PCSetFromOptions_GAMG(PC pc, PetscOptionItems *PetscOptionsObject
   PetscCall(PCGetOptionsPrefix(pc, &pcpre));
   PetscCall(PetscSNPrintf(prefix, sizeof(prefix), "%spc_gamg_", pcpre ? pcpre : ""));
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1554,9 +1560,9 @@ PetscErrorCode PCSetFromOptions_GAMG(PC pc, PetscOptionItems *PetscOptionsObject
 
    Options Database Keys:
 +   -pc_gamg_type <type,default=agg> - one of agg, geo, or classical
-.   -pc_gamg_repartition  <bool,default=false> - repartition the degrees of freedom accross the coarse grids as they are determined
+.   -pc_gamg_repartition  <bool,default=false> - repartition the degrees of freedom across the coarse grids as they are determined
 .   -pc_gamg_asm_use_agg <bool,default=false> - use the aggregates from the coasening process to defined the subdomains on each level for the PCASM smoother
-.   -pc_gamg_process_eq_limit <limit, default=50> - `PCGAMG` will reduce the number of MPI processes used directly on the coarse grids so that there are around <limit>
+.   -pc_gamg_process_eq_limit <limit, default=50> - `PCGAMG` will reduce the number of MPI ranks used directly on the coarse grids so that there are around <limit>
                                         equations on each process that has degrees of freedom
 .   -pc_gamg_coarse_eq_limit <limit, default=50> - Set maximum number of equations on coarsest grid to aim for.
 .   -pc_gamg_reuse_interpolation <bool,default=true> - when rebuilding the algebraic multigrid preconditioner reuse the previously computed interpolations (should always be true)
@@ -1569,11 +1575,13 @@ PetscErrorCode PCSetFromOptions_GAMG(PC pc, PetscOptionItems *PetscOptionsObject
 -  -pc_gamg_aggressive_coarsening <n,default=1> - number of aggressive coarsening (MIS-2) levels from finest.
 
    Options Database Keys for Multigrid:
-+  -pc_mg_cycles <v> - v or w, see `PCMGSetCycleType()`
++  -pc_mg_cycle_type <v> - v or w, see `PCMGSetCycleType()`
 .  -pc_mg_distinct_smoothup - configure the up and down (pre and post) smoothers separately, see PCMGSetDistinctSmoothUp()
 .  -pc_mg_type <multiplicative> - (one of) additive multiplicative full kascade
 -  -pc_mg_levels <levels> - Number of levels of multigrid to use. GAMG has a heuristic so pc_mg_levels is not usually used with GAMG
 
+  Level: intermediate
+
   Notes:
   To obtain good performance for `PCGAMG` for vector valued problems you must
   call `MatSetBlockSize()` to indicate the number of degrees of freedom per grid point
@@ -1581,8 +1589,6 @@ PetscErrorCode PCSetFromOptions_GAMG(PC pc, PetscOptionItems *PetscOptionsObject
 
   See [the Users Manual section on PCGAMG](sec_amg) for more details.
 
-  Level: intermediate
-
 .seealso: `PCCreate()`, `PCSetType()`, `MatSetBlockSize()`, `PCMGType`, `PCSetCoordinates()`, `MatSetNearNullSpace()`, `PCGAMGSetType()`, `PCGAMGAGG`, `PCGAMGGEO`, `PCGAMGCLASSICAL`, `PCGAMGSetProcEqLim()`,
           `PCGAMGSetCoarseEqLim()`, `PCGAMGSetRepartition()`, `PCGAMGRegister()`, `PCGAMGSetReuseInterpolation()`, `PCGAMGASMSetUseAggs()`, `PCGAMGSetUseParallelCoarseGridSolve()`, `PCGAMGSetNlevels()`, `PCGAMGSetThreshold()`, `PCGAMGGetType()`, `PCGAMGSetReuseInterpolation()`, `PCGAMGSetUseSAEstEig()`
 M*/
@@ -1655,7 +1661,7 @@ PETSC_EXTERN PetscErrorCode PCCreate_GAMG(PC pc)
 
   /* PCSetUp_GAMG assumes that the type has been set, so set it to the default now */
   PetscCall(PCGAMGSetType(pc, PCGAMGAGG));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1664,14 +1670,14 @@ PETSC_EXTERN PetscErrorCode PCCreate_GAMG(PC pc)
 
  Level: developer
 
- .seealso: `PetscInitialize()`
+.seealso: `PetscInitialize()`
 @*/
 PetscErrorCode PCGAMGInitializePackage(void)
 {
   PetscInt l;
 
   PetscFunctionBegin;
-  if (PCGAMGPackageInitialized) PetscFunctionReturn(0);
+  if (PCGAMGPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   PCGAMGPackageInitialized = PETSC_TRUE;
   PetscCall(PetscFunctionListAdd(&GAMGList, PCGAMGGEO, PCCreateGAMG_GEO));
   PetscCall(PetscFunctionListAdd(&GAMGList, PCGAMGAGG, PCCreateGAMG_AGG));
@@ -1708,11 +1714,11 @@ PetscErrorCode PCGAMGInitializePackage(void)
 #if defined(GAMG_STAGES)
   { /* create timer stages */
     char str[32];
-    sprintf(str, "GAMG Level %d", 0);
+    PetscCall(PetscSNPrintf(str, PETSC_STATIC_ARRAY_LENGTH(str), "GAMG Level %d", 0));
     PetscCall(PetscLogStageRegister(str, &gamg_stages[0]));
   }
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1721,14 +1727,14 @@ PetscErrorCode PCGAMGInitializePackage(void)
 
  Level: developer
 
- .seealso: `PetscFinalize()`
+.seealso: `PetscFinalize()`
 @*/
 PetscErrorCode PCGAMGFinalizePackage(void)
 {
   PetscFunctionBegin;
   PCGAMGPackageInitialized = PETSC_FALSE;
   PetscCall(PetscFunctionListDestroy(&GAMGList));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1740,14 +1746,14 @@ PetscErrorCode PCGAMGFinalizePackage(void)
 
   Level: developer
 
- .seealso: `PCGAMGType`, `PCGAMG`, `PCGAMGSetType()`
+.seealso: `PCGAMGType`, `PCGAMG`, `PCGAMGSetType()`
 @*/
 PetscErrorCode PCGAMGRegister(PCGAMGType type, PetscErrorCode (*create)(PC))
 {
   PetscFunctionBegin;
   PetscCall(PCGAMGInitializePackage());
   PetscCall(PetscFunctionListAdd(&GAMGList, type, create));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1762,7 +1768,7 @@ PetscErrorCode PCGAMGRegister(PCGAMGType type, PetscErrorCode (*create)(PC))
 
   Level: advanced
 
- .seealso: `PCGAMGType`, `PCGAMG`, `PCGAMGSetType()`
+.seealso: `PCGAMGType`, `PCGAMG`, `PCGAMGSetType()`
 @*/
 PetscErrorCode PCGAMGCreateGraph(PC pc, Mat A, Mat *G)
 {
@@ -1771,5 +1777,5 @@ PetscErrorCode PCGAMGCreateGraph(PC pc, Mat A, Mat *G)
 
   PetscFunctionBegin;
   PetscCall(pc_gamg->ops->creategraph(pc, A, G));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
