@@ -51,13 +51,13 @@ PetscErrorCode PCGetDefaultType_Private(PC pc, const char *type[])
       *type = PCBJACOBI;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCReset - Resets a PC context to the pcsetupcalled = 0 state and removes any allocated `Vec`s and `Mat`s
 
-   Collective on pc
+   Collective
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -80,13 +80,13 @@ PetscErrorCode PCReset(PC pc)
   PetscCall(MatDestroy(&pc->mat));
 
   pc->setupcalled = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PCDestroy - Destroys `PC` context that was created with `PCCreate()`.
 
-   Collective on pc
+   Collective
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -98,11 +98,11 @@ PetscErrorCode PCReset(PC pc)
 PetscErrorCode PCDestroy(PC *pc)
 {
   PetscFunctionBegin;
-  if (!*pc) PetscFunctionReturn(0);
+  if (!*pc) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific((*pc), PC_CLASSID, 1);
   if (--((PetscObject)(*pc))->refct > 0) {
     *pc = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(PCReset(*pc));
@@ -112,14 +112,14 @@ PetscErrorCode PCDestroy(PC *pc)
   PetscTryTypeMethod((*pc), destroy);
   PetscCall(DMDestroy(&(*pc)->dm));
   PetscCall(PetscHeaderDestroy(pc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PCGetDiagonalScale - Indicates if the preconditioner applies an additional left and right
       scaling as needed by certain time-stepping codes.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -144,14 +144,14 @@ PetscErrorCode PCGetDiagonalScale(PC pc, PetscBool *flag)
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscValidBoolPointer(flag, 2);
   *flag = pc->diagonalscale;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCSetDiagonalScale - Indicates the left scaling to use to apply an additional left and right
       scaling as needed by certain time-stepping codes.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -185,13 +185,13 @@ PetscErrorCode PCSetDiagonalScale(PC pc, Vec s)
   PetscCall(VecDuplicate(s, &pc->diagonalscaleright));
   PetscCall(VecCopy(s, pc->diagonalscaleright));
   PetscCall(VecReciprocal(pc->diagonalscaleright));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCDiagonalScaleLeft - Scales a vector by the left scaling as needed by certain time-stepping codes.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -224,13 +224,13 @@ PetscErrorCode PCDiagonalScaleLeft(PC pc, Vec in, Vec out)
   } else if (in != out) {
     PetscCall(VecCopy(in, out));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCDiagonalScaleRight - Scales a vector by the right scaling as needed by certain time-stepping codes.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -263,7 +263,7 @@ PetscErrorCode PCDiagonalScaleRight(PC pc, Vec in, Vec out)
   } else if (in != out) {
     PetscCall(VecCopy(in, out));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -271,7 +271,7 @@ PetscErrorCode PCDiagonalScaleRight(PC pc, Vec in, Vec out)
    operator during the preconditioning process it applies the Amat provided to `TSSetRHSJacobian()`,
    `TSSetIJacobian()`, `SNESSetJacobian()`, `KSPSetOperators()` or `PCSetOperators()` not the Pmat.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -280,12 +280,12 @@ PetscErrorCode PCDiagonalScaleRight(PC pc, Vec in, Vec out)
    Options Database Key:
 .  -pc_use_amat <true,false> - use the amat to apply the operator
 
+   Level: intermediate
+
    Note:
    For the common case in which the linear system matrix and the matrix used to construct the
    preconditioner are identical, this routine is does nothing.
 
-   Level: intermediate
-
 .seealso: `PC`, `PCGetUseAmat()`, `PCBJACOBI`, `PGMG`, `PCFIELDSPLIT`, `PCCOMPOSITE`
 @*/
 PetscErrorCode PCSetUseAmat(PC pc, PetscBool flg)
@@ -293,13 +293,13 @@ PetscErrorCode PCSetUseAmat(PC pc, PetscBool flg)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   pc->useAmat = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCSetErrorIfFailure - Causes `PC` to generate an error if a FPE, for example a zero pivot, is detected.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - iterative context obtained from PCCreate()
@@ -322,7 +322,7 @@ PetscErrorCode PCSetErrorIfFailure(PC pc, PetscBool flg)
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscValidLogicalCollectiveBool(pc, flg, 2);
   pc->erroriffailure = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -330,7 +330,7 @@ PetscErrorCode PCSetErrorIfFailure(PC pc, PetscBool flg)
    operator during the preconditioning process it applies the Amat provided to `TSSetRHSJacobian()`,
    `TSSetIJacobian()`, `SNESSetJacobian()`, `KSPSetOperators()` or `PCSetOperators()` not the Pmat.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -338,12 +338,12 @@ PetscErrorCode PCSetErrorIfFailure(PC pc, PetscBool flg)
    Output Parameter:
 .  flg - `PETSC_TRUE` to use the Amat, `PETSC_FALSE` to use the Pmat (default is false)
 
+   Level: intermediate
+
    Note:
    For the common case in which the linear system matrix and the matrix used to construct the
    preconditioner are identical, this routine is does nothing.
 
-   Level: intermediate
-
 .seealso: `PC`, `PCSetUseAmat()`, `PCBJACOBI`, `PGMG`, `PCFIELDSPLIT`, `PCCOMPOSITE`
 @*/
 PetscErrorCode PCGetUseAmat(PC pc, PetscBool *flg)
@@ -351,7 +351,7 @@ PetscErrorCode PCGetUseAmat(PC pc, PetscBool *flg)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   *flg = pc->useAmat;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -365,12 +365,12 @@ PetscErrorCode PCGetUseAmat(PC pc, PetscBool *flg)
    Output Parameter:
 .  pc - location to put the preconditioner context
 
+   Level: developer
+
    Note:
    The default preconditioner for sparse matrices is `PCILU` or `PCICC` with 0 fill on one process and block Jacobi (`PCBJACOBI`) with `PCILU` or `PCICC`
    in parallel. For dense matrices it is always `PCNONE`.
 
-   Level: developer
-
 .seealso: `PC`, `PCSetUp()`, `PCApply()`, `PCDestroy()`
 @*/
 PetscErrorCode PCCreate(MPI_Comm comm, PC *newpc)
@@ -397,13 +397,13 @@ PetscErrorCode PCCreate(MPI_Comm comm, PC *newpc)
   pc->modifysubmatricesP = NULL;
 
   *newpc = pc;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCApply - Applies the preconditioner to a vector.
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -442,13 +442,13 @@ PetscErrorCode PCApply(PC pc, Vec x, Vec y)
   PetscCall(PetscLogEventEnd(PC_Apply, pc, x, y, 0));
   if (pc->erroriffailure) PetscCall(VecValidValues_Internal(y, 3, PETSC_FALSE));
   PetscCall(VecLockReadPop(x));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCMatApply - Applies the preconditioner to multiple vectors stored as a `MATDENSE`. Like `PCApply()`, Y and X must be different matrices.
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -504,13 +504,13 @@ PetscErrorCode PCMatApply(PC pc, Mat X, Mat Y)
       PetscCall(MatDenseRestoreColumnVecRead(X, n1, &cx));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCApplySymmetricLeft - Applies the left part of a symmetric preconditioner to a vector.
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -519,11 +519,11 @@ PetscErrorCode PCMatApply(PC pc, Mat X, Mat Y)
    Output Parameter:
 .  y - output vector
 
+   Level: developer
+
    Note:
    Currently, this routine is implemented only for `PCICC` and `PCJACOBI` preconditioners.
 
-   Level: developer
-
 .seealso: `PC`, `PCApply()`, `PCApplySymmetricRight()`
 @*/
 PetscErrorCode PCApplySymmetricLeft(PC pc, Vec x, Vec y)
@@ -541,13 +541,13 @@ PetscErrorCode PCApplySymmetricLeft(PC pc, Vec x, Vec y)
   PetscCall(PetscLogEventEnd(PC_ApplySymmetricLeft, pc, x, y, 0));
   PetscCall(VecLockReadPop(x));
   if (pc->erroriffailure) PetscCall(VecValidValues_Internal(y, 3, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCApplySymmetricRight - Applies the right part of a symmetric preconditioner to a vector.
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -578,13 +578,13 @@ PetscErrorCode PCApplySymmetricRight(PC pc, Vec x, Vec y)
   PetscCall(PetscLogEventEnd(PC_ApplySymmetricRight, pc, x, y, 0));
   PetscCall(VecLockReadPop(x));
   if (pc->erroriffailure) PetscCall(VecValidValues_Internal(y, 3, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCApplyTranspose - Applies the transpose of preconditioner to a vector.
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -593,14 +593,14 @@ PetscErrorCode PCApplySymmetricRight(PC pc, Vec x, Vec y)
    Output Parameter:
 .  y - output vector
 
+   Level: developer
+
    Note:
     For complex numbers this applies the non-Hermitian transpose.
 
    Developer Note:
     We need to implement a `PCApplyHermitianTranspose()`
 
-   Level: developer
-
 .seealso: `PC`, `PCApply()`, `PCApplyBAorAB()`, `PCApplyBAorABTranspose()`, `PCApplyTransposeExists()`
 @*/
 PetscErrorCode PCApplyTranspose(PC pc, Vec x, Vec y)
@@ -618,13 +618,13 @@ PetscErrorCode PCApplyTranspose(PC pc, Vec x, Vec y)
   PetscCall(PetscLogEventEnd(PC_Apply, pc, x, y, 0));
   PetscCall(VecLockReadPop(x));
   if (pc->erroriffailure) PetscCall(VecValidValues_Internal(y, 3, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCApplyTransposeExists - Test whether the preconditioner has a transpose apply operation
 
-   Collective on pc
+   Collective
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -643,13 +643,13 @@ PetscErrorCode PCApplyTransposeExists(PC pc, PetscBool *flg)
   PetscValidBoolPointer(flg, 2);
   if (pc->ops->applytranspose) *flg = PETSC_TRUE;
   else *flg = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCApplyBAorAB - Applies the preconditioner and operator to a vector. y = B*A*x or y = A*B*x.
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -722,7 +722,7 @@ PetscErrorCode PCApplyBAorAB(PC pc, PCSide side, Vec x, Vec y, Vec work)
     }
   }
   if (pc->erroriffailure) PetscCall(VecValidValues_Internal(y, 4, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -730,7 +730,7 @@ PetscErrorCode PCApplyBAorAB(PC pc, PCSide side, Vec x, Vec y, Vec work)
    and operator to a vector. That is, applies tr(B) * tr(A) with left preconditioning,
    NOT tr(B*A) = tr(A)*tr(B).
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -741,12 +741,12 @@ PetscErrorCode PCApplyBAorAB(PC pc, PCSide side, Vec x, Vec y, Vec work)
    Output Parameter:
 .  y - output vector
 
+    Level: developer
+
    Note:
     This routine is used internally so that the same Krylov code can be used to solve A x = b and A' x = b, with a preconditioner
       defined by B'. This is why this has the funny form that it computes tr(B) * tr(A)
 
-    Level: developer
-
 .seealso: `PC`, `PCApply()`, `PCApplyTranspose()`, `PCApplyBAorAB()`
 @*/
 PetscErrorCode PCApplyBAorABTranspose(PC pc, PCSide side, Vec x, Vec y, Vec work)
@@ -761,7 +761,7 @@ PetscErrorCode PCApplyBAorABTranspose(PC pc, PCSide side, Vec x, Vec y, Vec work
   if (pc->ops->applyBAtranspose) {
     PetscUseTypeMethod(pc, applyBAtranspose, side, x, y, work);
     if (pc->erroriffailure) PetscCall(VecValidValues_Internal(y, 4, PETSC_FALSE));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCheck(side == PC_LEFT || side == PC_RIGHT, PetscObjectComm((PetscObject)pc), PETSC_ERR_ARG_OUTOFRANGE, "Side must be right or left");
 
@@ -775,7 +775,7 @@ PetscErrorCode PCApplyBAorABTranspose(PC pc, PCSide side, Vec x, Vec y, Vec work
   }
   /* add support for PC_SYMMETRIC */
   if (pc->erroriffailure) PetscCall(VecValidValues_Internal(y, 4, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -801,7 +801,7 @@ PetscErrorCode PCApplyRichardsonExists(PC pc, PetscBool *exists)
   PetscValidBoolPointer(exists, 2);
   if (pc->ops->applyrichardson) *exists = PETSC_TRUE;
   else *exists = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -809,7 +809,7 @@ PetscErrorCode PCApplyRichardsonExists(PC pc, PetscBool *exists)
    the particular preconditioner. This routine is usually used by the
    Krylov solvers and not the application code directly.
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc  - the preconditioner context
@@ -826,6 +826,8 @@ PetscErrorCode PCApplyRichardsonExists(PC pc, PetscBool *exists)
 .  reason - the reason the apply terminated
 -  y - the solution (also contains initial guess if guesszero is `PETSC_FALSE`
 
+   Level: developer
+
    Notes:
    Most preconditioners do not support this function. Use the command
    `PCApplyRichardsonExists()` to determine if one does.
@@ -833,8 +835,6 @@ PetscErrorCode PCApplyRichardsonExists(PC pc, PetscBool *exists)
    Except for the `PCMG` this routine ignores the convergence tolerances
    and always runs for the number of iterations
 
-   Level: developer
-
 .seealso: `PC`, `PCApplyRichardsonExists()`
 @*/
 PetscErrorCode PCApplyRichardson(PC pc, Vec b, Vec y, Vec w, PetscReal rtol, PetscReal abstol, PetscReal dtol, PetscInt its, PetscBool guesszero, PetscInt *outits, PCRichardsonConvergedReason *reason)
@@ -847,13 +847,13 @@ PetscErrorCode PCApplyRichardson(PC pc, Vec b, Vec y, Vec w, PetscReal rtol, Pet
   PetscCheck(b != y, PetscObjectComm((PetscObject)pc), PETSC_ERR_ARG_IDN, "b and y must be different vectors");
   PetscCall(PCSetUp(pc));
   PetscUseTypeMethod(pc, applyrichardson, b, y, w, rtol, abstol, dtol, its, guesszero, outits, reason);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCSetFailedReason - Sets the reason a `PCSetUp()` failed or `PC_NOERROR` if it did not fail
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -867,13 +867,13 @@ PetscErrorCode PCSetFailedReason(PC pc, PCFailedReason reason)
 {
   PetscFunctionBegin;
   pc->failedreason = reason;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGetFailedReason - Gets the reason a `PCSetUp()` failed or `PC_NOERROR` if it did not fail
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -895,7 +895,7 @@ PetscErrorCode PCGetFailedReason(PC pc, PCFailedReason *reason)
   PetscFunctionBegin;
   if (pc->setupcalled < 0) *reason = (PCFailedReason)pc->setupcalled;
   else *reason = pc->failedreason;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -909,11 +909,11 @@ PetscErrorCode PCGetFailedReason(PC pc, PCFailedReason *reason)
    Output Parameter:
 .  reason - the reason it failed
 
+   Level: advanced
+
    Note:
      Different ranks may have different reasons or no reason, see `PCGetFailedReason()`
 
-   Level: advanced
-
 .seealso: `PC`, `PCCreate()`, `PCApply()`, `PCDestroy()`, `PCGetFailedReason()`, `PCSetFailedReason()`
 @*/
 PetscErrorCode PCGetFailedReasonRank(PC pc, PCFailedReason *reason)
@@ -921,7 +921,7 @@ PetscErrorCode PCGetFailedReasonRank(PC pc, PCFailedReason *reason)
   PetscFunctionBegin;
   if (pc->setupcalled < 0) *reason = (PCFailedReason)pc->setupcalled;
   else *reason = pc->failedreason;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*  Next line needed to deactivate KSP_Solve logging */
@@ -935,7 +935,7 @@ PetscErrorCode PCGetFailedReasonRank(PC pc, PCFailedReason *reason)
 /*@
    PCSetUp - Prepares for the use of a preconditioner.
 
-   Collective on pc
+   Collective
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -955,7 +955,7 @@ PetscErrorCode PCSetUp(PC pc)
 
   if (pc->setupcalled && pc->reusepreconditioner) {
     PetscCall(PetscInfo(pc, "Leaving PC with identical preconditioner since reuse preconditioner is set\n"));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(PetscObjectStateGet((PetscObject)pc->pmat, &matstate));
@@ -965,7 +965,7 @@ PetscErrorCode PCSetUp(PC pc)
     pc->flag = DIFFERENT_NONZERO_PATTERN;
   } else if (matstate == pc->matstate) {
     PetscCall(PetscInfo(pc, "Leaving PC with identical preconditioner since operator is unchanged\n"));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   } else {
     if (matnonzerostate > pc->matnonzerostate) {
       PetscCall(PetscInfo(pc, "Setting up PC with different nonzero pattern\n"));
@@ -997,7 +997,7 @@ PetscErrorCode PCSetUp(PC pc)
   }
   PetscCall(PetscLogEventEnd(PC_SetUp, pc, 0, 0, 0));
   if (!pc->setupcalled) pc->setupcalled = 1;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1005,7 +1005,7 @@ PetscErrorCode PCSetUp(PC pc)
    the block Jacobi, block Gauss-Seidel, and overlapping Schwarz
    methods.
 
-   Collective on pc
+   Collective
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -1022,11 +1022,11 @@ PetscErrorCode PCSetUpOnBlocks(PC pc)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
-  if (!pc->ops->setuponblocks) PetscFunctionReturn(0);
+  if (!pc->ops->setuponblocks) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscLogEventBegin(PC_SetUpOnBlocks, pc, 0, 0, 0));
   PetscUseTypeMethod(pc, setuponblocks);
   PetscCall(PetscLogEventEnd(PC_SetUpOnBlocks, pc, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1036,17 +1036,17 @@ PetscErrorCode PCSetUpOnBlocks(PC pc)
    usual; the user can then alter these (for example, to set different boundary
    conditions for each submatrix) before they are used for the local solves.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
 .  func - routine for modifying the submatrices
 -  ctx - optional user-defined context (may be null)
 
-   Calling sequence of func:
-$     func (PC pc,PetscInt nsub,IS *row,IS *col,Mat *submat,void *ctx);
-
-+  row - an array of index sets that contain the global row numbers
+   Calling sequence of `func`:
+$  PetscErrorCode func (PC pc, PetscInt nsub, IS *row, IS *col, Mat *submat, void *ctx);
++  pc - the preconditioner context
+.  row - an array of index sets that contain the global row numbers
          that comprise each local submatrix
 .  col - an array of index sets that contain the global column numbers
          that comprise each local submatrix
@@ -1054,6 +1054,8 @@ $     func (PC pc,PetscInt nsub,IS *row,IS *col,Mat *submat,void *ctx);
 -  ctx - optional user-defined context for private data for the
          user-defined func routine (may be null)
 
+   Level: advanced
+
    Notes:
    `PCSetModifySubMatrices()` MUST be called before `KSPSetUp()` and
    `KSPSolve()`.
@@ -1062,8 +1064,6 @@ $     func (PC pc,PetscInt nsub,IS *row,IS *col,Mat *submat,void *ctx);
    the block Jacobi (`PCBJACOBI`) and additive Schwarz (`PCASM`)
    preconditioners.  All other preconditioners ignore this routine.
 
-   Level: advanced
-
 .seealso: `PC`, `PCBJACOBI`, `PCASM`, `PCModifySubMatrices()`
 @*/
 PetscErrorCode PCSetModifySubMatrices(PC pc, PetscErrorCode (*func)(PC, PetscInt, const IS[], const IS[], Mat[], void *), void *ctx)
@@ -1072,14 +1072,14 @@ PetscErrorCode PCSetModifySubMatrices(PC pc, PetscErrorCode (*func)(PC, PetscInt
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   pc->modifysubmatrices  = func;
   pc->modifysubmatricesP = ctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PCModifySubMatrices - Calls an optional user-defined routine within
    certain preconditioners if one has been set with `PCSetModifySubMatrices()`.
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1096,6 +1096,8 @@ PetscErrorCode PCSetModifySubMatrices(PC pc, PetscErrorCode (*func)(PC, PetscInt
 .  submat - array of local submatrices (the entries of which may
             have been modified)
 
+   Level: developer
+
    Notes:
    The user should NOT generally call this routine, as it will
    automatically be called within certain preconditioners (currently
@@ -1106,47 +1108,45 @@ PetscErrorCode PCSetModifySubMatrices(PC pc, PetscErrorCode (*func)(PC, PetscInt
    boundary conditions for each submatrix) before they are used for the
    local solves.
 
-   Level: developer
-
 .seealso: `PC`, `PCSetModifySubMatrices()`
 @*/
 PetscErrorCode PCModifySubMatrices(PC pc, PetscInt nsub, const IS row[], const IS col[], Mat submat[], void *ctx)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
-  if (!pc->modifysubmatrices) PetscFunctionReturn(0);
+  if (!pc->modifysubmatrices) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscLogEventBegin(PC_ModifySubMatrices, pc, 0, 0, 0));
   PetscCall((*pc->modifysubmatrices)(pc, nsub, row, col, submat, ctx));
   PetscCall(PetscLogEventEnd(PC_ModifySubMatrices, pc, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCSetOperators - Sets the matrix associated with the linear system and
    a (possibly) different one associated with the preconditioner.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
 .  Amat - the matrix that defines the linear system
 -  Pmat - the matrix to be used in constructing the preconditioner, usually the same as Amat.
 
-   Notes:
-    Passing a NULL for Amat or Pmat removes the matrix that is currently used.
+   Level: intermediate
 
-    If you wish to replace either Amat or Pmat but leave the other one untouched then
+   Notes:
+    Passing a `NULL` for `Amat` or `Pmat` removes the matrix that is currently used.
+
+    If you wish to replace either `Amat` or `Pmat` but leave the other one untouched then
     first call `KSPGetOperators()` to get the one you wish to keep, call `PetscObjectReference()`
     on it and then pass it back in in your call to `KSPSetOperators()`.
 
    More Notes about Repeated Solution of Linear Systems:
-   PETSc does NOT reset the matrix entries of either Amat or Pmat
+   PETSc does NOT reset the matrix entries of either `Amat` or `Pmat`
    to zero after a linear solve; the user is completely responsible for
    matrix assembly.  See the routine `MatZeroEntries()` if desiring to
    zero all elements of a matrix.
 
-   Level: intermediate
-
 .seealso: `PC`, `PCGetOperators()`, `MatZeroEntries()`
  @*/
 PetscErrorCode PCSetOperators(PC pc, Mat Amat, Mat Pmat)
@@ -1181,13 +1181,13 @@ PetscErrorCode PCSetOperators(PC pc, Mat Amat, Mat Pmat)
   PetscCall(MatDestroy(&pc->pmat));
   pc->mat  = Amat;
   pc->pmat = Pmat;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCSetReusePreconditioner - reuse the current preconditioner even if the operator in the preconditioner has changed.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1207,7 +1207,7 @@ PetscErrorCode PCSetReusePreconditioner(PC pc, PetscBool flag)
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscValidLogicalCollectiveBool(pc, flag, 2);
   pc->reusepreconditioner = flag;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1231,14 +1231,14 @@ PetscErrorCode PCGetReusePreconditioner(PC pc, PetscBool *flag)
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscValidBoolPointer(flag, 2);
   *flag = pc->reusepreconditioner;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGetOperators - Gets the matrix associated with the linear system and
    possibly a different one associated with the preconditioner.
 
-   Not collective, though parallel mats are returned if pc is parallel
+   Not Collective, though parallel mats are returned if pc is parallel
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -1285,7 +1285,7 @@ PetscErrorCode PCGetReusePreconditioner(PC pc, PetscBool *flag)
 .ve
 
     The rationale for this support is so that when creating a `TS`, `SNES`, or `KSP` the hierarchy
-    of underlying objects (i.e. `SNES`, `KSP`, `PC`, `Mat`) and their livespans can be completely
+    of underlying objects (i.e. `SNES`, `KSP`, `PC`, `Mat`) and their lifespans can be completely
     managed by the top most level object (i.e. the `TS`, `SNES`, or `KSP`). Another way to look
     at this is when you create a `SNES` you do not NEED to create a `KSP` and attach it to
     the `SNES` object (the `SNES` object manages it for you). Similarly when you create a KSP
@@ -1301,7 +1301,7 @@ PetscErrorCode PCGetOperators(PC pc, Mat *Amat, Mat *Pmat)
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   if (Amat) {
     if (!pc->mat) {
-      if (pc->pmat && !Pmat) { /* Apmat has been set, but user did not request it, so use for Amat */
+      if (pc->pmat && !Pmat) { /* Pmat has been set, but user did not request it, so use for Amat */
         pc->mat = pc->pmat;
         PetscCall(PetscObjectReference((PetscObject)pc->mat));
       } else { /* both Amat and Pmat are empty */
@@ -1329,14 +1329,14 @@ PetscErrorCode PCGetOperators(PC pc, Mat *Amat, Mat *Pmat)
     }
     *Pmat = pc->pmat;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PCGetOperatorsSet - Determines if the matrix associated with the linear system and
    possibly a different one associated with the preconditioner have been set in the `PC`.
 
-   Not collective, though the results on all processes should be the same
+   Not Collective, though the results on all processes should be the same
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -1355,7 +1355,7 @@ PetscErrorCode PCGetOperatorsSet(PC pc, PetscBool *mat, PetscBool *pmat)
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   if (mat) *mat = (pc->mat) ? PETSC_TRUE : PETSC_FALSE;
   if (pmat) *pmat = (pc->pmat) ? PETSC_TRUE : PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1363,7 +1363,7 @@ PetscErrorCode PCGetOperatorsSet(PC pc, PetscBool *mat, PetscBool *pmat)
    preconditioner context.  This routine is valid only for the `PCLU`,
    `PCILU`, `PCCHOLESKY`, and `PCICC` methods.
 
-   Not Collective on pc though mat is parallel if pc is parallel
+   Not Collective though mat is parallel if pc is parallel
 
    Input Parameter:
 .  pc - the preconditioner context
@@ -1384,14 +1384,14 @@ PetscErrorCode PCFactorGetMatrix(PC pc, Mat *mat)
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscValidPointer(mat, 2);
   PetscUseTypeMethod(pc, getfactoredmatrix, mat);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PCSetOptionsPrefix - Sets the prefix used for searching for all
    `PC` options in the database.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1411,14 +1411,14 @@ PetscErrorCode PCSetOptionsPrefix(PC pc, const char prefix[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)pc, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PCAppendOptionsPrefix - Appends to the prefix used for searching for all
    `PC` options in the database.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1438,7 +1438,7 @@ PetscErrorCode PCAppendOptionsPrefix(PC pc, const char prefix[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)pc, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1467,7 +1467,7 @@ PetscErrorCode PCGetOptionsPrefix(PC pc, const char *prefix[])
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscValidPointer(prefix, 2);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)pc, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -1479,10 +1479,10 @@ PETSC_INTERN PetscErrorCode PCPreSolveChangeRHS(PC pc, PetscBool *change)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
-  PetscValidPointer(change, 2);
+  PetscValidBoolPointer(change, 2);
   *change = PETSC_FALSE;
   PetscTryMethod(pc, "PCPreSolveChangeRHS_C", (PC, PetscBool *), (pc, change));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1490,7 +1490,7 @@ PETSC_INTERN PetscErrorCode PCPreSolveChangeRHS(PC pc, PetscBool *change)
    preconditioner-specific actions that must be performed before
    the iterative solve itself.
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1526,7 +1526,7 @@ PetscErrorCode PCPreSolve(PC pc, KSP ksp)
 
   if (pc->ops->presolve) PetscUseTypeMethod(pc, presolve, ksp, rhs, x);
   else if (pc->presolve) PetscCall((pc->presolve)(pc, ksp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1534,17 +1534,16 @@ PetscErrorCode PCPreSolve(PC pc, KSP ksp)
    preconditioner-specific actions that must be performed before
    the iterative solve itself.
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameters:
 +   pc - the preconditioner object
 -   presolve - the function to call before the solve
 
-   Calling sequence of presolve:
-$  func(PC pc,KSP ksp)
-
-+  pc - the PC context
--  ksp - the KSP context
+   Calling sequence of `presolve`:
+$  PetscErrorCode presolve(PC pc, KSP ksp)
++  pc - the `PC` context
+-  ksp - the `KSP` context
 
    Level: developer
 
@@ -1555,7 +1554,7 @@ PetscErrorCode PCSetPreSolve(PC pc, PetscErrorCode (*presolve)(PC, KSP))
   PetscFunctionBegin;
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   pc->presolve = presolve;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1563,7 +1562,7 @@ PetscErrorCode PCSetPreSolve(PC pc, PetscErrorCode (*presolve)(PC, KSP))
    preconditioner-specific actions that must be performed after
    the iterative solve itself.
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the preconditioner context
@@ -1594,13 +1593,13 @@ PetscErrorCode PCPostSolve(PC pc, KSP ksp)
   PetscCall(KSPGetSolution(ksp, &x));
   PetscCall(KSPGetRhs(ksp, &rhs));
   PetscTryTypeMethod(pc, postsolve, ksp, rhs, x);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   PCLoad - Loads a `PC` that has been stored in binary  with `PCView()`.
 
-  Collective on newdm
+  Collective
 
   Input Parameters:
 + newdm - the newly loaded `PC`, this needs to have been created with `PCCreate()` or
@@ -1631,7 +1630,7 @@ PetscErrorCode PCLoad(PC newdm, PetscViewer viewer)
   PetscCall(PetscViewerBinaryRead(viewer, type, 256, NULL, PETSC_CHAR));
   PetscCall(PCSetType(newdm, type));
   PetscTryTypeMethod(newdm, load, viewer);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #include <petscdraw.h>
@@ -1642,10 +1641,10 @@ PetscErrorCode PCLoad(PC newdm, PetscViewer viewer)
 /*@C
    PCViewFromOptions - View from the `PC` based on options in the database
 
-   Collective on pc
+   Collective
 
    Input Parameters:
-+  A - the PC context
++  A - the `PC` context
 .  obj - Optional object that provides the options prefix
 -  name - command line option
 
@@ -1658,18 +1657,20 @@ PetscErrorCode PCViewFromOptions(PC A, PetscObject obj, const char name[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A, PC_CLASSID, 1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)A, obj, name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PCView - Prints information about the `PC`
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  PC - the `PC` context
 -  viewer - optional visualization context
 
+   Level: developer
+
    Notes:
    The available visualization contexts include
 +     `PETSC_VIEWER_STDOUT_SELF` - standard output (default)
@@ -1681,8 +1682,6 @@ PetscErrorCode PCViewFromOptions(PC A, PetscObject obj, const char name[])
    The user can open an alternative visualization contexts with
    `PetscViewerASCIIOpen()` (output to a specified file).
 
-   Level: developer
-
 .seealso: `PC`, `PetscViewer`, `KSPView()`, `PetscViewerASCIIOpen()`
 @*/
 PetscErrorCode PCView(PC pc, PetscViewer viewer)
@@ -1783,7 +1782,7 @@ PetscErrorCode PCView(PC pc, PetscViewer viewer)
     if (pc->pmat && pc->pmat != pc->mat) PetscCall(MatView(pc->pmat, viewer));
 #endif
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1792,11 +1791,8 @@ PetscErrorCode PCView(PC pc, PetscViewer viewer)
    Not collective
 
    Input Parameters:
-+  name_solver - name of a new user-defined solver
--  routine_create - routine to create method context
-
-   Note:
-   `PCRegister()` may be called multiple times to add several user-defined preconditioners.
++  sname - name of a new user-defined solver
+-  function - routine to create method context
 
    Sample usage:
 .vb
@@ -1810,6 +1806,9 @@ $     -pc_type my_solver
 
    Level: advanced
 
+   Note:
+   `PCRegister()` may be called multiple times to add several user-defined preconditioners.
+
 .seealso: `PC`, `PCType`, `PCRegisterAll()`
 @*/
 PetscErrorCode PCRegister(const char sname[], PetscErrorCode (*function)(PC))
@@ -1817,7 +1816,7 @@ PetscErrorCode PCRegister(const char sname[], PetscErrorCode (*function)(PC))
   PetscFunctionBegin;
   PetscCall(PCInitializePackage());
   PetscCall(PetscFunctionListAdd(&PCList, sname, function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMult_PC(Mat A, Vec X, Vec Y)
@@ -1827,13 +1826,13 @@ static PetscErrorCode MatMult_PC(Mat A, Vec X, Vec Y)
   PetscFunctionBegin;
   PetscCall(MatShellGetContext(A, &pc));
   PetscCall(PCApply(pc, X, Y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     PCComputeOperator - Computes the explicit preconditioned operator.
 
-    Collective on pc
+    Collective
 
     Input Parameters:
 +   pc - the preconditioner object
@@ -1842,15 +1841,14 @@ static PetscErrorCode MatMult_PC(Mat A, Vec X, Vec Y)
     Output Parameter:
 .   mat - the explicit preconditioned operator
 
+    Level: advanced
+
     Note:
     This computation is done by applying the operators to columns of the identity matrix.
     This routine is costly in general, and is recommended for use only with relatively small systems.
     Currently, this routine uses a dense matrix format when mattype == NULL
 
-    Level: advanced
-
 .seealso: `PC`, `KSPComputeOperator()`, `MatType`
-
 @*/
 PetscErrorCode PCComputeOperator(PC pc, MatType mattype, Mat *mat)
 {
@@ -1867,13 +1865,13 @@ PetscErrorCode PCComputeOperator(PC pc, MatType mattype, Mat *mat)
   PetscCall(MatShellSetOperation(Apc, MATOP_MULT, (void (*)(void))MatMult_PC));
   PetscCall(MatComputeOperator(Apc, mattype, mat));
   PetscCall(MatDestroy(&Apc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCSetCoordinates - sets the coordinates of all the nodes on the local process
 
-   Collective on pc
+   Collective
 
    Input Parameters:
 +  pc - the solver context
@@ -1884,8 +1882,8 @@ PetscErrorCode PCComputeOperator(PC pc, MatType mattype, Mat *mat)
    Level: intermediate
 
    Note:
-   coords is an array of the dim coordinates for the nodes on
-   the local processor, of size dim*nloc.
+   `coords` is an array of the dim coordinates for the nodes on
+   the local processor, of size `dim`*`nloc`.
    If there are 108 equation on a processor
    for a displacement finite element discretization of elasticity (so
    that there are nloc = 36 = 108/3 nodes) then the array must have 108
@@ -1901,13 +1899,13 @@ PetscErrorCode PCSetCoordinates(PC pc, PetscInt dim, PetscInt nloc, PetscReal co
   PetscValidHeaderSpecific(pc, PC_CLASSID, 1);
   PetscValidLogicalCollectiveInt(pc, dim, 2);
   PetscTryMethod(pc, "PCSetCoordinates_C", (PC, PetscInt, PetscInt, PetscReal *), (pc, dim, nloc, coords));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGetInterpolations - Gets interpolation matrices for all levels (except level 0)
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameter:
 .  pc - the precondition context
@@ -1930,13 +1928,13 @@ PetscErrorCode PCGetInterpolations(PC pc, PetscInt *num_levels, Mat *interpolati
   PetscValidIntPointer(num_levels, 2);
   PetscValidPointer(interpolations, 3);
   PetscUseMethod(pc, "PCGetInterpolations_C", (PC, PetscInt *, Mat *[]), (pc, num_levels, interpolations));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PCGetCoarseOperators - Gets coarse operator matrices for all levels (except the finest level)
 
-   Logically Collective on pc
+   Logically Collective
 
    Input Parameter:
 .  pc - the precondition context
@@ -1959,5 +1957,5 @@ PetscErrorCode PCGetCoarseOperators(PC pc, PetscInt *num_levels, Mat *coarseOper
   PetscValidIntPointer(num_levels, 2);
   PetscValidPointer(coarseOperators, 3);
   PetscUseMethod(pc, "PCGetCoarseOperators_C", (PC, PetscInt *, Mat *[]), (pc, num_levels, coarseOperators));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
