@@ -32,15 +32,15 @@ PetscErrorCode MatColoringRegister(const char sname[], PetscErrorCode (*function
   PetscFunctionBegin;
   PetscCall(MatInitializePackage());
   PetscCall(PetscFunctionListAdd(&MatColoringList, sname, function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatColoringCreate - Creates a matrix coloring context.
 
-   Collective on m
+   Collective
 
-   Input Parameters:
+   Input Parameter:
 .  comm - MPI communicator
 
    Output Parameter:
@@ -59,7 +59,7 @@ PetscErrorCode MatColoringRegister(const char sname[], PetscErrorCode (*function
    Notes:
    A distance one coloring is useful, for example, multi-color SOR.
 
-   A distance two coloring is for the finite difference computation of Jacobians (see `MatFDColoringCreate())`.
+   A distance two coloring is for the finite difference computation of Jacobians (see `MatFDColoringCreate()`).
 
    Coloring of matrices can be computed directly from the sparse matrix nonzero structure via the `MatColoring` object or from the mesh from which the
    matrix comes from with `DMCreateColoring()`. In general using the mesh produces a more optimal coloring (fewer colors).
@@ -88,13 +88,13 @@ PetscErrorCode MatColoringCreate(Mat m, MatColoring *mcptr)
   mc->weight_type  = MAT_COLORING_WEIGHT_RANDOM;
   mc->user_weights = NULL;
   mc->user_lperm   = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatColoringDestroy - Destroys the matrix coloring context
 
-   Collective on mc
+   Collective
 
    Input Parameter:
 .  mc - the `MatColoring` context
@@ -108,20 +108,20 @@ PetscErrorCode MatColoringDestroy(MatColoring *mc)
   PetscFunctionBegin;
   if (--((PetscObject)(*mc))->refct > 0) {
     *mc = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCall(MatDestroy(&(*mc)->mat));
   if ((*mc)->ops->destroy) PetscCall((*((*mc)->ops->destroy))(*mc));
   if ((*mc)->user_weights) PetscCall(PetscFree((*mc)->user_weights));
   if ((*mc)->user_lperm) PetscCall(PetscFree((*mc)->user_lperm));
   PetscCall(PetscHeaderDestroy(mc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatColoringSetType - Sets the type of coloring algorithm used
 
-   Collective on type
+   Collective
 
    Input Parameters:
 +  mc - the `MatColoring` context
@@ -148,7 +148,7 @@ PetscErrorCode MatColoringSetType(MatColoring mc, MatColoringType type)
   PetscValidHeaderSpecific(mc, MAT_COLORING_CLASSID, 1);
   PetscValidCharPointer(type, 2);
   PetscCall(PetscObjectTypeCompare((PetscObject)mc, type, &match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscFunctionListFind(MatColoringList, type, &r));
   PetscCheck(r, PETSC_COMM_SELF, PETSC_ERR_ARG_UNKNOWN_TYPE, "Unable to find requested MatColoring type %s", type);
   if (mc->ops->destroy) {
@@ -162,13 +162,13 @@ PetscErrorCode MatColoringSetType(MatColoring mc, MatColoringType type)
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)mc, type));
   PetscCall((*r)(mc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatColoringSetFromOptions - Sets `MatColoring` options from options database
 
-   Collective on mc
+   Collective
 
    Input Parameter:
 .  mc - `MatColoring` context
@@ -217,13 +217,13 @@ PetscErrorCode MatColoringSetFromOptions(MatColoring mc)
   PetscCall(PetscOptionsEnum("-mat_coloring_weight_type", "Sets the type of vertex weighting used", "MatColoringSetWeightType", MatColoringWeightTypes, (PetscEnum)mc->weight_type, (PetscEnum *)&mc->weight_type, NULL));
   PetscCall(PetscObjectProcessOptionsHandlers((PetscObject)mc, PetscOptionsObject));
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatColoringSetDistance - Sets the distance of the coloring
 
-   Logically Collective on dist
+   Logically Collective
 
    Input Parameters:
 +  mc - the `MatColoring` context
@@ -248,13 +248,13 @@ PetscErrorCode MatColoringSetDistance(MatColoring mc, PetscInt dist)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mc, MAT_COLORING_CLASSID, 1);
   mc->dist = dist;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatColoringGetDistance - Gets the distance of the coloring
 
-   Logically Collective on mc
+   Logically Collective
 
    Input Parameter:
 .  mc - the `MatColoring` context
@@ -278,13 +278,13 @@ PetscErrorCode MatColoringGetDistance(MatColoring mc, PetscInt *dist)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mc, MAT_COLORING_CLASSID, 1);
   if (dist) *dist = mc->dist;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatColoringSetMaxColors - Sets the maximum number of colors to produce
 
-   Logically Collective on mc
+   Logically Collective
 
    Input Parameters:
 +  mc - the `MatColoring` context
@@ -309,13 +309,13 @@ PetscErrorCode MatColoringSetMaxColors(MatColoring mc, PetscInt maxcolors)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mc, MAT_COLORING_CLASSID, 1);
   mc->maxcolors = maxcolors;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatColoringGetMaxColors - Gets the maximum number of colors
 
-   Logically Collective on mc
+   Logically Collective
 
    Input Parameter:
 .  mc - the `MatColoring` context
@@ -332,7 +332,7 @@ PetscErrorCode MatColoringGetMaxColors(MatColoring mc, PetscInt *maxcolors)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mc, MAT_COLORING_CLASSID, 1);
   if (maxcolors) *maxcolors = mc->maxcolors;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -340,9 +340,9 @@ PetscErrorCode MatColoringGetMaxColors(MatColoring mc, PetscInt *maxcolors)
    sets corresponding to a number of independent sets in the induced
    graph.
 
-   Collective on mc
+   Collective
 
-   Input Parameters:
+   Input Parameter:
 .  mc - the `MatColoring` context
 
    Output Parameter:
@@ -383,13 +383,13 @@ PetscErrorCode MatColoringApply(MatColoring mc, ISColoring *coloring)
     PetscCall(PetscViewerPopFormat(viewer));
     PetscCall(PetscViewerDestroy(&viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatColoringView - Output details about the `MatColoring`.
 
-   Collective on mc
+   Collective
 
    Input Parameters:
 -  mc - the `MatColoring` context
@@ -419,13 +419,13 @@ PetscErrorCode MatColoringView(MatColoring mc, PetscViewer viewer)
       PetscCall(PetscViewerASCIIPrintf(viewer, "  Distance %" PetscInt_FMT "\n", mc->dist));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatColoringSetWeightType - Set the type of weight computation used while computing the coloring
 
-   Logically collective on MatColoring
+   Logically Collective
 
    Input Parameters:
 -  mc - the `MatColoring` context
@@ -439,5 +439,5 @@ PetscErrorCode MatColoringSetWeightType(MatColoring mc, MatColoringWeightType wt
 {
   PetscFunctionBegin;
   mc->weight_type = wt;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
