@@ -11,59 +11,59 @@
   output:
 .   cliq - Clique context
 */
-PetscErrorCode MatConvertToSparseElemental(Mat A,MatReuse reuse,Mat_SparseElemental *cliq)
+PetscErrorCode MatConvertToSparseElemental(Mat, MatReuse, Mat_SparseElemental *)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatView_SparseElemental(Mat A,PetscViewer viewer)
+PetscErrorCode MatView_SparseElemental(Mat A, PetscViewer viewer)
 {
   PetscBool iascii;
 
   PetscFunctionBegin;
-  PetscCall(PetscObjectTypeCompare((PetscObject)viewer,PETSCVIEWERASCII,&iascii));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
   if (iascii) {
     PetscViewerFormat format;
-    PetscCall(PetscViewerGetFormat(viewer,&format));
+    PetscCall(PetscViewerGetFormat(viewer, &format));
     if (format == PETSC_VIEWER_ASCII_INFO) {
-      PetscCall(PetscViewerASCIIPrintf(viewer,"SparseElemental run parameters:\n"));
+      PetscCall(PetscViewerASCIIPrintf(viewer, "SparseElemental run parameters:\n"));
     } else if (format == PETSC_VIEWER_DEFAULT) { /* matrix A is factored matrix, remove this block */
       Mat Aaij;
-      PetscCall(PetscViewerASCIIUseTabs(viewer,PETSC_FALSE));
-      PetscCall(PetscViewerASCIIUseTabs(viewer,PETSC_TRUE));
-      PetscCall(PetscPrintf(PetscObjectComm((PetscObject)viewer),"SparseElemental matrix\n"));
-      PetscCall(MatComputeOperator(A,MATAIJ,&Aaij));
-      PetscCall(MatView(Aaij,viewer));
+      PetscCall(PetscViewerASCIIUseTabs(viewer, PETSC_FALSE));
+      PetscCall(PetscViewerASCIIUseTabs(viewer, PETSC_TRUE));
+      PetscCall(PetscPrintf(PetscObjectComm((PetscObject)viewer), "SparseElemental matrix\n"));
+      PetscCall(MatComputeOperator(A, MATAIJ, &Aaij));
+      PetscCall(MatView(Aaij, viewer));
       PetscCall(MatDestroy(&Aaij));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDestroy_SparseElemental(Mat A)
 {
   PetscFunctionBegin;
-  PetscCall(PetscObjectComposeFunction((PetscObject)A,"MatFactorGetSolverType_C",NULL));
-  PetscFunctionReturn(0);
+  PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatFactorGetSolverType_C", nullptr));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatSolve_SparseElemental(Mat A,Vec B,Vec X)
+PetscErrorCode MatSolve_SparseElemental(Mat, Vec, Vec)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatCholeskyFactorNumeric_SparseElemental(Mat F,Mat A,const MatFactorInfo *info)
+PetscErrorCode MatCholeskyFactorNumeric_SparseElemental(Mat, Mat, const MatFactorInfo *)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatCholeskyFactorSymbolic_SparseElemental(Mat F,Mat A,IS r,const MatFactorInfo *info)
+PetscErrorCode MatCholeskyFactorSymbolic_SparseElemental(Mat, Mat, IS, const MatFactorInfo *)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -76,33 +76,33 @@ PetscErrorCode MatCholeskyFactorSymbolic_SparseElemental(Mat F,Mat A,IS r,const
 
   This is currently not supported.
 
-  Developer Note: Jed Brown made the interface for Clique when it was a standalone package. Later Jack Poulson merged and refactored Clique into
+  Developer Note:
+  Jed Brown made the interface for Clique when it was a standalone package. Later Jack Poulson merged and refactored Clique into
   Elemental but since the Clique interface was not tested in PETSc the interface was not updated for the new Elemental interface. Later Barry Smith updated
   all the boilerplate for the Clique interface to SparseElemental but since the solver interface changed dramatically he did not update the code
   that actually calls the SparseElemental solvers. We are waiting on someone who has a need to complete the SparseElemental interface from PETSc.
 
   Level: beginner
 
-.seealso: PCFactorSetMatSolverType(), MatSolverType
-
+.seealso: [](chapter_matrices), `Mat`, `PCFactorSetMatSolverType()`, `MatSolverType`
 M*/
 
-PetscErrorCode MatFactorGetSolverType_SparseElemental(Mat A,MatSolverType *type)
+PetscErrorCode MatFactorGetSolverType_SparseElemental(Mat, MatSolverType *type)
 {
   PetscFunctionBegin;
   *type = MATSOLVERSPARSEELEMENTAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-static PetscErrorCode MatGetFactor_aij_sparseelemental(Mat A,MatFactorType ftype,Mat *F)
+static PetscErrorCode MatGetFactor_aij_sparseelemental(Mat, MatFactorType, Mat *)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_EXTERN PetscErrorCode MatSolverTypeRegister_SparseElemental(void)
 {
   PetscFunctionBegin;
-  PetscCall(MatSolverTypeRegister(MATSOLVERSPARSEELEMENTAL,MATMPIAIJ,MAT_FACTOR_LU,MatGetFactor_aij_sparseelemental));
-  PetscFunctionReturn(0);
+  PetscCall(MatSolverTypeRegister(MATSOLVERSPARSEELEMENTAL, MATMPIAIJ, MAT_FACTOR_LU, MatGetFactor_aij_sparseelemental));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
