@@ -150,7 +150,7 @@ PetscErrorCode MatFDColoringApply_BAIJ(Mat J, MatFDColoring coloring, Vec x1, vo
 
   coloring->currentcolor = -1;
   PetscCall(VecBindToCPU(x1, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* this is declared PETSC_EXTERN because it is used by MatFDColoringUseDM() which is in the DM library */
@@ -211,7 +211,7 @@ PetscErrorCode MatFDColoringApply_AIJ(Mat J, MatFDColoring coloring, Vec x1, voi
   }
 
   /* (3) Loop over each color */
-  if (!coloring->w3) { PetscCall(VecDuplicate(x1, &coloring->w3)); }
+  if (!coloring->w3) PetscCall(VecDuplicate(x1, &coloring->w3));
   w3 = coloring->w3;
 
   PetscCall(VecGetOwnershipRange(x1, &cstart, &cend)); /* used by ghosted vscale */
@@ -374,7 +374,7 @@ PetscErrorCode MatFDColoringApply_AIJ(Mat J, MatFDColoring coloring, Vec x1, voi
   if (vscale) PetscCall(VecRestoreArray(vscale, &vscale_array));
   coloring->currentcolor = -1;
   if (!alreadyboundtocpu) PetscCall(VecBindToCPU(x1, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatFDColoringSetUp_MPIXAIJ(Mat mat, ISColoring iscoloring, MatFDColoring c)
@@ -392,7 +392,7 @@ PetscErrorCode MatFDColoringSetUp_MPIXAIJ(Mat mat, ISColoring iscoloring, MatFDC
   PetscBool              isBAIJ, isSELL;
   PetscInt               bcols = c->bcols;
 #if defined(PETSC_USE_CTABLE)
-  PetscTable colmap = NULL;
+  PetscHMapI colmap = NULL;
 #else
   PetscInt *colmap = NULL;      /* local col number of off-diag col */
 #endif
@@ -560,7 +560,7 @@ PetscErrorCode MatFDColoringSetUp_MPIXAIJ(Mat mat, ISColoring iscoloring, MatFDC
         }
       } else { /* column is in B, off-diagonal block of mat */
 #if defined(PETSC_USE_CTABLE)
-        PetscCall(PetscTableFind(colmap, col + 1, &colb));
+        PetscCall(PetscHMapIGetWithDefault(colmap, col + 1, 0, &colb));
         colb--;
 #else
         colb = colmap[col] - 1; /* local column index */
@@ -628,7 +628,7 @@ PetscErrorCode MatFDColoringSetUp_MPIXAIJ(Mat mat, ISColoring iscoloring, MatFDC
 
   if (ctype == IS_COLORING_LOCAL) PetscCall(ISLocalToGlobalMappingRestoreIndices(map, &ltog));
   PetscCall(PetscInfo(c, "ncolors %" PetscInt_FMT ", brows %" PetscInt_FMT " and bcols %" PetscInt_FMT " are used.\n", c->ncolors, c->brows, c->bcols));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatFDColoringCreate_MPIXAIJ(Mat mat, ISColoring iscoloring, MatFDColoring c)
@@ -696,28 +696,29 @@ PetscErrorCode MatFDColoringCreate_MPIXAIJ(Mat mat, ISColoring iscoloring, MatFD
   c->m       = mat->rmap->n / bs;
   c->rstart  = mat->rmap->rstart / bs;
   c->ncolors = nis;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
 
     MatFDColoringSetValues - takes a matrix in compressed color format and enters the matrix into a PETSc `Mat`
 
-   Collective on J
+   Collective
 
    Input Parameters:
 +    J - the sparse matrix
 .    coloring - created with `MatFDColoringCreate()` and a local coloring
 -    y - column major storage of matrix values with one color of values per column, the number of rows of y should match
-         the number of local rows of J and the number of columns is the number of colors.
+         the number of local rows of `J` and the number of columns is the number of colors.
 
    Level: intermediate
 
-   Notes: the matrix in compressed color format may come from an automatic differentiation code
+   Notes:
+   The matrix in compressed color format may come from an automatic differentiation code
 
    The code will be slightly faster if `MatFDColoringSetBlockSize`(coloring,`PETSC_DEFAULT`,nc); is called immediately after creating the coloring
 
-.seealso: `MatFDColoringCreate()`, `ISColoring`, `ISColoringCreate()`, `ISColoringSetType()`, `IS_COLORING_LOCAL`, `MatFDColoringSetBlockSize()`
+.seealso: [](chapter_matrices), `Mat`, `MatFDColoringCreate()`, `ISColoring`, `ISColoringCreate()`, `ISColoringSetType()`, `IS_COLORING_LOCAL`, `MatFDColoringSetBlockSize()`
 @*/
 PetscErrorCode MatFDColoringSetValues(Mat J, MatFDColoring coloring, const PetscScalar *y)
 {
@@ -746,5 +747,5 @@ PetscErrorCode MatFDColoringSetValues(Mat J, MatFDColoring coloring, const Petsc
   }
   PetscCall(MatAssemblyBegin(J, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(J, MAT_FINAL_ASSEMBLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
