@@ -6,24 +6,17 @@ static PetscErrorCode MatGetDiagonal_STRUMPACK(Mat A, Vec v)
 {
   PetscFunctionBegin;
   SETERRQ(PetscObjectComm((PetscObject)A), PETSC_ERR_SUP, "Mat type: STRUMPACK factor");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatDestroy_STRUMPACK(Mat A)
 {
-  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)A->spptr;
-  PetscBool               flg;
+  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)A->data;
 
   PetscFunctionBegin;
   /* Deallocate STRUMPACK storage */
   PetscStackCallExternalVoid("STRUMPACK_destroy", STRUMPACK_destroy(S));
-  PetscCall(PetscFree(A->spptr));
-  PetscCall(PetscObjectTypeCompare((PetscObject)A, MATSEQAIJ, &flg));
-  if (flg) {
-    PetscCall(MatDestroy_SeqAIJ(A));
-  } else {
-    PetscCall(MatDestroy_MPIAIJ(A));
-  }
+  PetscCall(PetscFree(A->data));
 
   /* clear composed functions */
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatFactorGetSolverType_C", NULL));
@@ -35,35 +28,35 @@ static PetscErrorCode MatDestroy_STRUMPACK(Mat A)
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatSTRUMPACKSetHSSLeafSize_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatSTRUMPACKSetHSSMinSepSize_C", NULL));
 
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatSTRUMPACKSetReordering_STRUMPACK(Mat F, MatSTRUMPACKReordering reordering)
 {
-  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->spptr;
+  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->data;
 
   PetscFunctionBegin;
   PetscStackCallExternalVoid("STRUMPACK_reordering_method", STRUMPACK_set_reordering_method(*S, (STRUMPACK_REORDERING_STRATEGY)reordering));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   MatSTRUMPACKSetReordering - Set STRUMPACK fill-reducing reordering
 
    Input Parameters:
-+  F - the factored matrix obtained by calling `MatGetFactor(`) from PETSc-STRUMPACK interface
--  reordering - the code to be used to find the fill-reducing reordering
-      Possible values: NATURAL=0 METIS=1 PARMETIS=2 SCOTCH=3 PTSCOTCH=4 RCM=5
++  F - the factored matrix obtained by calling `MatGetFactor()`
+-  reordering - the code to be used to find the fill-reducing reordering, see `MatSTRUMPACKReordering`
 
   Options Database Key:
-.   -mat_strumpack_reordering <METIS>  - Sparsity reducing matrix reordering (choose one of) NATURAL METIS PARMETIS SCOTCH PTSCOTCH RCM (None)
+.   -mat_strumpack_reordering <METIS>  - Sparsity reducing matrix reordering, see `MatSTRUMPACKReordering`
 
    Level: beginner
 
    References:
 .  * - STRUMPACK manual
 
-.seealso: `MatGetFactor()`
+.seealso: [](chapter_matrices), `Mat`, `MatSTRUMPACKReordering`, `MatGetFactor()`, `MatSTRUMPACKSetColPerm()`, `MatSTRUMPACKSetHSSRelTol()`,
+          `MatSTRUMPACKSetHSSAbsTol()`, `MatSTRUMPACKSetHSSMaxRank()`, `MatSTRUMPACKSetHSSLeafSize()`, `MatSTRUMPACKSetHSSMinSepSize()`
 @*/
 PetscErrorCode MatSTRUMPACKSetReordering(Mat F, MatSTRUMPACKReordering reordering)
 {
@@ -71,25 +64,25 @@ PetscErrorCode MatSTRUMPACKSetReordering(Mat F, MatSTRUMPACKReordering reorderin
   PetscValidHeaderSpecific(F, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveEnum(F, reordering, 2);
   PetscTryMethod(F, "MatSTRUMPACKSetReordering_C", (Mat, MatSTRUMPACKReordering), (F, reordering));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatSTRUMPACKSetColPerm_STRUMPACK(Mat F, PetscBool cperm)
 {
-  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->spptr;
+  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->data;
 
   PetscFunctionBegin;
   PetscStackCallExternalVoid("STRUMPACK_set_mc64job", STRUMPACK_set_mc64job(*S, cperm ? 5 : 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   MatSTRUMPACKSetColPerm - Set whether STRUMPACK should try to permute the columns of the matrix in order to get a nonzero diagonal
 
-   Logically Collective on F
+   Logically Collective
 
    Input Parameters:
-+  F - the factored matrix obtained by calling `MatGetFactor()` from PETSc-STRUMPACK interface
++  F - the factored matrix obtained by calling `MatGetFactor()`
 -  cperm - `PETSC_TRUE` to permute (internally) the columns of the matrix
 
   Options Database Key:
@@ -100,7 +93,8 @@ static PetscErrorCode MatSTRUMPACKSetColPerm_STRUMPACK(Mat F, PetscBool cperm)
    References:
 .  * - STRUMPACK manual
 
-.seealso: `MatGetFactor()`
+.seealso: [](chapter_matrices), `MatSTRUMPACKSetReordering()`, `Mat`, `MatGetFactor()`, `MatSTRUMPACKSetHSSRelTol()`, `MatSTRUMPACKSetHSSAbsTol()`,
+          `MatSTRUMPACKSetHSSMaxRank()`, `MatSTRUMPACKSetHSSLeafSize()`, `MatSTRUMPACKSetHSSMinSepSize()`
 @*/
 PetscErrorCode MatSTRUMPACKSetColPerm(Mat F, PetscBool cperm)
 {
@@ -108,25 +102,25 @@ PetscErrorCode MatSTRUMPACKSetColPerm(Mat F, PetscBool cperm)
   PetscValidHeaderSpecific(F, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveBool(F, cperm, 2);
   PetscTryMethod(F, "MatSTRUMPACKSetColPerm_C", (Mat, PetscBool), (F, cperm));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatSTRUMPACKSetHSSRelTol_STRUMPACK(Mat F, PetscReal rtol)
 {
-  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->spptr;
+  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->data;
 
   PetscFunctionBegin;
   PetscStackCallExternalVoid("STRUMPACK_set_HSS_rel_tol", STRUMPACK_set_HSS_rel_tol(*S, rtol));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   MatSTRUMPACKSetHSSRelTol - Set STRUMPACK relative tolerance for HSS compression
 
-  Logically Collective on F
+  Logically Collective
 
    Input Parameters:
-+  F - the factored matrix obtained by calling `MatGetFactor()` from PETSc-STRUMPACK interface
++  F - the factored matrix obtained by calling `MatGetFactor()`
 -  rtol - relative compression tolerance
 
   Options Database Key:
@@ -137,7 +131,8 @@ static PetscErrorCode MatSTRUMPACKSetHSSRelTol_STRUMPACK(Mat F, PetscReal rtol)
    References:
 .  * - STRUMPACK manual
 
-.seealso: `MatGetFactor()`
+.seealso: [](chapter_matrices), `Mat`, `MatGetFactor()`, `MatSTRUMPACKSetReordering()`, `MatSTRUMPACKSetColPerm()`, `MatSTRUMPACKSetHSSAbsTol()`,
+          `MatSTRUMPACKSetHSSMaxRank()`, `MatSTRUMPACKSetHSSLeafSize()`, `MatSTRUMPACKSetHSSMinSepSize()`
 @*/
 PetscErrorCode MatSTRUMPACKSetHSSRelTol(Mat F, PetscReal rtol)
 {
@@ -145,25 +140,25 @@ PetscErrorCode MatSTRUMPACKSetHSSRelTol(Mat F, PetscReal rtol)
   PetscValidHeaderSpecific(F, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveReal(F, rtol, 2);
   PetscTryMethod(F, "MatSTRUMPACKSetHSSRelTol_C", (Mat, PetscReal), (F, rtol));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatSTRUMPACKSetHSSAbsTol_STRUMPACK(Mat F, PetscReal atol)
 {
-  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->spptr;
+  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->data;
 
   PetscFunctionBegin;
   PetscStackCallExternalVoid("STRUMPACK_set_HSS_abs_tol", STRUMPACK_set_HSS_abs_tol(*S, atol));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   MatSTRUMPACKSetHSSAbsTol - Set STRUMPACK absolute tolerance for HSS compression
 
-   Logically Collective on F
+   Logically Collective
 
    Input Parameters:
-+  F - the factored matrix obtained by calling `MatGetFactor()` from PETSc-STRUMPACK interface
++  F - the factored matrix obtained by calling `MatGetFactor()`
 -  atol - absolute compression tolerance
 
   Options Database Key:
@@ -174,7 +169,8 @@ static PetscErrorCode MatSTRUMPACKSetHSSAbsTol_STRUMPACK(Mat F, PetscReal atol)
    References:
 .  * - STRUMPACK manual
 
-.seealso: `MatGetFactor()`
+.seealso: [](chapter_matrices), `Mat`, `MatGetFactor()`, `MatSTRUMPACKSetReordering()`, `MatSTRUMPACKSetColPerm()`, `MatSTRUMPACKSetHSSRelTol()`,
+          `MatSTRUMPACKSetHSSMaxRank()`, `MatSTRUMPACKSetHSSLeafSize()`, `MatSTRUMPACKSetHSSMinSepSize()`
 @*/
 PetscErrorCode MatSTRUMPACKSetHSSAbsTol(Mat F, PetscReal atol)
 {
@@ -182,25 +178,25 @@ PetscErrorCode MatSTRUMPACKSetHSSAbsTol(Mat F, PetscReal atol)
   PetscValidHeaderSpecific(F, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveReal(F, atol, 2);
   PetscTryMethod(F, "MatSTRUMPACKSetHSSAbsTol_C", (Mat, PetscReal), (F, atol));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatSTRUMPACKSetHSSMaxRank_STRUMPACK(Mat F, PetscInt hssmaxrank)
 {
-  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->spptr;
+  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->data;
 
   PetscFunctionBegin;
   PetscStackCallExternalVoid("STRUMPACK_set_HSS_max_rank", STRUMPACK_set_HSS_max_rank(*S, hssmaxrank));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   MatSTRUMPACKSetHSSMaxRank - Set STRUMPACK maximum HSS rank
 
-   Logically Collective on F
+   Logically Collective
 
    Input Parameters:
-+  F - the factored matrix obtained by calling `MatGetFactor()` from PETSc-STRUMPACK interface
++  F - the factored matrix obtained by calling `MatGetFactor()`
 -  hssmaxrank - maximum rank used in low-rank approximation
 
   Options Database Key:
@@ -211,7 +207,8 @@ static PetscErrorCode MatSTRUMPACKSetHSSMaxRank_STRUMPACK(Mat F, PetscInt hssmax
    References:
 .  * - STRUMPACK manual
 
-.seealso: `MatGetFactor()`
+.seealso: [](chapter_matrices), `Mat`, `MatGetFactor()`, `MatSTRUMPACKSetReordering()`, `MatSTRUMPACKSetColPerm()`, `MatSTRUMPACKSetHSSRelTol()`,
+          `MatSTRUMPACKSetHSSAbsTol()`, `MatSTRUMPACKSetHSSLeafSize()`, `MatSTRUMPACKSetHSSMinSepSize()`
 @*/
 PetscErrorCode MatSTRUMPACKSetHSSMaxRank(Mat F, PetscInt hssmaxrank)
 {
@@ -219,25 +216,25 @@ PetscErrorCode MatSTRUMPACKSetHSSMaxRank(Mat F, PetscInt hssmaxrank)
   PetscValidHeaderSpecific(F, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveInt(F, hssmaxrank, 2);
   PetscTryMethod(F, "MatSTRUMPACKSetHSSMaxRank_C", (Mat, PetscInt), (F, hssmaxrank));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatSTRUMPACKSetHSSLeafSize_STRUMPACK(Mat F, PetscInt leaf_size)
 {
-  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->spptr;
+  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->data;
 
   PetscFunctionBegin;
   PetscStackCallExternalVoid("STRUMPACK_set_HSS_leaf_size", STRUMPACK_set_HSS_leaf_size(*S, leaf_size));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   MatSTRUMPACKSetHSSLeafSize - Set STRUMPACK HSS leaf size
 
-   Logically Collective on F
+   Logically Collective
 
    Input Parameters:
-+  F - the factored matrix obtained by calling `MatGetFactor()` from PETSc-STRUMPACK interface
++  F - the factored matrix obtained by calling `MatGetFactor()`
 -  leaf_size - Size of diagonal blocks in HSS approximation
 
   Options Database Key:
@@ -248,7 +245,8 @@ static PetscErrorCode MatSTRUMPACKSetHSSLeafSize_STRUMPACK(Mat F, PetscInt leaf_
    References:
 .  * - STRUMPACK manual
 
-.seealso: `MatGetFactor()`
+.seealso: [](chapter_matrices), `Mat`, `MatGetFactor()`, `MatSTRUMPACKSetReordering()`, `MatSTRUMPACKSetColPerm()`, `MatSTRUMPACKSetHSSRelTol()`,
+          `MatSTRUMPACKSetHSSAbsTol()`, `MatSTRUMPACKSetHSSMaxRank()`, `MatSTRUMPACKSetHSSMinSepSize()`
 @*/
 PetscErrorCode MatSTRUMPACKSetHSSLeafSize(Mat F, PetscInt leaf_size)
 {
@@ -256,25 +254,25 @@ PetscErrorCode MatSTRUMPACKSetHSSLeafSize(Mat F, PetscInt leaf_size)
   PetscValidHeaderSpecific(F, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveInt(F, leaf_size, 2);
   PetscTryMethod(F, "MatSTRUMPACKSetHSSLeafSize_C", (Mat, PetscInt), (F, leaf_size));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatSTRUMPACKSetHSSMinSepSize_STRUMPACK(Mat F, PetscInt hssminsize)
 {
-  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->spptr;
+  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->data;
 
   PetscFunctionBegin;
   PetscStackCallExternalVoid("STRUMPACK_set_HSS_min_sep_size", STRUMPACK_set_HSS_min_sep_size(*S, hssminsize));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   MatSTRUMPACKSetHSSMinSepSize - Set STRUMPACK minimum separator size for low-rank approximation
 
-   Logically Collective on F
+   Logically Collective
 
    Input Parameters:
-+  F - the factored matrix obtained by calling `MatGetFactor()` from PETSc-STRUMPACK interface
++  F - the factored matrix obtained by calling `MatGetFactor()`
 -  hssminsize - minimum dense matrix size for low-rank approximation
 
   Options Database Key:
@@ -285,7 +283,8 @@ static PetscErrorCode MatSTRUMPACKSetHSSMinSepSize_STRUMPACK(Mat F, PetscInt hss
    References:
 .  * - STRUMPACK manual
 
-.seealso: `MatGetFactor()`
+.seealso: [](chapter_matrices), `Mat`, `MatGetFactor()`, `MatSTRUMPACKSetReordering()`, `MatSTRUMPACKSetColPerm()`, `MatSTRUMPACKSetHSSRelTol()`,
+          `MatSTRUMPACKSetHSSAbsTol()`, `MatSTRUMPACKSetHSSMaxRank()`, `MatSTRUMPACKSetHSSLeafSize()`
 @*/
 PetscErrorCode MatSTRUMPACKSetHSSMinSepSize(Mat F, PetscInt hssminsize)
 {
@@ -293,12 +292,12 @@ PetscErrorCode MatSTRUMPACKSetHSSMinSepSize(Mat F, PetscInt hssminsize)
   PetscValidHeaderSpecific(F, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveInt(F, hssminsize, 2);
   PetscTryMethod(F, "MatSTRUMPACKSetHSSMinSepSize_C", (Mat, PetscInt), (F, hssminsize));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatSolve_STRUMPACK(Mat A, Vec b_mpi, Vec x)
 {
-  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)A->spptr;
+  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)A->data;
   STRUMPACK_RETURN_CODE   sp_err;
   const PetscScalar      *bptr;
   PetscScalar            *xptr;
@@ -324,7 +323,7 @@ static PetscErrorCode MatSolve_STRUMPACK(Mat A, Vec b_mpi, Vec x)
   }
   PetscCall(VecRestoreArray(x, &xptr));
   PetscCall(VecRestoreArrayRead(b_mpi, &bptr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMatSolve_STRUMPACK(Mat A, Mat B_mpi, Mat X)
@@ -337,16 +336,16 @@ static PetscErrorCode MatMatSolve_STRUMPACK(Mat A, Mat B_mpi, Mat X)
   PetscCall(PetscObjectTypeCompareAny((PetscObject)X, &flg, MATSEQDENSE, MATMPIDENSE, NULL));
   PetscCheck(flg, PetscObjectComm((PetscObject)A), PETSC_ERR_ARG_WRONG, "Matrix X must be MATDENSE matrix");
   SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "MatMatSolve_STRUMPACK() is not implemented yet");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatView_Info_STRUMPACK(Mat A, PetscViewer viewer)
 {
   PetscFunctionBegin;
   /* check if matrix is strumpack type */
-  if (A->ops->solve != MatSolve_STRUMPACK) PetscFunctionReturn(0);
+  if (A->ops->solve != MatSolve_STRUMPACK) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscViewerASCIIPrintf(viewer, "STRUMPACK sparse solver!\n"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatView_STRUMPACK(Mat A, PetscViewer viewer)
@@ -360,28 +359,35 @@ static PetscErrorCode MatView_STRUMPACK(Mat A, PetscViewer viewer)
     PetscCall(PetscViewerGetFormat(viewer, &format));
     if (format == PETSC_VIEWER_ASCII_INFO) PetscCall(MatView_Info_STRUMPACK(A, viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatLUFactorNumeric_STRUMPACK(Mat F, Mat A, const MatFactorInfo *info)
 {
-  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->spptr;
+  STRUMPACK_SparseSolver *S = (STRUMPACK_SparseSolver *)F->data;
   STRUMPACK_RETURN_CODE   sp_err;
   Mat_SeqAIJ             *A_d, *A_o;
   Mat_MPIAIJ             *mat;
   PetscInt                M = A->rmap->N, m = A->rmap->n;
   PetscBool               flg;
+  const PetscScalar      *A_d_a, *A_o_a;
 
   PetscFunctionBegin;
-  PetscCall(PetscObjectTypeCompare((PetscObject)A, MATMPIAIJ, &flg));
-  if (flg) { /* A is MATMPIAIJ */
+  PetscCall(PetscObjectBaseTypeCompare((PetscObject)A, MATMPIAIJ, &flg));
+  if (flg) { /* A might be MATMPIAIJCUSPARSE etc */
     mat = (Mat_MPIAIJ *)A->data;
+    PetscCall(MatSeqAIJGetArrayRead(mat->A, &A_d_a)); /* Make sure mat is sync'ed to host */
+    PetscCall(MatSeqAIJGetArrayRead(mat->B, &A_o_a));
     A_d = (Mat_SeqAIJ *)(mat->A)->data;
     A_o = (Mat_SeqAIJ *)(mat->B)->data;
-    PetscStackCallExternalVoid("STRUMPACK_set_MPIAIJ_matrix", STRUMPACK_set_MPIAIJ_matrix(*S, &m, A_d->i, A_d->j, A_d->a, A_o->i, A_o->j, A_o->a, mat->garray));
-  } else { /* A is MATSEQAIJ */
+    PetscStackCallExternalVoid("STRUMPACK_set_MPIAIJ_matrix", STRUMPACK_set_MPIAIJ_matrix(*S, &m, A_d->i, A_d->j, A_d_a, A_o->i, A_o->j, A_o_a, mat->garray));
+    PetscCall(MatSeqAIJRestoreArrayRead(mat->A, &A_d_a));
+    PetscCall(MatSeqAIJRestoreArrayRead(mat->B, &A_o_a));
+  } else { /* A might be MATSEQAIJCUSPARSE etc */
+    PetscCall(MatSeqAIJGetArrayRead(A, &A_d_a));
     A_d = (Mat_SeqAIJ *)A->data;
-    PetscStackCallExternalVoid("STRUMPACK_set_csr_matrix", STRUMPACK_set_csr_matrix(*S, &M, A_d->i, A_d->j, A_d->a, 0));
+    PetscStackCallExternalVoid("STRUMPACK_set_csr_matrix", STRUMPACK_set_csr_matrix(*S, &M, A_d->i, A_d->j, A_d_a, 0));
+    PetscCall(MatSeqAIJRestoreArrayRead(A, &A_d_a));
   }
 
   /* Reorder and Factor the matrix. */
@@ -404,12 +410,12 @@ static PetscErrorCode MatLUFactorNumeric_STRUMPACK(Mat F, Mat A, const MatFactor
   }
   F->assembled    = PETSC_TRUE;
   F->preallocated = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatLUFactorSymbolic_STRUMPACK(Mat F, Mat A, IS r, IS c, const MatFactorInfo *info)
 {
-  STRUMPACK_SparseSolver       *S = (STRUMPACK_SparseSolver *)F->spptr;
+  STRUMPACK_SparseSolver       *S = (STRUMPACK_SparseSolver *)F->data;
   PetscBool                     flg, set;
   PetscReal                     ctol;
   PetscInt                      hssminsize, max_rank, leaf_size;
@@ -464,14 +470,14 @@ static PetscErrorCode MatLUFactorSymbolic_STRUMPACK(Mat F, Mat A, IS r, IS c, co
   F->ops->lufactornumeric = MatLUFactorNumeric_STRUMPACK;
   F->ops->solve           = MatSolve_STRUMPACK;
   F->ops->matsolve        = MatMatSolve_STRUMPACK;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatFactorGetSolverType_aij_strumpack(Mat A, MatSolverType *type)
 {
   PetscFunctionBegin;
   *type = MATSOLVERSTRUMPACK;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -480,17 +486,13 @@ static PetscErrorCode MatFactorGetSolverType_aij_strumpack(Mat A, MatSolverType
 
   Consult the STRUMPACK-sparse manual for more info.
 
-  Use
-     ./configure --download-strumpack
-  to have PETSc installed with STRUMPACK
+  Use ` ./configure --download-strumpack` to have PETSc installed with STRUMPACK
 
-  Use
-    -pc_type lu -pc_factor_mat_solver_type strumpack
-  to use this as an exact (direct) solver, use
-    -pc_type ilu -pc_factor_mat_solver_type strumpack
-  to enable low-rank compression (i.e, use as a preconditioner).
+  Use `-pc_type lu` `-pc_factor_mat_solver_type strumpack` to use this as an exact (direct) solver.
 
-  Works with AIJ matrices
+  Use `-pc_type ilu` `-pc_factor_mat_solver_type strumpack` to enable low-rank compression (i.e, use as a preconditioner).
+
+  Works with `MATAIJ` matrices
 
   Options Database Keys:
 + -mat_strumpack_verbose                    - verbose info
@@ -500,12 +502,15 @@ static PetscErrorCode MatFactorGetSolverType_aij_strumpack(Mat A, MatSolverType
 . -mat_strumpack_hss_min_sep_size <256>     - Minimum size of separator for HSS compression (None)
 . -mat_strumpack_max_rank                   - Maximum rank in HSS compression, when using pctype ilu (None)
 . -mat_strumpack_leaf_size                  - Size of diagonal blocks in HSS approximation, when using pctype ilu (None)
-. -mat_strumpack_reordering <METIS>         - Sparsity reducing matrix reordering (choose one of) NATURAL METIS PARMETIS SCOTCH PTSCOTCH RCM (None)
-- -mat_strumpack_iterative_solver <DIRECT>  - Select iterative solver from STRUMPACK (choose one of) AUTO DIRECT REFINE PREC_GMRES GMRES PREC_BICGSTAB BICGSTAB (None)
+. -mat_strumpack_reordering <METIS>         - Sparsity reducing matrix reordering see `MatSTRUMPACKReordering`
+- -mat_strumpack_iterative_solver <DIRECT>  - Select iterative solver from STRUMPACK (choose one of) `AUTO`, `DIRECT`, `REFINE`, `PREC_GMRES`,
+                                              `GMRES`, `PREC_BICGSTAB`, `BICGSTAB`
 
  Level: beginner
 
-.seealso: `PCLU`, `PCILU`, `MATSOLVERSUPERLU_DIST`, `MATSOLVERMUMPS`, `PCFactorSetMatSolverType()`, `MatSolverType`, `MatGetFactor()`
+.seealso: [](chapter_matrices), `Mat`, `PCLU`, `PCILU`, `MATSOLVERSUPERLU_DIST`, `MATSOLVERMUMPS`, `PCFactorSetMatSolverType()`, `MatSolverType`,
+          `MatGetFactor()`, `MatSTRUMPACKSetReordering()`, `MatSTRUMPACKSetColPerm()`, `MatSTRUMPACKSetHSSRelTol()`,
+          `MatSTRUMPACKSetHSSAbsTol()`, `MatSTRUMPACKSetHSSMaxRank()`, `MatSTRUMPACKSetHSSLeafSize()`, `MatSTRUMPACKSetHSSMinSepSize()`
 M*/
 static PetscErrorCode MatGetFactor_aij_strumpack(Mat A, MatFactorType ftype, Mat *F)
 {
@@ -524,14 +529,14 @@ static PetscErrorCode MatGetFactor_aij_strumpack(Mat A, MatFactorType ftype, Mat
   /* Create the factorization matrix */
   PetscCall(MatCreate(PetscObjectComm((PetscObject)A), &B));
   PetscCall(MatSetSizes(B, A->rmap->n, A->cmap->n, M, N));
-  PetscCall(MatSetType(B, ((PetscObject)A)->type_name));
-  PetscCall(MatSeqAIJSetPreallocation(B, 0, NULL));
-  PetscCall(MatMPIAIJSetPreallocation(B, 0, NULL, 0, NULL));
+  PetscCall(PetscStrallocpy("strumpack", &((PetscObject)B)->type_name));
+  PetscCall(MatSetUp(B));
   B->trivialsymbolic = PETSC_TRUE;
   if (ftype == MAT_FACTOR_LU || ftype == MAT_FACTOR_ILU) {
     B->ops->lufactorsymbolic  = MatLUFactorSymbolic_STRUMPACK;
     B->ops->ilufactorsymbolic = MatLUFactorSymbolic_STRUMPACK;
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Factor type not supported");
+  B->ops->getinfo     = MatGetInfo_External;
   B->ops->view        = MatView_STRUMPACK;
   B->ops->destroy     = MatDestroy_STRUMPACK;
   B->ops->getdiagonal = MatGetDiagonal_STRUMPACK;
@@ -545,9 +550,9 @@ static PetscErrorCode MatGetFactor_aij_strumpack(Mat A, MatFactorType ftype, Mat
   PetscCall(PetscObjectComposeFunction((PetscObject)B, "MatSTRUMPACKSetHSSMinSepSize_C", MatSTRUMPACKSetHSSMinSepSize_STRUMPACK));
   B->factortype = ftype;
   PetscCall(PetscNew(&S));
-  B->spptr = S;
+  B->data = S;
 
-  PetscCall(PetscObjectTypeCompare((PetscObject)A, MATSEQAIJ, &flg));
+  PetscCall(PetscObjectBaseTypeCompare((PetscObject)A, MATSEQAIJ, &flg)); /* A might be MATSEQAIJCUSPARSE */
   iface = flg ? STRUMPACK_MT : STRUMPACK_MPI_DIST;
 
   PetscOptionsBegin(PetscObjectComm((PetscObject)B), ((PetscObject)B)->prefix, "STRUMPACK Options", "Mat");
@@ -568,7 +573,7 @@ static PetscErrorCode MatGetFactor_aij_strumpack(Mat A, MatFactorType ftype, Mat
   PetscCall(PetscStrallocpy(MATSOLVERSTRUMPACK, &B->solvertype));
 
   *F = B;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_EXTERN PetscErrorCode MatSolverTypeRegister_STRUMPACK(void)
@@ -578,5 +583,5 @@ PETSC_EXTERN PetscErrorCode MatSolverTypeRegister_STRUMPACK(void)
   PetscCall(MatSolverTypeRegister(MATSOLVERSTRUMPACK, MATSEQAIJ, MAT_FACTOR_LU, MatGetFactor_aij_strumpack));
   PetscCall(MatSolverTypeRegister(MATSOLVERSTRUMPACK, MATMPIAIJ, MAT_FACTOR_ILU, MatGetFactor_aij_strumpack));
   PetscCall(MatSolverTypeRegister(MATSOLVERSTRUMPACK, MATSEQAIJ, MAT_FACTOR_ILU, MatGetFactor_aij_strumpack));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
