@@ -6,17 +6,17 @@
 #include <../src/mat/impls/aij/seq/aij.h>
 
 #if defined(PETSC_HAVE_FORTRAN_UNDERSCORE)
-#define LU1FAC   lu1fac_
-#define LU6SOL   lu6sol_
-#define M1PAGE   m1page_
-#define M5SETX   m5setx_
-#define M6RDEL   m6rdel_
+  #define LU1FAC lu1fac_
+  #define LU6SOL lu6sol_
+  #define M1PAGE m1page_
+  #define M5SETX m5setx_
+  #define M6RDEL m6rdel_
 #elif !defined(PETSC_HAVE_FORTRAN_CAPS)
-#define LU1FAC   lu1fac
-#define LU6SOL   lu6sol
-#define M1PAGE   m1page
-#define M5SETX   m5setx
-#define M6RDEL   m6rdel
+  #define LU1FAC lu1fac
+  #define LU6SOL lu6sol
+  #define M1PAGE m1page
+  #define M5SETX m5setx
+  #define M6RDEL m6rdel
 #endif
 
 /*
@@ -36,21 +36,13 @@ PETSC_EXTERN void M6RDEL()
   ;
 }
 
-PETSC_EXTERN void LU1FAC(int *m, int *n, int *nnz, int *size, int *luparm,
-                                 double *parmlu, double *data, int *indc, int *indr,
-                                 int *rowperm, int *colperm, int *collen, int *rowlen,
-                                 int *colstart, int *rowstart, int *rploc, int *cploc,
-                                 int *rpinv, int *cpinv, double *w, int *inform);
+PETSC_EXTERN void LU1FAC(int *m, int *n, int *nnz, int *size, int *luparm, double *parmlu, double *data, int *indc, int *indr, int *rowperm, int *colperm, int *collen, int *rowlen, int *colstart, int *rowstart, int *rploc, int *cploc, int *rpinv, int *cpinv, double *w, int *inform);
 
-PETSC_EXTERN void LU6SOL(int *mode, int *m, int *n, double *rhs, double *x,
-                                 int *size, int *luparm, double *parmlu, double *data,
-                                 int *indc, int *indr, int *rowperm, int *colperm,
-                                 int *collen, int *rowlen, int *colstart, int *rowstart,
-                                 int *inform);
+PETSC_EXTERN void LU6SOL(int *mode, int *m, int *n, double *rhs, double *x, int *size, int *luparm, double *parmlu, double *data, int *indc, int *indr, int *rowperm, int *colperm, int *collen, int *rowlen, int *colstart, int *rowstart, int *inform);
 
-extern PetscErrorCode MatDuplicate_LUSOL(Mat,MatDuplicateOption,Mat*);
+extern PetscErrorCode MatDuplicate_LUSOL(Mat, MatDuplicateOption, Mat *);
 
-typedef struct  {
+typedef struct {
   double *data;
   int    *indc;
   int    *indr;
@@ -69,13 +61,13 @@ typedef struct  {
   double *mnsv;
 
   double elbowroom;
-  double luroom;                /* Extra space allocated when factor fails   */
-  double parmlu[30];            /* Input/output to LUSOL                     */
+  double luroom;     /* Extra space allocated when factor fails   */
+  double parmlu[30]; /* Input/output to LUSOL                     */
 
-  int n;                        /* Number of rows/columns in matrix          */
-  int nz;                       /* Number of nonzeros                        */
-  int nnz;                      /* Number of nonzeros allocated for factors  */
-  int luparm[30];               /* Input/output to LUSOL                     */
+  int n;          /* Number of rows/columns in matrix          */
+  int nz;         /* Number of nonzeros                        */
+  int nnz;        /* Number of nonzeros allocated for factors  */
+  int luparm[30]; /* Input/output to LUSOL                     */
 
   PetscBool CleanUpLUSOL;
 
@@ -179,7 +171,7 @@ typedef struct  {
 
 PetscErrorCode MatDestroy_LUSOL(Mat A)
 {
-  Mat_LUSOL      *lusol=(Mat_LUSOL*)A->spptr;
+  Mat_LUSOL *lusol = (Mat_LUSOL *)A->spptr;
 
   PetscFunctionBegin;
   if (lusol && lusol->CleanUpLUSOL) {
@@ -195,55 +187,52 @@ PetscErrorCode MatDestroy_LUSOL(Mat A)
     PetscCall(PetscFree(lusol->iqinv));
     PetscCall(PetscFree(lusol->mnsw));
     PetscCall(PetscFree(lusol->mnsv));
-    PetscCall(PetscFree3(lusol->data,lusol->indc,lusol->indr));
+    PetscCall(PetscFree3(lusol->data, lusol->indc, lusol->indr));
   }
   PetscCall(PetscFree(A->spptr));
   PetscCall(MatDestroy_SeqAIJ(A));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatSolve_LUSOL(Mat A,Vec b,Vec x)
+PetscErrorCode MatSolve_LUSOL(Mat A, Vec b, Vec x)
 {
-  Mat_LUSOL      *lusol=(Mat_LUSOL*)A->spptr;
-  double         *xx;
-  const double   *bb;
-  int            mode=5;
-  int            i,m,n,nnz,status;
+  Mat_LUSOL    *lusol = (Mat_LUSOL *)A->spptr;
+  double       *xx;
+  const double *bb;
+  int           mode = 5;
+  int           i, m, n, nnz, status;
 
   PetscFunctionBegin;
   PetscCall(VecGetArray(x, &xx));
   PetscCall(VecGetArrayRead(b, &bb));
 
-  m   = n = lusol->n;
-  nnz = lusol->nnz;
+  m = n = lusol->n;
+  nnz   = lusol->nnz;
 
   for (i = 0; i < m; i++) lusol->mnsv[i] = bb[i];
 
-  LU6SOL(&mode, &m, &n, lusol->mnsv, xx, &nnz,
-         lusol->luparm, lusol->parmlu, lusol->data,
-         lusol->indc, lusol->indr, lusol->ip, lusol->iq,
-         lusol->lenc, lusol->lenr, lusol->locc, lusol->locr, &status);
+  LU6SOL(&mode, &m, &n, lusol->mnsv, xx, &nnz, lusol->luparm, lusol->parmlu, lusol->data, lusol->indc, lusol->indr, lusol->ip, lusol->iq, lusol->lenc, lusol->lenr, lusol->locc, lusol->locr, &status);
 
-  PetscCheck(!status,PETSC_COMM_SELF,PETSC_ERR_ARG_SIZ,"solve failed, error code %d",status);
+  PetscCheck(!status, PETSC_COMM_SELF, PETSC_ERR_ARG_SIZ, "solve failed, error code %d", status);
 
   PetscCall(VecRestoreArray(x, &xx));
   PetscCall(VecRestoreArrayRead(b, &bb));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatLUFactorNumeric_LUSOL(Mat F,Mat A,const MatFactorInfo *info)
+PetscErrorCode MatLUFactorNumeric_LUSOL(Mat F, Mat A, const MatFactorInfo *info)
 {
-  Mat_SeqAIJ     *a;
-  Mat_LUSOL      *lusol = (Mat_LUSOL*)F->spptr;
-  int            m, n, nz, nnz, status;
-  int            i, rs, re;
-  int            factorizations;
+  Mat_SeqAIJ *a;
+  Mat_LUSOL  *lusol = (Mat_LUSOL *)F->spptr;
+  int         m, n, nz, nnz, status;
+  int         i, rs, re;
+  int         factorizations;
 
   PetscFunctionBegin;
-  PetscCall(MatGetSize(A,&m,&n));
-  a    = (Mat_SeqAIJ*)A->data;
+  PetscCall(MatGetSize(A, &m, &n));
+  a = (Mat_SeqAIJ *)A->data;
 
-  PetscCheckFalse(m != lusol->n,PETSC_COMM_SELF,PETSC_ERR_ARG_SIZ,"factorization struct inconsistent");
+  PetscCheck(m == lusol->n, PETSC_COMM_SELF, PETSC_ERR_ARG_SIZ, "factorization struct inconsistent");
 
   factorizations = 0;
   do {
@@ -252,8 +241,8 @@ PetscErrorCode MatLUFactorNumeric_LUSOL(Mat F,Mat A,const MatFactorInfo *info)
     /*******************************************************************/
 
     nz  = a->nz;
-    nnz = PetscMax(lusol->nnz, (int)(lusol->elbowroom*nz));
-    nnz = PetscMax(nnz, 5*n);
+    nnz = PetscMax(lusol->nnz, (int)(lusol->elbowroom * nz));
+    nnz = PetscMax(nnz, 5 * n);
 
     if (nnz < lusol->luparm[12]) {
       nnz = (int)(lusol->luroom * lusol->luparm[12]);
@@ -261,11 +250,11 @@ PetscErrorCode MatLUFactorNumeric_LUSOL(Mat F,Mat A,const MatFactorInfo *info)
       lusol->luroom += 0.1;
     }
 
-    nnz = PetscMax(nnz, (int)(lusol->luroom*(lusol->luparm[22] + lusol->luparm[23])));
+    nnz = PetscMax(nnz, (int)(lusol->luroom * (lusol->luparm[22] + lusol->luparm[23])));
 
     if (nnz > lusol->nnz) {
-      PetscCall(PetscFree3(lusol->data,lusol->indc,lusol->indr));
-      PetscCall(PetscMalloc3(nnz,&lusol->data,nnz,&lusol->indc,nnz,&lusol->indr));
+      PetscCall(PetscFree3(lusol->data, lusol->indc, lusol->indr));
+      PetscCall(PetscMalloc3(nnz, &lusol->data, nnz, &lusol->indc, nnz, &lusol->indr));
       lusol->nnz = nnz;
     }
 
@@ -276,7 +265,7 @@ PetscErrorCode MatLUFactorNumeric_LUSOL(Mat F,Mat A,const MatFactorInfo *info)
     nz = 0;
     for (i = 0; i < n; i++) {
       rs = a->i[i];
-      re = a->i[i+1];
+      re = a->i[i + 1];
 
       while (rs < re) {
         if (a->a[rs] != 0.0) {
@@ -293,30 +282,25 @@ PetscErrorCode MatLUFactorNumeric_LUSOL(Mat F,Mat A,const MatFactorInfo *info)
     /* Do the factorization.                                           */
     /*******************************************************************/
 
-    LU1FAC(&m, &n, &nz, &nnz,
-           lusol->luparm, lusol->parmlu, lusol->data,
-           lusol->indc, lusol->indr, lusol->ip, lusol->iq,
-           lusol->lenc, lusol->lenr, lusol->locc, lusol->locr,
-           lusol->iploc, lusol->iqloc, lusol->ipinv,
-           lusol->iqinv, lusol->mnsw, &status);
+    LU1FAC(&m, &n, &nz, &nnz, lusol->luparm, lusol->parmlu, lusol->data, lusol->indc, lusol->indr, lusol->ip, lusol->iq, lusol->lenc, lusol->lenr, lusol->locc, lusol->locr, lusol->iploc, lusol->iqloc, lusol->ipinv, lusol->iqinv, lusol->mnsw, &status);
 
     switch (status) {
-    case 0:         /* factored */
+    case 0: /* factored */
       break;
 
-    case 7:         /* insufficient memory */
+    case 7: /* insufficient memory */
       break;
 
     case 1:
-    case -1:        /* singular */
-      SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"Singular matrix");
+    case -1: /* singular */
+      SETERRQ(PETSC_COMM_SELF, PETSC_ERR_LIB, "Singular matrix");
 
     case 3:
-    case 4:         /* error conditions */
-      SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"matrix error");
+    case 4: /* error conditions */
+      SETERRQ(PETSC_COMM_SELF, PETSC_ERR_LIB, "matrix error");
 
-    default:        /* unknown condition */
-      SETERRQ(PETSC_COMM_SELF,PETSC_ERR_LIB,"matrix unknown return code");
+    default: /* unknown condition */
+      SETERRQ(PETSC_COMM_SELF, PETSC_ERR_LIB, "matrix unknown return code");
     }
 
     factorizations++;
@@ -324,10 +308,10 @@ PetscErrorCode MatLUFactorNumeric_LUSOL(Mat F,Mat A,const MatFactorInfo *info)
   F->ops->solve   = MatSolve_LUSOL;
   F->assembled    = PETSC_TRUE;
   F->preallocated = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatLUFactorSymbolic_LUSOL(Mat F,Mat A, IS r, IS c,const MatFactorInfo *info)
+PetscErrorCode MatLUFactorSymbolic_LUSOL(Mat F, Mat A, IS r, IS c, const MatFactorInfo *info)
 {
   /************************************************************************/
   /* Input                                                                */
@@ -338,9 +322,8 @@ PetscErrorCode MatLUFactorSymbolic_LUSOL(Mat F,Mat A, IS r, IS c,const MatFactor
   /* Output                                                               */
   /*     F  - matrix storing the factorization;                           */
   /************************************************************************/
-  Mat_LUSOL      *lusol;
-  PetscErrorCode ierr;
-  int            i, m, n, nz, nnz;
+  Mat_LUSOL *lusol;
+  int        i, m, n, nz, nnz;
 
   PetscFunctionBegin;
   /************************************************************************/
@@ -348,14 +331,14 @@ PetscErrorCode MatLUFactorSymbolic_LUSOL(Mat F,Mat A, IS r, IS c,const MatFactor
   /************************************************************************/
 
   PetscCall(MatGetSize(A, &m, &n));
-  nz   = ((Mat_SeqAIJ*)A->data)->nz;
+  nz = ((Mat_SeqAIJ *)A->data)->nz;
 
   /************************************************************************/
   /* Create the factorization.                                            */
   /************************************************************************/
 
   F->ops->lufactornumeric = MatLUFactorNumeric_LUSOL;
-  lusol                   = (Mat_LUSOL*)(F->spptr);
+  lusol                   = (Mat_LUSOL *)(F->spptr);
 
   /************************************************************************/
   /* Initialize parameters                                                */
@@ -384,87 +367,82 @@ PetscErrorCode MatLUFactorSymbolic_LUSOL(Mat F,Mat A, IS r, IS c,const MatFactor
   /************************************************************************/
 
   lusol->elbowroom = PetscMax(lusol->elbowroom, info->fill);
-  nnz              = PetscMax((int)(lusol->elbowroom*nz), 5*n);
+  nnz              = PetscMax((int)(lusol->elbowroom * nz), 5 * n);
 
   lusol->n      = n;
   lusol->nz     = nz;
   lusol->nnz    = nnz;
   lusol->luroom = 1.75;
 
-  ierr = PetscMalloc(sizeof(int)*n,&lusol->ip);
-  ierr = PetscMalloc(sizeof(int)*n,&lusol->iq);
-  ierr = PetscMalloc(sizeof(int)*n,&lusol->lenc);
-  ierr = PetscMalloc(sizeof(int)*n,&lusol->lenr);
-  ierr = PetscMalloc(sizeof(int)*n,&lusol->locc);
-  ierr = PetscMalloc(sizeof(int)*n,&lusol->locr);
-  ierr = PetscMalloc(sizeof(int)*n,&lusol->iploc);
-  ierr = PetscMalloc(sizeof(int)*n,&lusol->iqloc);
-  ierr = PetscMalloc(sizeof(int)*n,&lusol->ipinv);
-  ierr = PetscMalloc(sizeof(int)*n,&lusol->iqinv);
-  ierr = PetscMalloc(sizeof(double)*n,&lusol->mnsw);
-  ierr = PetscMalloc(sizeof(double)*n,&lusol->mnsv);
-
-  PetscCall(PetscMalloc3(nnz,&lusol->data,nnz,&lusol->indc,nnz,&lusol->indr));
+  PetscCall(PetscMalloc(sizeof(int) * n, &lusol->ip));
+  PetscCall(PetscMalloc(sizeof(int) * n, &lusol->iq));
+  PetscCall(PetscMalloc(sizeof(int) * n, &lusol->lenc));
+  PetscCall(PetscMalloc(sizeof(int) * n, &lusol->lenr));
+  PetscCall(PetscMalloc(sizeof(int) * n, &lusol->locc));
+  PetscCall(PetscMalloc(sizeof(int) * n, &lusol->locr));
+  PetscCall(PetscMalloc(sizeof(int) * n, &lusol->iploc));
+  PetscCall(PetscMalloc(sizeof(int) * n, &lusol->iqloc));
+  PetscCall(PetscMalloc(sizeof(int) * n, &lusol->ipinv));
+  PetscCall(PetscMalloc(sizeof(int) * n, &lusol->iqinv));
+  PetscCall(PetscMalloc(sizeof(double) * n, &lusol->mnsw));
+  PetscCall(PetscMalloc(sizeof(double) * n, &lusol->mnsv));
+  PetscCall(PetscMalloc3(nnz, &lusol->data, nnz, &lusol->indc, nnz, &lusol->indr));
 
   lusol->CleanUpLUSOL     = PETSC_TRUE;
   F->ops->lufactornumeric = MatLUFactorNumeric_LUSOL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PetscErrorCode MatFactorGetSolverType_seqaij_lusol(Mat A,MatSolverType *type)
+PetscErrorCode MatFactorGetSolverType_seqaij_lusol(Mat A, MatSolverType *type)
 {
   PetscFunctionBegin;
   *type = MATSOLVERLUSOL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-PETSC_EXTERN PetscErrorCode MatGetFactor_seqaij_lusol(Mat A,MatFactorType ftype,Mat *F)
+PETSC_EXTERN PetscErrorCode MatGetFactor_seqaij_lusol(Mat A, MatFactorType ftype, Mat *F)
 {
-  Mat            B;
-  Mat_LUSOL      *lusol;
-  int            m, n;
+  Mat        B;
+  Mat_LUSOL *lusol;
+  int        m, n;
 
   PetscFunctionBegin;
   PetscCall(MatGetSize(A, &m, &n));
-  PetscCall(MatCreate(PetscObjectComm((PetscObject)A),&B));
-  PetscCall(MatSetSizes(B,PETSC_DECIDE,PETSC_DECIDE,m,n));
-  PetscCall(MatSetType(B,((PetscObject)A)->type_name));
-  PetscCall(MatSeqAIJSetPreallocation(B,0,NULL));
+  PetscCall(MatCreate(PetscObjectComm((PetscObject)A), &B));
+  PetscCall(MatSetSizes(B, PETSC_DECIDE, PETSC_DECIDE, m, n));
+  PetscCall(MatSetType(B, ((PetscObject)A)->type_name));
+  PetscCall(MatSeqAIJSetPreallocation(B, 0, NULL));
 
-  PetscCall(PetscNewLog(B,&lusol));
+  PetscCall(PetscNew(&lusol));
   B->spptr = lusol;
 
   B->trivialsymbolic       = PETSC_TRUE;
   B->ops->lufactorsymbolic = MatLUFactorSymbolic_LUSOL;
   B->ops->destroy          = MatDestroy_LUSOL;
 
-  PetscCall(PetscObjectComposeFunction((PetscObject)B,"MatFactorGetSolverType_C",MatFactorGetSolverType_seqaij_lusol));
+  PetscCall(PetscObjectComposeFunction((PetscObject)B, "MatFactorGetSolverType_C", MatFactorGetSolverType_seqaij_lusol));
 
   B->factortype = MAT_FACTOR_LU;
   PetscCall(PetscFree(B->solvertype));
-  PetscCall(PetscStrallocpy(MATSOLVERLUSOL,&B->solvertype));
+  PetscCall(PetscStrallocpy(MATSOLVERLUSOL, &B->solvertype));
 
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_EXTERN PetscErrorCode MatSolverTypeRegister_Lusol(void)
 {
   PetscFunctionBegin;
-  PetscCall(MatSolverTypeRegister(MATSOLVERLUSOL,MATSEQAIJ,        MAT_FACTOR_LU,MatGetFactor_seqaij_lusol));
-  PetscFunctionReturn(0);
+  PetscCall(MatSolverTypeRegister(MATSOLVERLUSOL, MATSEQAIJ, MAT_FACTOR_LU, MatGetFactor_seqaij_lusol));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
-  MATSOLVERLUSOL - "lusol" - Provides direct solvers (LU) for sequential matrices
+  MATSOLVERLUSOL - "lusol" - Provides direct solvers, LU, for sequential matrices
                          via the external package LUSOL.
 
-  If LUSOL is installed (see the manual for
-  instructions on how to declare the existence of external packages),
-
-  Works with MATSEQAIJ matrices
+  Works with `MATSEQAIJ` matrices
 
    Level: beginner
 
-.seealso: PCLU, PCFactorSetMatSolverType(), MatSolverType
-
+.seealso: [](chapter_matrices), `Mat`, `PCLU`, `PCFactorSetMatSolverType()`, `MatSolverType`
 M*/
