@@ -1,6 +1,5 @@
 
-/*  --------------------------------------------------------------------
-
+/*
      This file implements a subclass of the SeqAIJ matrix class that uses
      the SuperLU sparse solver.
 */
@@ -87,7 +86,7 @@ static PetscErrorCode MatView_Info_SuperLU(Mat A, PetscViewer viewer)
     PetscCall(PetscViewerASCIIPrintf(viewer, "  ILU_Norm: %" PetscInt_FMT "\n", options.ILU_Norm));
     PetscCall(PetscViewerASCIIPrintf(viewer, "  ILU_MILU: %" PetscInt_FMT "\n", options.ILU_MILU));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSolve_SuperLU_Private(Mat A, Vec b, Vec x)
@@ -100,7 +99,7 @@ PetscErrorCode MatSolve_SuperLU_Private(Mat A, Vec b, Vec x)
   static PetscBool   cite = PETSC_FALSE;
 
   PetscFunctionBegin;
-  if (lu->lwork == -1) PetscFunctionReturn(0);
+  if (lu->lwork == -1) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscCitationsRegister("@article{superlu99,\n  author  = {James W. Demmel and Stanley C. Eisenstat and\n             John R. Gilbert and Xiaoye S. Li and Joseph W. H. Liu},\n  title = {A supernodal approach to sparse partial "
                                    "pivoting},\n  journal = {SIAM J. Matrix Analysis and Applications},\n  year = {1999},\n  volume  = {20},\n  number = {3},\n  pages = {720-755}\n}\n",
                                    &cite));
@@ -186,39 +185,45 @@ PetscErrorCode MatSolve_SuperLU_Private(Mat A, Vec b, Vec x)
     PetscCall(PetscPrintf(PETSC_COMM_SELF, "MatSolve__SuperLU():\n"));
     PetscStackCallExternalVoid("SuperLU:StatPrint", StatPrint(&lu->stat));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSolve_SuperLU(Mat A, Vec b, Vec x)
 {
   Mat_SuperLU *lu = (Mat_SuperLU *)A->data;
+  trans_t      oldOption;
 
   PetscFunctionBegin;
   if (A->factorerrortype) {
     PetscCall(PetscInfo(A, "MatSolve is called with singular matrix factor, skip\n"));
     PetscCall(VecSetInf(x));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
+  oldOption         = lu->options.Trans;
   lu->options.Trans = TRANS;
   PetscCall(MatSolve_SuperLU_Private(A, b, x));
-  PetscFunctionReturn(0);
+  lu->options.Trans = oldOption;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSolveTranspose_SuperLU(Mat A, Vec b, Vec x)
 {
   Mat_SuperLU *lu = (Mat_SuperLU *)A->data;
+  trans_t      oldOption;
 
   PetscFunctionBegin;
   if (A->factorerrortype) {
     PetscCall(PetscInfo(A, "MatSolve is called with singular matrix factor, skip\n"));
     PetscCall(VecSetInf(x));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
+  oldOption         = lu->options.Trans;
   lu->options.Trans = NOTRANS;
   PetscCall(MatSolve_SuperLU_Private(A, b, x));
-  PetscFunctionReturn(0);
+  lu->options.Trans = oldOption;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatLUFactorNumeric_SuperLU(Mat F, Mat A, const MatFactorInfo *info)
@@ -231,7 +236,7 @@ static PetscErrorCode MatLUFactorNumeric_SuperLU(Mat F, Mat A, const MatFactorIn
   SCformat    *Lstore;
 
   PetscFunctionBegin;
-  if (lu->flg == SAME_NONZERO_PATTERN) { /* successing numerical factorization */
+  if (lu->flg == SAME_NONZERO_PATTERN) { /* successive numerical factorization */
     lu->options.Fact = SamePattern;
     /* Ref: ~SuperLU_3.0/EXAMPLE/dlinsolx2.c */
     Destroy_SuperMatrix_Store(&lu->A);
@@ -340,7 +345,7 @@ static PetscErrorCode MatLUFactorNumeric_SuperLU(Mat F, Mat A, const MatFactorIn
   F->ops->solve          = MatSolve_SuperLU;
   F->ops->solvetranspose = MatSolveTranspose_SuperLU;
   F->ops->matsolve       = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatDestroy_SuperLU(Mat A)
@@ -370,7 +375,7 @@ static PetscErrorCode MatDestroy_SuperLU(Mat A)
   /* clear composed functions */
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatFactorGetSolverType_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatSuperluSetILUDropTol_C", NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatView_SuperLU(Mat A, PetscViewer viewer)
@@ -384,7 +389,7 @@ static PetscErrorCode MatView_SuperLU(Mat A, PetscViewer viewer)
     PetscCall(PetscViewerGetFormat(viewer, &format));
     if (format == PETSC_VIEWER_ASCII_INFO) PetscCall(MatView_Info_SuperLU(A, viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMatSolve_SuperLU(Mat A, Mat B, Mat X)
@@ -399,7 +404,7 @@ PetscErrorCode MatMatSolve_SuperLU(Mat A, Mat B, Mat X)
   PetscCheck(flg, PetscObjectComm((PetscObject)A), PETSC_ERR_ARG_WRONG, "Matrix X must be MATDENSE matrix");
   lu->options.Trans = TRANS;
   SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "MatMatSolve_SuperLU() is not implemented yet");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatLUFactorSymbolic_SuperLU(Mat F, Mat A, IS r, IS c, const MatFactorInfo *info)
@@ -466,7 +471,7 @@ static PetscErrorCode MatLUFactorSymbolic_SuperLU(Mat F, Mat A, IS r, IS c, cons
   if (lu->options.Equil == YES && !lu->A_dup) { /* superlu overwrites input matrix and rhs when Equil is used, thus create A_dup to keep user's A unchanged */
     PetscCall(MatDuplicate_SeqAIJ(A, MAT_COPY_VALUES, &lu->A_dup));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatSuperluSetILUDropTol_SuperLU(Mat F, PetscReal dtol)
@@ -475,16 +480,16 @@ static PetscErrorCode MatSuperluSetILUDropTol_SuperLU(Mat F, PetscReal dtol)
 
   PetscFunctionBegin;
   lu->options.ILU_DropTol = dtol;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   MatSuperluSetILUDropTol - Set SuperLU ILU drop tolerance
 
-   Logically Collective on F
+   Logically Collective
 
    Input Parameters:
-+  F - the factored matrix obtained by calling `MatGetFactor()` from PETSc-SuperLU interface
++  F - the factored matrix obtained by calling `MatGetFactor()`
 -  dtol - drop tolerance
 
   Options Database Key:
@@ -495,7 +500,7 @@ static PetscErrorCode MatSuperluSetILUDropTol_SuperLU(Mat F, PetscReal dtol)
    References:
 .  * - SuperLU Users' Guide
 
-.seealso: `MatGetFactor()`
+.seealso: [](chapter_matrices), `Mat`, `MatGetFactor()`, `MATSOLVERSUPERLU`
 @*/
 PetscErrorCode MatSuperluSetILUDropTol(Mat F, PetscReal dtol)
 {
@@ -503,33 +508,33 @@ PetscErrorCode MatSuperluSetILUDropTol(Mat F, PetscReal dtol)
   PetscValidHeaderSpecific(F, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveReal(F, dtol, 2);
   PetscTryMethod(F, "MatSuperluSetILUDropTol_C", (Mat, PetscReal), (F, dtol));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatFactorGetSolverType_seqaij_superlu(Mat A, MatSolverType *type)
 {
   PetscFunctionBegin;
   *type = MATSOLVERSUPERLU;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
   MATSOLVERSUPERLU = "superlu" - A solver package providing solvers LU and ILU for sequential matrices
   via the external package SuperLU.
 
-  Use ./configure --download-superlu to have PETSc installed with SuperLU
+  Use `./configure --download-superlu` to have PETSc installed with SuperLU
 
-  Use -pc_type lu -pc_factor_mat_solver_type superlu to use this direct solver
+  Use `-pc_type lu` `-pc_factor_mat_solver_type superlu` to use this direct solver
 
   Options Database Keys:
 + -mat_superlu_equil <FALSE>            - Equil (None)
-. -mat_superlu_colperm <COLAMD>         - (choose one of) NATURAL MMD_ATA MMD_AT_PLUS_A COLAMD
-. -mat_superlu_iterrefine <NOREFINE>    - (choose one of) NOREFINE SINGLE DOUBLE EXTRA
+. -mat_superlu_colperm <COLAMD>         - (choose one of) `NATURAL`, `MMD_ATA MMD_AT_PLUS_A`, `COLAMD`
+. -mat_superlu_iterrefine <NOREFINE>    - (choose one of) `NOREFINE`, `SINGLE`, `DOUBLE`, `EXTRA`
 . -mat_superlu_symmetricmode: <FALSE>   - SymmetricMode (None)
 . -mat_superlu_diagpivotthresh <1>      - DiagPivotThresh (None)
 . -mat_superlu_pivotgrowth <FALSE>      - PivotGrowth (None)
 . -mat_superlu_conditionnumber <FALSE>  - ConditionNumber (None)
-. -mat_superlu_rowperm <NOROWPERM>      - (choose one of) NOROWPERM LargeDiag
+. -mat_superlu_rowperm <NOROWPERM>      - (choose one of) `NOROWPERM`, `LargeDiag`
 . -mat_superlu_replacetinypivot <FALSE> - ReplaceTinyPivot (None)
 . -mat_superlu_printstat <FALSE>        - PrintStat (None)
 . -mat_superlu_lwork <0>                - size of work array in bytes used by factorization (None)
@@ -540,14 +545,14 @@ PetscErrorCode MatFactorGetSolverType_seqaij_superlu(Mat A, MatSolverType *type)
 . -mat_superlu_ilu_norm <0>             - ILU_Norm (None)
 - -mat_superlu_ilu_milu <0>             - ILU_MILU (None)
 
+   Level: beginner
+
    Notes:
     Do not confuse this with `MATSOLVERSUPERLU_DIST` which is for parallel sparse solves
 
     Cannot use ordering provided by PETSc, provides its own.
 
-   Level: beginner
-
-.seealso: `PCLU`, `PCILU`, `MATSOLVERSUPERLU_DIST`, `MATSOLVERMUMPS`, `PCFactorSetMatSolverType()`, `MatSolverType`
+.seealso: [](chapter_matrices), `Mat`, `PCLU`, `PCILU`, `MATSOLVERSUPERLU_DIST`, `MATSOLVERMUMPS`, `PCFactorSetMatSolverType()`, `MatSolverType`
 M*/
 
 static PetscErrorCode MatGetFactor_seqaij_superlu(Mat A, MatFactorType ftype, Mat *F)
@@ -630,7 +635,7 @@ static PetscErrorCode MatGetFactor_seqaij_superlu(Mat A, MatFactorType ftype, Ma
   B->data = lu;
 
   *F = B;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatGetFactor_seqsell_superlu(Mat A, MatFactorType ftype, Mat *F)
@@ -641,7 +646,7 @@ static PetscErrorCode MatGetFactor_seqsell_superlu(Mat A, MatFactorType ftype, M
   PetscCall(MatGetFactor_seqaij_superlu(A, ftype, F));
   lu                 = (Mat_SuperLU *)((*F)->data);
   lu->needconversion = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_EXTERN PetscErrorCode MatSolverTypeRegister_SuperLU(void)
@@ -651,5 +656,5 @@ PETSC_EXTERN PetscErrorCode MatSolverTypeRegister_SuperLU(void)
   PetscCall(MatSolverTypeRegister(MATSOLVERSUPERLU, MATSEQAIJ, MAT_FACTOR_ILU, MatGetFactor_seqaij_superlu));
   PetscCall(MatSolverTypeRegister(MATSOLVERSUPERLU, MATSEQSELL, MAT_FACTOR_LU, MatGetFactor_seqsell_superlu));
   PetscCall(MatSolverTypeRegister(MATSOLVERSUPERLU, MATSEQSELL, MAT_FACTOR_ILU, MatGetFactor_seqsell_superlu));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
