@@ -74,7 +74,7 @@ PetscErrorCode MatDestroy_Composite(Mat mat)
   PetscCall(PetscObjectComposeFunction((PetscObject)mat, "MatCompositeGetMat_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)mat, "MatCompositeSetScalings_C", NULL));
   PetscCall(PetscFree(mat->data));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMult_Composite_Multiplicative(Mat A, Vec x, Vec y)
@@ -109,7 +109,7 @@ PetscErrorCode MatMult_Composite_Multiplicative(Mat A, Vec x, Vec y)
     for (i = 0; i < shell->nmat; i++) scale *= shell->scalings[i];
   }
   PetscCall(VecScale(y, scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultTranspose_Composite_Multiplicative(Mat A, Vec x, Vec y)
@@ -145,7 +145,7 @@ PetscErrorCode MatMultTranspose_Composite_Multiplicative(Mat A, Vec x, Vec y)
     for (i = 0; i < shell->nmat; i++) scale *= shell->scalings[i];
   }
   PetscCall(VecScale(y, scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMult_Composite(Mat mat, Vec x, Vec y)
@@ -264,7 +264,7 @@ skip_merge_mvctx:
 
   if (shell->Mvctx) { /* Have a merged Mvctx */
     /* Suppose we want to compute y = sMx, where s is the scaling factor and A, B are matrix M's diagonal/off-diagonal part. We could do
-       in y = s(Ax1 + Bx2) or y = sAx1 + sBx2. The former incurs less FLOPS than the latter, but the latter provides an oppertunity to
+       in y = s(Ax1 + Bx2) or y = sAx1 + sBx2. The former incurs less FLOPS than the latter, but the latter provides an opportunity to
        overlap communication/computation since we can do sAx1 while communicating x2. Here, we use the former approach.
      */
     PetscCall(VecScatterBegin(shell->Mvctx, in, shell->gvec, INSERT_VALUES, SCATTER_FORWARD));
@@ -297,7 +297,7 @@ skip_merge_mvctx:
 
   if (shell->left) PetscCall(VecPointwiseMult(y, shell->left, y));
   PetscCall(VecScale(y, shell->scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultTranspose_Composite(Mat A, Vec x, Vec y)
@@ -332,7 +332,7 @@ PetscErrorCode MatMultTranspose_Composite(Mat A, Vec x, Vec y)
   }
   if (shell->right) PetscCall(VecPointwiseMult(y, shell->right, y));
   PetscCall(VecScale(y, shell->scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultAdd_Composite(Mat A, Vec x, Vec y, Vec z)
@@ -349,7 +349,7 @@ PetscErrorCode MatMultAdd_Composite(Mat A, Vec x, Vec y, Vec z)
     PetscCall(VecCopy(y, z));
     PetscCall(VecAXPY(z, 1.0, shell->leftwork));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultTransposeAdd_Composite(Mat A, Vec x, Vec y, Vec z)
@@ -366,7 +366,7 @@ PetscErrorCode MatMultTransposeAdd_Composite(Mat A, Vec x, Vec y, Vec z)
     PetscCall(VecCopy(y, z));
     PetscCall(VecAXPY(z, 1.0, shell->rightwork));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatGetDiagonal_Composite(Mat A, Vec v)
@@ -389,7 +389,7 @@ PetscErrorCode MatGetDiagonal_Composite(Mat A, Vec v)
     PetscCall(VecAXPY(v, (shell->scalings ? shell->scalings[i++] : 1.0), shell->work));
   }
   PetscCall(VecScale(v, shell->scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatAssemblyEnd_Composite(Mat Y, MatAssemblyType t)
@@ -398,7 +398,7 @@ PetscErrorCode MatAssemblyEnd_Composite(Mat Y, MatAssemblyType t)
 
   PetscFunctionBegin;
   if (shell->merge) PetscCall(MatCompositeMerge(Y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatScale_Composite(Mat inA, PetscScalar alpha)
@@ -407,7 +407,7 @@ PetscErrorCode MatScale_Composite(Mat inA, PetscScalar alpha)
 
   PetscFunctionBegin;
   a->scale *= alpha;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDiagonalScale_Composite(Mat inA, Vec left, Vec right)
@@ -431,7 +431,7 @@ PetscErrorCode MatDiagonalScale_Composite(Mat inA, Vec left, Vec right)
       PetscCall(VecPointwiseMult(a->right, right, a->right));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSetFromOptions_Composite(Mat A, PetscOptionItems *PetscOptionsObject)
@@ -444,7 +444,7 @@ PetscErrorCode MatSetFromOptions_Composite(Mat A, PetscOptionItems *PetscOptions
   PetscCall(PetscOptionsEnum("-mat_composite_merge_type", "Set composite merge direction", "MatCompositeSetMergeType", MatCompositeMergeTypes, (PetscEnum)a->mergetype, (PetscEnum *)&a->mergetype, NULL));
   PetscCall(PetscOptionsBool("-mat_composite_merge_mvctx", "Merge MatMult() vecscat contexts", "MatCreateComposite", a->merge_mvctx, &a->merge_mvctx, NULL));
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -469,18 +469,21 @@ PetscErrorCode MatSetFromOptions_Composite(Mat A, PetscOptionItems *PetscOptions
 
    Note:
      Alternative construction
-$       MatCreate(comm,&mat);
-$       MatSetSizes(mat,m,n,M,N);
-$       MatSetType(mat,MATCOMPOSITE);
-$       MatCompositeAddMat(mat,mats[0]);
-$       ....
-$       MatCompositeAddMat(mat,mats[nmat-1]);
-$       MatAssemblyBegin(mat,MAT_FINAL_ASSEMBLY);
-$       MatAssemblyEnd(mat,MAT_FINAL_ASSEMBLY);
+.vb
+       MatCreate(comm,&mat);
+       MatSetSizes(mat,m,n,M,N);
+       MatSetType(mat,MATCOMPOSITE);
+       MatCompositeAddMat(mat,mats[0]);
+       ....
+       MatCompositeAddMat(mat,mats[nmat-1]);
+       MatAssemblyBegin(mat,MAT_FINAL_ASSEMBLY);
+       MatAssemblyEnd(mat,MAT_FINAL_ASSEMBLY);
+.ve
 
      For the multiplicative form the product is mat[nmat-1]*mat[nmat-2]*....*mat[0]
 
-.seealso: `MatDestroy()`, `MatMult()`, `MatCompositeAddMat()`, `MatCompositeGetMat()`, `MatCompositeMerge()`, `MatCompositeSetType()`, `MATCOMPOSITE`
+.seealso: [](chapter_matrices), `Mat`, `MatDestroy()`, `MatMult()`, `MatCompositeAddMat()`, `MatCompositeGetMat()`, `MatCompositeMerge()`, `MatCompositeSetType()`,
+          `MATCOMPOSITE`, `MatCompositeType`
 @*/
 PetscErrorCode MatCreateComposite(MPI_Comm comm, PetscInt nmat, const Mat *mats, Mat *mat)
 {
@@ -500,7 +503,7 @@ PetscErrorCode MatCreateComposite(MPI_Comm comm, PetscInt nmat, const Mat *mats,
   for (i = 0; i < nmat; i++) PetscCall(MatCompositeAddMat(*mat, mats[i]));
   PetscCall(MatAssemblyBegin(*mat, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(*mat, MAT_FINAL_ASSEMBLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCompositeAddMat_Composite(Mat mat, Mat smat)
@@ -528,13 +531,13 @@ static PetscErrorCode MatCompositeAddMat_Composite(Mat mat, Mat smat)
     PetscCall(PetscRealloc(sizeof(PetscScalar) * shell->nmat, &shell->scalings));
     shell->scalings[shell->nmat - 1] = 1.0;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatCompositeAddMat - Add another matrix to a composite matrix.
 
-   Collective on mat
+   Collective
 
     Input Parameters:
 +   mat - the composite matrix
@@ -542,7 +545,7 @@ static PetscErrorCode MatCompositeAddMat_Composite(Mat mat, Mat smat)
 
    Level: advanced
 
-.seealso: `MatCreateComposite()`, `MatCompositeGetMat()`, `MATCOMPOSITE`
+.seealso: [](chapter_matrices), `Mat`, `MatCreateComposite()`, `MatCompositeGetMat()`, `MATCOMPOSITE`
 @*/
 PetscErrorCode MatCompositeAddMat(Mat mat, Mat smat)
 {
@@ -550,7 +553,7 @@ PetscErrorCode MatCompositeAddMat(Mat mat, Mat smat)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidHeaderSpecific(smat, MAT_CLASSID, 2);
   PetscUseMethod(mat, "MatCompositeAddMat_C", (Mat, Mat), (mat, smat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCompositeSetType_Composite(Mat mat, MatCompositeType type)
@@ -569,20 +572,22 @@ static PetscErrorCode MatCompositeSetType_Composite(Mat mat, MatCompositeType ty
     mat->ops->mult          = MatMult_Composite;
     mat->ops->multtranspose = MatMultTranspose_Composite;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatCompositeSetType - Indicates if the matrix is defined as the sum of a set of matrices or the product.
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
-.  mat - the composite matrix
++  mat - the composite matrix
+-  type - the `MatCompositeType` to use for the matrix
 
    Level: advanced
 
-.seealso: `MatDestroy()`, `MatMult()`, `MatCompositeAddMat()`, `MatCreateComposite()`, `MatCompositeGetType()`, `MATCOMPOSITE`
+.seealso: [](chapter_matrices), `Mat`, `MatDestroy()`, `MatMult()`, `MatCompositeAddMat()`, `MatCreateComposite()`, `MatCompositeGetType()`, `MATCOMPOSITE`,
+          `MatCompositeType`
 @*/
 PetscErrorCode MatCompositeSetType(Mat mat, MatCompositeType type)
 {
@@ -590,7 +595,7 @@ PetscErrorCode MatCompositeSetType(Mat mat, MatCompositeType type)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveEnum(mat, type, 2);
   PetscUseMethod(mat, "MatCompositeSetType_C", (Mat, MatCompositeType), (mat, type));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCompositeGetType_Composite(Mat mat, MatCompositeType *type)
@@ -599,7 +604,7 @@ static PetscErrorCode MatCompositeGetType_Composite(Mat mat, MatCompositeType *t
 
   PetscFunctionBegin;
   *type = b->type;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -615,7 +620,7 @@ static PetscErrorCode MatCompositeGetType_Composite(Mat mat, MatCompositeType *t
 
    Level: advanced
 
-.seealso: `MatCreateComposite()`, `MatCompositeSetType()`, `MATCOMPOSITE`, `MatCompositeType`
+.seealso: [](chapter_matrices), `Mat`, `MatCreateComposite()`, `MatCompositeSetType()`, `MATCOMPOSITE`, `MatCompositeType`
 @*/
 PetscErrorCode MatCompositeGetType(Mat mat, MatCompositeType *type)
 {
@@ -623,7 +628,7 @@ PetscErrorCode MatCompositeGetType(Mat mat, MatCompositeType *type)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidPointer(type, 2);
   PetscUseMethod(mat, "MatCompositeGetType_C", (Mat, MatCompositeType *), (mat, type));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCompositeSetMatStructure_Composite(Mat mat, MatStructure str)
@@ -632,7 +637,7 @@ static PetscErrorCode MatCompositeSetMatStructure_Composite(Mat mat, MatStructur
 
   PetscFunctionBegin;
   b->structure = str;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -649,14 +654,14 @@ static PetscErrorCode MatCompositeSetMatStructure_Composite(Mat mat, MatStructur
    Note:
     Information about the matrices structure is used in `MatCompositeMerge()` for additive composite matrix.
 
-.seealso: `MatAXPY()`, `MatCreateComposite()`, `MatCompositeMerge()` `MatCompositeGetMatStructure()`, `MATCOMPOSITE`
+.seealso: [](chapter_matrices), `Mat`, `MatAXPY()`, `MatCreateComposite()`, `MatCompositeMerge()` `MatCompositeGetMatStructure()`, `MATCOMPOSITE`
 @*/
 PetscErrorCode MatCompositeSetMatStructure(Mat mat, MatStructure str)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscUseMethod(mat, "MatCompositeSetMatStructure_C", (Mat, MatStructure), (mat, str));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCompositeGetMatStructure_Composite(Mat mat, MatStructure *str)
@@ -665,7 +670,7 @@ static PetscErrorCode MatCompositeGetMatStructure_Composite(Mat mat, MatStructur
 
   PetscFunctionBegin;
   *str = b->structure;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -681,7 +686,7 @@ static PetscErrorCode MatCompositeGetMatStructure_Composite(Mat mat, MatStructur
 
    Level: advanced
 
-.seealso: `MatCreateComposite()`, `MatCompositeSetMatStructure()`, `MATCOMPOSITE`
+.seealso: [](chapter_matrices), `Mat`, `MatCreateComposite()`, `MatCompositeSetMatStructure()`, `MATCOMPOSITE`
 @*/
 PetscErrorCode MatCompositeGetMatStructure(Mat mat, MatStructure *str)
 {
@@ -689,7 +694,7 @@ PetscErrorCode MatCompositeGetMatStructure(Mat mat, MatStructure *str)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidPointer(str, 2);
   PetscUseMethod(mat, "MatCompositeGetMatStructure_C", (Mat, MatStructure *), (mat, str));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCompositeSetMergeType_Composite(Mat mat, MatCompositeMergeType type)
@@ -698,13 +703,13 @@ static PetscErrorCode MatCompositeSetMergeType_Composite(Mat mat, MatCompositeMe
 
   PetscFunctionBegin;
   shell->mergetype = type;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatCompositeSetMergeType - Sets order of `MatCompositeMerge()`.
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
 +  mat - the composite matrix
@@ -714,11 +719,11 @@ static PetscErrorCode MatCompositeSetMergeType_Composite(Mat mat, MatCompositeMe
    Level: advanced
 
    Note:
-    The resulting matrix is the same regardles of the `MatCompositeMergeType`. Only the order of operation is changed.
+    The resulting matrix is the same regardless of the `MatCompositeMergeType`. Only the order of operation is changed.
     If set to `MAT_COMPOSITE_MERGE_RIGHT` the order of the merge is mat[nmat-1]*(mat[nmat-2]*(...*(mat[1]*mat[0])))
     otherwise the order is (((mat[nmat-1]*mat[nmat-2])*mat[nmat-3])*...)*mat[0].
 
-.seealso: `MatCreateComposite()`, `MatCompositeMerge()`, `MATCOMPOSITE`
+.seealso: [](chapter_matrices), `Mat`, `MatCreateComposite()`, `MatCompositeMerge()`, `MATCOMPOSITE`
 @*/
 PetscErrorCode MatCompositeSetMergeType(Mat mat, MatCompositeMergeType type)
 {
@@ -726,7 +731,7 @@ PetscErrorCode MatCompositeSetMergeType(Mat mat, MatCompositeMergeType type)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveEnum(mat, type, 2);
   PetscUseMethod(mat, "MatCompositeSetMergeType_C", (Mat, MatCompositeMergeType), (mat, type));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCompositeMerge_Composite(Mat mat)
@@ -783,7 +788,7 @@ static PetscErrorCode MatCompositeMerge_Composite(Mat mat)
   PetscCall(MatScale(mat, scale));
   PetscCall(VecDestroy(&left));
   PetscCall(VecDestroy(&right));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -804,14 +809,14 @@ static PetscErrorCode MatCompositeMerge_Composite(Mat mat)
    Note:
       The `MatType` of the resulting matrix will be the same as the `MatType` of the FIRST matrix in the composite matrix.
 
-.seealso: `MatDestroy()`, `MatMult()`, `MatCompositeAddMat()`, `MatCreateComposite()`, `MatCompositeSetMatStructure()`, `MatCompositeSetMergeType()`, `MATCOMPOSITE`
+.seealso: [](chapter_matrices), `Mat`, `MatDestroy()`, `MatMult()`, `MatCompositeAddMat()`, `MatCreateComposite()`, `MatCompositeSetMatStructure()`, `MatCompositeSetMergeType()`, `MATCOMPOSITE`
 @*/
 PetscErrorCode MatCompositeMerge(Mat mat)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscUseMethod(mat, "MatCompositeMerge_C", (Mat), (mat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCompositeGetNumberMat_Composite(Mat mat, PetscInt *nmat)
@@ -820,7 +825,7 @@ static PetscErrorCode MatCompositeGetNumberMat_Composite(Mat mat, PetscInt *nmat
 
   PetscFunctionBegin;
   *nmat = shell->nmat;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -836,7 +841,7 @@ static PetscErrorCode MatCompositeGetNumberMat_Composite(Mat mat, PetscInt *nmat
 
    Level: advanced
 
-.seealso: `MatCreateComposite()`, `MatCompositeGetMat()`, `MATCOMPOSITE`
+.seealso: [](chapter_matrices), `Mat`, `MatCreateComposite()`, `MatCompositeGetMat()`, `MATCOMPOSITE`
 @*/
 PetscErrorCode MatCompositeGetNumberMat(Mat mat, PetscInt *nmat)
 {
@@ -844,7 +849,7 @@ PetscErrorCode MatCompositeGetNumberMat(Mat mat, PetscInt *nmat)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidIntPointer(nmat, 2);
   PetscUseMethod(mat, "MatCompositeGetNumberMat_C", (Mat, PetscInt *), (mat, nmat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatCompositeGetMat_Composite(Mat mat, PetscInt i, Mat *Ai)
@@ -858,13 +863,13 @@ static PetscErrorCode MatCompositeGetMat_Composite(Mat mat, PetscInt i, Mat *Ai)
   ilink = shell->head;
   for (k = 0; k < i; k++) ilink = ilink->next;
   *Ai = ilink->mat;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatCompositeGetMat - Returns the ith matrix from the composite matrix.
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
 +  mat - the composite matrix
@@ -875,7 +880,7 @@ static PetscErrorCode MatCompositeGetMat_Composite(Mat mat, PetscInt i, Mat *Ai)
 
    Level: advanced
 
-.seealso: `MatCreateComposite()`, `MatCompositeGetNumberMat()`, `MatCompositeAddMat()`, `MATCOMPOSITE`
+.seealso: [](chapter_matrices), `Mat`, `MatCreateComposite()`, `MatCompositeGetNumberMat()`, `MatCompositeAddMat()`, `MATCOMPOSITE`
 @*/
 PetscErrorCode MatCompositeGetMat(Mat mat, PetscInt i, Mat *Ai)
 {
@@ -884,7 +889,7 @@ PetscErrorCode MatCompositeGetMat(Mat mat, PetscInt i, Mat *Ai)
   PetscValidLogicalCollectiveInt(mat, i, 2);
   PetscValidPointer(Ai, 3);
   PetscUseMethod(mat, "MatCompositeGetMat_C", (Mat, PetscInt, Mat *), (mat, i, Ai));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatCompositeSetScalings_Composite(Mat mat, const PetscScalar *scalings)
@@ -896,13 +901,13 @@ PetscErrorCode MatCompositeSetScalings_Composite(Mat mat, const PetscScalar *sca
   PetscCall(MatCompositeGetNumberMat(mat, &nmat));
   if (!shell->scalings) PetscCall(PetscMalloc1(nmat, &shell->scalings));
   PetscCall(PetscArraycpy(shell->scalings, scalings, nmat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatCompositeSetScalings - Sets separate scaling factors for component matrices.
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
 +  mat      - the composite matrix
@@ -910,7 +915,7 @@ PetscErrorCode MatCompositeSetScalings_Composite(Mat mat, const PetscScalar *sca
 
    Level: advanced
 
-.seealso: `MatScale()`, `MatDiagonalScale()`, `MATCOMPOSITE`
+.seealso: [](chapter_matrices), `Mat`, `MatScale()`, `MatDiagonalScale()`, `MATCOMPOSITE`
 @*/
 PetscErrorCode MatCompositeSetScalings(Mat mat, const PetscScalar *scalings)
 {
@@ -919,7 +924,7 @@ PetscErrorCode MatCompositeSetScalings(Mat mat, const PetscScalar *scalings)
   PetscValidScalarPointer(scalings, 2);
   PetscValidLogicalCollectiveScalar(mat, *scalings, 2);
   PetscUseMethod(mat, "MatCompositeSetScalings_C", (Mat, const PetscScalar *), (mat, scalings));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static struct _MatOps MatOps_Values = {NULL,
@@ -1072,18 +1077,19 @@ static struct _MatOps MatOps_Values = {NULL,
                                        NULL,
                                        NULL,
                                        NULL,
-                                       /*150*/ NULL};
+                                       /*150*/ NULL,
+                                       NULL};
 
 /*MC
    MATCOMPOSITE - A matrix defined by the sum (or product) of one or more matrices.
     The matrices need to have a correct size and parallel layout for the sum or product to be valid.
 
+  Level: advanced
+
    Note:
    To use the product of the matrices call `MatCompositeSetType`(mat,`MAT_COMPOSITE_MULTIPLICATIVE`);
 
-  Level: advanced
-
-.seealso: `MatCreateComposite()`, `MatCompositeSetScalings()`, `MatCompositeAddMat()`, `MatSetType()`, `MatCompositeSetType()`, `MatCompositeGetType()`,
+.seealso: [](chapter_matrices), `Mat`, `MatCreateComposite()`, `MatCompositeSetScalings()`, `MatCompositeAddMat()`, `MatSetType()`, `MatCompositeSetType()`, `MatCompositeGetType()`,
           `MatCompositeSetMatStructure()`, `MatCompositeGetMatStructure()`, `MatCompositeMerge()`, `MatCompositeSetMergeType()`, `MatCompositeGetNumberMat()`, `MatCompositeGetMat()`
 M*/
 
@@ -1121,5 +1127,5 @@ PETSC_EXTERN PetscErrorCode MatCreate_Composite(Mat A)
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatCompositeSetScalings_C", MatCompositeSetScalings_Composite));
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)A, MATCOMPOSITE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
