@@ -23,7 +23,7 @@ typedef struct {
   PetscInt     partial_dim;
   fftw_plan    p_forward, p_backward;
   unsigned     p_flag;                                      /* planner flags, FFTW_ESTIMATE,FFTW_MEASURE, FFTW_PATIENT, FFTW_EXHAUSTIVE */
-  PetscScalar *finarray, *foutarray, *binarray, *boutarray; /* keep track of arrays becaue fftw plan should be
+  PetscScalar *finarray, *foutarray, *binarray, *boutarray; /* keep track of arrays because fftw plan should be
                                                             executed for the arrays with which the plan was created */
 } Mat_FFTW;
 
@@ -37,15 +37,6 @@ extern PetscErrorCode MatMultTranspose_MPIFFTW(Mat, Vec, Vec);
 extern PetscErrorCode VecDestroy_MPIFFTW(Vec);
 #endif
 
-/*
-   MatMult_SeqFFTW performs forward DFT
-   Input parameter:
-     A - the matrix
-     x - the vector on which FDFT will be performed
-
-   Output parameter:
-     y - vector that stores result of FDFT
-*/
 PetscErrorCode MatMult_SeqFFTW(Mat A, Vec x, Vec y)
 {
   Mat_FFT           *fft  = (Mat_FFT *)A->data;
@@ -136,18 +127,9 @@ PetscErrorCode MatMult_SeqFFTW(Mat A, Vec x, Vec y)
   }
   PetscCall(VecRestoreArray(y, &y_array));
   PetscCall(VecRestoreArrayRead(x, &x_array));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* MatMultTranspose_SeqFFTW performs serial backward DFT
-   Input parameter:
-     A - the matrix
-     x - the vector on which BDFT will be performed
-
-   Output parameter:
-     y - vector that stores result of BDFT
-*/
-
 PetscErrorCode MatMultTranspose_SeqFFTW(Mat A, Vec x, Vec y)
 {
   Mat_FFT           *fft  = (Mat_FFT *)A->data;
@@ -217,18 +199,10 @@ PetscErrorCode MatMultTranspose_SeqFFTW(Mat A, Vec x, Vec y)
   }
   PetscCall(VecRestoreArray(y, &y_array));
   PetscCall(VecRestoreArrayRead(x, &x_array));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if !PetscDefined(HAVE_MPIUNI)
-/* MatMult_MPIFFTW performs forward DFT in parallel
-   Input parameter:
-     A - the matrix
-     x - the vector on which FDFT will be performed
-
-   Output parameter:
-   y   - vector that stores result of FDFT
-*/
 PetscErrorCode MatMult_MPIFFTW(Mat A, Vec x, Vec y)
 {
   Mat_FFT           *fft  = (Mat_FFT *)A->data;
@@ -287,18 +261,9 @@ PetscErrorCode MatMult_MPIFFTW(Mat A, Vec x, Vec y)
   }
   PetscCall(VecRestoreArray(y, &y_array));
   PetscCall(VecRestoreArrayRead(x, &x_array));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*
-   MatMultTranspose_MPIFFTW performs parallel backward DFT
-   Input parameter:
-     A - the matrix
-     x - the vector on which BDFT will be performed
-
-   Output parameter:
-     y - vector that stores result of BDFT
-*/
 PetscErrorCode MatMultTranspose_MPIFFTW(Mat A, Vec x, Vec y)
 {
   Mat_FFT           *fft  = (Mat_FFT *)A->data;
@@ -355,7 +320,7 @@ PetscErrorCode MatMultTranspose_MPIFFTW(Mat A, Vec x, Vec y)
   }
   PetscCall(VecRestoreArray(y, &y_array));
   PetscCall(VecRestoreArrayRead(x, &x_array));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
 
@@ -376,7 +341,7 @@ PetscErrorCode MatDestroy_FFTW(Mat A)
 #if !PetscDefined(HAVE_MPIUNI)
   fftw_mpi_cleanup();
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if !PetscDefined(HAVE_MPIUNI)
@@ -390,7 +355,7 @@ PetscErrorCode VecDestroy_MPIFFTW(Vec v)
   fftw_free((fftw_complex *)array);
   PetscCall(VecRestoreArray(v, &array));
   PetscCall(VecDestroy_MPI(v));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
 
@@ -402,7 +367,7 @@ static PetscErrorCode VecDuplicate_FFTW_fin(Vec fin, Vec *fin_new)
   PetscFunctionBegin;
   PetscCall(PetscObjectQuery((PetscObject)fin, "FFTmatrix", (PetscObject *)&A));
   PetscCall(MatCreateVecsFFTW_FFTW(A, fin_new, NULL, NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecDuplicate_FFTW_fout(Vec fout, Vec *fout_new)
@@ -412,7 +377,7 @@ static PetscErrorCode VecDuplicate_FFTW_fout(Vec fout, Vec *fout_new)
   PetscFunctionBegin;
   PetscCall(PetscObjectQuery((PetscObject)fout, "FFTmatrix", (PetscObject *)&A));
   PetscCall(MatCreateVecsFFTW_FFTW(A, NULL, fout_new, NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecDuplicate_FFTW_bout(Vec bout, Vec *bout_new)
@@ -422,7 +387,7 @@ static PetscErrorCode VecDuplicate_FFTW_bout(Vec bout, Vec *bout_new)
   PetscFunctionBegin;
   PetscCall(PetscObjectQuery((PetscObject)bout, "FFTmatrix", (PetscObject *)&A));
   PetscCall(MatCreateVecsFFTW_FFTW(A, NULL, NULL, bout_new));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
 
@@ -430,7 +395,7 @@ static PetscErrorCode VecDuplicate_FFTW_bout(Vec bout, Vec *bout_new)
    MatCreateVecsFFTW - Get vector(s) compatible with the matrix, i.e. with the
      parallel layout determined by `MATFFTW`
 
-   Collective on Mat
+   Collective
 
    Input Parameter:
 .   A - the matrix
@@ -440,6 +405,9 @@ static PetscErrorCode VecDuplicate_FFTW_bout(Vec bout, Vec *bout_new)
 .   y - (optional) output vector of forward FFTW
 -   z - (optional) output vector of backward FFTW
 
+   Options Database Key:
+.  -mat_fftw_plannerflags - set FFTW planner flags
+
   Level: advanced
 
   Notes:
@@ -461,13 +429,13 @@ static PetscErrorCode VecDuplicate_FFTW_bout(Vec bout, Vec *bout_new)
   Developer Note:
   How come `MatCreateVecs()` doesn't produce the correctly padded vectors automatically?
 
-.seealso: `MATFFTW`, `MatCreateFFT()`, `MatCreateVecs()`
+.seealso: [](chapter_matrices), `Mat`, `MATFFTW`, `MatCreateFFT()`, `MatCreateVecs()`
 @*/
 PetscErrorCode MatCreateVecsFFTW(Mat A, Vec *x, Vec *y, Vec *z)
 {
   PetscFunctionBegin;
   PetscUseMethod(A, "MatCreateVecsFFTW_C", (Mat, Vec *, Vec *, Vec *), (A, x, y, z));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatCreateVecsFFTW_FFTW(Mat A, Vec *fin, Vec *fout, Vec *bout)
@@ -699,26 +667,26 @@ PetscErrorCode MatCreateVecsFFTW_FFTW(Mat A, Vec *fin, Vec *fout, Vec *bout)
     }
     /* fftw vectors have their data array allocated by fftw_malloc, such that v->array=xxx but
        v->array_allocated=NULL. A regular replacearray call won't free the memory and only causes
-       memory leaks. We void these pointers here to avoid acident uses.
+       memory leaks. We void these pointers here to avoid accident uses.
     */
     if (fin) (*fin)->ops->replacearray = NULL;
     if (fout) (*fout)->ops->replacearray = NULL;
     if (bout) (*bout)->ops->replacearray = NULL;
 #endif
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    VecScatterPetscToFFTW - Copies a PETSc vector to the vector that goes into `MATFFTW` calls.
 
-   Collective on Mat
+   Collective
 
    Input Parameters:
 +  A - FFTW matrix
 -  x - the PETSc vector
 
-   Output Parameters:
+   Output Parameter:
 .  y - the FFTW vector
 
    Level: intermediate
@@ -728,13 +696,13 @@ PetscErrorCode MatCreateVecsFFTW_FFTW(Mat A, Vec *fin, Vec *fout, Vec *bout)
    one is not doing in-place transform. The last dimension size must be changed to 2*(dim[last]/2+1) to accommodate these extra
    zeros. This routine does that job by scattering operation.
 
-.seealso: `MATFFTW`, `VecScatterFFTWToPetsc()`, `MatCreateVecsFFTW()`
+.seealso: [](chapter_matrices), `Mat`, `MATFFTW`, `VecScatterFFTWToPetsc()`, `MatCreateVecsFFTW()`
 @*/
 PetscErrorCode VecScatterPetscToFFTW(Mat A, Vec x, Vec y)
 {
   PetscFunctionBegin;
   PetscUseMethod(A, "VecScatterPetscToFFTW_C", (Mat, Vec, Vec), (A, x, y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode VecScatterPetscToFFTW_FFTW(Mat A, Vec x, Vec y)
@@ -941,19 +909,19 @@ PetscErrorCode VecScatterPetscToFFTW_FFTW(Mat A, Vec x, Vec y)
     }
 #endif
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    VecScatterFFTWToPetsc - Converts `MATFFTW` output vector to a PETSc vector.
 
-   Collective on Mat
+   Collective
 
     Input Parameters:
 +   A - `MATFFTW` matrix
 -   x - FFTW vector
 
-   Output Parameters:
+   Output Parameter:
 .  y - PETSc vector
 
    Level: intermediate
@@ -962,13 +930,13 @@ PetscErrorCode VecScatterPetscToFFTW_FFTW(Mat A, Vec x, Vec y)
    While doing real transform the FFTW output of backward DFT contains extra zeros at the end of last dimension.
    `VecScatterFFTWToPetsc()` removes those extra zeros.
 
-.seealso: `VecScatterPetscToFFTW()`, `MATFFTW`, `MatCreateVecsFFTW()`
+.seealso: [](chapter_matrices), `Mat`, `VecScatterPetscToFFTW()`, `MATFFTW`, `MatCreateVecsFFTW()`
 @*/
 PetscErrorCode VecScatterFFTWToPetsc(Mat A, Vec x, Vec y)
 {
   PetscFunctionBegin;
   PetscUseMethod(A, "VecScatterFFTWToPetsc_C", (Mat, Vec, Vec), (A, x, y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode VecScatterFFTWToPetsc_FFTW(Mat A, Vec x, Vec y)
@@ -1166,18 +1134,16 @@ PetscErrorCode VecScatterFFTWToPetsc_FFTW(Mat A, Vec x, Vec y)
     }
 #endif
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*
-    MatCreate_FFTW - Creates a matrix object that provides FFT via the external package FFTW
+/*MC
+  MATFFTW -  "fftw" - Matrix type that provides FFT via the FFTW external package.
 
-  Options Database Keys:
-+ -mat_fftw_plannerflags - set FFTW planner flags
+  Level: intermediate
 
-   Level: intermediate
-
-*/
+.seealso: [](chapter_matrices), `Mat`, `MatCreate()`, `MatType`, `MatCreateFFT()`
+M*/
 PETSC_EXTERN PetscErrorCode MatCreate_FFTW(Mat A)
 {
   MPI_Comm    comm;
@@ -1336,5 +1302,5 @@ PETSC_EXTERN PetscErrorCode MatCreate_FFTW(Mat A)
   PetscCall(PetscOptionsEList("-mat_fftw_plannerflags", "Planner Flags", "None", plans, 4, plans[0], &p_flag, &flg));
   if (flg) fftw->p_flag = iplans[p_flag];
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
