@@ -15,7 +15,7 @@ static PetscBool MatMFFDPackageInitialized = PETSC_FALSE;
 
   Level: developer
 
-.seealso: `MATMFFD`, `PetscFinalize()`, `MatCreateMFFD()`, `MatCreateSNESMF()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `PetscFinalize()`, `MatCreateMFFD()`, `MatCreateSNESMF()`
 @*/
 PetscErrorCode MatMFFDFinalizePackage(void)
 {
@@ -23,7 +23,7 @@ PetscErrorCode MatMFFDFinalizePackage(void)
   PetscCall(PetscFunctionListDestroy(&MatMFFDList));
   MatMFFDPackageInitialized = PETSC_FALSE;
   MatMFFDRegisterAllCalled  = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -32,7 +32,7 @@ PetscErrorCode MatMFFDFinalizePackage(void)
 
   Level: developer
 
-.seealso: `MATMFFD`, `PetscInitialize()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `PetscInitialize()`
 @*/
 PetscErrorCode MatMFFDInitializePackage(void)
 {
@@ -40,7 +40,7 @@ PetscErrorCode MatMFFDInitializePackage(void)
   PetscBool opt, pkg;
 
   PetscFunctionBegin;
-  if (MatMFFDPackageInitialized) PetscFunctionReturn(0);
+  if (MatMFFDPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   MatMFFDPackageInitialized = PETSC_TRUE;
   /* Register Classes */
   PetscCall(PetscClassIdRegister("MatMFFD", &MATMFFD_CLASSID));
@@ -63,7 +63,7 @@ PetscErrorCode MatMFFDInitializePackage(void)
   }
   /* Register package finalizer */
   PetscCall(PetscRegisterFinalize(MatMFFDFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMFFDSetType_MFFD(Mat mat, MatMFFDType ftype)
@@ -79,7 +79,7 @@ static PetscErrorCode MatMFFDSetType_MFFD(Mat mat, MatMFFDType ftype)
 
   /* already set, so just return */
   PetscCall(PetscObjectTypeCompare((PetscObject)ctx, ftype, &match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* destroy the old one if it exists */
   PetscTryTypeMethod(ctx, destroy);
@@ -88,12 +88,12 @@ static PetscErrorCode MatMFFDSetType_MFFD(Mat mat, MatMFFDType ftype)
   PetscCheck(r, PETSC_COMM_SELF, PETSC_ERR_ARG_UNKNOWN_TYPE, "Unknown MatMFFD type %s given", ftype);
   PetscCall((*r)(ctx));
   PetscCall(PetscObjectChangeTypeName((PetscObject)ctx, ftype));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     MatMFFDSetType - Sets the method that is used to compute the
-    differencing parameter for finite differene matrix-free formulations.
+    differencing parameter for finite difference matrix-free formulations.
 
     Input Parameters:
 +   mat - the "matrix-free" matrix created via `MatCreateSNESMF()`, or `MatCreateMFFD()`
@@ -103,14 +103,16 @@ static PetscErrorCode MatMFFDSetType_MFFD(Mat mat, MatMFFDType ftype)
     Level: advanced
 
     Note:
-    For example, such routines can compute h for use in
+    For example, such routines can compute `h` for use in
     Jacobian-vector products of the form
+.vb
 
                         F(x+ha) - F(x)
           F'(u)a  ~=  ----------------
                               h
+.ve
 
-.seealso: `MATMFFD`, `MATMFFD_WP`, `MATMFFD_DS`, `MatCreateSNESMF()`, `MatMFFDRegister()`, `MatMFFDSetFunction()`, `MatCreateMFFD()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MATMFFD_WP`, `MATMFFD_DS`, `MatCreateSNESMF()`, `MatMFFDRegister()`, `MatMFFDSetFunction()`, `MatCreateMFFD()`
 @*/
 PetscErrorCode MatMFFDSetType(Mat mat, MatMFFDType ftype)
 {
@@ -118,7 +120,7 @@ PetscErrorCode MatMFFDSetType(Mat mat, MatMFFDType ftype)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidCharPointer(ftype, 2);
   PetscTryMethod(mat, "MatMFFDSetType_C", (Mat, MatMFFDType), (mat, ftype));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatGetDiagonal_MFFD(Mat, Vec);
@@ -131,7 +133,7 @@ static PetscErrorCode MatMFFDSetFunctioniBase_MFFD(Mat mat, FCN1 func)
   PetscFunctionBegin;
   PetscCall(MatShellGetContext(mat, &ctx));
   ctx->funcisetbase = func;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 typedef PetscErrorCode (*FCN2)(void *, PetscInt, Vec, PetscScalar *); /* force argument to next function to not be extern C*/
@@ -143,7 +145,7 @@ static PetscErrorCode MatMFFDSetFunctioni_MFFD(Mat mat, FCN2 funci)
   PetscCall(MatShellGetContext(mat, &ctx));
   ctx->funci = funci;
   PetscCall(MatShellSetOperation(mat, MATOP_GET_DIAGONAL, (void (*)(void))MatGetDiagonal_MFFD));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMFFDGetH_MFFD(Mat mat, PetscScalar *h)
@@ -153,7 +155,7 @@ static PetscErrorCode MatMFFDGetH_MFFD(Mat mat, PetscScalar *h)
   PetscFunctionBegin;
   PetscCall(MatShellGetContext(mat, &ctx));
   *h = ctx->currenth;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMFFDResetHHistory_MFFD(Mat J)
@@ -163,17 +165,17 @@ static PetscErrorCode MatMFFDResetHHistory_MFFD(Mat J)
   PetscFunctionBegin;
   PetscCall(MatShellGetContext(J, &ctx));
   ctx->ncurrenth = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   MatMFFDRegister - Adds a method to the MATMFFD` registry.
+   MatMFFDRegister - Adds a method to the `MATMFFD` registry.
 
    Not Collective
 
    Input Parameters:
-+  name_solver - name of a new user-defined compute-h module
--  routine_create - routine to create method context
++  sname - name of a new user-defined compute-h module
+-  function - routine to create method context
 
    Level: developer
 
@@ -190,17 +192,16 @@ $     `MatMFFDSetType`(mfctx,"my_h")
    or at runtime via the option
 $     -mat_mffd_type my_h
 
-.seealso: `MATMFFD`, `MatMFFDRegisterAll()`, `MatMFFDRegisterDestroy()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatMFFDRegisterAll()`, `MatMFFDRegisterDestroy()`
  @*/
 PetscErrorCode MatMFFDRegister(const char sname[], PetscErrorCode (*function)(MatMFFD))
 {
   PetscFunctionBegin;
   PetscCall(MatInitializePackage());
   PetscCall(PetscFunctionListAdd(&MatMFFDList, sname, function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* ----------------------------------------------------------------------------------------*/
 static PetscErrorCode MatDestroy_MFFD(Mat mat)
 {
   MatMFFD ctx;
@@ -226,7 +227,7 @@ static PetscErrorCode MatDestroy_MFFD(Mat mat)
   PetscCall(PetscObjectComposeFunction((PetscObject)mat, "MatMFFDGetH_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)mat, "MatSNESMFSetReuseBase_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)mat, "MatSNESMFGetReuseBase_C", NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -269,7 +270,7 @@ static PetscErrorCode MatView_MFFD(Mat J, PetscViewer viewer)
     }
     PetscCall(PetscViewerASCIIPopTab(viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -289,7 +290,7 @@ PETSC_EXTERN PetscErrorCode MatAssemblyEnd_MFFD(Mat J, MatAssemblyType mt)
   PetscFunctionBegin;
   PetscCall(MatShellGetContext(J, &j));
   PetscCall(MatMFFDResetHHistory(J));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -330,7 +331,7 @@ static PetscErrorCode MatMult_MFFD(Mat mat, Vec a, Vec y)
   if (zeroa) {
     PetscCall(VecSet(y, 0.0));
     PetscCall(PetscLogEventEnd(MATMFFD_Mult, a, y, 0, 0));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCheck(!mat->erroriffailure || !PetscIsInfOrNanScalar(h), PETSC_COMM_SELF, PETSC_ERR_PLIB, "Computed Nan differencing parameter h");
@@ -371,7 +372,7 @@ static PetscErrorCode MatMult_MFFD(Mat mat, Vec a, Vec y)
   if (mat->nullsp) PetscCall(MatNullSpaceRemove(mat->nullsp, y));
 
   PetscCall(PetscLogEventEnd(MATMFFD_Mult, a, y, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -420,7 +421,7 @@ PetscErrorCode MatGetDiagonal_MFFD(Mat mat, Vec a)
     PetscCall(VecRestoreArray(w, &ww));
   }
   PetscCall(VecRestoreArray(a, &aa));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_EXTERN PetscErrorCode MatMFFDSetBase_MFFD(Mat J, Vec U, Vec F)
@@ -447,7 +448,7 @@ PETSC_EXTERN PetscErrorCode MatMFFDSetBase_MFFD(Mat J, Vec U, Vec F)
   }
   if (!ctx->w) PetscCall(VecDuplicate(ctx->current_u, &ctx->w));
   J->assembled = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 typedef PetscErrorCode (*FCN3)(void *, Vec, Vec, PetscScalar *); /* force argument to next function to not be extern C*/
@@ -460,14 +461,14 @@ static PetscErrorCode MatMFFDSetCheckh_MFFD(Mat J, FCN3 fun, void *ectx)
   PetscCall(MatShellGetContext(J, &ctx));
   ctx->checkh    = fun;
   ctx->checkhctx = ectx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatMFFDSetOptionsPrefix - Sets the prefix used for searching for all
    MATMFFD` options in the database.
 
-   Collective on mat
+   Collective
 
    Input Parameters:
 +  A - the `MATMFFD` context
@@ -479,7 +480,7 @@ static PetscErrorCode MatMFFDSetCheckh_MFFD(Mat J, FCN3 fun, void *ectx)
 
    Level: advanced
 
-.seealso: `MATMFFD`, `MatSetFromOptions()`, `MatCreateSNESMF()`, `MatCreateMFFD()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatSetFromOptions()`, `MatCreateSNESMF()`, `MatCreateMFFD()`
 @*/
 PetscErrorCode MatMFFDSetOptionsPrefix(Mat mat, const char prefix[])
 {
@@ -490,7 +491,7 @@ PetscErrorCode MatMFFDSetOptionsPrefix(Mat mat, const char prefix[])
   PetscCall(MatShellGetContext(mat, &mfctx));
   PetscValidHeaderSpecific(mfctx, MATMFFD_CLASSID, 1);
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)mfctx, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatSetFromOptions_MFFD(Mat mat, PetscOptionItems *PetscOptionsObject)
@@ -517,7 +518,7 @@ static PetscErrorCode MatSetFromOptions_MFFD(Mat mat, PetscOptionItems *PetscOpt
 #endif
   PetscTryTypeMethod(mfctx, setfromoptions, PetscOptionsObject);
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMFFDSetPeriod_MFFD(Mat mat, PetscInt period)
@@ -527,7 +528,7 @@ static PetscErrorCode MatMFFDSetPeriod_MFFD(Mat mat, PetscInt period)
   PetscFunctionBegin;
   PetscCall(MatShellGetContext(mat, &ctx));
   ctx->recomputeperiod = period;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMFFDSetFunction_MFFD(Mat mat, PetscErrorCode (*func)(void *, Vec, Vec), void *funcctx)
@@ -538,17 +539,19 @@ static PetscErrorCode MatMFFDSetFunction_MFFD(Mat mat, PetscErrorCode (*func)(vo
   PetscCall(MatShellGetContext(mat, &ctx));
   ctx->func    = func;
   ctx->funcctx = funcctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatMFFDSetFunctionError_MFFD(Mat mat, PetscReal error)
 {
-  MatMFFD ctx;
-
   PetscFunctionBegin;
-  PetscCall(MatShellGetContext(mat, &ctx));
-  if (error != PETSC_DEFAULT) ctx->error_rel = error;
-  PetscFunctionReturn(0);
+  if (error != (PetscReal)PETSC_DEFAULT) {
+    MatMFFD ctx;
+
+    PetscCall(MatShellGetContext(mat, &ctx));
+    ctx->error_rel = error;
+  }
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMFFDSetHHistory_MFFD(Mat J, PetscScalar history[], PetscInt nhistory)
@@ -560,17 +563,18 @@ PetscErrorCode MatMFFDSetHHistory_MFFD(Mat J, PetscScalar history[], PetscInt nh
   ctx->historyh    = history;
   ctx->maxcurrenth = nhistory;
   ctx->currenth    = 0.;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
-  MATMFFD - MATMFFD = "mffd" - A matrix free matrix type.
+  MATMFFD - "mffd" - A matrix free matrix type.
 
   Level: advanced
 
-  Developers Note: This is implemented on top of `MATSHELL` to get support for scaling and shifting without requiring duplicate code
+  Developers Note:
+  This is implemented on top of `MATSHELL` to get support for scaling and shifting without requiring duplicate code
 
-.seealso: `MatCreateMFFD()`, `MatCreateSNESMF()`, `MatMFFDSetFunction()`, `MatMFFDSetType()`,
+.seealso: [](chapter_matrices), `Mat`, `MatCreateMFFD()`, `MatCreateSNESMF()`, `MatMFFDSetFunction()`, `MatMFFDSetType()`,
           `MatMFFDSetFunctionError()`, `MatMFFDDSSetUmin()`, `MatMFFDSetFunction()`
           `MatMFFDSetHHistory()`, `MatMFFDResetHHistory()`, `MatCreateSNESMF()`,
           `MatMFFDGetH()`,
@@ -630,7 +634,7 @@ PETSC_EXTERN PetscErrorCode MatCreate_MFFD(Mat A)
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatMFFDSetType_C", MatMFFDSetType_MFFD));
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatMFFDGetH_C", MatMFFDGetH_MFFD));
   PetscCall(PetscObjectChangeTypeName((PetscObject)A, MATMFFD));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -640,14 +644,14 @@ PETSC_EXTERN PetscErrorCode MatCreate_MFFD(Mat A)
 
    Input Parameters:
 +  comm - MPI communicator
-.  m - number of local rows (or `PETSC_DECIDE` to have calculated if M is given)
+.  m - number of local rows (or `PETSC_DECIDE` to have calculated if `M` is given)
            This value should be the same as the local size used in creating the
            y vector for the matrix-vector product y = Ax.
 .  n - This value should be the same as the local size used in creating the
        x vector for the matrix-vector product y = Ax. (or `PETSC_DECIDE` to have
-       calculated if N is given) For square matrices n is almost always m.
-.  M - number of global rows (or `PETSC_DETERMINE` to have calculated if m is given)
--  N - number of global columns (or `PETSC_DETERMINE` to have calculated if n is given)
+       calculated if `N` is given) For square matrices `n` is almost always `m`.
+.  M - number of global rows (or `PETSC_DETERMINE` to have calculated if `m` is given)
+-  N - number of global columns (or `PETSC_DETERMINE` to have calculated if `n` is given)
 
    Output Parameter:
 .  J - the matrix-free matrix
@@ -656,7 +660,7 @@ PETSC_EXTERN PetscErrorCode MatCreate_MFFD(Mat A)
 +  -mat_mffd_type - wp or ds (see `MATMFFD_WP` or `MATMFFD_DS`)
 .  -mat_mffd_err - square root of estimated relative error in function evaluation
 .  -mat_mffd_period - how often h is recomputed, defaults to 1, every time
-.  -mat_mffd_check_positivity - possibly decrease h until U + h*a has only positive values
+.  -mat_mffd_check_positivity - possibly decrease `h` until U + h*a has only positive values
 .  -mat_mffd_umin <umin> - Sets umin (for default PETSc routine that computes h only)
 -  -mat_mffd_complex - use the Lyness trick with complex numbers to compute the matrix-vector product instead of differencing
                        (requires real valued functions but that PETSc be configured for complex numbers)
@@ -683,12 +687,12 @@ PETSC_EXTERN PetscErrorCode MatCreate_MFFD(Mat A)
    preconditioner matrix
 
    The user can set the error_rel via `MatMFFDSetFunctionError()` and
-   umin via `MatMFFDDSSetUmin()`; see Users-Manual: ch_snes for details.
+   umin via `MatMFFDDSSetUmin()`.
 
    The user should call `MatDestroy()` when finished with the matrix-free
    matrix context.
 
-.seealso: `MATMFFD`, `MatDestroy()`, `MatMFFDSetFunctionError()`, `MatMFFDDSSetUmin()`, `MatMFFDSetFunction()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatDestroy()`, `MatMFFDSetFunctionError()`, `MatMFFDDSSetUmin()`, `MatMFFDSetFunction()`
           `MatMFFDSetHHistory()`, `MatMFFDResetHHistory()`, `MatCreateSNESMF()`,
           `MatMFFDGetH()`, `MatMFFDRegister()`, `MatMFFDComputeJacobian()`
 @*/
@@ -699,7 +703,7 @@ PetscErrorCode MatCreateMFFD(MPI_Comm comm, PetscInt m, PetscInt n, PetscInt M,
   PetscCall(MatSetSizes(*J, m, n, M, N));
   PetscCall(MatSetType(*J, MATMFFD));
   PetscCall(MatSetUp(*J));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -716,7 +720,7 @@ PetscErrorCode MatCreateMFFD(MPI_Comm comm, PetscInt m, PetscInt n, PetscInt M,
 
    Level: advanced
 
-.seealso: `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDSetHHistory()`, `MatCreateMFFD()`, `MATMFFD`, `MatMFFDResetHHistory()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDSetHHistory()`, `MatCreateMFFD()`, `MATMFFD`, `MatMFFDResetHHistory()`
 @*/
 PetscErrorCode MatMFFDGetH(Mat mat, PetscScalar *h)
 {
@@ -724,22 +728,21 @@ PetscErrorCode MatMFFDGetH(Mat mat, PetscScalar *h)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidScalarPointer(h, 2);
   PetscUseMethod(mat, "MatMFFDGetH_C", (Mat, PetscScalar *), (mat, h));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatMFFDSetFunction - Sets the function used in applying the matrix free `MATMFFD` matrix.
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
 +  mat - the matrix free matrix `MATMFFD` created via `MatCreateSNESMF()` or `MatCreateMFFD()`
 .  func - the function to use
 -  funcctx - optional function context passed to function
 
-   Calling Sequence of func:
-$     func (void *funcctx, Vec x, Vec f)
-
+   Calling Sequence of `func`:
+$  PetscErrorCode func(void *funcctx, Vec x, Vec f)
 +  funcctx - user provided context
 .  x - input vector
 -  f - computed output function
@@ -752,7 +755,7 @@ $     func (void *funcctx, Vec x, Vec f)
 
     If this is not set then it will use the function set with `SNESSetFunction()` if `MatCreateSNESMF()` was used.
 
-.seealso: `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDGetH()`, `MatCreateMFFD()`, `MATMFFD`,
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDGetH()`, `MatCreateMFFD()`, `MATMFFD`,
           `MatMFFDSetHHistory()`, `MatMFFDResetHHistory()`, `SNESetFunction()`
 @*/
 PetscErrorCode MatMFFDSetFunction(Mat mat, PetscErrorCode (*func)(void *, Vec, Vec), void *funcctx)
@@ -760,13 +763,13 @@ PetscErrorCode MatMFFDSetFunction(Mat mat, PetscErrorCode (*func)(void *, Vec, V
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscTryMethod(mat, "MatMFFDSetFunction_C", (Mat, PetscErrorCode(*)(void *, Vec, Vec), void *), (mat, func, funcctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatMFFDSetFunctioni - Sets the function for a single component for a `MATMFFD` matrix
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
 +  mat - the matrix free matrix `MATMFFD`
@@ -781,20 +784,20 @@ PetscErrorCode MatMFFDSetFunction(Mat mat, PetscErrorCode (*func)(void *, Vec, V
     This function is necessary to compute the diagonal of the matrix.
     funci must not contain any MPI call as it is called inside a loop on the local portion of the vector.
 
-.seealso: `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDGetH()`, `MatMFFDSetHHistory()`, `MatMFFDResetHHistory()`, `SNESetFunction()`, `MatGetDiagonal()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDGetH()`, `MatMFFDSetHHistory()`, `MatMFFDResetHHistory()`, `SNESetFunction()`, `MatGetDiagonal()`
 @*/
 PetscErrorCode MatMFFDSetFunctioni(Mat mat, PetscErrorCode (*funci)(void *, PetscInt, Vec, PetscScalar *))
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscTryMethod(mat, "MatMFFDSetFunctioni_C", (Mat, PetscErrorCode(*)(void *, PetscInt, Vec, PetscScalar *)), (mat, funci));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatMFFDSetFunctioniBase - Sets the base vector for a single component function evaluation for a `MATMFFD` matrix
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
 +  mat - the `MATMFFD` matrix free matrix
@@ -808,7 +811,7 @@ PetscErrorCode MatMFFDSetFunctioni(Mat mat, PetscErrorCode (*funci)(void *, Pets
 
     This function is necessary to compute the diagonal of the matrix, used for example with `PCJACOBI`
 
-.seealso: `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDGetH()`, `MatCreateMFFD()`, `MATMFFD`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDGetH()`, `MatCreateMFFD()`, `MATMFFD`
           `MatMFFDSetHHistory()`, `MatMFFDResetHHistory()`, `SNESetFunction()`, `MatGetDiagonal()`
 @*/
 PetscErrorCode MatMFFDSetFunctioniBase(Mat mat, PetscErrorCode (*func)(void *, Vec))
@@ -816,24 +819,24 @@ PetscErrorCode MatMFFDSetFunctioniBase(Mat mat, PetscErrorCode (*func)(void *, V
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscTryMethod(mat, "MatMFFDSetFunctioniBase_C", (Mat, PetscErrorCode(*)(void *, Vec)), (mat, func));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatMFFDSetPeriod - Sets how often h is recomputed for a `MATMFFD` matrix, by default it is every time
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
 +  mat - the `MATMFFD` matrix free matrix
 -  period - 1 for every time, 2 for every second etc
 
-   Options Database Keys:
-.  -mat_mffd_period <period> - Sets how often h is recomputed
+   Options Database Key:
+.  -mat_mffd_period <period> - Sets how often `h` is recomputed
 
    Level: advanced
 
-.seealso: `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDGetH()`,
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDGetH()`,
           `MatMFFDSetHHistory()`, `MatMFFDResetHHistory()`
 @*/
 PetscErrorCode MatMFFDSetPeriod(Mat mat, PetscInt period)
@@ -842,19 +845,19 @@ PetscErrorCode MatMFFDSetPeriod(Mat mat, PetscInt period)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveInt(mat, period, 2);
   PetscTryMethod(mat, "MatMFFDSetPeriod_C", (Mat, PetscInt), (mat, period));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatMFFDSetFunctionError - Sets the error_rel for the approximation of matrix-vector products using finite differences with the `MATMFFD` matrix
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
 +  mat - the `MATMFFD` matrix free matrix
 -  error_rel - relative error (should be set to the square root of the relative error in the function evaluations)
 
-   Options Database Keys:
+   Options Database Key:
 .  -mat_mffd_err <error_rel> - Sets error_rel
 
    Level: advanced
@@ -867,7 +870,7 @@ PetscErrorCode MatMFFDSetPeriod(Mat mat, PetscInt period)
        = error_rel*umin*sign(u'a)*||a||_{1}/||a||^2   else
 .ve
 
-.seealso: `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDGetH()`, `MatCreateMFFD()`, `MATMFFD`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatCreateSNESMF()`, `MatMFFDGetH()`, `MatCreateMFFD()`, `MATMFFD`
           `MatMFFDSetHHistory()`, `MatMFFDResetHHistory()`
 @*/
 PetscErrorCode MatMFFDSetFunctionError(Mat mat, PetscReal error)
@@ -876,14 +879,14 @@ PetscErrorCode MatMFFDSetFunctionError(Mat mat, PetscReal error)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveReal(mat, error, 2);
   PetscTryMethod(mat, "MatMFFDSetFunctionError_C", (Mat, PetscReal), (mat, error));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatMFFDSetHHistory - Sets an array to collect a history of the
    differencing values (h) computed for the matrix-free product `MATMFFD` matrix
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
 +  J - the `MATMFFD` matrix-free matrix
@@ -897,7 +900,7 @@ PetscErrorCode MatMFFDSetFunctionError(Mat mat, PetscReal error)
    Use `MatMFFDResetHHistory()` to reset the history counter and collect
    a new batch of differencing parameters, h.
 
-.seealso: `MATMFFD`, `MatMFFDGetH()`, `MatCreateSNESMF()`,
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatMFFDGetH()`, `MatCreateSNESMF()`,
           `MatMFFDResetHHistory()`, `MatMFFDSetFunctionError()`
 @*/
 PetscErrorCode MatMFFDSetHHistory(Mat J, PetscScalar history[], PetscInt nhistory)
@@ -907,16 +910,16 @@ PetscErrorCode MatMFFDSetHHistory(Mat J, PetscScalar history[], PetscInt nhistor
   if (history) PetscValidScalarPointer(history, 2);
   PetscValidLogicalCollectiveInt(J, nhistory, 3);
   PetscUseMethod(J, "MatMFFDSetHHistory_C", (Mat, PetscScalar[], PetscInt), (J, history, nhistory));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatMFFDResetHHistory - Resets the counter to zero to begin
    collecting a new set of differencing histories for the `MATMFFD` matrix
 
-   Logically Collective on mat
+   Logically Collective
 
-   Input Parameters:
+   Input Parameter:
 .  J - the matrix-free matrix context
 
    Level: advanced
@@ -924,7 +927,7 @@ PetscErrorCode MatMFFDSetHHistory(Mat J, PetscScalar history[], PetscInt nhistor
    Note:
    Use `MatMFFDSetHHistory()` to create the original history counter.
 
-.seealso: `MATMFFD`, `MatMFFDGetH()`, `MatCreateSNESMF()`,
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatMFFDGetH()`, `MatCreateSNESMF()`,
           `MatMFFDSetHHistory()`, `MatMFFDSetFunctionError()`
 @*/
 PetscErrorCode MatMFFDResetHHistory(Mat J)
@@ -932,29 +935,29 @@ PetscErrorCode MatMFFDResetHHistory(Mat J)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(J, MAT_CLASSID, 1);
   PetscTryMethod(J, "MatMFFDResetHHistory_C", (Mat), (J));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-    MatMFFDSetBase - Sets the vector U at which matrix vector products of the
+    MatMFFDSetBase - Sets the vector `U` at which matrix vector products of the
         Jacobian are computed for the `MATMFFD` matrix
 
-    Logically Collective on mat
+    Logically Collective
 
     Input Parameters:
 +   J - the `MATMFFD` matrix
 .   U - the vector
 -   F - (optional) vector that contains F(u) if it has been already computed
 
+    Level: advanced
+
     Notes:
     This is rarely used directly
 
-    If F is provided then it is not recomputed. Otherwise the function is evaluated at the base
+    If `F` is provided then it is not recomputed. Otherwise the function is evaluated at the base
     point during the first `MatMult()` after each call to `MatMFFDSetBase()`.
 
-    Level: advanced
-
-.seealso: `MATMFFD`, `MatMult()`, `MatMFFDSetBase()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatMult()`, `MatMFFDSetBase()`
 @*/
 PetscErrorCode MatMFFDSetBase(Mat J, Vec U, Vec F)
 {
@@ -963,18 +966,18 @@ PetscErrorCode MatMFFDSetBase(Mat J, Vec U, Vec F)
   PetscValidHeaderSpecific(U, VEC_CLASSID, 2);
   if (F) PetscValidHeaderSpecific(F, VEC_CLASSID, 3);
   PetscTryMethod(J, "MatMFFDSetBase_C", (Mat, Vec, Vec), (J, U, F));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     MatMFFDSetCheckh - Sets a function that checks the computed h and adjusts
         it to satisfy some criteria for the `MATMFFD` matrix
 
-    Logically Collective on mat
+    Logically Collective
 
     Input Parameters:
 +   J - the `MATMFFD` matrix
-.   fun - the function that checks h
+.   fun - the function that checks `h`
 -   ctx - any context needed by the function
 
     Options Database Keys:
@@ -983,27 +986,26 @@ PetscErrorCode MatMFFDSetBase(Mat J, Vec U, Vec F)
     Level: advanced
 
     Notes:
-    For example, `MatMFFDCheckPositivity()` insures that all entries
-       of U + h*a are non-negative
+    For example, `MatMFFDCheckPositivity()` insures that all entries of U + h*a are non-negative
 
-     The function you provide is called after the default h has been computed and allows you to
+     The function you provide is called after the default `h` has been computed and allows you to
      modify it.
 
-.seealso: `MATMFFD`, `MatMFFDCheckPositivity()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatMFFDCheckPositivity()`
 @*/
 PetscErrorCode MatMFFDSetCheckh(Mat J, PetscErrorCode (*fun)(void *, Vec, Vec, PetscScalar *), void *ctx)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(J, MAT_CLASSID, 1);
   PetscTryMethod(J, "MatMFFDSetCheckh_C", (Mat, PetscErrorCode(*)(void *, Vec, Vec, PetscScalar *), void *), (J, fun, ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatMFFDCheckPositivity - Checks that all entries in U + h*a are positive or
         zero, decreases h until this is satisfied for a `MATMFFD` matrix
 
-    Logically Collective on U
+    Logically Collective
 
     Input Parameters:
 +   U - base vector that is added to
@@ -1017,10 +1019,9 @@ PetscErrorCode MatMFFDSetCheckh(Mat J, PetscErrorCode (*fun)(void *, Vec, Vec, P
     Level: advanced
 
     Note:
-    This is rarely used directly, rather it is passed as an argument to
-           `MatMFFDSetCheckh()`
+    This is rarely used directly, rather it is passed as an argument to `MatMFFDSetCheckh()`
 
-.seealso: `MATMFFD`, `MatMFFDSetCheckh()`
+.seealso: [](chapter_matrices), `Mat`, `MATMFFD`, `MatMFFDSetCheckh()`
 @*/
 PetscErrorCode MatMFFDCheckPositivity(void *dummy, Vec U, Vec a, PetscScalar *h)
 {
@@ -1052,5 +1053,5 @@ PetscErrorCode MatMFFDCheckPositivity(void *dummy, Vec U, Vec a, PetscScalar *h)
     if (PetscRealPart(*h) > 0.0) *h = 0.99 * val;
     else *h = -0.99 * val;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
