@@ -14,7 +14,7 @@ PetscErrorCode MatScale_NormalHermitian(Mat inA, PetscScalar scale)
 
   PetscFunctionBegin;
   a->scale *= scale;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDiagonalScale_NormalHermitian(Mat inA, Vec left, Vec right)
@@ -38,7 +38,7 @@ PetscErrorCode MatDiagonalScale_NormalHermitian(Mat inA, Vec left, Vec right)
       PetscCall(VecPointwiseMult(a->right, right, a->right));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatCreateSubMatrices_NormalHermitian(Mat mat, PetscInt n, const IS irow[], const IS icol[], MatReuse scall, Mat *submat[])
@@ -64,7 +64,7 @@ PetscErrorCode MatCreateSubMatrices_NormalHermitian(Mat mat, PetscInt n, const I
   PetscCall(ISDestroy(&row[0]));
   PetscCall(PetscFree(row));
   PetscCall(MatDestroySubMatrices(n, &suba));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatPermute_NormalHermitian(Mat A, IS rowp, IS colp, Mat *B)
@@ -81,7 +81,7 @@ PetscErrorCode MatPermute_NormalHermitian(Mat A, IS rowp, IS colp, Mat *B)
   PetscCall(ISDestroy(&row));
   PetscCall(MatCreateNormalHermitian(C, B));
   PetscCall(MatDestroy(&C));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDuplicate_NormalHermitian(Mat A, MatDuplicateOption op, Mat *B)
@@ -95,7 +95,7 @@ PetscErrorCode MatDuplicate_NormalHermitian(Mat A, MatDuplicateOption op, Mat *B
   PetscCall(MatCreateNormalHermitian(C, B));
   PetscCall(MatDestroy(&C));
   if (op == MAT_COPY_VALUES) ((Mat_Normal *)(*B)->data)->scale = a->scale;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatCopy_NormalHermitian(Mat A, Mat B, MatStructure str)
@@ -110,7 +110,7 @@ PetscErrorCode MatCopy_NormalHermitian(Mat A, Mat B, MatStructure str)
   PetscCall(VecDestroy(&b->right));
   PetscCall(VecDestroy(&b->leftwork));
   PetscCall(VecDestroy(&b->rightwork));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMult_NormalHermitian(Mat N, Vec x, Vec y)
@@ -129,7 +129,7 @@ PetscErrorCode MatMult_NormalHermitian(Mat N, Vec x, Vec y)
   PetscCall(MatMultHermitianTranspose(Na->A, Na->w, y));
   if (Na->left) PetscCall(VecPointwiseMult(y, Na->left, y));
   PetscCall(VecScale(y, Na->scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultHermitianAdd_Normal(Mat N, Vec v1, Vec v2, Vec v3)
@@ -153,7 +153,7 @@ PetscErrorCode MatMultHermitianAdd_Normal(Mat N, Vec v1, Vec v2, Vec v3)
   } else {
     PetscCall(MatMultHermitianTransposeAdd(Na->A, Na->w, v2, v3));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultHermitianTranspose_Normal(Mat N, Vec x, Vec y)
@@ -172,7 +172,7 @@ PetscErrorCode MatMultHermitianTranspose_Normal(Mat N, Vec x, Vec y)
   PetscCall(MatMultHermitianTranspose(Na->A, Na->w, y));
   if (Na->right) PetscCall(VecPointwiseMult(y, Na->right, y));
   PetscCall(VecScale(y, Na->scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultHermitianTransposeAdd_Normal(Mat N, Vec v1, Vec v2, Vec v3)
@@ -196,7 +196,7 @@ PetscErrorCode MatMultHermitianTransposeAdd_Normal(Mat N, Vec v1, Vec v2, Vec v3
   } else {
     PetscCall(MatMultHermitianTransposeAdd(Na->A, Na->w, v2, v3));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDestroy_NormalHermitian(Mat N)
@@ -215,7 +215,10 @@ PetscErrorCode MatDestroy_NormalHermitian(Mat N)
   PetscCall(PetscObjectComposeFunction((PetscObject)N, "MatNormalGetMatHermitian_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)N, "MatConvert_normalh_seqaij_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)N, "MatConvert_normalh_mpiaij_C", NULL));
-  PetscFunctionReturn(0);
+#if defined(PETSC_HAVE_HYPRE)
+  PetscCall(PetscObjectComposeFunction((PetscObject)N, "MatConvert_normalh_hypre_C", NULL));
+#endif
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -247,7 +250,7 @@ PetscErrorCode MatGetDiagonal_NormalHermitian(Mat N, Vec v)
   PetscCall(VecRestoreArray(v, &values));
   PetscCall(PetscFree2(diag, work));
   PetscCall(VecScale(v, Na->scale));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatGetDiagonalBlock_NormalHermitian(Mat N, Mat *D)
@@ -259,7 +262,7 @@ PetscErrorCode MatGetDiagonalBlock_NormalHermitian(Mat N, Mat *D)
   PetscCall(MatGetDiagonalBlock(A, &M));
   PetscCall(MatCreateNormalHermitian(M, &Na->D));
   *D = Na->D;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatNormalGetMat_NormalHermitian(Mat A, Mat *M)
@@ -268,13 +271,13 @@ PetscErrorCode MatNormalGetMat_NormalHermitian(Mat A, Mat *M)
 
   PetscFunctionBegin;
   *M = Aa->A;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
       MatNormalHermitianGetMat - Gets the `Mat` object stored inside a `MATNORMALHERMITIAN`
 
-   Logically collective on A
+   Logically Collective
 
    Input Parameter:
 .   A  - the `MATNORMALHERMITIAN` matrix
@@ -284,7 +287,7 @@ PetscErrorCode MatNormalGetMat_NormalHermitian(Mat A, Mat *M)
 
    Level: intermediate
 
-.seealso: `MATNORMALHERMITIAN`, `MatCreateNormalHermitian()`
+.seealso: [](chapter_matrices), `Mat`, `MATNORMALHERMITIAN`, `MatCreateNormalHermitian()`
 @*/
 PetscErrorCode MatNormalHermitianGetMat(Mat A, Mat *M)
 {
@@ -293,7 +296,7 @@ PetscErrorCode MatNormalHermitianGetMat(Mat A, Mat *M)
   PetscValidType(A, 1);
   PetscValidPointer(M, 2);
   PetscUseMethod(A, "MatNormalGetMatHermitian_C", (Mat, Mat *), (A, M));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatConvert_NormalHermitian_AIJ(Mat A, MatType newtype, MatReuse reuse, Mat *newmat)
@@ -326,13 +329,33 @@ PetscErrorCode MatConvert_NormalHermitian_AIJ(Mat A, MatType newtype, MatReuse r
     PetscCall(MatHeaderReplace(A, &B));
   } else if (reuse == MAT_INITIAL_MATRIX) *newmat = B;
   PetscCall(MatConvert(*newmat, MATAIJ, MAT_INPLACE_MATRIX, newmat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+#if defined(PETSC_HAVE_HYPRE)
+PetscErrorCode MatConvert_NormalHermitian_HYPRE(Mat A, MatType type, MatReuse reuse, Mat *B)
+{
+  PetscFunctionBegin;
+  if (reuse == MAT_INITIAL_MATRIX) {
+    PetscCall(MatConvert(A, MATAIJ, reuse, B));
+    PetscCall(MatConvert(*B, type, MAT_INPLACE_MATRIX, B));
+  } else PetscCall(MatConvert_Basic(A, type, reuse, B)); /* fall back to basic convert */
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+#endif
+
+/*MC
+  MATNORMALHERMITIAN - a matrix that behaves like (A*)'*A for `MatMult()` while only containing A
+
+  Level: intermediate
+
+.seealso: [](chapter_matrices), `Mat`, `MatCreateNormalHermitian()`, `MatMult()`, `MatNormalHermitianGetMat()`, `MATNORMAL`, `MatCreateNormal()`
+M*/
+
 /*@
       MatCreateNormalHermitian - Creates a new matrix object `MATNORMALHERMITIAN` that behaves like (A*)'*A.
 
-   Collective on A
+   Collective
 
    Input Parameter:
 .   A  - the (possibly rectangular complex) matrix
@@ -347,7 +370,7 @@ PetscErrorCode MatConvert_NormalHermitian_AIJ(Mat A, MatType newtype, MatReuse r
           object performs the matrix-vector product, `MatMult()`, by first multiplying by
           A and then (A*)'
 
-.seealso: `MATNORMAL`, `MATNORMALHERMITIAN`, `MatNormalHermitianGetMat()`
+.seealso: [](chapter_matrices), `Mat`, `MATNORMAL`, `MATNORMALHERMITIAN`, `MatNormalHermitianGetMat()`
 @*/
 PetscErrorCode MatCreateNormalHermitian(Mat A, Mat *N)
 {
@@ -390,11 +413,14 @@ PetscErrorCode MatCreateNormalHermitian(Mat A, Mat *N)
   PetscCall(PetscObjectComposeFunction((PetscObject)(*N), "MatNormalGetMatHermitian_C", MatNormalGetMat_NormalHermitian));
   PetscCall(PetscObjectComposeFunction((PetscObject)(*N), "MatConvert_normalh_seqaij_C", MatConvert_NormalHermitian_AIJ));
   PetscCall(PetscObjectComposeFunction((PetscObject)(*N), "MatConvert_normalh_mpiaij_C", MatConvert_NormalHermitian_AIJ));
+#if defined(PETSC_HAVE_HYPRE)
+  PetscCall(PetscObjectComposeFunction((PetscObject)(*N), "MatConvert_normalh_hypre_C", MatConvert_NormalHermitian_HYPRE));
+#endif
   PetscCall(MatSetOption(*N, MAT_HERMITIAN, PETSC_TRUE));
   PetscCall(MatGetVecType(A, &vtype));
   PetscCall(MatSetVecType(*N, vtype));
 #if defined(PETSC_HAVE_DEVICE)
   PetscCall(MatBindToCPU(*N, A->boundtocpu));
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
