@@ -3,7 +3,7 @@
 /*@C
    MatPythonSetType - Initialize a `Mat` object implemented in Python.
 
-   Collective on Mat
+   Collective
 
    Input Parameters:
 +  mat - the matrix object.
@@ -14,7 +14,7 @@
 
    Level: intermediate
 
-.seealso: `Mat`, `MatType`, `MatCreate()`, `MatSetType()`, `MATPYTHON`, `PetscPythonInitialize()`
+.seealso: [](chapter_matrices), `Mat`, `MatType`, `MatCreate()`, `MatSetType()`, `MATPYTHON`, `PetscPythonInitialize()`
 @*/
 PetscErrorCode MatPythonSetType(Mat mat, const char pyname[])
 {
@@ -22,13 +22,13 @@ PetscErrorCode MatPythonSetType(Mat mat, const char pyname[])
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidCharPointer(pyname, 2);
   PetscTryMethod(mat, "MatPythonSetType_C", (Mat, const char[]), (mat, pyname));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   MatPythonGetType - Get the type of a `Mat` object implemented in Python.
+   MatPythonGetType - Get the Python name of a `Mat` object implemented in Python.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  mat - the matrix
@@ -38,7 +38,7 @@ PetscErrorCode MatPythonSetType(Mat mat, const char pyname[])
 
    Level: intermediate
 
-.seealso: `Mat`, `MatType`, `MatCreate()`, `MatSetType()`, `MATPYTHON`, `PetscPythonInitialize()`, `MatPythonSetType()`
+.seealso: [](chapter_matrices), `Mat`, `MatType`, `MatCreate()`, `MatSetType()`, `MATPYTHON`, `PetscPythonInitialize()`, `MatPythonSetType()`
 @*/
 PetscErrorCode MatPythonGetType(Mat mat, const char *pyname[])
 {
@@ -46,20 +46,20 @@ PetscErrorCode MatPythonGetType(Mat mat, const char *pyname[])
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidPointer(pyname, 2);
   PetscUseMethod(mat, "MatPythonGetType_C", (Mat, const char *[]), (mat, pyname));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatPythonCreate - Create a `Mat` object implemented in Python.
 
-   Collective on Mat
+   Collective
 
    Input Parameters:
 +  comm - MPI communicator
-.  m - number of local rows (or `PETSC_DECIDE` to have calculated if M is given)
-.  n - number of local columns (or `PETSC_DECIDE` to have calculated if N is given)
-.  M - number of global rows (or `PETSC_DECIDE` to have calculated if m is given)
-.  N - number of global columns (or `PETSC_DECIDE` to have calculated if n is given)
+.  m - number of local rows (or `PETSC_DECIDE` to have calculated if `M` is given)
+.  n - number of local columns (or `PETSC_DECIDE` to have calculated if `N` is given)
+.  M - number of global rows (or `PETSC_DECIDE` to have calculated if `m` is given)
+.  N - number of global columns (or `PETSC_DECIDE` to have calculated if `n` is given)
 -  pyname - full dotted Python name [package].module[.{class|function}]
 
    Output Parameter:
@@ -67,7 +67,7 @@ PetscErrorCode MatPythonGetType(Mat mat, const char *pyname[])
 
    Level: intermediate
 
-.seealso: `Mat`, `MatType`, `MATPYTHON`, `MatPythonSetType()`, `PetscPythonInitialize()`
+.seealso: [](chapter_matrices), `Mat`, `MatType`, `MATPYTHON`, `MatPythonSetType()`, `PetscPythonInitialize()`
 @*/
 PetscErrorCode MatPythonCreate(MPI_Comm comm, PetscInt m, PetscInt n, PetscInt M, PetscInt N, const char pyname[], Mat *A)
 {
@@ -79,5 +79,5 @@ PetscErrorCode MatPythonCreate(MPI_Comm comm, PetscInt m, PetscInt n, PetscInt M
   PetscCall(MatSetType(*A, MATPYTHON));
   PetscCall(MatPythonSetType(*A, pyname));
   PetscCall(MatBindToCPU(*A, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
