@@ -81,7 +81,7 @@ PetscErrorCode MatIncreaseOverlap_SeqSBAIJ(Mat A, PetscInt is_max, IS is[], Pets
   PetscCall(PetscBTDestroy(&table_out));
   PetscCall(PetscFree(nidx));
   PetscCall(PetscBTDestroy(&table_in));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Bseq is non-symmetric SBAIJ matrix, only used internally by PETSc.
@@ -99,7 +99,7 @@ PetscErrorCode MatSeqSBAIJZeroOps_Private(Mat Bseq)
   Bseq->ops->lufactorsymbolic       = NULL;
   Bseq->ops->choleskyfactorsymbolic = NULL;
   Bseq->ops->getinertia             = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* same as MatCreateSubMatrices_SeqBAIJ(), except cast Mat_SeqSBAIJ */
@@ -193,49 +193,19 @@ PetscErrorCode MatCreateSubMatrix_SeqSBAIJ_Private(Mat A, IS isrow, IS iscol, Ma
 
   PetscCall(ISRestoreIndices(isrow, &irow));
   *B = C;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatCreateSubMatrix_SeqSBAIJ(Mat A, IS isrow, IS iscol, MatReuse scall, Mat *B)
 {
-  Mat_SeqSBAIJ   *a = (Mat_SeqSBAIJ *)A->data;
-  IS              is1, is2;
-  PetscInt       *vary, *iary, nrows, ncols, i, bs = A->rmap->bs, count, maxmnbs;
-  const PetscInt *irow, *icol;
+  IS is1, is2;
 
   PetscFunctionBegin;
-  PetscCall(ISGetIndices(isrow, &irow));
-  PetscCall(ISGetIndices(iscol, &icol));
-  PetscCall(ISGetLocalSize(isrow, &nrows));
-  PetscCall(ISGetLocalSize(iscol, &ncols));
-
-  /* Verify if the indices correspond to each element in a block
-   and form the IS with compressed IS */
-  maxmnbs = PetscMax(a->mbs, a->nbs);
-  PetscCall(PetscMalloc2(maxmnbs, &vary, maxmnbs, &iary));
-  PetscCall(PetscArrayzero(vary, a->mbs));
-  for (i = 0; i < nrows; i++) vary[irow[i] / bs]++;
-  for (i = 0; i < a->mbs; i++) PetscCheck(vary[i] == 0 || vary[i] == bs, PETSC_COMM_SELF, PETSC_ERR_ARG_SIZ, "Index set does not match blocks");
-  count = 0;
-  for (i = 0; i < nrows; i++) {
-    PetscInt j = irow[i] / bs;
-    if ((vary[j]--) == bs) iary[count++] = j;
-  }
-  PetscCall(ISCreateGeneral(PETSC_COMM_SELF, count, iary, PETSC_COPY_VALUES, &is1));
-
-  PetscCall(PetscArrayzero(vary, a->nbs));
-  for (i = 0; i < ncols; i++) vary[icol[i] / bs]++;
-  for (i = 0; i < a->nbs; i++) PetscCheck(vary[i] == 0 || vary[i] == bs, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Internal error in PETSc");
-  count = 0;
-  for (i = 0; i < ncols; i++) {
-    PetscInt j = icol[i] / bs;
-    if ((vary[j]--) == bs) iary[count++] = j;
-  }
-  PetscCall(ISCreateGeneral(PETSC_COMM_SELF, count, iary, PETSC_COPY_VALUES, &is2));
-  PetscCall(ISRestoreIndices(isrow, &irow));
-  PetscCall(ISRestoreIndices(iscol, &icol));
-  PetscCall(PetscFree2(vary, iary));
-
+  PetscCall(ISCompressIndicesGeneral(A->rmap->N, A->rmap->n, A->rmap->bs, 1, &isrow, &is1));
+  if (isrow == iscol) {
+    is2 = is1;
+    PetscCall(PetscObjectReference((PetscObject)is2));
+  } else PetscCall(ISCompressIndicesGeneral(A->cmap->N, A->cmap->n, A->cmap->bs, 1, &iscol, &is2));
   PetscCall(MatCreateSubMatrix_SeqSBAIJ_Private(A, is1, is2, scall, B));
   PetscCall(ISDestroy(&is1));
   PetscCall(ISDestroy(&is2));
@@ -245,7 +215,7 @@ PetscErrorCode MatCreateSubMatrix_SeqSBAIJ(Mat A, IS isrow, IS iscol, MatReuse s
     PetscCall(ISEqual(isrow, iscol, &isequal));
     if (!isequal) PetscCall(MatSeqSBAIJZeroOps_Private(*B));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatCreateSubMatrices_SeqSBAIJ(Mat A, PetscInt n, const IS irow[], const IS icol[], MatReuse scall, Mat *B[])
@@ -256,13 +226,10 @@ PetscErrorCode MatCreateSubMatrices_SeqSBAIJ(Mat A, PetscInt n, const IS irow[],
   if (scall == MAT_INITIAL_MATRIX) PetscCall(PetscCalloc1(n + 1, B));
 
   for (i = 0; i < n; i++) PetscCall(MatCreateSubMatrix_SeqSBAIJ(A, irow[i], icol[i], scall, &(*B)[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* -------------------------------------------------------*/
 /* Should check that shapes of vectors and matrices match */
-/* -------------------------------------------------------*/
-
 PetscErrorCode MatMult_SeqSBAIJ_2(Mat A, Vec xx, Vec zz)
 {
   Mat_SeqSBAIJ      *a = (Mat_SeqSBAIJ *)A->data;
@@ -275,7 +242,7 @@ PetscErrorCode MatMult_SeqSBAIJ_2(Mat A, Vec xx, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecSet(zz, zero));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -314,7 +281,7 @@ PetscErrorCode MatMult_SeqSBAIJ_2(Mat A, Vec xx, Vec zz)
   PetscCall(VecRestoreArrayRead(xx, &x));
   PetscCall(VecRestoreArray(zz, &z));
   PetscCall(PetscLogFlops(8.0 * (a->nz * 2.0 - nonzerorow) - nonzerorow));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMult_SeqSBAIJ_3(Mat A, Vec xx, Vec zz)
@@ -329,7 +296,7 @@ PetscErrorCode MatMult_SeqSBAIJ_3(Mat A, Vec xx, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecSet(zz, zero));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -372,7 +339,7 @@ PetscErrorCode MatMult_SeqSBAIJ_3(Mat A, Vec xx, Vec zz)
   PetscCall(VecRestoreArrayRead(xx, &x));
   PetscCall(VecRestoreArray(zz, &z));
   PetscCall(PetscLogFlops(18.0 * (a->nz * 2.0 - nonzerorow) - nonzerorow));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMult_SeqSBAIJ_4(Mat A, Vec xx, Vec zz)
@@ -387,7 +354,7 @@ PetscErrorCode MatMult_SeqSBAIJ_4(Mat A, Vec xx, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecSet(zz, zero));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -434,7 +401,7 @@ PetscErrorCode MatMult_SeqSBAIJ_4(Mat A, Vec xx, Vec zz)
   PetscCall(VecRestoreArrayRead(xx, &x));
   PetscCall(VecRestoreArray(zz, &z));
   PetscCall(PetscLogFlops(32.0 * (a->nz * 2.0 - nonzerorow) - nonzerorow));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMult_SeqSBAIJ_5(Mat A, Vec xx, Vec zz)
@@ -449,7 +416,7 @@ PetscErrorCode MatMult_SeqSBAIJ_5(Mat A, Vec xx, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecSet(zz, zero));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -500,7 +467,7 @@ PetscErrorCode MatMult_SeqSBAIJ_5(Mat A, Vec xx, Vec zz)
   PetscCall(VecRestoreArrayRead(xx, &x));
   PetscCall(VecRestoreArray(zz, &z));
   PetscCall(PetscLogFlops(50.0 * (a->nz * 2.0 - nonzerorow) - nonzerorow));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMult_SeqSBAIJ_6(Mat A, Vec xx, Vec zz)
@@ -515,7 +482,7 @@ PetscErrorCode MatMult_SeqSBAIJ_6(Mat A, Vec xx, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecSet(zz, zero));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -570,7 +537,7 @@ PetscErrorCode MatMult_SeqSBAIJ_6(Mat A, Vec xx, Vec zz)
   PetscCall(VecRestoreArrayRead(xx, &x));
   PetscCall(VecRestoreArray(zz, &z));
   PetscCall(PetscLogFlops(72.0 * (a->nz * 2.0 - nonzerorow) - nonzerorow));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMult_SeqSBAIJ_7(Mat A, Vec xx, Vec zz)
@@ -585,7 +552,7 @@ PetscErrorCode MatMult_SeqSBAIJ_7(Mat A, Vec xx, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecSet(zz, zero));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -643,7 +610,7 @@ PetscErrorCode MatMult_SeqSBAIJ_7(Mat A, Vec xx, Vec zz)
   PetscCall(VecRestoreArrayRead(xx, &x));
   PetscCall(VecRestoreArray(zz, &z));
   PetscCall(PetscLogFlops(98.0 * (a->nz * 2.0 - nonzerorow) - nonzerorow));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -661,7 +628,7 @@ PetscErrorCode MatMult_SeqSBAIJ_N(Mat A, Vec xx, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecSet(zz, zero));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -719,7 +686,7 @@ PetscErrorCode MatMult_SeqSBAIJ_N(Mat A, Vec xx, Vec zz)
   PetscCall(VecRestoreArrayRead(xx, &x));
   PetscCall(VecRestoreArray(zz, &z));
   PetscCall(PetscLogFlops(2.0 * (a->nz * 2.0 - nonzerorow) * bs2 - nonzerorow));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultAdd_SeqSBAIJ_1(Mat A, Vec xx, Vec yy, Vec zz)
@@ -739,7 +706,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_1(Mat A, Vec xx, Vec yy, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecCopy(yy, zz));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
   v  = a->a;
@@ -776,7 +743,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_1(Mat A, Vec xx, Vec yy, Vec zz)
   PetscCall(VecRestoreArray(zz, &z));
 
   PetscCall(PetscLogFlops(2.0 * (a->nz * 2.0 - nonzerorow)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultAdd_SeqSBAIJ_2(Mat A, Vec xx, Vec yy, Vec zz)
@@ -791,7 +758,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_2(Mat A, Vec xx, Vec yy, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecCopy(yy, zz));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -830,7 +797,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_2(Mat A, Vec xx, Vec yy, Vec zz)
   PetscCall(VecRestoreArray(zz, &z));
 
   PetscCall(PetscLogFlops(4.0 * (a->nz * 2.0 - nonzerorow)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultAdd_SeqSBAIJ_3(Mat A, Vec xx, Vec yy, Vec zz)
@@ -845,7 +812,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_3(Mat A, Vec xx, Vec yy, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecCopy(yy, zz));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -889,7 +856,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_3(Mat A, Vec xx, Vec yy, Vec zz)
   PetscCall(VecRestoreArray(zz, &z));
 
   PetscCall(PetscLogFlops(18.0 * (a->nz * 2.0 - nonzerorow)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultAdd_SeqSBAIJ_4(Mat A, Vec xx, Vec yy, Vec zz)
@@ -904,7 +871,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_4(Mat A, Vec xx, Vec yy, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecCopy(yy, zz));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -952,7 +919,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_4(Mat A, Vec xx, Vec yy, Vec zz)
   PetscCall(VecRestoreArray(zz, &z));
 
   PetscCall(PetscLogFlops(32.0 * (a->nz * 2.0 - nonzerorow)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultAdd_SeqSBAIJ_5(Mat A, Vec xx, Vec yy, Vec zz)
@@ -967,7 +934,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_5(Mat A, Vec xx, Vec yy, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecCopy(yy, zz));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -1019,7 +986,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_5(Mat A, Vec xx, Vec yy, Vec zz)
   PetscCall(VecRestoreArray(zz, &z));
 
   PetscCall(PetscLogFlops(50.0 * (a->nz * 2.0 - nonzerorow)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultAdd_SeqSBAIJ_6(Mat A, Vec xx, Vec yy, Vec zz)
@@ -1034,7 +1001,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_6(Mat A, Vec xx, Vec yy, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecCopy(yy, zz));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -1090,7 +1057,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_6(Mat A, Vec xx, Vec yy, Vec zz)
   PetscCall(VecRestoreArray(zz, &z));
 
   PetscCall(PetscLogFlops(72.0 * (a->nz * 2.0 - nonzerorow)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultAdd_SeqSBAIJ_7(Mat A, Vec xx, Vec yy, Vec zz)
@@ -1105,7 +1072,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_7(Mat A, Vec xx, Vec yy, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecCopy(yy, zz));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   PetscCall(VecGetArray(zz, &z));
 
@@ -1165,7 +1132,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_7(Mat A, Vec xx, Vec yy, Vec zz)
   PetscCall(VecRestoreArray(zz, &z));
 
   PetscCall(PetscLogFlops(98.0 * (a->nz * 2.0 - nonzerorow)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultAdd_SeqSBAIJ_N(Mat A, Vec xx, Vec yy, Vec zz)
@@ -1180,7 +1147,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_N(Mat A, Vec xx, Vec yy, Vec zz)
 
   PetscFunctionBegin;
   PetscCall(VecCopy(yy, zz));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArrayRead(xx, &x));
   x_ptr = x;
   PetscCall(VecGetArray(zz, &z));
@@ -1238,7 +1205,7 @@ PetscErrorCode MatMultAdd_SeqSBAIJ_N(Mat A, Vec xx, Vec yy, Vec zz)
   PetscCall(VecRestoreArray(zz, &z));
 
   PetscCall(PetscLogFlops(2.0 * (a->nz * 2.0 - nonzerorow)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatScale_SeqSBAIJ(Mat inA, PetscScalar alpha)
@@ -1251,7 +1218,7 @@ PetscErrorCode MatScale_SeqSBAIJ(Mat inA, PetscScalar alpha)
   PetscCall(PetscBLASIntCast(a->bs2 * a->nz, &totalnz));
   PetscCallBLAS("BLASscal", BLASscal_(&totalnz, &oalpha, a->a, &one));
   PetscCall(PetscLogFlops(totalnz));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatNorm_SeqSBAIJ(Mat A, NormType type, PetscReal *norm)
@@ -1265,7 +1232,7 @@ PetscErrorCode MatNorm_SeqSBAIJ(Mat A, NormType type, PetscReal *norm)
   PetscFunctionBegin;
   if (!a->nz) {
     *norm = 0.0;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if (type == NORM_FROBENIUS) {
     for (k = 0; k < mbs; k++) {
@@ -1349,7 +1316,7 @@ PetscErrorCode MatNorm_SeqSBAIJ(Mat A, NormType type, PetscReal *norm)
     PetscCall(PetscFree3(sum, il, jl));
     PetscCall(PetscLogFlops(PetscMax(mbs * a->nz - 1, 0)));
   } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "No support for this norm yet");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatEqual_SeqSBAIJ(Mat A, Mat B, PetscBool *flg)
@@ -1360,20 +1327,20 @@ PetscErrorCode MatEqual_SeqSBAIJ(Mat A, Mat B, PetscBool *flg)
   /* If the  matrix/block dimensions are not equal, or no of nonzeros or shift */
   if ((A->rmap->N != B->rmap->N) || (A->cmap->n != B->cmap->n) || (A->rmap->bs != B->rmap->bs) || (a->nz != b->nz)) {
     *flg = PETSC_FALSE;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   /* if the a->i are the same */
   PetscCall(PetscArraycmp(a->i, b->i, a->mbs + 1, flg));
-  if (!*flg) PetscFunctionReturn(0);
+  if (!*flg) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* if a->j are the same */
   PetscCall(PetscArraycmp(a->j, b->j, a->nz, flg));
-  if (!*flg) PetscFunctionReturn(0);
+  if (!*flg) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* if a->a are the same */
   PetscCall(PetscArraycmp(a->a, b->a, (a->nz) * (A->rmap->bs) * (A->rmap->bs), flg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatGetDiagonal_SeqSBAIJ(Mat A, Vec v)
@@ -1398,14 +1365,14 @@ PetscErrorCode MatGetDiagonal_SeqSBAIJ(Mat A, Vec v)
     PetscCall(VecGetArray(v, &x));
     for (i = 0; i < ambs; i++) x[i] = 1.0 / aa[diag[i]];
     PetscCall(VecRestoreArray(v, &x));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   ai  = a->i;
   aj  = a->j;
   bs2 = a->bs2;
   PetscCall(VecSet(v, zero));
-  if (!a->nz) PetscFunctionReturn(0);
+  if (!a->nz) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecGetArray(v, &x));
   for (i = 0; i < ambs; i++) {
     j = ai[i];
@@ -1416,7 +1383,7 @@ PetscErrorCode MatGetDiagonal_SeqSBAIJ(Mat A, Vec v)
     }
   }
   PetscCall(VecRestoreArray(v, &x));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDiagonalScale_SeqSBAIJ(Mat A, Vec ll, Vec rr)
@@ -1434,7 +1401,7 @@ PetscErrorCode MatDiagonalScale_SeqSBAIJ(Mat A, Vec ll, Vec rr)
     PetscCall(VecEqual(ll, rr, &flg));
     PetscCheck(flg, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "For symmetric format, left and right scaling vectors must be same");
   }
-  if (!ll) PetscFunctionReturn(0);
+  if (!ll) PetscFunctionReturn(PETSC_SUCCESS);
   ai  = a->i;
   aj  = a->j;
   aa  = a->a;
@@ -1460,7 +1427,7 @@ PetscErrorCode MatDiagonalScale_SeqSBAIJ(Mat A, Vec ll, Vec rr)
   }
   PetscCall(VecRestoreArrayRead(ll, &l));
   PetscCall(PetscLogFlops(2.0 * a->nz));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatGetInfo_SeqSBAIJ(Mat A, MatInfoType flag, MatInfo *info)
@@ -1484,7 +1451,7 @@ PetscErrorCode MatGetInfo_SeqSBAIJ(Mat A, MatInfoType flag, MatInfo *info)
     info->fill_ratio_needed = 0;
     info->factor_mallocs    = 0;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatZeroEntries_SeqSBAIJ(Mat A)
@@ -1493,7 +1460,7 @@ PetscErrorCode MatZeroEntries_SeqSBAIJ(Mat A)
 
   PetscFunctionBegin;
   PetscCall(PetscArrayzero(a->a, a->bs2 * a->i[a->mbs]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatGetRowMaxAbs_SeqSBAIJ(Mat A, Vec v, PetscInt idx[])
@@ -1539,7 +1506,7 @@ PetscErrorCode MatGetRowMaxAbs_SeqSBAIJ(Mat A, Vec v, PetscInt idx[])
     }
   }
   PetscCall(VecRestoreArray(v, &x));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMatMultSymbolic_SeqSBAIJ_SeqDense(Mat A, Mat B, PetscReal fill, Mat C)
@@ -1547,7 +1514,7 @@ PetscErrorCode MatMatMultSymbolic_SeqSBAIJ_SeqDense(Mat A, Mat B, PetscReal fill
   PetscFunctionBegin;
   PetscCall(MatMatMultSymbolic_SeqDense_SeqDense(A, B, 0.0, C));
   C->ops->matmultnumeric = MatMatMultNumeric_SeqSBAIJ_SeqDense;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMatMult_SeqSBAIJ_1_Private(Mat A, PetscScalar *b, PetscInt bm, PetscScalar *c, PetscInt cm, PetscInt cn)
@@ -1586,7 +1553,7 @@ PetscErrorCode MatMatMult_SeqSBAIJ_1_Private(Mat A, PetscScalar *b, PetscInt bm,
     }
     z += 1;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMatMult_SeqSBAIJ_2_Private(Mat A, PetscScalar *b, PetscInt bm, PetscScalar *c, PetscInt cm, PetscInt cn)
@@ -1625,7 +1592,7 @@ PetscErrorCode MatMatMult_SeqSBAIJ_2_Private(Mat A, PetscScalar *b, PetscInt bm,
     }
     z += 2;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMatMult_SeqSBAIJ_3_Private(Mat A, PetscScalar *b, PetscInt bm, PetscScalar *c, PetscInt cm, PetscInt cn)
@@ -1667,7 +1634,7 @@ PetscErrorCode MatMatMult_SeqSBAIJ_3_Private(Mat A, PetscScalar *b, PetscInt bm,
     }
     z += 3;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMatMult_SeqSBAIJ_4_Private(Mat A, PetscScalar *b, PetscInt bm, PetscScalar *c, PetscInt cm, PetscInt cn)
@@ -1712,7 +1679,7 @@ PetscErrorCode MatMatMult_SeqSBAIJ_4_Private(Mat A, PetscScalar *b, PetscInt bm,
     }
     z += 4;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMatMult_SeqSBAIJ_5_Private(Mat A, PetscScalar *b, PetscInt bm, PetscScalar *c, PetscInt cm, PetscInt cn)
@@ -1760,7 +1727,7 @@ PetscErrorCode MatMatMult_SeqSBAIJ_5_Private(Mat A, PetscScalar *b, PetscInt bm,
     }
     z += 5;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMatMultNumeric_SeqSBAIJ_SeqDense(Mat A, Mat B, Mat C)
@@ -1778,7 +1745,7 @@ PetscErrorCode MatMatMultNumeric_SeqSBAIJ_SeqDense(Mat A, Mat B, Mat C)
   PetscScalar      _DOne = 1.0;
 
   PetscFunctionBegin;
-  if (!cm || !cn) PetscFunctionReturn(0);
+  if (!cm || !cn) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheck(B->rmap->n == A->cmap->n, PETSC_COMM_SELF, PETSC_ERR_ARG_SIZ, "Number columns in A %" PetscInt_FMT " not equal rows in B %" PetscInt_FMT, A->cmap->n, B->rmap->n);
   PetscCheck(A->rmap->n == C->rmap->n, PETSC_COMM_SELF, PETSC_ERR_ARG_SIZ, "Number rows in C %" PetscInt_FMT " not equal rows in A %" PetscInt_FMT, C->rmap->n, A->rmap->n);
   PetscCheck(B->cmap->n == C->cmap->n, PETSC_COMM_SELF, PETSC_ERR_ARG_SIZ, "Number columns in B %" PetscInt_FMT " not equal columns in C %" PetscInt_FMT, B->cmap->n, C->cmap->n);
@@ -1824,5 +1791,5 @@ PetscErrorCode MatMatMultNumeric_SeqSBAIJ_SeqDense(Mat A, Mat B, Mat C)
   }
   PetscCall(MatDenseRestoreArray(C, &c));
   PetscCall(PetscLogFlops((2.0 * (a->nz * 2.0 - a->nonzerorowcnt) * bs2 - a->nonzerorowcnt) * cn));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
