@@ -13,7 +13,7 @@ typedef struct {
 /*@
     MatScatterGetVecScatter - Returns the user-provided scatter set with `MatScatterSetVecScatter()` in a `MATSCATTER` matrix
 
-    Not Collective, but not cannot use scatter if not used collectively on `Mat`
+    Logically Collective
 
     Input Parameter:
 .   mat - the matrix, should have been created with MatCreateScatter() or have type `MATSCATTER`
@@ -23,7 +23,7 @@ typedef struct {
 
     Level: intermediate
 
-.seealso: `MATSCATTER`, `MatCreateScatter()`, `MatScatterSetVecScatter()`, `MATSCATTER`
+.seealso: [](chapter_matrices), `Mat`, `MATSCATTER`, `MatCreateScatter()`, `MatScatterSetVecScatter()`, `MATSCATTER`
 @*/
 PetscErrorCode MatScatterGetVecScatter(Mat mat, VecScatter *scatter)
 {
@@ -34,7 +34,7 @@ PetscErrorCode MatScatterGetVecScatter(Mat mat, VecScatter *scatter)
   PetscValidPointer(scatter, 2);
   mscatter = (Mat_Scatter *)mat->data;
   *scatter = mscatter->scatter;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDestroy_Scatter(Mat mat)
@@ -44,7 +44,7 @@ PetscErrorCode MatDestroy_Scatter(Mat mat)
   PetscFunctionBegin;
   PetscCall(VecScatterDestroy(&scatter->scatter));
   PetscCall(PetscFree(mat->data));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMult_Scatter(Mat A, Vec x, Vec y)
@@ -56,7 +56,7 @@ PetscErrorCode MatMult_Scatter(Mat A, Vec x, Vec y)
   PetscCall(VecZeroEntries(y));
   PetscCall(VecScatterBegin(scatter->scatter, x, y, ADD_VALUES, SCATTER_FORWARD));
   PetscCall(VecScatterEnd(scatter->scatter, x, y, ADD_VALUES, SCATTER_FORWARD));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultAdd_Scatter(Mat A, Vec x, Vec y, Vec z)
@@ -68,7 +68,7 @@ PetscErrorCode MatMultAdd_Scatter(Mat A, Vec x, Vec y, Vec z)
   if (z != y) PetscCall(VecCopy(y, z));
   PetscCall(VecScatterBegin(scatter->scatter, x, z, ADD_VALUES, SCATTER_FORWARD));
   PetscCall(VecScatterEnd(scatter->scatter, x, z, ADD_VALUES, SCATTER_FORWARD));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultTranspose_Scatter(Mat A, Vec x, Vec y)
@@ -80,7 +80,7 @@ PetscErrorCode MatMultTranspose_Scatter(Mat A, Vec x, Vec y)
   PetscCall(VecZeroEntries(y));
   PetscCall(VecScatterBegin(scatter->scatter, x, y, ADD_VALUES, SCATTER_REVERSE));
   PetscCall(VecScatterEnd(scatter->scatter, x, y, ADD_VALUES, SCATTER_REVERSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultTransposeAdd_Scatter(Mat A, Vec x, Vec y, Vec z)
@@ -92,7 +92,7 @@ PetscErrorCode MatMultTransposeAdd_Scatter(Mat A, Vec x, Vec y, Vec z)
   if (z != y) PetscCall(VecCopy(y, z));
   PetscCall(VecScatterBegin(scatter->scatter, x, z, ADD_VALUES, SCATTER_REVERSE));
   PetscCall(VecScatterEnd(scatter->scatter, x, z, ADD_VALUES, SCATTER_REVERSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static struct _MatOps MatOps_Values = {NULL,
@@ -245,14 +245,15 @@ static struct _MatOps MatOps_Values = {NULL,
                                        NULL,
                                        NULL,
                                        NULL,
-                                       /*150*/ NULL};
+                                       /*150*/ NULL,
+                                       NULL};
 
 /*MC
-   MATSCATTER - MATSCATTER = "scatter" - A matrix type that simply applies a `VecScatterBegin()` and `VecScatterEnd()`
+   MATSCATTER - "scatter" - A matrix type that simply applies a `VecScatterBegin()` and `VecScatterEnd()` to perform `MatMult()`
 
   Level: advanced
 
-.seealso: ``MATSCATTER`, MatCreateScatter()`, `MatScatterSetVecScatter()`, `MatScatterGetVecScatter()`
+.seealso: [](chapter_matrices), `Mat`, ``MATSCATTER`, MatCreateScatter()`, `MatScatterSetVecScatter()`, `MatScatterGetVecScatter()`
 M*/
 
 PETSC_EXTERN PetscErrorCode MatCreate_Scatter(Mat A)
@@ -272,7 +273,7 @@ PETSC_EXTERN PetscErrorCode MatCreate_Scatter(Mat A)
   A->preallocated = PETSC_FALSE;
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)A, MATSCATTER));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #include <petsc/private/sfimpl.h>
@@ -303,7 +304,7 @@ PETSC_EXTERN PetscErrorCode MatCreate_Scatter(Mat A)
    This directly accesses information inside the `VecScatter` associated with the matrix-vector product
    for this matrix. This is not desirable..
 
-.seealso: `MatScatterSetVecScatter()`, `MatScatterGetVecScatter()`, `MATSCATTER`
+.seealso: [](chapter_matrices), `Mat`, `MatScatterSetVecScatter()`, `MatScatterGetVecScatter()`, `MATSCATTER`
 @*/
 PetscErrorCode MatCreateScatter(MPI_Comm comm, VecScatter scatter, Mat *A)
 {
@@ -313,13 +314,13 @@ PetscErrorCode MatCreateScatter(MPI_Comm comm, VecScatter scatter, Mat *A)
   PetscCall(MatSetType(*A, MATSCATTER));
   PetscCall(MatScatterSetVecScatter(*A, scatter));
   PetscCall(MatSetUp(*A));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatScatterSetVecScatter - sets the scatter that the matrix is to apply as its linear operator in a `MATSCATTER`
 
-   Collective on mat
+   Logically Collective
 
     Input Parameters:
 +   mat - the `MATSCATTER` matrix
@@ -327,7 +328,7 @@ PetscErrorCode MatCreateScatter(MPI_Comm comm, VecScatter scatter, Mat *A)
 
    Level: advanced
 
-.seealso: `MATSCATTER`, `MatCreateScatter()`, `MATSCATTER`
+.seealso: [](chapter_matrices), `Mat`, `MATSCATTER`, `MatCreateScatter()`, `MATSCATTER`
 @*/
 PetscErrorCode MatScatterSetVecScatter(Mat mat, VecScatter scatter)
 {
@@ -344,5 +345,5 @@ PetscErrorCode MatScatterSetVecScatter(Mat mat, VecScatter scatter)
   PetscCall(VecScatterDestroy(&mscatter->scatter));
 
   mscatter->scatter = scatter;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
