@@ -44,41 +44,37 @@ static const char citation[] = "@inproceedings{ZhangELLPACK2018,\n"
 
 /*@C
  MatSeqSELLSetPreallocation - For good matrix assembly performance
- the user should preallocate the matrix storage by setting the parameter nz
- (or the array nnz).  By setting these parameters accurately, performance
- during matrix assembly can be increased significantly.
+ the user should preallocate the matrix storage by setting the parameter `nz`
+ (or the array `nnz`).
 
  Collective
 
  Input Parameters:
- +  B - The `MATSEQSELL` matrix
- .  nz - number of nonzeros per row (same for all rows)
- -  nnz - array containing the number of nonzeros in the various rows
- (possibly different for each row) or NULL
++  B - The `MATSEQSELL` matrix
+.  rlenmax - number of nonzeros per row (same for all rows), ignored if `rlen` is provided
+-  rlen - array containing the number of nonzeros in the various rows (possibly different for each row) or `NULL`
+
+ Level: intermediate
 
  Notes:
- If nnz is given then nz is ignored.
-
- Specify the preallocated storage with either nz or nnz (not both).
- Set nz = `PETSC_DEFAULT` and nnz = NULL for PETSc to control dynamic memory
- allocation.  For large problems you MUST preallocate memory or you
- will get TERRIBLE performance, see the users' manual chapter on matrices.
+ Specify the preallocated storage with either `rlenmax` or `rlen` (not both).
+ Set `rlenmax` = `PETSC_DEFAULT` and `rlen` = `NULL` for PETSc to control dynamic memory
+ allocation.
 
  You can call `MatGetInfo()` to get information on how effective the preallocation was;
  for example the fields mallocs,nz_allocated,nz_used,nz_unneeded;
- You can also run with the option -info and look for messages with the string
+ You can also run with the option `-info` and look for messages with the string
  malloc in them to see if additional memory allocation was needed.
 
- Developers: Use nz of `MAT_SKIP_ALLOCATION` to not allocate any space for the matrix
+ Developer Note:
+ Use `rlenmax` of `MAT_SKIP_ALLOCATION` to not allocate any space for the matrix
  entries or columns indices.
 
  The maximum number of nonzeos in any row should be as accurate as possible.
  If it is underestimated, you will get bad performance due to reallocation
- (MatSeqXSELLReallocateSELL).
+ (`MatSeqXSELLReallocateSELL()`).
 
- Level: intermediate
-
- .seealso: `MATSEQSELL`, `MATSELL`, `MatCreate()`, `MatCreateSELL()`, `MatSetValues()`, `MatGetInfo()`
+.seealso: `Mat`, `MATSEQSELL`, `MATSELL`, `MatCreate()`, `MatCreateSELL()`, `MatSetValues()`, `MatGetInfo()`
  @*/
 PetscErrorCode MatSeqSELLSetPreallocation(Mat B, PetscInt rlenmax, const PetscInt rlen[])
 {
@@ -86,7 +82,7 @@ PetscErrorCode MatSeqSELLSetPreallocation(Mat B, PetscInt rlenmax, const PetscIn
   PetscValidHeaderSpecific(B, MAT_CLASSID, 1);
   PetscValidType(B, 1);
   PetscTryMethod(B, "MatSeqSELLSetPreallocation_C", (Mat, PetscInt, const PetscInt[]), (B, rlenmax, rlen));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSeqSELLSetPreallocation_SeqSELL(Mat B, PetscInt maxallocrow, const PetscInt rlen[])
@@ -169,7 +165,7 @@ PetscErrorCode MatSeqSELLSetPreallocation_SeqSELL(Mat B, PetscInt maxallocrow, c
   b->maxallocmat      = b->sliidx[totalslices];
   B->info.nz_unneeded = (double)b->maxallocmat;
   if (realalloc) PetscCall(MatSetOption(B, MAT_NEW_NONZERO_ALLOCATION_ERR, PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatGetRow_SeqSELL(Mat A, PetscInt row, PetscInt *nz, PetscInt **idx, PetscScalar **v)
@@ -192,13 +188,13 @@ PetscErrorCode MatGetRow_SeqSELL(Mat A, PetscInt row, PetscInt *nz, PetscInt **i
     for (j = 0; j < a->rlen[row]; j++) a->getrowvals[j] = a->val[shift + 8 * j];
     *v = a->getrowvals;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatRestoreRow_SeqSELL(Mat A, PetscInt row, PetscInt *nz, PetscInt **idx, PetscScalar **v)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatConvert_SeqSELL_SeqAIJ(Mat A, MatType newtype, MatReuse reuse, Mat *newmat)
@@ -236,7 +232,7 @@ PetscErrorCode MatConvert_SeqSELL_SeqAIJ(Mat A, MatType newtype, MatReuse reuse,
   } else {
     *newmat = B;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #include <../src/mat/impls/aij/seq/aij.h>
@@ -286,7 +282,7 @@ PetscErrorCode MatConvert_SeqAIJ_SeqSELL(Mat A, MatType newtype, MatReuse reuse,
   } else {
     *newmat = B;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMult_SeqSELL(Mat A, Vec xx, Vec yy)
@@ -335,7 +331,7 @@ PetscErrorCode MatMult_SeqSELL(Mat A, Vec xx, Vec yy)
     vec_y3 = _mm512_setzero_pd();
     vec_y4 = _mm512_setzero_pd();
 
-    j = a->sliidx[i] >> 3; /* 8 bytes are read at each time, corresponding to a slice columnn */
+    j = a->sliidx[i] >> 3; /* 8 bytes are read at each time, corresponding to a slice column */
     switch ((a->sliidx[i + 1] - a->sliidx[i]) / 8 & 3) {
     case 3:
       AVX512_Mult_Private(vec_idx, vec_x, vec_vals, vec_y);
@@ -501,7 +497,7 @@ PetscErrorCode MatMult_SeqSELL(Mat A, Vec xx, Vec yy)
   PetscCall(PetscLogFlops(2.0 * a->nz - a->nonzerorowcnt)); /* theoretical minimal FLOPs */
   PetscCall(VecRestoreArrayRead(xx, &x));
   PetscCall(VecRestoreArray(yy, &y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #include <../src/mat/impls/aij/seq/ftn-kernels/fmultadd.h>
@@ -551,7 +547,7 @@ PetscErrorCode MatMultAdd_SeqSELL(Mat A, Vec xx, Vec yy, Vec zz)
     vec_y3 = _mm512_setzero_pd();
     vec_y4 = _mm512_setzero_pd();
 
-    j = a->sliidx[i] >> 3; /* 8 bytes are read at each time, corresponding to a slice columnn */
+    j = a->sliidx[i] >> 3; /* 8 bytes are read at each time, corresponding to a slice column */
     switch ((a->sliidx[i + 1] - a->sliidx[i]) / 8 & 3) {
     case 3:
       AVX512_Mult_Private(vec_idx, vec_x, vec_vals, vec_y);
@@ -678,7 +674,7 @@ PetscErrorCode MatMultAdd_SeqSELL(Mat A, Vec xx, Vec yy, Vec zz)
   PetscCall(PetscLogFlops(2.0 * a->nz));
   PetscCall(VecRestoreArrayRead(xx, &x));
   PetscCall(VecRestoreArrayPair(yy, zz, &y, &z));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultTransposeAdd_SeqSELL(Mat A, Vec xx, Vec zz, Vec yy)
@@ -697,7 +693,7 @@ PetscErrorCode MatMultTransposeAdd_SeqSELL(Mat A, Vec xx, Vec zz, Vec yy)
   PetscFunctionBegin;
   if (A->symmetric == PETSC_BOOL3_TRUE) {
     PetscCall(MatMultAdd_SeqSELL(A, xx, zz, yy));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if (zz != yy) PetscCall(VecCopy(zz, yy));
   PetscCall(VecGetArrayRead(xx, &x));
@@ -725,7 +721,7 @@ PetscErrorCode MatMultTransposeAdd_SeqSELL(Mat A, Vec xx, Vec zz, Vec yy)
   PetscCall(PetscLogFlops(2.0 * a->sliidx[a->totalslices]));
   PetscCall(VecRestoreArrayRead(xx, &x));
   PetscCall(VecRestoreArray(yy, &y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMultTranspose_SeqSELL(Mat A, Vec xx, Vec yy)
@@ -737,7 +733,7 @@ PetscErrorCode MatMultTranspose_SeqSELL(Mat A, Vec xx, Vec yy)
     PetscCall(VecSet(yy, 0.0));
     PetscCall(MatMultTransposeAdd_SeqSELL(A, xx, yy, yy));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -765,7 +761,7 @@ PetscErrorCode MatMissingDiagonal_SeqSELL(Mat A, PetscBool *missing, PetscInt *d
       }
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatMarkDiagonal_SeqSELL(Mat A)
@@ -788,7 +784,7 @@ PetscErrorCode MatMarkDiagonal_SeqSELL(Mat A)
       }
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -802,7 +798,7 @@ PetscErrorCode MatInvertDiagonal_SeqSELL(Mat A, PetscScalar omega, PetscScalar f
   PetscScalar *idiag, *mdiag;
 
   PetscFunctionBegin;
-  if (a->idiagvalid) PetscFunctionReturn(0);
+  if (a->idiagvalid) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(MatMarkDiagonal_SeqSELL(A));
   diag = a->diag;
   if (!a->idiag) {
@@ -816,12 +812,11 @@ PetscErrorCode MatInvertDiagonal_SeqSELL(Mat A, PetscScalar omega, PetscScalar f
     for (i = 0; i < m; i++) {
       mdiag[i] = val[diag[i]];
       if (!PetscAbsScalar(mdiag[i])) { /* zero diagonal */
-        if (PetscRealPart(fshift)) {
-          PetscCall(PetscInfo(A, "Zero diagonal on row %" PetscInt_FMT "\n", i));
-          A->factorerrortype             = MAT_FACTOR_NUMERIC_ZEROPIVOT;
-          A->factorerror_zeropivot_value = 0.0;
-          A->factorerror_zeropivot_row   = i;
-        } else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_INCOMP, "Zero diagonal on row %" PetscInt_FMT, i);
+        PetscCheck(PetscRealPart(fshift), PETSC_COMM_SELF, PETSC_ERR_ARG_INCOMP, "Zero diagonal on row %" PetscInt_FMT, i);
+        PetscCall(PetscInfo(A, "Zero diagonal on row %" PetscInt_FMT "\n", i));
+        A->factorerrortype             = MAT_FACTOR_NUMERIC_ZEROPIVOT;
+        A->factorerror_zeropivot_value = 0.0;
+        A->factorerror_zeropivot_row   = i;
       }
       idiag[i] = 1.0 / val[diag[i]];
     }
@@ -834,7 +829,7 @@ PetscErrorCode MatInvertDiagonal_SeqSELL(Mat A, PetscScalar omega, PetscScalar f
     PetscCall(PetscLogFlops(2.0 * m));
   }
   a->idiagvalid = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatZeroEntries_SeqSELL(Mat A)
@@ -844,7 +839,7 @@ PetscErrorCode MatZeroEntries_SeqSELL(Mat A)
   PetscFunctionBegin;
   PetscCall(PetscArrayzero(a->val, a->sliidx[a->totalslices]));
   PetscCall(MatSeqSELLInvalidateDiagonal(A));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDestroy_SeqSELL(Mat A)
@@ -853,7 +848,7 @@ PetscErrorCode MatDestroy_SeqSELL(Mat A)
 
   PetscFunctionBegin;
 #if defined(PETSC_USE_LOG)
-  PetscLogObjectState((PetscObject)A, "Rows=%" PetscInt_FMT ", Cols=%" PetscInt_FMT ", NZ=%" PetscInt_FMT, A->rmap->n, A->cmap->n, a->nz);
+  PetscCall(PetscLogObjectState((PetscObject)A, "Rows=%" PetscInt_FMT ", Cols=%" PetscInt_FMT ", NZ=%" PetscInt_FMT, A->rmap->n, A->cmap->n, a->nz));
 #endif
   PetscCall(MatSeqXSELLFreeSELL(A, &a->val, &a->colidx));
   PetscCall(ISDestroy(&a->row));
@@ -876,7 +871,7 @@ PetscErrorCode MatDestroy_SeqSELL(Mat A)
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatSeqSELLGetArray_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatSeqSELLRestoreArray_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)A, "MatConvert_seqsell_seqaij_C", NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSetOption_SeqSELL(Mat A, MatOption op, PetscBool flg)
@@ -921,7 +916,7 @@ PetscErrorCode MatSetOption_SeqSELL(Mat A, MatOption op, PetscBool flg)
   default:
     SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "unknown option %d", op);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatGetDiagonal_SeqSELL(Mat A, Vec v)
@@ -939,7 +934,7 @@ PetscErrorCode MatGetDiagonal_SeqSELL(Mat A, Vec v)
     PetscCall(VecGetArray(v, &x));
     for (i = 0; i < n; i++) x[i] = 1.0 / a->val[diag[i]];
     PetscCall(VecRestoreArray(v, &x));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(VecSet(v, zero));
@@ -955,7 +950,7 @@ PetscErrorCode MatGetDiagonal_SeqSELL(Mat A, Vec v)
     }
   }
   PetscCall(VecRestoreArray(v, &x));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDiagonalScale_SeqSELL(Mat A, Vec ll, Vec rr)
@@ -1000,7 +995,7 @@ PetscErrorCode MatDiagonalScale_SeqSELL(Mat A, Vec ll, Vec rr)
     PetscCall(PetscLogFlops(a->nz));
   }
   PetscCall(MatSeqSELLInvalidateDiagonal(A));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatGetValues_SeqSELL(Mat A, PetscInt m, const PetscInt im[], PetscInt n, const PetscInt in[], PetscScalar v[])
@@ -1040,7 +1035,7 @@ PetscErrorCode MatGetValues_SeqSELL(Mat A, PetscInt m, const PetscInt im[], Pets
     finished:;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatView_SeqSELL_ASCII(Mat A, PetscViewer viewer)
@@ -1092,7 +1087,7 @@ PetscErrorCode MatView_SeqSELL_ASCII(Mat A, PetscViewer viewer)
     PetscCall(PetscViewerASCIIPrintf(viewer, "];\n %s = spconvert(zzz);\n", name));
     PetscCall(PetscViewerASCIIUseTabs(viewer, PETSC_TRUE));
   } else if (format == PETSC_VIEWER_ASCII_FACTOR_INFO || format == PETSC_VIEWER_ASCII_INFO) {
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   } else if (format == PETSC_VIEWER_ASCII_COMMON) {
     PetscCall(PetscViewerASCIIUseTabs(viewer, PETSC_FALSE));
     for (i = 0; i < m; i++) {
@@ -1262,7 +1257,7 @@ PetscErrorCode MatView_SeqSELL_ASCII(Mat A, PetscViewer viewer)
     PetscCall(PetscViewerASCIIUseTabs(viewer, PETSC_TRUE));
   }
   PetscCall(PetscViewerFlush(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #include <petscdraw.h>
@@ -1351,7 +1346,7 @@ PetscErrorCode MatView_SeqSELL_Draw_Zoom(PetscDraw draw, void *Aa)
     }
     PetscDrawCollectiveEnd(draw);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #include <petscdraw.h>
@@ -1364,7 +1359,7 @@ PetscErrorCode MatView_SeqSELL_Draw(Mat A, PetscViewer viewer)
   PetscFunctionBegin;
   PetscCall(PetscViewerDrawGetDraw(viewer, 0, &draw));
   PetscCall(PetscDrawIsNull(draw, &isnull));
-  if (isnull) PetscFunctionReturn(0);
+  if (isnull) PetscFunctionReturn(PETSC_SUCCESS);
 
   xr = A->cmap->n;
   yr = A->rmap->n;
@@ -1379,7 +1374,7 @@ PetscErrorCode MatView_SeqSELL_Draw(Mat A, PetscViewer viewer)
   PetscCall(PetscDrawZoom(draw, MatView_SeqSELL_Draw_Zoom, A));
   PetscCall(PetscObjectCompose((PetscObject)A, "Zoomviewer", NULL));
   PetscCall(PetscDrawSave(draw));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatView_SeqSELL(Mat A, PetscViewer viewer)
@@ -1395,7 +1390,7 @@ PetscErrorCode MatView_SeqSELL(Mat A, PetscViewer viewer)
   } else if (isbinary) {
     /* PetscCall(MatView_SeqSELL_Binary(A,viewer)); */
   } else if (isdraw) PetscCall(MatView_SeqSELL_Draw(A, viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatAssemblyEnd_SeqSELL(Mat A, MatAssemblyType mode)
@@ -1405,7 +1400,7 @@ PetscErrorCode MatAssemblyEnd_SeqSELL(Mat A, MatAssemblyType mode)
   MatScalar   *vp;
 
   PetscFunctionBegin;
-  if (mode == MAT_FLUSH_ASSEMBLY) PetscFunctionReturn(0);
+  if (mode == MAT_FLUSH_ASSEMBLY) PetscFunctionReturn(PETSC_SUCCESS);
   /* To do: compress out the unused elements */
   PetscCall(MatMarkDiagonal_SeqSELL(A));
   PetscCall(PetscInfo(A, "Matrix size: %" PetscInt_FMT " X %" PetscInt_FMT "; storage space: %" PetscInt_FMT " allocated %" PetscInt_FMT " used (%" PetscInt_FMT " nonzeros+%" PetscInt_FMT " paddedzeros)\n", A->rmap->n, A->cmap->n, a->maxallocmat, a->sliidx[a->totalslices], a->nz, a->sliidx[a->totalslices] - a->nz));
@@ -1426,7 +1421,7 @@ PetscErrorCode MatAssemblyEnd_SeqSELL(Mat A, MatAssemblyType mode)
       lastcol = 0;
       if (nrow > 0) {                                /* nonempty row */
         lastcol = cp[8 * (nrow - 1) + row_in_slice]; /* use the index from the last nonzero at current row */
-      } else if (!row_in_slice) {                    /* first row of the currect slice is empty */
+      } else if (!row_in_slice) {                    /* first row of the correct slice is empty */
         for (j = 1; j < 8; j++) {
           if (a->rlen[8 * i + j]) {
             lastcol = cp[j];
@@ -1448,7 +1443,7 @@ PetscErrorCode MatAssemblyEnd_SeqSELL(Mat A, MatAssemblyType mode)
   a->reallocs = 0;
 
   PetscCall(MatSeqSELLInvalidateDiagonal(A));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatGetInfo_SeqSELL(Mat A, MatInfoType flag, MatInfo *info)
@@ -1472,7 +1467,7 @@ PetscErrorCode MatGetInfo_SeqSELL(Mat A, MatInfoType flag, MatInfo *info)
     info->fill_ratio_needed = 0;
     info->factor_mallocs    = 0;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSetValues_SeqSELL(Mat A, PetscInt m, const PetscInt im[], PetscInt n, const PetscInt in[], const PetscScalar v[], InsertMode is)
@@ -1545,7 +1540,7 @@ PetscErrorCode MatSetValues_SeqSELL(Mat A, PetscInt m, const PetscInt im[], Pets
     }
     a->rlen[row] = nrow;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatCopy_SeqSELL(Mat A, Mat B, MatStructure str)
@@ -1561,14 +1556,14 @@ PetscErrorCode MatCopy_SeqSELL(Mat A, Mat B, MatStructure str)
   } else {
     PetscCall(MatCopy_Basic(A, B, str));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSetUp_SeqSELL(Mat A)
 {
   PetscFunctionBegin;
   PetscCall(MatSeqSELLSetPreallocation(A, PETSC_DEFAULT, NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSeqSELLGetArray_SeqSELL(Mat A, PetscScalar *array[])
@@ -1577,13 +1572,13 @@ PetscErrorCode MatSeqSELLGetArray_SeqSELL(Mat A, PetscScalar *array[])
 
   PetscFunctionBegin;
   *array = a->val;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSeqSELLRestoreArray_SeqSELL(Mat A, PetscScalar *array[])
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatRealPart_SeqSELL(Mat A)
@@ -1594,7 +1589,7 @@ PetscErrorCode MatRealPart_SeqSELL(Mat A)
 
   PetscFunctionBegin;
   for (i = 0; i < a->sliidx[a->totalslices]; i++) aval[i] = PetscRealPart(aval[i]);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatImaginaryPart_SeqSELL(Mat A)
@@ -1606,7 +1601,7 @@ PetscErrorCode MatImaginaryPart_SeqSELL(Mat A)
   PetscFunctionBegin;
   for (i = 0; i < a->sliidx[a->totalslices]; i++) aval[i] = PetscImaginaryPart(aval[i]);
   PetscCall(MatSeqSELLInvalidateDiagonal(A));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatScale_SeqSELL(Mat inA, PetscScalar alpha)
@@ -1621,7 +1616,7 @@ PetscErrorCode MatScale_SeqSELL(Mat inA, PetscScalar alpha)
   PetscCallBLAS("BLASscal", BLASscal_(&size, &oalpha, aval, &one));
   PetscCall(PetscLogFlops(a->nz));
   PetscCall(MatSeqSELLInvalidateDiagonal(inA));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatShift_SeqSELL(Mat Y, PetscScalar a)
@@ -1631,7 +1626,7 @@ PetscErrorCode MatShift_SeqSELL(Mat Y, PetscScalar a)
   PetscFunctionBegin;
   if (!Y->preallocated || !y->nz) PetscCall(MatSeqSELLSetPreallocation(Y, 1, NULL));
   PetscCall(MatShift_Basic(Y, a));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSOR_SeqSELL(Mat A, Vec bb, PetscReal omega, MatSORType flag, PetscReal fshift, PetscInt its, PetscInt lits, Vec xx)
@@ -1733,10 +1728,9 @@ PetscErrorCode MatSOR_SeqSELL(Mat A, Vec bb, PetscReal omega, MatSORType flag, P
   }
   PetscCall(VecRestoreArray(xx, &x));
   PetscCall(VecRestoreArrayRead(bb, &b));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* -------------------------------------------------------------------*/
 static struct _MatOps MatOps_Values = {MatSetValues_SeqSELL,
                                        MatGetRow_SeqSELL,
                                        MatRestoreRow_SeqSELL,
@@ -1887,7 +1881,8 @@ static struct _MatOps MatOps_Values = {MatSetValues_SeqSELL,
                                        NULL,
                                        NULL,
                                        NULL,
-                                       /*150*/ NULL};
+                                       /*150*/ NULL,
+                                       NULL};
 
 PetscErrorCode MatStoreValues_SeqSELL(Mat mat)
 {
@@ -1897,11 +1892,11 @@ PetscErrorCode MatStoreValues_SeqSELL(Mat mat)
   PetscCheck(a->nonew, PETSC_COMM_SELF, PETSC_ERR_ORDER, "Must call MatSetOption(A,MAT_NEW_NONZERO_LOCATIONS,PETSC_FALSE);first");
 
   /* allocate space for values if not already there */
-  if (!a->saved_values) { PetscCall(PetscMalloc1(a->sliidx[a->totalslices] + 1, &a->saved_values)); }
+  if (!a->saved_values) PetscCall(PetscMalloc1(a->sliidx[a->totalslices] + 1, &a->saved_values));
 
   /* copy values over */
   PetscCall(PetscArraycpy(a->saved_values, a->val, a->sliidx[a->totalslices]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatRetrieveValues_SeqSELL(Mat mat)
@@ -1912,7 +1907,7 @@ PetscErrorCode MatRetrieveValues_SeqSELL(Mat mat)
   PetscCheck(a->nonew, PETSC_COMM_SELF, PETSC_ERR_ORDER, "Must call MatSetOption(A,MAT_NEW_NONZERO_LOCATIONS,PETSC_FALSE);first");
   PetscCheck(a->saved_values, PETSC_COMM_SELF, PETSC_ERR_ORDER, "Must call MatStoreValues(A);first");
   PetscCall(PetscArraycpy(a->val, a->saved_values, a->sliidx[a->totalslices]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1921,18 +1916,18 @@ PetscErrorCode MatRetrieveValues_SeqSELL(Mat mat)
  Not Collective
 
  Input Parameters:
- .  mat - a `MATSEQSELL` matrix
- .  array - pointer to the data
++  mat - a `MATSEQSELL` matrix
+-  array - pointer to the data
 
  Level: intermediate
 
- .seealso: `MATSEQSELL`, `MatSeqSELLGetArray()`, `MatSeqSELLRestoreArrayF90()`
+.seealso: `Mat`, `MATSEQSELL`, `MatSeqSELLGetArray()`, `MatSeqSELLRestoreArrayF90()`
  @*/
 PetscErrorCode MatSeqSELLRestoreArray(Mat A, PetscScalar **array)
 {
   PetscFunctionBegin;
   PetscUseMethod(A, "MatSeqSELLRestoreArray_C", (Mat, PetscScalar **), (A, array));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_EXTERN PetscErrorCode MatCreate_SeqSELL(Mat B)
@@ -1977,7 +1972,7 @@ PETSC_EXTERN PetscErrorCode MatCreate_SeqSELL(Mat B)
   PetscCall(PetscObjectComposeFunction((PetscObject)B, "MatRetrieveValues_C", MatRetrieveValues_SeqSELL));
   PetscCall(PetscObjectComposeFunction((PetscObject)B, "MatSeqSELLSetPreallocation_C", MatSeqSELLSetPreallocation_SeqSELL));
   PetscCall(PetscObjectComposeFunction((PetscObject)B, "MatConvert_seqsell_seqaij_C", MatConvert_SeqSELL_SeqAIJ));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -2048,7 +2043,7 @@ PetscErrorCode MatDuplicateNoCreate_SeqSELL(Mat C, Mat A, MatDuplicateOption cpv
   C->nonzerostate  = A->nonzerostate;
 
   PetscCall(PetscFunctionListDuplicate(((PetscObject)A)->qlist, &((PetscObject)C)->qlist));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDuplicate_SeqSELL(Mat A, MatDuplicateOption cpvalues, Mat *B)
@@ -2059,19 +2054,19 @@ PetscErrorCode MatDuplicate_SeqSELL(Mat A, MatDuplicateOption cpvalues, Mat *B)
   if (!(A->rmap->n % A->rmap->bs) && !(A->cmap->n % A->cmap->bs)) PetscCall(MatSetBlockSizesFromMats(*B, A, A));
   PetscCall(MatSetType(*B, ((PetscObject)A)->type_name));
   PetscCall(MatDuplicateNoCreate_SeqSELL(*B, A, cpvalues, PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
    MATSEQSELL - MATSEQSELL = "seqsell" - A matrix type to be used for sequential sparse matrices,
    based on the sliced Ellpack format
 
-   Options Database Keys:
+   Options Database Key:
 . -mat_type seqsell - sets the matrix type to "`MATSEQELL` during a call to `MatSetFromOptions()`
 
    Level: beginner
 
-.seealso: `MatCreateSeqSell()`, `MATSELL`, `MATMPISELL`, `MATSEQAIJ`, `MATAIJ`, `MATMPIAIJ`
+.seealso: `Mat`, `MatCreateSeqSell()`, `MATSELL`, `MATMPISELL`, `MATSEQAIJ`, `MATAIJ`, `MATMPIAIJ`
 M*/
 
 /*MC
@@ -2083,7 +2078,7 @@ M*/
   for communicators controlling multiple processes.  It is recommended that you call both of
   the above preallocation routines for simplicity.
 
-   Options Database Keys:
+   Options Database Key:
 . -mat_type sell - sets the matrix type to "sell" during a call to MatSetFromOptions()
 
   Level: beginner
@@ -2126,49 +2121,45 @@ M*/
 . * - Hong Zhang, Richard T. Mills, Karl Rupp, and Barry F. Smith, Vectorized Parallel Sparse Matrix-Vector Multiplication in {PETSc} Using {AVX-512},
    Proceedings of the 47th International Conference on Parallel Processing, 2018.
 
-.seealso: `MatCreateSeqSELL()`, `MatCreateSeqAIJ()`, `MatCreateSell()`, `MATSEQSELL`, `MATMPISELL`, `MATSEQAIJ`, `MATMPIAIJ`, `MATAIJ`
+.seealso: `Mat`, `MatCreateSeqSELL()`, `MatCreateSeqAIJ()`, `MatCreateSell()`, `MATSEQSELL`, `MATMPISELL`, `MATSEQAIJ`, `MATMPIAIJ`, `MATAIJ`
 M*/
 
 /*@C
        MatCreateSeqSELL - Creates a sparse matrix in `MATSEQSELL` format.
 
- Collective on comm
+ Collective
 
  Input Parameters:
 +  comm - MPI communicator, set to `PETSC_COMM_SELF`
 .  m - number of rows
 .  n - number of columns
-.  rlenmax - maximum number of nonzeros in a row
--  rlen - array containing the number of nonzeros in the various rows
- (possibly different for each row) or NULL
+.  rlenmax - maximum number of nonzeros in a row, ignored if `rlen` is provided
+-  rlen - array containing the number of nonzeros in the various rows (possibly different for each row) or NULL
 
  Output Parameter:
 .  A - the matrix
 
+ Level: intermediate
+
+ Notes:
  It is recommended that one use the `MatCreate()`, `MatSetType()` and/or `MatSetFromOptions()`,
  MatXXXXSetPreallocation() paradigm instead of this routine directly.
  [MatXXXXSetPreallocation() is, for example, `MatSeqSELLSetPreallocation()`]
 
- Notes:
- If nnz is given then nz is ignored
+ Specify the preallocated storage with either `rlenmax` or `rlen` (not both).
+ Set `rlenmax` = `PETSC_DEFAULT` and `rlen` = `NULL` for PETSc to control dynamic memory
+ allocation.
 
- Specify the preallocated storage with either rlenmax or rlen (not both).
- Set rlenmax = `PETSC_DEFAULT` and rlen = NULL for PETSc to control dynamic memory
- allocation.  For large problems you MUST preallocate memory or you
- will get TERRIBLE performance, see the users' manual chapter on matrices.
-
- Level: intermediate
-
- .seealso: `MATSEQSELL`, `MatCreate()`, `MatCreateSELL()`, `MatSetValues()`, `MatSeqSELLSetPreallocation()`, `MATSELL`, `MATSEQSELL`, `MATMPISELL`
+.seealso: `Mat`, `MATSEQSELL`, `MatCreate()`, `MatCreateSELL()`, `MatSetValues()`, `MatSeqSELLSetPreallocation()`, `MATSELL`, `MATSEQSELL`, `MATMPISELL`
  @*/
-PetscErrorCode MatCreateSeqSELL(MPI_Comm comm, PetscInt m, PetscInt n, PetscInt maxallocrow, const PetscInt rlen[], Mat *A)
+PetscErrorCode MatCreateSeqSELL(MPI_Comm comm, PetscInt m, PetscInt n, PetscInt rlenmax, const PetscInt rlen[], Mat *A)
 {
   PetscFunctionBegin;
   PetscCall(MatCreate(comm, A));
   PetscCall(MatSetSizes(*A, m, n, m, n));
   PetscCall(MatSetType(*A, MATSEQSELL));
-  PetscCall(MatSeqSELLSetPreallocation_SeqSELL(*A, maxallocrow, rlen));
-  PetscFunctionReturn(0);
+  PetscCall(MatSeqSELLSetPreallocation_SeqSELL(*A, rlenmax, rlen));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatEqual_SeqSELL(Mat A, Mat B, PetscBool *flg)
@@ -2180,14 +2171,14 @@ PetscErrorCode MatEqual_SeqSELL(Mat A, Mat B, PetscBool *flg)
   /* If the  matrix dimensions are not equal,or no of nonzeros */
   if ((A->rmap->n != B->rmap->n) || (A->cmap->n != B->cmap->n) || (a->nz != b->nz) || (a->rlenmax != b->rlenmax)) {
     *flg = PETSC_FALSE;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   /* if the a->colidx are the same */
   PetscCall(PetscArraycmp(a->colidx, b->colidx, a->sliidx[totalslices], flg));
-  if (!*flg) PetscFunctionReturn(0);
+  if (!*flg) PetscFunctionReturn(PETSC_SUCCESS);
   /* if a->val are the same */
   PetscCall(PetscArraycmp(a->val, b->val, a->sliidx[totalslices], flg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSeqSELLInvalidateDiagonal(Mat A)
@@ -2196,7 +2187,7 @@ PetscErrorCode MatSeqSELLInvalidateDiagonal(Mat A)
 
   PetscFunctionBegin;
   a->idiagvalid = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatConjugate_SeqSELL(Mat A)
@@ -2211,5 +2202,5 @@ PetscErrorCode MatConjugate_SeqSELL(Mat A)
 #else
   PetscFunctionBegin;
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
