@@ -16,7 +16,7 @@ PetscErrorCode MatFDColoringSetF(MatFDColoring fd, Vec F)
   } else {
     fd->fset = PETSC_FALSE;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #include <petscdraw.h>
@@ -38,7 +38,7 @@ static PetscErrorCode MatFDColoringView_Draw_Zoom(PetscDraw draw, void *Aa)
       PetscCall(PetscDrawRectangle(draw, x, y, x + 1, y + 1, i + 1, i + 1, i + 1, i + 1));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode MatFDColoringView_Draw(MatFDColoring fd, PetscViewer viewer)
@@ -50,7 +50,7 @@ static PetscErrorCode MatFDColoringView_Draw(MatFDColoring fd, PetscViewer viewe
   PetscFunctionBegin;
   PetscCall(PetscViewerDrawGetDraw(viewer, 0, &draw));
   PetscCall(PetscDrawIsNull(draw, &isnull));
-  if (isnull) PetscFunctionReturn(0);
+  if (isnull) PetscFunctionReturn(PETSC_SUCCESS);
 
   xr = fd->N;
   yr = fd->M;
@@ -65,15 +65,15 @@ static PetscErrorCode MatFDColoringView_Draw(MatFDColoring fd, PetscViewer viewe
   PetscCall(PetscDrawZoom(draw, MatFDColoringView_Draw_Zoom, fd));
   PetscCall(PetscObjectCompose((PetscObject)fd, "Zoomviewer", NULL));
   PetscCall(PetscDrawSave(draw));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatFDColoringView - Views a finite difference coloring context.
 
-   Collective on c
+   Collective
 
-   Input  Parameters:
+   Input Parameters:
 +  c - the coloring context
 -  viewer - visualization context
 
@@ -92,7 +92,7 @@ static PetscErrorCode MatFDColoringView_Draw(MatFDColoring fd, PetscViewer viewe
    involves more than 33 then some seemingly identical colors are displayed making it look
    like an illegal coloring. This is just a graphical artifact.
 
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`
 @*/
 PetscErrorCode MatFDColoringView(MatFDColoring c, PetscViewer viewer)
 {
@@ -136,16 +136,24 @@ PetscErrorCode MatFDColoringView(MatFDColoring c, PetscViewer viewer)
     }
     PetscCall(PetscViewerFlush(viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatFDColoringSetParameters - Sets the parameters for the sparse approximation of
    a Jacobian matrix using finite differences.
 
-   Logically Collective on matfd
+   Logically Collective
 
-   The Jacobian is estimated with the differencing approximation
+   Input Parameters:
++  matfd - the coloring context
+.  error - relative error
+-  umin - minimum allowable u-value magnitude
+
+   Level: advanced
+
+   Note:
+     The Jacobian is estimated with the differencing approximation
 .vb
        F'(u)_{:,i} = [F(u+h*dx_{i}) - F(u)]/h where
        htype = 'ds':
@@ -157,14 +165,7 @@ PetscErrorCode MatFDColoringView(MatFDColoring c, PetscViewer viewer)
          h = error_rel * sqrt(1 + ||u||)
 .ve
 
-   Input Parameters:
-+  coloring - the coloring context
-.  error_rel - relative error
--  umin - minimum allowable u-value magnitude
-
-   Level: advanced
-
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringSetFromOptions()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringSetFromOptions()`
 @*/
 PetscErrorCode MatFDColoringSetParameters(MatFDColoring matfd, PetscReal error, PetscReal umin)
 {
@@ -172,15 +173,15 @@ PetscErrorCode MatFDColoringSetParameters(MatFDColoring matfd, PetscReal error,
   PetscValidHeaderSpecific(matfd, MAT_FDCOLORING_CLASSID, 1);
   PetscValidLogicalCollectiveReal(matfd, error, 2);
   PetscValidLogicalCollectiveReal(matfd, umin, 3);
-  if (error != PETSC_DEFAULT) matfd->error_rel = error;
-  if (umin != PETSC_DEFAULT) matfd->umin = umin;
-  PetscFunctionReturn(0);
+  if (error != (PetscReal)PETSC_DEFAULT) matfd->error_rel = error;
+  if (umin != (PetscReal)PETSC_DEFAULT) matfd->umin = umin;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatFDColoringSetBlockSize - Sets block size for efficient inserting entries of Jacobian matrix.
 
-   Logically Collective on matfd
+   Logically Collective
 
    Input Parameters:
 +  coloring - the coloring context
@@ -189,7 +190,7 @@ PetscErrorCode MatFDColoringSetParameters(MatFDColoring matfd, PetscReal error,
 
    Level: intermediate
 
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringSetFromOptions()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringSetFromOptions()`
 @*/
 PetscErrorCode MatFDColoringSetBlockSize(MatFDColoring matfd, PetscInt brows, PetscInt bcols)
 {
@@ -199,13 +200,13 @@ PetscErrorCode MatFDColoringSetBlockSize(MatFDColoring matfd, PetscInt brows, Pe
   PetscValidLogicalCollectiveInt(matfd, bcols, 3);
   if (brows != PETSC_DEFAULT) matfd->brows = brows;
   if (bcols != PETSC_DEFAULT) matfd->bcols = bcols;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatFDColoringSetUp - Sets up the internal data structures of matrix coloring context for the later use.
 
-   Collective on mat
+   Collective
 
    Input Parameters:
 +  mat - the matrix containing the nonzero structure of the Jacobian
@@ -217,7 +218,7 @@ PetscErrorCode MatFDColoringSetBlockSize(MatFDColoring matfd, PetscInt brows, Pe
    Notes:
    When the coloring type is `IS_COLORING_LOCAL` the coloring is in the local ordering of the unknowns.
 
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringDestroy()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringDestroy()`
 @*/
 PetscErrorCode MatFDColoringSetUp(Mat mat, ISColoring iscoloring, MatFDColoring color)
 {
@@ -226,7 +227,7 @@ PetscErrorCode MatFDColoringSetUp(Mat mat, ISColoring iscoloring, MatFDColoring
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidHeaderSpecific(color, MAT_FDCOLORING_CLASSID, 3);
-  if (color->setupcalled) PetscFunctionReturn(0);
+  if (color->setupcalled) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscObjectCompareId((PetscObject)mat, color->matid, &eq));
   PetscCheck(eq, PetscObjectComm((PetscObject)mat), PETSC_ERR_ARG_WRONG, "Matrix used with MatFDColoringSetUp() must be that used with MatFDColoringCreate()");
 
@@ -235,7 +236,7 @@ PetscErrorCode MatFDColoringSetUp(Mat mat, ISColoring iscoloring, MatFDColoring
 
   color->setupcalled = PETSC_TRUE;
   PetscCall(PetscLogEventEnd(MAT_FDColoringSetUp, mat, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -252,7 +253,7 @@ PetscErrorCode MatFDColoringSetUp(Mat mat, ISColoring iscoloring, MatFDColoring
 
    Level: intermediate
 
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringSetFunction()`, `MatFDColoringSetFromOptions()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringSetFunction()`, `MatFDColoringSetFromOptions()`
 @*/
 PetscErrorCode MatFDColoringGetFunction(MatFDColoring matfd, PetscErrorCode (**f)(void), void **fctx)
 {
@@ -260,22 +261,24 @@ PetscErrorCode MatFDColoringGetFunction(MatFDColoring matfd, PetscErrorCode (**f
   PetscValidHeaderSpecific(matfd, MAT_FDCOLORING_CLASSID, 1);
   if (f) *f = matfd->f;
   if (fctx) *fctx = matfd->fctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatFDColoringSetFunction - Sets the function to use for computing the Jacobian.
 
-   Logically Collective on matfd
+   Logically Collective
 
    Input Parameters:
 +  coloring - the coloring context
 .  f - the function
 -  fctx - the optional user-defined function context
 
-   Calling sequence of (*f) function:
-    For `SNES`:    PetscErrorCode (*f)(SNES,Vec,Vec,void*)
-    If not using `SNES`: PetscErrorCode (*f)(void *dummy,Vec,Vec,void*) and dummy is ignored
+   Calling sequence with `SNES` of `f`:
+$   PetscErrorCode f(SNES, Vec in, Vec out, void *fctx)
+
+   Calling sequence without `SNES` of `f`:
+$   PetscErrorCode f(void *dummy, Vec in, Vec out, void *fctx)
 
    Level: advanced
 
@@ -288,7 +291,7 @@ PetscErrorCode MatFDColoringGetFunction(MatFDColoring matfd, PetscErrorCode (**f
     In Fortran you must call `MatFDColoringSetFunction()` for a coloring object to
   be used without `SNES` or within the `SNES` solvers.
 
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringGetFunction()`, `MatFDColoringSetFromOptions()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringGetFunction()`, `MatFDColoringSetFromOptions()`
 @*/
 PetscErrorCode MatFDColoringSetFunction(MatFDColoring matfd, PetscErrorCode (*f)(void), void *fctx)
 {
@@ -296,14 +299,14 @@ PetscErrorCode MatFDColoringSetFunction(MatFDColoring matfd, PetscErrorCode (*f)
   PetscValidHeaderSpecific(matfd, MAT_FDCOLORING_CLASSID, 1);
   matfd->f    = f;
   matfd->fctx = fctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatFDColoringSetFromOptions - Sets coloring finite difference parameters from
    the options database.
 
-   Collective on matfd
+   Collective
 
    The Jacobian, F'(u), is estimated with the differencing approximation
 .vb
@@ -326,7 +329,7 @@ PetscErrorCode MatFDColoringSetFunction(MatFDColoring matfd, PetscErrorCode (*f)
 
     Level: intermediate
 
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringView()`, `MatFDColoringSetParameters()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringView()`, `MatFDColoringSetParameters()`
 @*/
 PetscErrorCode MatFDColoringSetFromOptions(MatFDColoring matfd)
 {
@@ -355,29 +358,29 @@ PetscErrorCode MatFDColoringSetFromOptions(MatFDColoring matfd)
   /* process any options handlers added with PetscObjectAddOptionsHandler() */
   PetscCall(PetscObjectProcessOptionsHandlers((PetscObject)matfd, PetscOptionsObject));
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatFDColoringSetType - Sets the approach for computing the finite difference parameter
 
-   Collective on matfd
+   Collective
 
    Input Parameters:
 +  coloring - the coloring context
 -  type - either `MATMFFD_WP` or `MATMFFD_DS`
 
-   Options Database Keys:
+   Options Database Key:
 .  -mat_fd_type - "wp" or "ds"
 
+   Level: intermediate
+
    Note:
    It is goofy that the argument type is `MatMFFDType` since the `MatFDColoring` actually computes the matrix entries
          but the process of computing the entries is the same as as with the `MATMFFD` operation so we should reuse the names instead of
          introducing another one.
 
-   Level: intermediate
-
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringView()`, `MatFDColoringSetParameters()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringView()`, `MatFDColoringSetParameters()`
 @*/
 PetscErrorCode MatFDColoringSetType(MatFDColoring matfd, MatMFFDType type)
 {
@@ -385,12 +388,12 @@ PetscErrorCode MatFDColoringSetType(MatFDColoring matfd, MatMFFDType type)
   PetscValidHeaderSpecific(matfd, MAT_FDCOLORING_CLASSID, 1);
   /*
      It is goofy to handle the strings this way but currently there is no code to free a dynamically created matfd->htype
-     and this function is being provided as patch for a release so it shouldn't change the implementaton
+     and this function is being provided as patch for a release so it shouldn't change the implementation
   */
   if (type[0] == 'w' && type[1] == 'p') matfd->htype = "wp";
   else if (type[0] == 'd' && type[1] == 's') matfd->htype = "ds";
   else SETERRQ(PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Unknown finite differencing type %s", type);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatFDColoringViewFromOptions(MatFDColoring fd, const char prefix[], const char optionname[])
@@ -411,14 +414,14 @@ PetscErrorCode MatFDColoringViewFromOptions(MatFDColoring fd, const char prefix[
     PetscCall(PetscViewerPopFormat(viewer));
     PetscCall(PetscViewerDestroy(&viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatFDColoringCreate - Creates a matrix coloring context for finite difference
    computation of Jacobians.
 
-   Collective on mat
+   Collective
 
    Input Parameters:
 +  mat - the matrix containing the nonzero structure of the Jacobian
@@ -429,7 +432,7 @@ PetscErrorCode MatFDColoringViewFromOptions(MatFDColoring fd, const char prefix[
 
     Level: intermediate
 
-.seealso: `MatFDColoring`, `MatFDColoringDestroy()`, `SNESComputeJacobianDefaultColor()`, `ISColoringCreate()`,
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringDestroy()`, `SNESComputeJacobianDefaultColor()`, `ISColoringCreate()`,
           `MatFDColoringSetFunction()`, `MatFDColoringSetFromOptions()`, `MatFDColoringApply()`,
           `MatFDColoringView()`, `MatFDColoringSetParameters()`, `MatColoringCreate()`, `DMCreateColoring()`, `MatFDColoringSetValues()`
 @*/
@@ -470,21 +473,21 @@ PetscErrorCode MatFDColoringCreate(Mat mat, ISColoring iscoloring, MatFDColoring
   *color = c;
   PetscCall(PetscObjectCompose((PetscObject)mat, "SNESMatFDColoring", (PetscObject)c));
   PetscCall(PetscLogEventEnd(MAT_FDColoringCreate, mat, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatFDColoringDestroy - Destroys a matrix coloring context that was created
     via `MatFDColoringCreate()`.
 
-    Collective on c
+    Collective
 
     Input Parameter:
 .   c - coloring context
 
     Level: intermediate
 
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`
 @*/
 PetscErrorCode MatFDColoringDestroy(MatFDColoring *c)
 {
@@ -492,10 +495,10 @@ PetscErrorCode MatFDColoringDestroy(MatFDColoring *c)
   MatFDColoring color = *c;
 
   PetscFunctionBegin;
-  if (!*c) PetscFunctionReturn(0);
+  if (!*c) PetscFunctionReturn(PETSC_SUCCESS);
   if (--((PetscObject)color)->refct > 0) {
     *c = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   /* we do not free the column arrays since their entries are owned by the ISs in color->isa */
@@ -514,7 +517,7 @@ PetscErrorCode MatFDColoringDestroy(MatFDColoring *c)
   PetscCall(VecDestroy(&color->w2));
   PetscCall(VecDestroy(&color->w3));
   PetscCall(PetscHeaderDestroy(c));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -537,16 +540,18 @@ PetscErrorCode MatFDColoringDestroy(MatFDColoring *c)
 
    Fortran Note:
    This routine has a different interface for Fortran
-$     #include <petsc/finclude/petscmat.h>
-$          use petscmat
-$          PetscInt, pointer :: array(:)
-$          PetscErrorCode  ierr
-$          MatFDColoring   i
-$          call MatFDColoringGetPerturbedColumnsF90(i,array,ierr)
-$      use the entries of array ...
-$          call MatFDColoringRestorePerturbedColumnsF90(i,array,ierr)
+.vb
+     #include <petsc/finclude/petscmat.h>
+          use petscmat
+          PetscInt, pointer :: array(:)
+          PetscErrorCode  ierr
+          MatFDColoring   i
+          call MatFDColoringGetPerturbedColumnsF90(i,array,ierr)
+      use the entries of array ...
+          call MatFDColoringRestorePerturbedColumnsF90(i,array,ierr)
+.ve
 
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringDestroy()`, `MatFDColoringView()`, `MatFDColoringApply()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringDestroy()`, `MatFDColoringView()`, `MatFDColoringApply()`
 @*/
 PetscErrorCode MatFDColoringGetPerturbedColumns(MatFDColoring coloring, PetscInt *n, const PetscInt *cols[])
 {
@@ -557,14 +562,14 @@ PetscErrorCode MatFDColoringGetPerturbedColumns(MatFDColoring coloring, PetscInt
   } else {
     *n = 0;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatFDColoringApply - Given a matrix for which a `MatFDColoring` context
     has been created, computes the Jacobian for a function via finite differences.
 
-    Collective on J
+    Collective
 
     Input Parameters:
 +   mat - location to store Jacobian
@@ -580,7 +585,7 @@ PetscErrorCode MatFDColoringGetPerturbedColumns(MatFDColoring coloring, PetscInt
 
     Level: intermediate
 
-.seealso: `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringDestroy()`, `MatFDColoringView()`, `MatFDColoringSetFunction()`, `MatFDColoringSetValues()`
+.seealso: `Mat`, `MatFDColoring`, `MatFDColoringCreate()`, `MatFDColoringDestroy()`, `MatFDColoringView()`, `MatFDColoringSetFunction()`, `MatFDColoringSetValues()`
 @*/
 PetscErrorCode MatFDColoringApply(Mat J, MatFDColoring coloring, Vec x1, void *sctx)
 {
@@ -603,5 +608,5 @@ PetscErrorCode MatFDColoringApply(Mat J, MatFDColoring coloring, Vec x1, void *s
     PetscCall(MatFDColoringViewFromOptions(coloring, NULL, "-mat_fd_coloring_view"));
     coloring->viewed = PETSC_TRUE;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
