@@ -1,25 +1,26 @@
 static char help[] = "Example use of PetscInfo() as a configurable informative logging or warning tool\n";
 
-# include <petscsys.h>
-# include <petscmat.h>
-# include <petscvec.h>
+#include <petscsys.h>
+#include <petscmat.h>
+#include <petscvec.h>
 
 int main(int argc, char **argv)
 {
-  Mat             A, Aself;
-  Vec             b, bself;
+  Mat A, Aself;
+  Vec b, bself;
 #if defined(PETSC_USE_INFO)
-  PetscInt        testarg = 1234;
+  PetscInt testarg = 1234;
 #endif
-  int             numClasses;
-  PetscClassId    testMatClassid, testVecClassid, testSysClassid;
-  PetscBool       isEnabled = PETSC_FALSE, invert = PETSC_FALSE;
-  char            *testClassesStr, *filename;
-  const char      *testMatClassname, *testVecClassname;
-  char            **testClassesStrArr;
-  FILE            *infoFile;
+  int          numClasses;
+  PetscClassId testMatClassid, testVecClassid, testSysClassid;
+  PetscBool    isEnabled = PETSC_FALSE, invert = PETSC_FALSE;
+  char        *testClassesStr, *filename;
+  const char  *testMatClassname, *testVecClassname;
+  char       **testClassesStrArr;
+  FILE        *infoFile;
 
-  PetscCall(PetscInitialize(&argc, &argv,(char *) 0, help));
+  PetscFunctionBeginUser;
+  PetscCall(PetscInitialize(&argc, &argv, (char *)0, help));
 
   /*
      Examples on how to call PetscInfo() using different objects with or without arguments, and different communicators.
@@ -51,12 +52,12 @@ int main(int argc, char **argv)
   /*
      First retrieve some basic information regarding the classes for which we want to filter
   */
-  PetscCall(PetscObjectGetClassId((PetscObject) A, &testMatClassid));
-  PetscCall(PetscObjectGetClassId((PetscObject) b, &testVecClassid));
+  PetscCall(PetscObjectGetClassId((PetscObject)A, &testMatClassid));
+  PetscCall(PetscObjectGetClassId((PetscObject)b, &testVecClassid));
   /* Sys class has PetscClassId = PETSC_SMALLEST_CLASSID */
   testSysClassid = PETSC_SMALLEST_CLASSID;
-  PetscCall(PetscObjectGetClassName((PetscObject) A, &testMatClassname));
-  PetscCall(PetscObjectGetClassName((PetscObject) b, &testVecClassname));
+  PetscCall(PetscObjectGetClassName((PetscObject)A, &testMatClassname));
+  PetscCall(PetscObjectGetClassName((PetscObject)b, &testVecClassname));
 
   /*
      Examples on how to use individual PetscInfo() commands.
@@ -118,7 +119,7 @@ int main(int argc, char **argv)
   */
   PetscCall(PetscStrallocpy("mat,vec,sys", &testClassesStr));
   PetscCall(PetscStrToArray((const char *)testClassesStr, ',', &numClasses, &testClassesStrArr));
-  PetscCall(PetscInfoSetClasses(invert, (PetscInt) numClasses, (const char *const *) testClassesStrArr));
+  PetscCall(PetscInfoSetClasses(invert, (PetscInt)numClasses, (const char *const *)testClassesStrArr));
   PetscCall(PetscInfoProcessClass(testMatClassname, 1, &testMatClassid));
   PetscCall(PetscInfoProcessClass(testVecClassname, 1, &testVecClassid));
   PetscCall(PetscInfoProcessClass("sys", 1, &testSysClassid));
@@ -141,7 +142,7 @@ int main(int argc, char **argv)
   PetscCall(PetscStrallocpy("vec,sys", &testClassesStr));
   PetscCall(PetscStrToArray((const char *)testClassesStr, ',', &numClasses, &testClassesStrArr));
   invert = PETSC_TRUE;
-  PetscCall(PetscInfoSetClasses(invert, (PetscInt) numClasses, (const char *const *) testClassesStrArr));
+  PetscCall(PetscInfoSetClasses(invert, (PetscInt)numClasses, (const char *const *)testClassesStrArr));
   PetscCall(PetscInfoProcessClass(testMatClassname, 1, &testMatClassid));
   PetscCall(PetscInfoProcessClass(testVecClassname, 1, &testVecClassid));
   PetscCall(PetscInfoProcessClass("sys", 1, &testSysClassid));
@@ -165,23 +166,23 @@ int main(int argc, char **argv)
 /*TEST
 
    test:
-      requires: defined(PETSC_USE_INFO)
+      requires: defined(PETSC_USE_INFO) !defined(PETSC_HAVE_THREADSAFETY)
       suffix: 1
       args: -info
-      filter: grep -h -ve Running -ve communicator -ve MPI_Comm -ve OpenMP -ve PetscGetHostName -ve PetscDetermineInitialFPTrap -ve libpetscbamg -ve PetscDeviceContext -ve PetscDeviceType
+      filter: grep -h -ve Running -ve communicator -ve MPI_Comm -ve OpenMP -ve PetscGetHostName -ve PetscDetermineInitialFPTrap -ve libpetscbamg -ve PetscDeviceContext -ve PetscDeviceType -ve PetscDeviceInitializeTypeFromOptions_Private
 
    test:
-      requires: defined(PETSC_USE_INFO)
+      requires: defined(PETSC_USE_INFO) !defined(PETSC_HAVE_THREADSAFETY)
       suffix: 2
       args: -info ex7info.2
-      filter: grep -h -ve Running -ve communicator -ve MPI_Comm -ve OpenMP -ve PetscGetHostName -ve PetscDetermineInitialFPTrap -ve libpetscbamg -ve PetscDeviceContext -ve PetscDeviceType "ex7info.2.0"
+      filter: grep -h -ve Running -ve communicator -ve MPI_Comm -ve OpenMP -ve PetscGetHostName -ve PetscDetermineInitialFPTrap -ve libpetscbamg -ve PetscDeviceContext -ve PetscDeviceType -ve PetscDeviceInitializeTypeFromOptions_Private "ex7info.2.0"
 
    test:
-      requires: defined(PETSC_USE_INFO)
+      requires: defined(PETSC_USE_INFO) !defined(PETSC_HAVE_THREADSAFETY)
       suffix: 3
       nsize: 2
       args: -info ex7info.3
-      filter: grep -h -ve Running -ve communicator -ve MPI_Comm -ve OpenMP -ve PetscGetHostName  -ve PetscDetermineInitialFPTrap -ve libpetscbamg -ve PetscDeviceContext -ve PetscDeviceType "ex7info.3.0" | sort -b
+      filter: grep -h -ve Running -ve communicator -ve MPI_Comm -ve OpenMP -ve PetscGetHostName  -ve PetscDetermineInitialFPTrap -ve libpetscbamg -ve PetscDeviceContext -ve PetscDeviceType -ve PetscDeviceInitializeTypeFromOptions_Private "ex7info.3.0" | sort -b
 
    test:
       requires: defined(PETSC_USE_INFO)
