@@ -31,26 +31,23 @@ static PetscErrorCode MatTransposeAXPY_Private(Mat Y, PetscScalar a, Mat X, MatS
   }
   PetscCall(MatAXPY(A, a, F, str));
   PetscCall(MatDestroy(&F));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatAXPY - Computes Y = a*X + Y.
 
-   Logically  Collective on Mat
+   Logically Collective
 
    Input Parameters:
 +  a - the scalar multiplier
 .  X - the first matrix
 .  Y - the second matrix
--  str - either SAME_NONZERO_PATTERN, DIFFERENT_NONZERO_PATTERN, UNKNOWN_NONZERO_PATTERN, or SUBSET_NONZERO_PATTERN (nonzeros of X is a subset of Y's)
-
-   Note:
-   No operation is performed when a is zero.
+-  str - either `SAME_NONZERO_PATTERN`, `DIFFERENT_NONZERO_PATTERN`, `UNKNOWN_NONZERO_PATTERN`, or `SUBSET_NONZERO_PATTERN` (nonzeros of `X` is a subset of `Y`'s)
 
    Level: intermediate
 
-.seealso: `MatAYPX()`
+.seealso: [](chapter_matrices), `Mat`, `MatAYPX()`
  @*/
 PetscErrorCode MatAXPY(Mat Y, PetscScalar a, Mat X, MatStructure str)
 {
@@ -71,10 +68,10 @@ PetscErrorCode MatAXPY(Mat Y, PetscScalar a, Mat X, MatStructure str)
   PetscCheck(m1 == m2 && n1 == n2, PETSC_COMM_SELF, PETSC_ERR_ARG_SIZ, "Non conforming matrix add: local sizes X %" PetscInt_FMT " x %" PetscInt_FMT ", Y %" PetscInt_FMT " x %" PetscInt_FMT, m1, n1, m2, n2);
   PetscCheck(Y->assembled, PetscObjectComm((PetscObject)Y), PETSC_ERR_ARG_WRONGSTATE, "Not for unassembled matrix (Y)");
   PetscCheck(X->assembled, PetscObjectComm((PetscObject)X), PETSC_ERR_ARG_WRONGSTATE, "Not for unassembled matrix (X)");
-  if (a == (PetscScalar)0.0) PetscFunctionReturn(0);
+  if (a == (PetscScalar)0.0) PetscFunctionReturn(PETSC_SUCCESS);
   if (Y == X) {
     PetscCall(MatScale(Y, 1.0 + a));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCall(PetscObjectObjectTypeCompare((PetscObject)X, (PetscObject)Y, &sametype));
   PetscCall(PetscLogEventBegin(MAT_AXPY, Y, 0, 0, 0));
@@ -94,7 +91,7 @@ PetscErrorCode MatAXPY(Mat Y, PetscScalar a, Mat X, MatStructure str)
     }
   }
   PetscCall(PetscLogEventEnd(MAT_AXPY, Y, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatAXPY_Basic_Preallocate(Mat Y, Mat X, Mat *B)
@@ -144,7 +141,7 @@ PetscErrorCode MatAXPY_Basic_Preallocate(Mat Y, Mat X, Mat *B)
     PetscCall(MatPreallocatorPreallocate(preallocator, PETSC_FALSE, *B));
     PetscCall(MatDestroy(&preallocator));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatAXPY_Basic(Mat Y, PetscScalar a, Mat X, MatStructure str)
@@ -159,7 +156,7 @@ PetscErrorCode MatAXPY_Basic(Mat Y, PetscScalar a, Mat X, MatStructure str)
     PetscCall(MatGetOperation(Y, MATOP_AXPY, (void (**)(void)) & f));
     if (f) {
       PetscCall((*f)(Y, a, X, str));
-      PetscFunctionReturn(0);
+      PetscFunctionReturn(PETSC_SUCCESS);
     }
   }
   /* no need to preallocate if Y is dense */
@@ -168,7 +165,7 @@ PetscErrorCode MatAXPY_Basic(Mat Y, PetscScalar a, Mat X, MatStructure str)
     PetscCall(PetscObjectTypeCompare((PetscObject)X, MATNEST, &isnest));
     if (isnest) {
       PetscCall(MatAXPY_Dense_Nest(Y, a, X));
-      PetscFunctionReturn(0);
+      PetscFunctionReturn(PETSC_SUCCESS);
     }
     if (str == DIFFERENT_NONZERO_PATTERN || str == UNKNOWN_NONZERO_PATTERN) str = SUBSET_NONZERO_PATTERN;
   }
@@ -213,7 +210,7 @@ PetscErrorCode MatAXPY_Basic(Mat Y, PetscScalar a, Mat X, MatStructure str)
     PetscCall(MatAXPY_BasicWithPreallocation(B, Y, a, X, str));
     PetscCall(MatHeaderMerge(Y, &B));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatAXPY_BasicWithPreallocation(Mat B, Mat Y, PetscScalar a, Mat X, MatStructure str)
@@ -262,30 +259,30 @@ PetscErrorCode MatAXPY_BasicWithPreallocation(Mat B, Mat Y, PetscScalar a, Mat X
   PetscCall(MatRestoreRowUpperTriangular(X));
   PetscCall(MatAssemblyBegin(B, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(B, MAT_FINAL_ASSEMBLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   MatShift - Computes Y =  Y + a I, where a is a PetscScalar and I is the identity matrix.
+   MatShift - Computes `Y =  Y + a I`, where `a` is a `PetscScalar`
 
-   Neighbor-wise Collective on Mat
+   Neighbor-wise Collective
 
    Input Parameters:
-+  Y - the matrices
--  a - the PetscScalar
++  Y - the matrix
+-  a - the `PetscScalar`
 
    Level: intermediate
 
    Notes:
-    If Y is a rectangular matrix, the shift is done on the main diagonal Y_{ii} of the matrix (https://en.wikipedia.org/wiki/Main_diagonal)
+    If `Y` is a rectangular matrix, the shift is done on the main diagonal of the matrix (https://en.wikipedia.org/wiki/Main_diagonal)
 
-    If the matrix Y is missing some diagonal entries this routine can be very slow. To make it fast one should initially
+    If the matrix `Y` is missing some diagonal entries this routine can be very slow. To make it fast one should initially
    fill the matrix so that all diagonal entries have a value (with a value of zero for those locations that would not have an
    entry). No operation is performed when a is zero.
 
-   To form Y = Y + diag(V) use MatDiagonalSet()
+   To form Y = Y + diag(V) use `MatDiagonalSet()`
 
-.seealso: `MatDiagonalSet()`, `MatScale()`, `MatDiagonalScale()`
+.seealso: [](chapter_matrices), `Mat`, `MatDiagonalSet()`, `MatScale()`, `MatDiagonalScale()`
  @*/
 PetscErrorCode MatShift(Mat Y, PetscScalar a)
 {
@@ -294,13 +291,13 @@ PetscErrorCode MatShift(Mat Y, PetscScalar a)
   PetscCheck(Y->assembled, PetscObjectComm((PetscObject)Y), PETSC_ERR_ARG_WRONGSTATE, "Not for unassembled matrix");
   PetscCheck(!Y->factortype, PetscObjectComm((PetscObject)Y), PETSC_ERR_ARG_WRONGSTATE, "Not for factored matrix");
   MatCheckPreallocated(Y, 1);
-  if (a == 0.0) PetscFunctionReturn(0);
+  if (a == 0.0) PetscFunctionReturn(PETSC_SUCCESS);
 
   if (Y->ops->shift) PetscUseTypeMethod(Y, shift, a);
   else PetscCall(MatShift_Basic(Y, a));
 
   PetscCall(PetscObjectStateIncrease((PetscObject)Y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatDiagonalSet_Default(Mat Y, Vec D, InsertMode is)
@@ -315,29 +312,29 @@ PetscErrorCode MatDiagonalSet_Default(Mat Y, Vec D, InsertMode is)
   PetscCall(VecRestoreArrayRead(D, &v));
   PetscCall(MatAssemblyBegin(Y, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(Y, MAT_FINAL_ASSEMBLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   MatDiagonalSet - Computes Y = Y + D, where D is a diagonal matrix
-   that is represented as a vector. Or Y[i,i] = D[i] if InsertMode is
-   INSERT_VALUES.
+   MatDiagonalSet - Computes `Y` = `Y` + `D`, where `D` is a diagonal matrix
+   that is represented as a vector. Or Y[i,i] = D[i] if `InsertMode` is
+   `INSERT_VALUES`.
 
-   Neighbor-wise Collective on Mat
+   Neighbor-wise Collective
 
    Input Parameters:
 +  Y - the input matrix
 .  D - the diagonal matrix, represented as a vector
--  i - INSERT_VALUES or ADD_VALUES
-
-   Note:
-    If the matrix Y is missing some diagonal entries this routine can be very slow. To make it fast one should initially
-   fill the matrix so that all diagonal entries have a value (with a value of zero for those locations that would not have an
-   entry).
+-  i - `INSERT_VALUES` or `ADD_VALUES`
 
    Level: intermediate
 
-.seealso: `MatShift()`, `MatScale()`, `MatDiagonalScale()`
+   Note:
+    If the matrix `Y` is missing some diagonal entries this routine can be very slow. To make it fast one should initially
+   fill the matrix so that all diagonal entries have a value (with a value of zero for those locations that would not have an
+   entry).
+
+.seealso: [](chapter_matrices), `Mat`, `MatShift()`, `MatScale()`, `MatDiagonalScale()`
 @*/
 PetscErrorCode MatDiagonalSet(Mat Y, Vec D, InsertMode is)
 {
@@ -352,36 +349,36 @@ PetscErrorCode MatDiagonalSet(Mat Y, Vec D, InsertMode is)
   if (Y->ops->diagonalset) PetscUseTypeMethod(Y, diagonalset, D, is);
   else PetscCall(MatDiagonalSet_Default(Y, D, is));
   PetscCall(PetscObjectStateIncrease((PetscObject)Y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatAYPX - Computes Y = a*Y + X.
 
-   Logically on Mat
+   Logically Collective
 
    Input Parameters:
-+  a - the PetscScalar multiplier
++  a - the `PetscScalar` multiplier
 .  Y - the first matrix
 .  X - the second matrix
--  str - either SAME_NONZERO_PATTERN, DIFFERENT_NONZERO_PATTERN, UNKNOWN_NONZERO_PATTERN, or SUBSET_NONZERO_PATTERN (nonzeros of X is a subset of Y's)
+-  str - either `SAME_NONZERO_PATTERN`, `DIFFERENT_NONZERO_PATTERN`, `UNKNOWN_NONZERO_PATTERN`, or `SUBSET_NONZERO_PATTERN` (nonzeros of `X` is a subset of `Y`'s)
 
    Level: intermediate
 
-.seealso: `MatAXPY()`
+.seealso: [](chapter_matrices), `Mat`, `MatAXPY()`
  @*/
 PetscErrorCode MatAYPX(Mat Y, PetscScalar a, Mat X, MatStructure str)
 {
   PetscFunctionBegin;
   PetscCall(MatScale(Y, a));
   PetscCall(MatAXPY(Y, 1.0, X, str));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatComputeOperator - Computes the explicit matrix
 
-    Collective on Mat
+    Collective
 
     Input Parameters:
 +   inmat - the matrix
@@ -390,13 +387,14 @@ PetscErrorCode MatAYPX(Mat Y, PetscScalar a, Mat X, MatStructure str)
     Output Parameter:
 .   mat - the explicit  operator
 
+    Level: advanced
+
     Note:
     This computation is done by applying the operators to columns of the identity matrix.
     This routine is costly in general, and is recommended for use only with relatively small systems.
-    Currently, this routine uses a dense matrix format if mattype == NULL.
-
-    Level: advanced
+    Currently, this routine uses a dense matrix format if `mattype` == `NULL`.
 
+.seealso: [](chapter_matrices), `Mat`, `MatConvert()`, `MatMult()`, `MatComputeOperatorTranspose()`
 @*/
 PetscErrorCode MatComputeOperator(Mat inmat, MatType mattype, Mat *mat)
 {
@@ -404,14 +402,14 @@ PetscErrorCode MatComputeOperator(Mat inmat, MatType mattype, Mat *mat)
   PetscValidHeaderSpecific(inmat, MAT_CLASSID, 1);
   PetscValidPointer(mat, 3);
   PetscCall(MatConvert_Shell(inmat, mattype ? mattype : MATDENSE, MAT_INITIAL_MATRIX, mat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     MatComputeOperatorTranspose - Computes the explicit matrix representation of
-        a give matrix that can apply MatMultTranspose()
+        a give matrix that can apply `MatMultTranspose()`
 
-    Collective on Mat
+    Collective
 
     Input Parameters:
 +   inmat - the matrix
@@ -420,13 +418,14 @@ PetscErrorCode MatComputeOperator(Mat inmat, MatType mattype, Mat *mat)
     Output Parameter:
 .   mat - the explicit  operator transposed
 
+    Level: advanced
+
     Note:
     This computation is done by applying the transpose of the operator to columns of the identity matrix.
     This routine is costly in general, and is recommended for use only with relatively small systems.
-    Currently, this routine uses a dense matrix format if mattype == NULL.
-
-    Level: advanced
+    Currently, this routine uses a dense matrix format if `mattype` == `NULL`.
 
+.seealso: [](chapter_matrices), `Mat`, `MatConvert()`, `MatMult()`, `MatComputeOperator()`
 @*/
 PetscErrorCode MatComputeOperatorTranspose(Mat inmat, MatType mattype, Mat *mat)
 {
@@ -438,7 +437,7 @@ PetscErrorCode MatComputeOperatorTranspose(Mat inmat, MatType mattype, Mat *mat)
   PetscCall(MatCreateTranspose(inmat, &A));
   PetscCall(MatConvert_Shell(A, mattype ? mattype : MATDENSE, MAT_INITIAL_MATRIX, mat));
   PetscCall(MatDestroy(&A));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -448,12 +447,9 @@ PetscErrorCode MatComputeOperatorTranspose(Mat inmat, MatType mattype, Mat *mat)
 + A   - The matrix
 - tol - The zero tolerance
 
-  Output Parameters:
-. A - The chopped matrix
-
   Level: intermediate
 
-.seealso: `MatCreate()`, `MatZeroEntries()`
+.seealso: [](chapter_matrices), `Mat`, `MatCreate()`, `MatZeroEntries()`
  @*/
 PetscErrorCode MatChop(Mat A, PetscReal tol)
 {
@@ -512,5 +508,5 @@ PetscErrorCode MatChop(Mat A, PetscReal tol)
     PetscCall(PetscFree2(newCols, newVals));
     PetscCall(MatSetOption(A, MAT_NO_OFF_PROC_ENTRIES, flg)); /* reset option to its user-defined value */
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
