@@ -3,10 +3,10 @@
 PETSC_INTERN PetscErrorCode MatSetBlockSizes_Default(Mat mat, PetscInt rbs, PetscInt cbs)
 {
   PetscFunctionBegin;
-  if (!mat->preallocated) PetscFunctionReturn(0);
+  if (!mat->preallocated) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheck(mat->rmap->bs <= 0 || mat->rmap->bs == rbs, PetscObjectComm((PetscObject)mat), PETSC_ERR_SUP, "Cannot change row block size %" PetscInt_FMT " to %" PetscInt_FMT, mat->rmap->bs, rbs);
   PetscCheck(mat->cmap->bs <= 0 || mat->cmap->bs == cbs, PetscObjectComm((PetscObject)mat), PETSC_ERR_SUP, "Cannot change column block size %" PetscInt_FMT " to %" PetscInt_FMT, mat->cmap->bs, cbs);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_INTERN PetscErrorCode MatShift_Basic(Mat Y, PetscScalar a)
@@ -25,7 +25,7 @@ PETSC_INTERN PetscErrorCode MatShift_Basic(Mat Y, PetscScalar a)
   PetscCall(MatAssemblyBegin(Y, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(Y, MAT_FINAL_ASSEMBLY));
   PetscCall(MatSetOption(Y, MAT_NO_OFF_PROC_ENTRIES, prevoption));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -53,13 +53,12 @@ PETSC_INTERN PetscErrorCode MatShift_Basic(Mat Y, PetscScalar a)
 .    -mat_type seqbaij  - `MATSEQBAIJ` type, uses `MatCreateSeqBAIJ()`
 -    -mat_type mpibaij  - `MATMPIBAIJ` type, uses `MatCreateBAIJ()`
 
-   Even More Options Database Keys:
-   See the manpages for particular formats (e.g., `MatCreateSeqAIJ()`)
+   See the manpages for particular formats (e.g., `MATSEQAIJ`)
    for additional format-specific options.
 
    Level: beginner
 
-.seealso: `MatCreateSeqAIJ()`, `MatCreateAIJ()`,
+.seealso: [](chapter_matrices), `Mat`, `MatCreateSeqAIJ()`, `MatCreateAIJ()`,
           `MatCreateSeqDense()`, `MatCreateDense()`,
           `MatCreateSeqBAIJ()`, `MatCreateBAIJ()`,
           `MatCreateSeqSBAIJ()`, `MatCreateSBAIJ()`,
@@ -94,13 +93,13 @@ PetscErrorCode MatCreate(MPI_Comm comm, Mat *A)
   B->boundtocpu = PETSC_TRUE;
 #endif
   *A = B;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatSetErrorIfFailure - Causes `Mat` to generate an immediate error, for example a zero pivot, is detected.
 
-   Logically Collective on mat
+   Logically Collective
 
    Input Parameters:
 +  mat -  matrix obtained from `MatCreate()`
@@ -112,7 +111,7 @@ PetscErrorCode MatCreate(MPI_Comm comm, Mat *A)
    If this flag is not set then the matrix operation will note the error and continue. The error may cause a later `PC` or `KSP` error
    or result in a `KSPConvergedReason` indicating the method did not converge.
 
-.seealso: `PCSetErrorIfFailure()`, `KSPConvergedReason`, `SNESConvergedReason`
+.seealso: [](chapter_matrices), `Mat`, `PCSetErrorIfFailure()`, `KSPConvergedReason`, `SNESConvergedReason`
 @*/
 PetscErrorCode MatSetErrorIfFailure(Mat mat, PetscBool flg)
 {
@@ -120,13 +119,13 @@ PetscErrorCode MatSetErrorIfFailure(Mat mat, PetscBool flg)
   PetscValidHeaderSpecific(mat, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveBool(mat, flg, 2);
   mat->erroriffailure = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   MatSetSizes - Sets the local and global sizes, and checks to determine compatibility
 
-  Collective on Mat
+  Collective
 
   Input Parameters:
 +  A - the matrix
@@ -135,25 +134,25 @@ PetscErrorCode MatSetErrorIfFailure(Mat mat, PetscBool flg)
 .  M - number of global rows (or `PETSC_DETERMINE`)
 -  N - number of global columns (or `PETSC_DETERMINE`)
 
+  Level: beginner
+
    Notes:
-   m (n) and M (N) cannot be both `PETSC_DECIDE`
-   If one processor calls this with M (N) of `PETSC_DECIDE` then all processors must, otherwise the program will hang.
+   `m` (`n`) and `M` (`N`) cannot be both `PETSC_DECIDE`
+   If one processor calls this with `M` (`N`) of `PETSC_DECIDE` then all processors must, otherwise the program will hang.
 
    If `PETSC_DECIDE` is not used for the arguments 'm' and 'n', then the
    user must ensure that they are chosen to be compatible with the
    vectors. To do this, one first considers the matrix-vector product
-   'y = A x'. The 'm' that is used in the above routine must match the
-   local size used in the vector creation routine VecCreateMPI() for 'y'.
-   Likewise, the 'n' used must match that used as the local size in
+   'y = A x'. The `m` that is used in the above routine must match the
+   local size used in the vector creation routine `VecCreateMPI()` for 'y'.
+   Likewise, the `n` used must match that used as the local size in
    `VecCreateMPI()` for 'x'.
 
    You cannot change the sizes once they have been set.
 
    The sizes must be set before `MatSetUp()` or MatXXXSetPreallocation() is called.
 
-  Level: beginner
-
-.seealso: `MatGetSize()`, `PetscSplitOwnership()`
+.seealso: [](chapter_matrices), `Mat`, `MatGetSize()`, `PetscSplitOwnership()`
 @*/
 PetscErrorCode MatSetSizes(Mat A, PetscInt m, PetscInt n, PetscInt M, PetscInt N)
 {
@@ -171,7 +170,7 @@ PetscErrorCode MatSetSizes(Mat A, PetscInt m, PetscInt n, PetscInt M, PetscInt N
   A->cmap->n = n;
   A->rmap->N = M > -1 ? M : A->rmap->N;
   A->cmap->N = N > -1 ? N : A->cmap->N;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -181,7 +180,7 @@ PetscErrorCode MatSetSizes(Mat A, PetscInt m, PetscInt n, PetscInt M, PetscInt N
    `MATAIJ`, using the routines `MatCreateSeqAIJ()` and `MatCreateAIJ()` if
    you do not select a type in the options database.
 
-   Collective on B
+   Collective
 
    Input Parameter:
 .  A - the matrix
@@ -194,13 +193,12 @@ PetscErrorCode MatSetSizes(Mat A, PetscInt m, PetscInt n, PetscInt M, PetscInt N
 .    -mat_type seqbaij  - `MATSEQBAIJ`, uses `MatCreateSeqBAIJ()`
 -    -mat_type mpibaij  - `MATMPIBAIJ`, uses `MatCreateBAIJ()`
 
-   Even More Options Database Keys:
-   See the manpages for particular formats (e.g., `MatCreateSeqAIJ()`)
+   See the manpages for particular formats (e.g., `MATSEQAIJ`)
    for additional format-specific options.
 
    Level: beginner
 
-.seealso: `MatCreateSeqAIJ(()`, `MatCreateAIJ()`,
+.seealso: [](chapter_matrices), `Mat`, `MatCreateSeqAIJ()`, `MatCreateAIJ()`,
           `MatCreateSeqDense()`, `MatCreateDense()`,
           `MatCreateSeqBAIJ()`, `MatCreateBAIJ()`,
           `MatCreateSeqSBAIJ()`, `MatCreateSBAIJ()`,
@@ -264,13 +262,13 @@ PetscErrorCode MatSetFromOptions(Mat B)
   /* process any options handlers added with PetscObjectAddOptionsHandler() */
   PetscCall(PetscObjectProcessOptionsHandlers((PetscObject)B, PetscOptionsObject));
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatXAIJSetPreallocation - set preallocation for serial and parallel `MATAIJ`, `MATBAIJ`, and `MATSBAIJ` matrices and their unassembled versions.
 
-   Collective on A
+   Collective
 
    Input Parameters:
 +  A - matrix being preallocated
@@ -282,7 +280,8 @@ PetscErrorCode MatSetFromOptions(Mat B)
 
    Level: beginner
 
-.seealso: `MatSeqAIJSetPreallocation()`, `MatMPIAIJSetPreallocation()`, `MatSeqBAIJSetPreallocation()`, `MatMPIBAIJSetPreallocation()`, `MatSeqSBAIJSetPreallocation()`, `MatMPISBAIJSetPreallocation()`,
+.seealso: [](chapter_matrices), `Mat`, `MatSeqAIJSetPreallocation()`, `MatMPIAIJSetPreallocation()`, `MatSeqBAIJSetPreallocation()`, `MatMPIBAIJSetPreallocation()`,
+          `MatSeqSBAIJSetPreallocation()`, `MatMPISBAIJSetPreallocation()`,
           `PetscSplitOwnership()`
 @*/
 PetscErrorCode MatXAIJSetPreallocation(Mat A, PetscInt bs, const PetscInt dnnz[], const PetscInt onnz[], const PetscInt dnnzu[], const PetscInt onnzu[])
@@ -339,7 +338,7 @@ PetscErrorCode MatXAIJSetPreallocation(Mat A, PetscInt bs, const PetscInt dnnz[]
       PetscCall(PetscFree2(sdnnz, sonnz));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -360,7 +359,7 @@ PetscErrorCode MatHeaderMerge(Mat A, Mat *C)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A, MAT_CLASSID, 1);
   PetscValidHeaderSpecific(*C, MAT_CLASSID, 2);
-  if (A == *C) PetscFunctionReturn(0);
+  if (A == *C) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheckSameComm(A, 1, *C, 2);
   /* save the parts of A we need */
   Abops     = ((PetscObject)A)->bops[0];
@@ -412,7 +411,7 @@ PetscErrorCode MatHeaderMerge(Mat A, Mat *C)
   ((PetscObject)*C)->olist = NULL;
 
   PetscCall(PetscHeaderDestroy(C));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /*
         Replace A's header with that of C; the C object is then destroyed
@@ -433,7 +432,7 @@ PETSC_EXTERN PetscErrorCode MatHeaderReplace(Mat A, Mat *C)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A, MAT_CLASSID, 1);
   PetscValidHeaderSpecific(*C, MAT_CLASSID, 2);
-  if (A == *C) PetscFunctionReturn(0);
+  if (A == *C) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheckSameComm(A, 1, *C, 2);
   PetscCheck(((PetscObject)*C)->refct == 1, PetscObjectComm((PetscObject)C), PETSC_ERR_ARG_WRONGSTATE, "Object C has refct %" PetscInt_FMT " > 1, would leave hanging reference", ((PetscObject)*C)->refct);
 
@@ -451,13 +450,13 @@ PETSC_EXTERN PetscErrorCode MatHeaderReplace(Mat A, Mat *C)
   ((PetscObject)*C)->refct = 1;
   PetscCall(MatShellSetOperation(*C, MATOP_DESTROY, (void (*)(void))NULL));
   PetscCall(MatDestroy(C));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
      MatBindToCPU - marks a matrix to temporarily stay on the CPU and perform computations on the CPU
 
-   Logically collective on A
+   Logically Collective
 
    Input Parameters:
 +   A - the matrix
@@ -465,7 +464,7 @@ PETSC_EXTERN PetscErrorCode MatHeaderReplace(Mat A, Mat *C)
 
    Level: intermediate
 
-.seealso: `MatBoundToCPU()`
+.seealso: [](chapter_matrices), `Mat`, `MatBoundToCPU()`
 @*/
 PetscErrorCode MatBindToCPU(Mat A, PetscBool flg)
 {
@@ -473,11 +472,11 @@ PetscErrorCode MatBindToCPU(Mat A, PetscBool flg)
   PetscValidHeaderSpecific(A, MAT_CLASSID, 1);
   PetscValidLogicalCollectiveBool(A, flg, 2);
 #if defined(PETSC_HAVE_DEVICE)
-  if (A->boundtocpu == flg) PetscFunctionReturn(0);
+  if (A->boundtocpu == flg) PetscFunctionReturn(PETSC_SUCCESS);
   A->boundtocpu = flg;
   PetscTryTypeMethod(A, bindtocpu, flg);
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -491,7 +490,7 @@ PetscErrorCode MatBindToCPU(Mat A, PetscBool flg)
 
    Level: intermediate
 
-.seealso: `MatBindToCPU()`
+.seealso: [](chapter_matrices), `Mat`, `MatBindToCPU()`
 @*/
 PetscErrorCode MatBoundToCPU(Mat A, PetscBool *flg)
 {
@@ -503,7 +502,7 @@ PetscErrorCode MatBoundToCPU(Mat A, PetscBool *flg)
 #else
   *flg = PETSC_TRUE;
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSetValuesCOO_Basic(Mat A, const PetscScalar coo_v[], InsertMode imode)
@@ -527,7 +526,7 @@ PetscErrorCode MatSetValuesCOO_Basic(Mat A, const PetscScalar coo_v[], InsertMod
   for (n = 0; n < n_i; n++) PetscCall(MatSetValue(A, coo_i[n], coo_j[n], coo_v ? coo_v[n] : zero, ADD_VALUES));
   PetscCall(ISRestoreIndices(is_coo_i, &coo_i));
   PetscCall(ISRestoreIndices(is_coo_j, &coo_j));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode MatSetPreallocationCOO_Basic(Mat A, PetscCount ncoo, const PetscInt coo_i[], const PetscInt coo_j[])
@@ -556,13 +555,13 @@ PetscErrorCode MatSetPreallocationCOO_Basic(Mat A, PetscCount ncoo, const PetscI
   PetscCall(PetscObjectCompose((PetscObject)A, "__PETSc_coo_j", (PetscObject)is_coo_j));
   PetscCall(ISDestroy(&is_coo_i));
   PetscCall(ISDestroy(&is_coo_j));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatSetPreallocationCOO - set preallocation for matrices using a coordinate format of the entries with global indices
 
-   Collective on A
+   Collective
 
    Input Parameters:
 +  A - matrix being preallocated
@@ -573,7 +572,7 @@ PetscErrorCode MatSetPreallocationCOO_Basic(Mat A, PetscCount ncoo, const PetscI
    Level: beginner
 
    Notes:
-   The indices coo_i and coo_j may be modified within this function. The caller should not rely on them
+   The indices `coo_i` and `coo_j` may be modified within this function. The caller should not rely on them
    having any specific value after this function returns. The arrays can be freed or reused immediately
    after this function returns.
 
@@ -585,7 +584,9 @@ PetscErrorCode MatSetPreallocationCOO_Basic(Mat A, PetscCount ncoo, const PetscI
    If you just want to create a sequential AIJ matrix (`MATSEQAIJ`), and your matrix entries in COO format are unique, you can also use
    `MatCreateSeqAIJFromTriple()`. But that is not recommended for iterative applications.
 
-.seealso: `MatSetValuesCOO()`, `MatSeqAIJSetPreallocation()`, `MatMPIAIJSetPreallocation()`, `MatSeqBAIJSetPreallocation()`, `MatMPIBAIJSetPreallocation()`, `MatSeqSBAIJSetPreallocation()`, `MatMPISBAIJSetPreallocation()`, `MatSetPreallocationCOOLocal()`, `DMSetMatrixPreallocateSkip()`, `MatCreateSeqAIJFromTriple()`
+.seealso: [](chapter_matrices), `Mat`, `MatSetValuesCOO()`, `MatSeqAIJSetPreallocation()`, `MatMPIAIJSetPreallocation()`, `MatSeqBAIJSetPreallocation()`,
+          `MatMPIBAIJSetPreallocation()`, `MatSeqSBAIJSetPreallocation()`, `MatMPISBAIJSetPreallocation()`, `MatSetPreallocationCOOLocal()`,
+          `DMSetMatrixPreallocateSkip()`, `MatCreateSeqAIJFromTriple()`
 @*/
 PetscErrorCode MatSetPreallocationCOO(Mat A, PetscCount ncoo, PetscInt coo_i[], PetscInt coo_j[])
 {
@@ -609,13 +610,13 @@ PetscErrorCode MatSetPreallocationCOO(Mat A, PetscCount ncoo, PetscInt coo_i[],
   PetscCall(PetscLogEventEnd(MAT_PreallCOO, A, 0, 0, 0));
   A->preallocated = PETSC_TRUE;
   A->nonzerostate++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    MatSetPreallocationCOOLocal - set preallocation for matrices using a coordinate format of the entries with local indices
 
-   Collective on A
+   Collective
 
    Input Parameters:
 +  A - matrix being preallocated
@@ -629,7 +630,7 @@ PetscErrorCode MatSetPreallocationCOO(Mat A, PetscCount ncoo, PetscInt coo_i[],
    The local indices are translated using the local to global mapping, thus `MatSetLocalToGlobalMapping()` must have been
    called prior to this function. For matrices created with `DMCreateMatrix()` the local to global mapping is often already provided.
 
-   The indices coo_i and coo_j may be modified within this function. They might be translated to corresponding global
+   The indices `coo_i` and `coo_j` may be modified within this function. They might be translated to corresponding global
    indices, but the caller should not rely on them having any specific value after this function returns. The arrays
    can be freed or reused immediately after this function returns.
 
@@ -637,7 +638,9 @@ PetscErrorCode MatSetPreallocationCOO(Mat A, PetscCount ncoo, PetscInt coo_i[],
    but will be ignored. The corresponding entries in `MatSetValuesCOO()` will be ignored too. Remote entries
    are allowed and will be properly added or inserted to the matrix.
 
-.seealso: `MatSetValuesCOO()`, `MatSeqAIJSetPreallocation()`, `MatMPIAIJSetPreallocation()`, `MatSeqBAIJSetPreallocation()`, `MatMPIBAIJSetPreallocation()`, `MatSeqSBAIJSetPreallocation()`, `MatMPISBAIJSetPreallocation()`, `MatSetPreallocationCOO()`, `DMSetMatrixPreallocateSkip()`
+.seealso: [](chapter_matrices), `Mat`, `MatSetValuesCOO()`, `MatSeqAIJSetPreallocation()`, `MatMPIAIJSetPreallocation()`, `MatSeqBAIJSetPreallocation()`,
+          `MatMPIBAIJSetPreallocation()`, `MatSeqSBAIJSetPreallocation()`, `MatMPISBAIJSetPreallocation()`, `MatSetPreallocationCOO()`,
+          `DMSetMatrixPreallocateSkip()`
 @*/
 PetscErrorCode MatSetPreallocationCOOLocal(Mat A, PetscCount ncoo, PetscInt coo_i[], PetscInt coo_j[])
 {
@@ -664,17 +667,17 @@ PetscErrorCode MatSetPreallocationCOOLocal(Mat A, PetscCount ncoo, PetscInt coo_
     PetscCall(MatSetPreallocationCOO(A, ncoo, coo_i, coo_j));
   }
   A->preallocated = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    MatSetValuesCOO - set values at once in a matrix preallocated using `MatSetPreallocationCOO()`
 
-   Collective on A
+   Collective
 
    Input Parameters:
 +  A - matrix being preallocated
-.  coo_v - the matrix values (can be NULL)
+.  coo_v - the matrix values (can be `NULL`)
 -  imode - the insert mode
 
    Level: beginner
@@ -682,12 +685,12 @@ PetscErrorCode MatSetPreallocationCOOLocal(Mat A, PetscCount ncoo, PetscInt coo_
    Notes:
    The values must follow the order of the indices prescribed with `MatSetPreallocationCOO()` or `MatSetPreallocationCOOLocal()`.
 
-          When repeated entries are specified in the COO indices the coo_v values are first properly summed, regardless of the value of imode.
+          When repeated entries are specified in the COO indices the `coo_v` values are first properly summed, regardless of the value of imode.
           The imode flag indicates if coo_v must be added to the current values of the matrix (`ADD_VALUES`) or overwritten (`INSERT_VALUES`).
 
           `MatAssemblyBegin()` and `MatAssemblyEnd()` do not need to be called after this routine. It automatically handles the assembly process.
 
-.seealso: `MatSetPreallocationCOO()`, `MatSetPreallocationCOOLocal()`, `InsertMode`, `INSERT_VALUES`, `ADD_VALUES`
+.seealso: [](chapter_matrices), `Mat`, `MatSetPreallocationCOO()`, `MatSetPreallocationCOOLocal()`, `InsertMode`, `INSERT_VALUES`, `ADD_VALUES`
 @*/
 PetscErrorCode MatSetValuesCOO(Mat A, const PetscScalar coo_v[], InsertMode imode)
 {
@@ -708,7 +711,7 @@ PetscErrorCode MatSetValuesCOO(Mat A, const PetscScalar coo_v[], InsertMode imod
   PetscCall(PetscLogEventEnd(MAT_SetVCOO, A, 0, 0, 0));
   PetscCall(MatAssemblyBegin(A, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(A, MAT_FINAL_ASSEMBLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -721,27 +724,26 @@ PetscErrorCode MatSetValuesCOO(Mat A, const PetscScalar coo_v[], InsertMode imod
    Level: developer
 
    Notes:
-   If the value of flg is set to true, the following will occur:
+   If the value of flg is set to true, the following will occur
++   `MatCreateSubMatrices()` and `MatCreateRedundantMatrix()` - bind created matrices to CPU if the input matrix is bound to the CPU.
+-   `MatCreateVecs()` - bind created vectors to CPU if the input matrix is bound to the CPU.
 
-   `MatCreateSubMatrices()` and `MatCreateRedundantMatrix()` will bind created matrices to CPU if the input matrix is bound to the CPU.
-
-   `MatCreateVecs()` will bind created vectors to CPU if the input matrix is bound to the CPU.
    The bindingpropagates flag itself is also propagated by the above routines.
 
    Developer Note:
-   If the fine-scale `DMDA `has the -dm_bind_below option set to true, then `DMCreateInterpolationScale()` calls `MatSetBindingPropagates()`
+   If the fine-scale `DMDA` has the `-dm_bind_below` option set to true, then `DMCreateInterpolationScale()` calls `MatSetBindingPropagates()`
    on the restriction/interpolation operator to set the bindingpropagates flag to true.
 
-.seealso: `VecSetBindingPropagates()`, `MatGetBindingPropagates()`
+.seealso: [](chapter_matrices), `Mat`, `VecSetBindingPropagates()`, `MatGetBindingPropagates()`
 @*/
 PetscErrorCode MatSetBindingPropagates(Mat A, PetscBool flg)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A, MAT_CLASSID, 1);
-#if defined(PETSC_HAVE_VIENNACL) || defined(PETSC_HAVE_CUDA)
+#if defined(PETSC_HAVE_VIENNACL) || defined(PETSC_HAVE_CUDA) || defined(PETSC_HAVE_HIP)
   A->bindingpropagates = flg;
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -755,17 +757,17 @@ PetscErrorCode MatSetBindingPropagates(Mat A, PetscBool flg)
 
    Level: developer
 
-.seealso: `MatSetBindingPropagates()`
+.seealso: [](chapter_matrices), `Mat`, `MatSetBindingPropagates()`
 @*/
 PetscErrorCode MatGetBindingPropagates(Mat A, PetscBool *flg)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A, MAT_CLASSID, 1);
   PetscValidBoolPointer(flg, 2);
-#if defined(PETSC_HAVE_VIENNACL) || defined(PETSC_HAVE_CUDA)
+#if defined(PETSC_HAVE_VIENNACL) || defined(PETSC_HAVE_CUDA) || defined(PETSC_HAVE_HIP)
   *flg = A->bindingpropagates;
 #else
   *flg = PETSC_FALSE;
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
