@@ -14,7 +14,7 @@ static PetscErrorCode DMAdaptorTransferSolution_Exact_Private(DMAdaptor adaptor,
 {
   PetscFunctionBeginUser;
   PetscCall(DMProjectFunction(adm, 0.0, adaptor->exactSol, adaptor->exactCtx, INSERT_ALL_VALUES, au));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -57,13 +57,13 @@ PetscErrorCode DMAdaptorCreate(MPI_Comm comm, DMAdaptor *adaptor)
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)(*adaptor)->coarsenTag, "coarsen_"));
   PetscCall(VecTaggerSetType((*adaptor)->coarsenTag, VECTAGGERABSOLUTE));
   PetscCall(VecTaggerAbsoluteSetBox((*adaptor)->coarsenTag, &coarsenBox));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMAdaptorDestroy - Destroys a `DMAdaptor` object
 
-  Collective on adaptor
+  Collective
 
   Input Parameter:
 . adaptor - The `DMAdaptor` object
@@ -75,23 +75,23 @@ PetscErrorCode DMAdaptorCreate(MPI_Comm comm, DMAdaptor *adaptor)
 PetscErrorCode DMAdaptorDestroy(DMAdaptor *adaptor)
 {
   PetscFunctionBegin;
-  if (!*adaptor) PetscFunctionReturn(0);
+  if (!*adaptor) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific((*adaptor), DM_CLASSID, 1);
   if (--((PetscObject)(*adaptor))->refct > 0) {
     *adaptor = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCall(VecTaggerDestroy(&(*adaptor)->refineTag));
   PetscCall(VecTaggerDestroy(&(*adaptor)->coarsenTag));
   PetscCall(PetscFree2((*adaptor)->exactSol, (*adaptor)->exactCtx));
   PetscCall(PetscHeaderDestroy(adaptor));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMAdaptorSetFromOptions - Sets properties of a `DMAdaptor` object from the options database
 
-  Collective on adaptor
+  Collective
 
   Input Parameter:
 . adaptor - The `DMAdaptor` object
@@ -117,13 +117,13 @@ PetscErrorCode DMAdaptorSetFromOptions(DMAdaptor adaptor)
   PetscOptionsEnd();
   PetscCall(VecTaggerSetFromOptions(adaptor->refineTag));
   PetscCall(VecTaggerSetFromOptions(adaptor->coarsenTag));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    DMAdaptorView - Views a `DMAdaptor` object
 
-   Collective on adaptor
+   Collective
 
    Input Parameters:
 +  adaptor - The `DMAdaptor` object
@@ -141,13 +141,13 @@ PetscErrorCode DMAdaptorView(DMAdaptor adaptor, PetscViewer viewer)
   PetscCall(PetscViewerASCIIPrintf(viewer, "  sequence length: %" PetscInt_FMT "\n", adaptor->numSeq));
   PetscCall(VecTaggerView(adaptor->refineTag, viewer));
   PetscCall(VecTaggerView(adaptor->coarsenTag, viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMAdaptorGetSolver - Gets the solver used to produce discrete solutions
 
-  Not collective
+  Not Collective
 
   Input Parameter:
 . adaptor   - The `DMAdaptor` object
@@ -165,13 +165,13 @@ PetscErrorCode DMAdaptorGetSolver(DMAdaptor adaptor, SNES *snes)
   PetscValidHeaderSpecific(adaptor, DM_CLASSID, 1);
   PetscValidPointer(snes, 2);
   *snes = adaptor->snes;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMAdaptorSetSolver - Sets the solver used to produce discrete solutions
 
-  Not collective
+  Not Collective
 
   Input Parameters:
 + adaptor   - The `DMAdaptor` object
@@ -180,7 +180,7 @@ PetscErrorCode DMAdaptorGetSolver(DMAdaptor adaptor, SNES *snes)
   Level: intermediate
 
   Note:
-  The solver MUST have an attached `DM`/`DS`, so that we know the exact solution
+  The solver MUST have an attached `DM`/`PetscDS`, so that we know the exact solution
 
 .seealso: `DMAdaptor`, `DMAdaptorGetSolver()`, `DMAdaptorCreate()`, `DMAdaptorAdapt()`
 @*/
@@ -191,13 +191,13 @@ PetscErrorCode DMAdaptorSetSolver(DMAdaptor adaptor, SNES snes)
   PetscValidHeaderSpecific(snes, SNES_CLASSID, 2);
   adaptor->snes = snes;
   PetscCall(SNESGetDM(adaptor->snes, &adaptor->idm));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMAdaptorGetSequenceLength - Gets the number of sequential adaptations used by an adapter
 
-  Not collective
+  Not Collective
 
   Input Parameter:
 . adaptor - The `DMAdaptor` object
@@ -215,13 +215,13 @@ PetscErrorCode DMAdaptorGetSequenceLength(DMAdaptor adaptor, PetscInt *num)
   PetscValidHeaderSpecific(adaptor, DM_CLASSID, 1);
   PetscValidIntPointer(num, 2);
   *num = adaptor->numSeq;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMAdaptorSetSequenceLength - Sets the number of sequential adaptations
 
-  Not collective
+  Not Collective
 
   Input Parameters:
 + adaptor - The `DMAdaptor` object
@@ -236,15 +236,15 @@ PetscErrorCode DMAdaptorSetSequenceLength(DMAdaptor adaptor, PetscInt num)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(adaptor, DM_CLASSID, 1);
   adaptor->numSeq = num;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMAdaptorSetUp - After the solver is specified, we create structures for controlling adaptivity
 
-  Collective on adaptor
+  Collective
 
-  Input Parameters:
+  Input Parameter:
 . adaptor - The `DMAdaptor` object
 
   Level: beginner
@@ -267,21 +267,21 @@ PetscErrorCode DMAdaptorSetUp(DMAdaptor adaptor)
     /* TODO Have a flag that forces projection rather than using the exact solution */
     if (adaptor->exactSol[0]) PetscCall(DMAdaptorSetTransferFunction(adaptor, DMAdaptorTransferSolution_Exact_Private));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DMAdaptorGetTransferFunction(DMAdaptor adaptor, PetscErrorCode (**tfunc)(DMAdaptor, DM, Vec, DM, Vec, void *))
 {
   PetscFunctionBegin;
   *tfunc = adaptor->ops->transfersolution;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DMAdaptorSetTransferFunction(DMAdaptor adaptor, PetscErrorCode (*tfunc)(DMAdaptor, DM, Vec, DM, Vec, void *))
 {
   PetscFunctionBegin;
   adaptor->ops->transfersolution = tfunc;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DMAdaptorPreAdapt(DMAdaptor adaptor, Vec locX)
@@ -357,7 +357,7 @@ PetscErrorCode DMAdaptorPreAdapt(DMAdaptor adaptor, Vec locX)
     PetscCall(VecGetArrayRead(adaptor->cellGrad, &adaptor->cellGradArray));
   }
   PetscCall(DMDestroy(&plex));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DMAdaptorTransferSolution(DMAdaptor adaptor, DM dm, Vec x, DM adm, Vec ax)
@@ -385,7 +385,7 @@ PetscErrorCode DMAdaptorTransferSolution(DMAdaptor adaptor, DM dm, Vec x, DM adm
       SETERRQ(PetscObjectComm((PetscObject)adaptor), PETSC_ERR_SUP, "No built-in projection for this adaptation criterion: %d", adaptor->adaptCriterion);
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DMAdaptorPostAdapt(DMAdaptor adaptor)
@@ -409,7 +409,7 @@ PetscErrorCode DMAdaptorPostAdapt(DMAdaptor adaptor)
     PetscCall(VecRestoreArrayRead(adaptor->cellGrad, &adaptor->cellGradArray));
     PetscCall(DMRestoreLocalVector(adaptor->gradDM, &adaptor->cellGrad));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -442,7 +442,7 @@ static PetscErrorCode DMAdaptorSimpleErrorIndicator_Private(DMAdaptor adaptor, P
     for (d = 0; d < dim; ++d) err += PetscSqr(PetscRealPart(gradient[c * dim + d]));
   }
   *errInd = cg->volume * err;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMAdaptorComputeErrorIndicator_Private(DMAdaptor adaptor, DM plex, PetscInt cell, Vec locX, PetscReal *errInd)
@@ -523,7 +523,7 @@ static PetscErrorCode DMAdaptorComputeErrorIndicator_Private(DMAdaptor adaptor,
     PetscUseTypeMethod(adaptor, computeerrorindicator, dim, Nc, field, gradient, &cg, errInd, ctx);
     PetscCall(PetscFree6(field, gradient, coords, fegeom.detJ, fegeom.J, fegeom.invJ));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static void identityFunc(PetscInt dim, PetscInt Nf, PetscInt NfAux, const PetscInt uOff[], const PetscInt uOff_x[], const PetscScalar u[], const PetscScalar u_t[], const PetscScalar u_x[], const PetscInt aOff[], const PetscInt aOff_x[], const PetscScalar a[], const PetscScalar a_t[], const PetscScalar a_x[], PetscReal t, const PetscReal x[], PetscInt numConstants, const PetscScalar constants[], PetscScalar f[])
@@ -766,13 +766,13 @@ static PetscErrorCode DMAdaptorAdapt_Sequence_Private(DMAdaptor adaptor, Vec inx
   }
   PetscCall(DMViewFromOptions(*adm, NULL, "-dm_adapt_view"));
   PetscCall(VecViewFromOptions(*ax, NULL, "-sol_adapt_view"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMAdaptorAdapt - Creates a new `DM` that is adapted to the problem
 
-  Not collective
+  Not Collective
 
   Input Parameters:
 + adaptor  - The `DMAdaptor` object
@@ -789,13 +789,14 @@ static PetscErrorCode DMAdaptorAdapt_Sequence_Private(DMAdaptor adaptor, Vec inx
 . -adapt_hessian_view - View the Clement interpolant of the solution Hessian
 - -adapt_metric_view - View the metric tensor for adaptive mesh refinement
 
-  Note: The available adaptation strategies are:
+  Level: intermediate
+
+  Note:
+  The available adaptation strategies are:
 + * - Adapt the initial mesh until a quality metric, e.g., a priori error bound, is satisfied
 . * - Solve the problem on a series of adapted meshes until a quality metric, e.g. a posteriori error bound, is satisfied
 - * - Solve the problem on a hierarchy of adapted meshes generated to satisfy a quality metric using multigrid
 
-  Level: intermediate
-
 .seealso: `DMAdaptor`, `DMAdaptorSetSolver()`, `DMAdaptorCreate()`, `DMAdaptorAdapt()`
 @*/
 PetscErrorCode DMAdaptorAdapt(DMAdaptor adaptor, Vec x, DMAdaptationStrategy strategy, DM *adm, Vec *ax)
@@ -811,5 +812,5 @@ PetscErrorCode DMAdaptorAdapt(DMAdaptor adaptor, Vec x, DMAdaptationStrategy str
   default:
     SETERRQ(PetscObjectComm((PetscObject)adaptor), PETSC_ERR_ARG_WRONG, "Unrecognized adaptation strategy %d", strategy);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
