@@ -10,9 +10,10 @@ static void pressure_Private(PetscInt dim, PetscInt Nf, PetscInt NfAux, const Pe
 }
 
 /*
-  SNESCorrectDiscretePressure_Private - Add a vector in the nullspace to make the continuum integral of the pressure field equal to zero. This is normally used only to evaluate convergence rates for the pressure accurately.
+  SNESCorrectDiscretePressure_Private - Add a vector in the nullspace to make the continuum integral of the pressure field equal to zero.
+  This is normally used only to evaluate convergence rates for the pressure accurately.
 
-  Collective on snes
+  Collective
 
   Input Parameters:
 + snes      - The SNES
@@ -24,11 +25,11 @@ static void pressure_Private(PetscInt dim, PetscInt Nf, PetscInt NfAux, const Pe
   Output Parameter:
 . u         - The solution with a continuum pressure integral of zero
 
+  Level: developer
+
   Notes:
   If int(u) = a and int(n) = b, then int(u - a/b n) = a - a/b b = 0. We assume that the nullspace is a single vector given explicitly.
 
-  Level: developer
-
 .seealso: `SNESConvergedCorrectPressure()`
 */
 static PetscErrorCode SNESCorrectDiscretePressure_Private(SNES snes, PetscInt pfield, MatNullSpace nullspace, Vec u, void *ctx)
@@ -61,14 +62,14 @@ static PetscErrorCode SNESCorrectDiscretePressure_Private(SNES snes, PetscInt pf
   PetscCheck(PetscAbsScalar(intc[pfield]) <= PETSC_SMALL, comm, PETSC_ERR_ARG_WRONG, "Continuum integral of pressure after correction: %g", (double)PetscRealPart(intc[pfield]));
 #endif
   PetscCall(PetscFree2(intc, intn));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    SNESConvergedCorrectPressure - Convergence test that adds a vector in the nullspace to make the continuum integral of the pressure field equal to zero.
    This is normally used only to evaluate convergence rates for the pressure accurately. The convergence test itself just mimics `SNESConvergedDefault()`.
 
-   Logically Collective on snes
+   Logically Collective
 
    Input Parameters:
 +  snes - the `SNES` context
@@ -81,17 +82,17 @@ static PetscErrorCode SNESCorrectDiscretePressure_Private(SNES snes, PetscInt pf
    Output Parameter:
 .  reason  - `SNES_CONVERGED_ITERATING`, `SNES_CONVERGED_ITS`, or `SNES_DIVERGED_FNORM_NAN`
 
+   Options Database Key:
+.  -snes_convergence_test correct_pressure - see `SNESSetFromOptions()`
+
+   Level: advanced
+
    Notes:
    In order to use this convergence test, you must set up several PETSc structures. First fields must be added to the `DM`, and a `PetscDS`
    must be created with discretizations of those fields. We currently assume that the pressure field has index 1.
    The pressure field must have a nullspace, likely created using the `DMSetNullSpaceConstructor()` interface.
    Last we must be able to integrate the pressure over the domain, so the `DM` attached to the SNES `must` be a `DMPLEX` at this time.
 
-   Options Database Key:
-.  -snes_convergence_test correct_pressure - see `SNESSetFromOptions()`
-
-   Level: advanced
-
 .seealso: `SNES`, `DM`, `SNESConvergedDefault()`, `SNESSetConvergenceTest()`, `DMSetNullSpaceConstructor()`, `DMSetNullSpaceConstructor()`
 @*/
 PetscErrorCode SNESConvergedCorrectPressure(SNES snes, PetscInt it, PetscReal xnorm, PetscReal gnorm, PetscReal f, SNESConvergedReason *reason, void *ctx)
@@ -125,7 +126,7 @@ PetscErrorCode SNESConvergedCorrectPressure(SNES snes, PetscInt it, PetscReal xn
     PetscCall(MatGetNullSpace(J, &nullspace));
     PetscCall(SNESCorrectDiscretePressure_Private(snes, pfield, nullspace, u, ctx));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /************************** Interpolation *******************************/
@@ -152,7 +153,7 @@ static PetscErrorCode DMSNESConvertPlex(DM dm, DM *plex, PetscBool copy)
       PetscCall(PetscObjectReference((PetscObject)*plex));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -183,13 +184,13 @@ PetscErrorCode DMInterpolationCreate(MPI_Comm comm, DMInterpolationInfo *ctx)
   (*ctx)->cells  = NULL;
   (*ctx)->n      = -1;
   (*ctx)->coords = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMInterpolationSetDim - Sets the spatial dimension for the interpolation context
 
-  Not collective
+  Not Collective
 
   Input Parameters:
 + ctx - the context
@@ -204,13 +205,13 @@ PetscErrorCode DMInterpolationSetDim(DMInterpolationInfo ctx, PetscInt dim)
   PetscFunctionBegin;
   PetscCheck(!(dim < 1) && !(dim > 3), ctx->comm, PETSC_ERR_ARG_OUTOFRANGE, "Invalid dimension for points: %" PetscInt_FMT, dim);
   ctx->dim = dim;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMInterpolationGetDim - Gets the spatial dimension for the interpolation context
 
-  Not collective
+  Not Collective
 
   Input Parameter:
 . ctx - the context
@@ -227,13 +228,13 @@ PetscErrorCode DMInterpolationGetDim(DMInterpolationInfo ctx, PetscInt *dim)
   PetscFunctionBegin;
   PetscValidIntPointer(dim, 2);
   *dim = ctx->dim;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMInterpolationSetDof - Sets the number of fields interpolated at a point for the interpolation context
 
-  Not collective
+  Not Collective
 
   Input Parameters:
 + ctx - the context
@@ -248,13 +249,13 @@ PetscErrorCode DMInterpolationSetDof(DMInterpolationInfo ctx, PetscInt dof)
   PetscFunctionBegin;
   PetscCheck(dof >= 1, ctx->comm, PETSC_ERR_ARG_OUTOFRANGE, "Invalid number of components: %" PetscInt_FMT, dof);
   ctx->dof = dof;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMInterpolationGetDof - Gets the number of fields interpolated at a point for the interpolation context
 
-  Not collective
+  Not Collective
 
   Input Parameter:
 . ctx - the context
@@ -271,24 +272,24 @@ PetscErrorCode DMInterpolationGetDof(DMInterpolationInfo ctx, PetscInt *dof)
   PetscFunctionBegin;
   PetscValidIntPointer(dof, 2);
   *dof = ctx->dof;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMInterpolationAddPoints - Add points at which we will interpolate the fields
 
-  Not collective
+  Not Collective
 
   Input Parameters:
 + ctx    - the context
 . n      - the number of points
 - points - the coordinates for each point, an array of size n * dim
 
+  Level: intermediate
+
   Note:
   The coordinate information is copied.
 
-  Level: intermediate
-
 .seealso: `DMInterpolationInfo`, `DMInterpolationSetDim()`, `DMInterpolationEvaluate()`, `DMInterpolationCreate()`
 @*/
 PetscErrorCode DMInterpolationAddPoints(DMInterpolationInfo ctx, PetscInt n, PetscReal points[])
@@ -300,13 +301,13 @@ PetscErrorCode DMInterpolationAddPoints(DMInterpolationInfo ctx, PetscInt n, Pet
 
   PetscCall(PetscMalloc1(n * ctx->dim, &ctx->points));
   PetscCall(PetscArraycpy(ctx->points, points, n * ctx->dim));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMInterpolationSetUp - Compute spatial indices for point location during interpolation
 
-  Collective on ctx
+  Collective
 
   Input Parameters:
 + ctx - the context
@@ -427,13 +428,13 @@ PetscErrorCode DMInterpolationSetUp(DMInterpolationInfo ctx, DM dm, PetscBool re
   if ((void *)globalPointsScalar != (void *)globalPoints) PetscCall(PetscFree(globalPointsScalar));
   if (!redundantPoints) PetscCall(PetscFree3(globalPoints, counts, displs));
   PetscCall(PetscLayoutDestroy(&layout));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMInterpolationGetCoordinates - Gets a `Vec` with the coordinates of each interpolation point
 
-  Collective on ctx
+  Collective
 
   Input Parameter:
 . ctx - the context
@@ -441,12 +442,12 @@ PetscErrorCode DMInterpolationSetUp(DMInterpolationInfo ctx, DM dm, PetscBool re
   Output Parameter:
 . coordinates  - the coordinates of interpolation points
 
+  Level: intermediate
+
   Note:
   The local vector entries correspond to interpolation points lying on this process, according to the associated `DM`.
   This is a borrowed vector that the user should not destroy.
 
-  Level: intermediate
-
 .seealso: `DMInterpolationInfo`, `DMInterpolationEvaluate()`, `DMInterpolationAddPoints()`, `DMInterpolationCreate()`
 @*/
 PetscErrorCode DMInterpolationGetCoordinates(DMInterpolationInfo ctx, Vec *coordinates)
@@ -455,13 +456,13 @@ PetscErrorCode DMInterpolationGetCoordinates(DMInterpolationInfo ctx, Vec *coord
   PetscValidPointer(coordinates, 2);
   PetscCheck(ctx->coords, ctx->comm, PETSC_ERR_ARG_WRONGSTATE, "The interpolation context has not been setup.");
   *coordinates = ctx->coords;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMInterpolationGetVector - Gets a `Vec` which can hold all the interpolated field values
 
-  Collective on ctx
+  Collective
 
   Input Parameter:
 . ctx - the context
@@ -469,11 +470,11 @@ PetscErrorCode DMInterpolationGetCoordinates(DMInterpolationInfo ctx, Vec *coord
   Output Parameter:
 . v  - a vector capable of holding the interpolated field values
 
+  Level: intermediate
+
   Note:
   This vector should be returned using `DMInterpolationRestoreVector()`.
 
-  Level: intermediate
-
 .seealso: `DMInterpolationInfo`, `DMInterpolationRestoreVector()`, `DMInterpolationEvaluate()`, `DMInterpolationAddPoints()`, `DMInterpolationCreate()`
 @*/
 PetscErrorCode DMInterpolationGetVector(DMInterpolationInfo ctx, Vec *v)
@@ -485,13 +486,13 @@ PetscErrorCode DMInterpolationGetVector(DMInterpolationInfo ctx, Vec *v)
   PetscCall(VecSetSizes(*v, ctx->n * ctx->dof, PETSC_DECIDE));
   PetscCall(VecSetBlockSize(*v, ctx->dof));
   PetscCall(VecSetType(*v, VECSTANDARD));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMInterpolationRestoreVector - Returns a `Vec` which can hold all the interpolated field values
 
-  Collective on ctx
+  Collective
 
   Input Parameters:
 + ctx - the context
@@ -507,7 +508,7 @@ PetscErrorCode DMInterpolationRestoreVector(DMInterpolationInfo ctx, Vec *v)
   PetscValidPointer(v, 2);
   PetscCheck(ctx->coords, ctx->comm, PETSC_ERR_ARG_WRONGSTATE, "The interpolation context has not been setup.");
   PetscCall(VecDestroy(v));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode DMInterpolate_Segment_Private(DMInterpolationInfo ctx, DM dm, Vec xLocal, Vec v)
@@ -540,7 +541,7 @@ static inline PetscErrorCode DMInterpolate_Segment_Private(DMInterpolationInfo c
   }
   PetscCall(VecRestoreArray(v, &a));
   PetscCall(VecRestoreArrayRead(ctx->coords, &coords));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode DMInterpolate_Triangle_Private(DMInterpolationInfo ctx, DM dm, Vec xLocal, Vec v)
@@ -575,7 +576,7 @@ static inline PetscErrorCode DMInterpolate_Triangle_Private(DMInterpolationInfo
   PetscCall(VecRestoreArray(v, &a));
   PetscCall(VecRestoreArrayRead(ctx->coords, &coords));
   PetscCall(PetscFree3(v0, J, invJ));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode DMInterpolate_Tetrahedron_Private(DMInterpolationInfo ctx, DM dm, Vec xLocal, Vec v)
@@ -611,7 +612,7 @@ static inline PetscErrorCode DMInterpolate_Tetrahedron_Private(DMInterpolationIn
   PetscCall(VecRestoreArray(v, &a));
   PetscCall(VecRestoreArrayRead(ctx->coords, &coords));
   PetscCall(PetscFree3(v0, J, invJ));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode QuadMap_Private(SNES snes, Vec Xref, Vec Xreal, void *ctx)
@@ -647,7 +648,7 @@ static inline PetscErrorCode QuadMap_Private(SNES snes, Vec Xref, Vec Xreal, voi
   PetscCall(PetscLogFlops(28));
   PetscCall(VecRestoreArrayRead(Xref, &ref));
   PetscCall(VecRestoreArray(Xreal, &real));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #include <petsc/private/dmimpl.h>
@@ -684,7 +685,7 @@ static inline PetscErrorCode QuadJacobian_Private(SNES snes, Vec Xref, Mat J, Ma
   PetscCall(VecRestoreArrayRead(Xref, &ref));
   PetscCall(MatAssemblyBegin(J, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(J, MAT_FINAL_ASSEMBLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode DMInterpolate_Quad_Private(DMInterpolationInfo ctx, DM dm, Vec xLocal, Vec v)
@@ -786,7 +787,7 @@ static inline PetscErrorCode DMInterpolate_Quad_Private(DMInterpolationInfo ctx,
   PetscCall(VecDestroy(&ref));
   PetscCall(VecDestroy(&real));
   PetscCall(MatDestroy(&J));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode HexMap_Private(SNES snes, Vec Xref, Vec Xreal, void *ctx)
@@ -855,7 +856,7 @@ static inline PetscErrorCode HexMap_Private(SNES snes, Vec Xref, Vec Xreal, void
   PetscCall(PetscLogFlops(114));
   PetscCall(VecRestoreArrayRead(Xref, &ref));
   PetscCall(VecRestoreArray(Xreal, &real));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode HexJacobian_Private(SNES snes, Vec Xref, Mat J, Mat M, void *ctx)
@@ -924,7 +925,7 @@ static inline PetscErrorCode HexJacobian_Private(SNES snes, Vec Xref, Mat J, Mat
   PetscCall(VecRestoreArrayRead(Xref, &ref));
   PetscCall(MatAssemblyBegin(J, MAT_FINAL_ASSEMBLY));
   PetscCall(MatAssemblyEnd(J, MAT_FINAL_ASSEMBLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static inline PetscErrorCode DMInterpolate_Hex_Private(DMInterpolationInfo ctx, DM dm, Vec xLocal, Vec v)
@@ -1005,7 +1006,7 @@ static inline PetscErrorCode DMInterpolate_Hex_Private(DMInterpolationInfo ctx,
   PetscCall(VecDestroy(&ref));
   PetscCall(VecDestroy(&real));
   PetscCall(MatDestroy(&J));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1016,14 +1017,14 @@ static inline PetscErrorCode DMInterpolate_Hex_Private(DMInterpolationInfo ctx,
 . dm  - The `DM`
 - x   - The local vector containing the field to be interpolated
 
-  Output Parameters:
+  Output Parameter:
 . v   - The vector containing the interpolated values
 
-  Note:
-  A suitable v can be obtained using `DMInterpolationGetVector()`.
-
   Level: beginner
 
+  Note:
+  A suitable `v` can be obtained using `DMInterpolationGetVector()`.
+
 .seealso: `DMInterpolationInfo`, `DMInterpolationGetVector()`, `DMInterpolationAddPoints()`, `DMInterpolationCreate()`
 @*/
 PetscErrorCode DMInterpolationEvaluate(DMInterpolationInfo ctx, DM dm, Vec x, Vec v)
@@ -1038,7 +1039,7 @@ PetscErrorCode DMInterpolationEvaluate(DMInterpolationInfo ctx, DM dm, Vec x, Ve
   PetscValidHeaderSpecific(v, VEC_CLASSID, 4);
   PetscCall(VecGetLocalSize(v, &n));
   PetscCheck(n == ctx->n * ctx->dof, ctx->comm, PETSC_ERR_ARG_SIZ, "Invalid input vector size %" PetscInt_FMT " should be %" PetscInt_FMT, n, ctx->n * ctx->dof);
-  if (!n) PetscFunctionReturn(0);
+  if (!n) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(DMGetDS(dm, &ds));
   if (ds) {
     useDS = PETSC_TRUE;
@@ -1124,13 +1125,13 @@ PetscErrorCode DMInterpolationEvaluate(DMInterpolationInfo ctx, DM dm, Vec x, Ve
       SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "No support for cell type %s", DMPolytopeTypes[PetscMax(0, PetscMin(ct, DM_NUM_POLYTOPES))]);
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMInterpolationDestroy - Destroys a `DMInterpolationInfo` context
 
-  Collective on ctx
+  Collective
 
   Input Parameter:
 . ctx - the context
@@ -1148,13 +1149,13 @@ PetscErrorCode DMInterpolationDestroy(DMInterpolationInfo *ctx)
   PetscCall(PetscFree((*ctx)->cells));
   PetscCall(PetscFree(*ctx));
   *ctx = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   SNESMonitorFields - Monitors the residual for each field separately
 
-  Collective on snes
+  Collective
 
   Input Parameters:
 + snes   - the `SNES` context
@@ -1162,11 +1163,11 @@ PetscErrorCode DMInterpolationDestroy(DMInterpolationInfo *ctx)
 . fgnorm - 2-norm of residual
 - vf  - `PetscViewerAndFormat` of `PetscViewerType` `PETSCVIEWERASCII`
 
+  Level: intermediate
+
   Note:
   This routine prints the residual norm at each iteration.
 
-  Level: intermediate
-
 .seealso: `SNES`, `SNESMonitorSet()`, `SNESMonitorDefault()`
 @*/
 PetscErrorCode SNESMonitorFields(SNES snes, PetscInt its, PetscReal fgnorm, PetscViewerAndFormat *vf)
@@ -1210,7 +1211,7 @@ PetscErrorCode SNESMonitorFields(SNES snes, PetscInt its, PetscReal fgnorm, Pets
   PetscCall(PetscViewerASCIISubtractTab(viewer, ((PetscObject)snes)->tablevel));
   PetscCall(PetscViewerPopFormat(viewer));
   PetscCall(PetscFree2(lnorms, norms));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /********************* Residual Computation **************************/
@@ -1223,7 +1224,7 @@ PetscErrorCode DMPlexGetAllCells_Internal(DM plex, IS *cellIS)
   PetscCall(DMPlexGetDepth(plex, &depth));
   PetscCall(DMGetStratumIS(plex, "dim", depth, cellIS));
   if (!*cellIS) PetscCall(DMGetStratumIS(plex, "depth", depth, cellIS));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1237,11 +1238,11 @@ PetscErrorCode DMPlexGetAllCells_Internal(DM plex, IS *cellIS)
   Output Parameter:
 . F  - Local output vector
 
+  Level: developer
+
   Note:
   The residual is summed into F; the caller is responsible for using `VecZeroEntries()` or otherwise ensuring that any data in F is intentional.
 
-  Level: developer
-
 .seealso: `DM`, `DMPlexComputeJacobianAction()`
 @*/
 PetscErrorCode DMPlexSNESComputeResidualFEM(DM dm, Vec X, Vec F, void *user)
@@ -1259,7 +1260,7 @@ PetscErrorCode DMPlexSNESComputeResidualFEM(DM dm, Vec X, Vec F, void *user)
     IS           cellIS;
     PetscFormKey key;
 
-    PetscCall(DMGetRegionNumDS(dm, s, &key.label, NULL, &ds));
+    PetscCall(DMGetRegionNumDS(dm, s, &key.label, NULL, &ds, NULL));
     key.value = 0;
     key.field = 0;
     key.part  = 0;
@@ -1279,7 +1280,7 @@ PetscErrorCode DMPlexSNESComputeResidualFEM(DM dm, Vec X, Vec F, void *user)
   }
   PetscCall(ISDestroy(&allcellIS));
   PetscCall(DMDestroy(&plex));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DMSNESComputeResidual(DM dm, Vec X, Vec F, void *user)
@@ -1297,7 +1298,7 @@ PetscErrorCode DMSNESComputeResidual(DM dm, Vec X, Vec F, void *user)
     DMLabel label;
     IS      cellIS;
 
-    PetscCall(DMGetRegionNumDS(dm, s, &label, NULL, &ds));
+    PetscCall(DMGetRegionNumDS(dm, s, &label, NULL, &ds, NULL));
     {
       PetscWeakFormKind resmap[2] = {PETSC_WF_F0, PETSC_WF_F1};
       PetscWeakForm     wf;
@@ -1345,7 +1346,7 @@ PetscErrorCode DMSNESComputeResidual(DM dm, Vec X, Vec F, void *user)
   }
   PetscCall(ISDestroy(&allcellIS));
   PetscCall(DMDestroy(&plex));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1370,7 +1371,7 @@ PetscErrorCode DMPlexSNESComputeBoundaryFEM(DM dm, Vec X, void *user)
   PetscCall(DMSNESConvertPlex(dm, &plex, PETSC_TRUE));
   PetscCall(DMPlexInsertBoundaryValues(plex, PETSC_TRUE, X, PETSC_MIN_REAL, NULL, NULL, NULL));
   PetscCall(DMDestroy(&plex));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1383,7 +1384,7 @@ PetscErrorCode DMPlexSNESComputeBoundaryFEM(DM dm, Vec X, void *user)
 - user - The user context
 
   Output Parameter:
-. F    - lcoal output vector
+. F    - local output vector
 
   Level: developer
 
@@ -1407,7 +1408,7 @@ PetscErrorCode DMSNESComputeJacobianAction(DM dm, Vec X, Vec Y, Vec F, void *use
     DMLabel label;
     IS      cellIS;
 
-    PetscCall(DMGetRegionNumDS(dm, s, &label, NULL, &ds));
+    PetscCall(DMGetRegionNumDS(dm, s, &label, NULL, &ds, NULL));
     {
       PetscWeakFormKind jacmap[4] = {PETSC_WF_G0, PETSC_WF_G1, PETSC_WF_G2, PETSC_WF_G3};
       PetscWeakForm     wf;
@@ -1455,26 +1456,27 @@ PetscErrorCode DMSNESComputeJacobianAction(DM dm, Vec X, Vec Y, Vec F, void *use
   }
   PetscCall(ISDestroy(&allcellIS));
   PetscCall(DMDestroy(&plex));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-  DMPlexSNESComputeJacobianFEM - Form the local portion of the Jacobian matrix J at the local solution X using pointwise functions specified by the user.
+  DMPlexSNESComputeJacobianFEM - Form the local portion of the Jacobian matrix `Jac` at the local solution `X` using pointwise functions specified by the user.
 
   Input Parameters:
-+ dm - The mesh
++ dm - The `DM`
 . X  - Local input vector
 - user - The user context
 
-  Output Parameter:
-. Jac  - Jacobian matrix
+  Output Parameters:
++ Jac  - Jacobian matrix
+- JacP - approximate Jacobian from which the preconditioner will be built, often `Jac`
+
+  Level: developer
 
   Note:
   We form the residual one batch of elements at a time. This allows us to offload work onto an accelerator,
   like a GPU, or vectorize on a multicore machine.
 
-  Level: developer
-
 .seealso: `DMPLEX`, `Mat`
 @*/
 PetscErrorCode DMPlexSNESComputeJacobianFEM(DM dm, Vec X, Mat Jac, Mat JacP, void *user)
@@ -1493,7 +1495,7 @@ PetscErrorCode DMPlexSNESComputeJacobianFEM(DM dm, Vec X, Mat Jac, Mat JacP, voi
     IS           cellIS;
     PetscFormKey key;
 
-    PetscCall(DMGetRegionNumDS(dm, s, &key.label, NULL, &ds));
+    PetscCall(DMGetRegionNumDS(dm, s, &key.label, NULL, &ds, NULL));
     key.value = 0;
     key.field = 0;
     key.part  = 0;
@@ -1519,7 +1521,7 @@ PetscErrorCode DMPlexSNESComputeJacobianFEM(DM dm, Vec X, Mat Jac, Mat JacP, voi
   }
   PetscCall(ISDestroy(&allcellIS));
   PetscCall(DMDestroy(&plex));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 struct _DMSNESJacobianMFCtx {
@@ -1538,7 +1540,7 @@ static PetscErrorCode DMSNESJacobianMF_Destroy_Private(Mat A)
   PetscCall(DMDestroy(&ctx->dm));
   PetscCall(VecDestroy(&ctx->X));
   PetscCall(PetscFree(ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMSNESJacobianMF_Mult_Private(Mat A, Vec Y, Vec Z)
@@ -1548,18 +1550,18 @@ static PetscErrorCode DMSNESJacobianMF_Mult_Private(Mat A, Vec Y, Vec Z)
   PetscFunctionBegin;
   PetscCall(MatShellGetContext(A, &ctx));
   PetscCall(DMSNESComputeJacobianAction(ctx->dm, ctx->X, Y, Z, ctx->ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   DMSNESCreateJacobianMF - Create a `Mat` which computes the action of the Jacobian matrix-free
 
-  Collective on dm
+  Collective
 
   Input Parameters:
 + dm   - The `DM`
 . X    - The evaluation point for the Jacobian
-- user - A user context, or NULL
+- user - A user context, or `NULL`
 
   Output Parameter:
 . J    - The `Mat`
@@ -1567,7 +1569,7 @@ static PetscErrorCode DMSNESJacobianMF_Mult_Private(Mat A, Vec Y, Vec Z)
   Level: advanced
 
   Note:
-  Vec X is kept in `Mat` J, so updating X then updates the evaluation point.
+  Vec `X` is kept in `J`, so updating `X` then updates the evaluation point.
 
 .seealso: `DM`, `DMSNESComputeJacobianAction()`
 @*/
@@ -1591,14 +1593,14 @@ PetscErrorCode DMSNESCreateJacobianMF(DM dm, Vec X, void *user, Mat *J)
   PetscCall(MatShellSetContext(*J, ctx));
   PetscCall(MatShellSetOperation(*J, MATOP_DESTROY, (void (*)(void))DMSNESJacobianMF_Destroy_Private));
   PetscCall(MatShellSetOperation(*J, MATOP_MULT, (void (*)(void))DMSNESJacobianMF_Mult_Private));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
      MatComputeNeumannOverlap - Computes an unassembled (Neumann) local overlapping Mat in nonlinear context.
 
    Input Parameters:
-+     X - SNES linearization point
++     X - `SNES` linearization point
 .     ovl - index set of overlapping subdomains
 
    Output Parameter:
@@ -1651,7 +1653,7 @@ static PetscErrorCode MatComputeNeumannOverlap_Plex(Mat J, PetscReal t, Vec X, V
     PetscCall(MatISGetLocalMat(pJ, &locpJ));
     PetscCall(MatCopy(locpJ, J, SAME_NONZERO_PATTERN));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1674,7 +1676,7 @@ PetscErrorCode DMPlexSetSNESLocalFEM(DM dm, void *boundaryctx, void *residualctx
   PetscCall(DMSNESSetFunctionLocal(dm, DMPlexSNESComputeResidualFEM, residualctx));
   PetscCall(DMSNESSetJacobianLocal(dm, DMPlexSNESComputeJacobianFEM, jacobianctx));
   PetscCall(PetscObjectComposeFunction((PetscObject)dm, "MatComputeNeumannOverlap_C", MatComputeNeumannOverlap_Plex));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1687,14 +1689,14 @@ PetscErrorCode DMPlexSetSNESLocalFEM(DM dm, void *boundaryctx, void *residualctx
 . u    - a `DM` vector
 - tol  - A tolerance for the check, or -1 to print the results instead
 
-  Output Parameters:
-. error - An array which holds the discretization error in each field, or NULL
+  Output Parameter:
+. error - An array which holds the discretization error in each field, or `NULL`
+
+  Level: developer
 
   Note:
   The user must call `PetscDSSetExactSolution()` beforehand
 
-  Level: developer
-
 .seealso: `PetscDSSetExactSolution()`, `DNSNESCheckFromOptions()`, `DMSNESCheckResidual()`, `DMSNESCheckJacobian()`, `PetscDSSetExactSolution()`
 @*/
 PetscErrorCode DMSNESCheckDiscretization(SNES snes, DM dm, PetscReal t, Vec u, PetscReal tol, PetscReal error[])
@@ -1728,7 +1730,7 @@ PetscErrorCode DMSNESCheckDiscretization(SNES snes, DM dm, PetscReal t, Vec u, P
       const PetscInt *fields;
       PetscInt        dsNf, f;
 
-      PetscCall(DMGetRegionNumDS(dm, s, &label, &fieldIS, &ds));
+      PetscCall(DMGetRegionNumDS(dm, s, &label, &fieldIS, &ds, NULL));
       PetscCall(PetscDSGetNumFields(ds, &dsNf));
       PetscCall(ISGetIndices(fieldIS, &fields));
       for (f = 0; f < dsNf; ++f) {
@@ -1763,7 +1765,7 @@ PetscErrorCode DMSNESCheckDiscretization(SNES snes, DM dm, PetscReal t, Vec u, P
     }
   }
   PetscCall(PetscFree3(exacts, ectxs, err));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1776,7 +1778,7 @@ PetscErrorCode DMSNESCheckDiscretization(SNES snes, DM dm, PetscReal t, Vec u, P
 - tol  - A tolerance for the check, or -1 to print the results instead
 
   Output Parameter:
-. residual - The residual norm of the exact solution, or NULL
+. residual - The residual norm of the exact solution, or `NULL`
 
   Level: developer
 
@@ -1810,7 +1812,7 @@ PetscErrorCode DMSNESCheckResidual(SNES snes, DM dm, Vec u, PetscReal tol, Petsc
     PetscCall(VecViewFromOptions(r, NULL, "-vec_view"));
   }
   PetscCall(VecDestroy(&r));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1823,8 +1825,8 @@ PetscErrorCode DMSNESCheckResidual(SNES snes, DM dm, Vec u, PetscReal tol, Petsc
 - tol  - A tolerance for the check, or -1 to print the results instead
 
   Output Parameters:
-+ isLinear - Flag indicaing that the function looks linear, or NULL
-- convRate - The rate of convergence of the linear model, or NULL
++ isLinear - Flag indicaing that the function looks linear, or `NULL`
+- convRate - The rate of convergence of the linear model, or `NULL`
 
   Level: developer
 
@@ -1931,7 +1933,7 @@ PetscErrorCode DMSNESCheckJacobian(SNES snes, DM dm, Vec u, PetscReal tol, Petsc
     }
   }
   PetscCall(MatDestroy(&J));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode DMSNESCheck_Internal(SNES snes, DM dm, Vec u)
@@ -1940,7 +1942,7 @@ PetscErrorCode DMSNESCheck_Internal(SNES snes, DM dm, Vec u)
   PetscCall(DMSNESCheckDiscretization(snes, dm, 0.0, u, -1.0, NULL));
   PetscCall(DMSNESCheckResidual(snes, dm, u, -1.0, NULL));
   PetscCall(DMSNESCheckJacobian(snes, dm, u, -1.0, NULL, NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1950,10 +1952,12 @@ PetscErrorCode DMSNESCheck_Internal(SNES snes, DM dm, Vec u)
 + snes - the `SNES` object
 - u    - representative `SNES` vector
 
+  Level: developer
+
   Note:
   The user must call `PetscDSSetExactSolution()` beforehand
 
-  Level: developer
+.seealso: `SNES`, `DM`
 @*/
 PetscErrorCode DMSNESCheckFromOptions(SNES snes, Vec u)
 {
@@ -1963,11 +1967,11 @@ PetscErrorCode DMSNESCheckFromOptions(SNES snes, Vec u)
 
   PetscFunctionBegin;
   PetscCall(PetscOptionsHasName(((PetscObject)snes)->options, ((PetscObject)snes)->prefix, "-dmsnes_check", &check));
-  if (!check) PetscFunctionReturn(0);
+  if (!check) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(SNESGetDM(snes, &dm));
   PetscCall(VecDuplicate(u, &sol));
   PetscCall(SNESSetSolution(snes, sol));
   PetscCall(DMSNESCheck_Internal(snes, dm, sol));
   PetscCall(VecDestroy(&sol));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
