@@ -29,6 +29,8 @@ PetscClassId MATLABENGINE_CLASSID = -1;
 .    -matlab_engine_host - hostname, machine to run the MATLAB engine on
 -    -info - print out all requests to MATLAB and all if its responses (for debugging)
 
+   Level: advanced
+
    Notes:
    If a host string is passed in, any MATLAB scripts that need to run in the
    engine must be available via MATLABPATH on that machine.
@@ -36,8 +38,6 @@ PetscClassId MATLABENGINE_CLASSID = -1;
    One must `./configure` PETSc with  `--with-matlab [-with-matlab-dir=matlab_root_directory]` to
    use this capability
 
-   Level: advanced
-
 .seealso: `PetscMatlabEngineDestroy()`, `PetscMatlabEnginePut()`, `PetscMatlabEngineGet()`,
           `PetscMatlabEngineEvaluate()`, `PetscMatlabEngineGetOutput()`, `PetscMatlabEnginePrintOutput()`,
           `PETSC_MATLAB_ENGINE_()`, `PetscMatlabEnginePutArray()`, `PetscMatlabEngineGetArray()`, `PetscMatlabEngine`
@@ -62,13 +62,13 @@ PetscErrorCode PetscMatlabEngineCreate(MPI_Comm comm, const char host[], PetscMa
 
   if (host) {
     PetscCall(PetscInfo(0, "Starting MATLAB engine on %s\n", host));
-    PetscCall(PetscStrcpy(buffer, "ssh "));
-    PetscCall(PetscStrcat(buffer, host));
-    PetscCall(PetscStrcat(buffer, " \""));
+    PetscCall(PetscStrncpy(buffer, "ssh ", sizeof(buffer)));
+    PetscCall(PetscStrlcat(buffer, host, sizeof(buffer)));
+    PetscCall(PetscStrlcat(buffer, " \"", sizeof(buffer)));
     PetscCall(PetscStrlcat(buffer, PETSC_MATLAB_COMMAND, sizeof(buffer)));
     if (!flg) PetscCall(PetscStrlcat(buffer, " -nodisplay ", sizeof(buffer)));
     PetscCall(PetscStrlcat(buffer, " -nosplash ", sizeof(buffer)));
-    PetscCall(PetscStrcat(buffer, "\""));
+    PetscCall(PetscStrlcat(buffer, "\"", sizeof(buffer)));
   } else {
     PetscCall(PetscStrncpy(buffer, PETSC_MATLAB_COMMAND, sizeof(buffer)));
     if (!flg) PetscCall(PetscStrlcat(buffer, " -nodisplay ", sizeof(buffer)));
@@ -87,15 +87,15 @@ PetscErrorCode PetscMatlabEngineCreate(MPI_Comm comm, const char host[], PetscMa
   /* work around bug in MATLAB R2021b https://www.mathworks.com/matlabcentral/answers/1566246-got-error-using-exit-in-nodesktop-mode */
   PetscCall(PetscMatlabEngineEvaluate(e, "settings"));
   *mengine = e;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PetscMatlabEngineDestroy - Shuts down a MATLAB engine.
 
-   Collective on v
+   Collective
 
-   Input Parameters:
+   Input Parameter:
 .  e  - the engine
 
    Level: advanced
@@ -109,15 +109,15 @@ PetscErrorCode PetscMatlabEngineDestroy(PetscMatlabEngine *v)
   int err;
 
   PetscFunctionBegin;
-  if (!*v) PetscFunctionReturn(0);
+  if (!*v) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*v, MATLABENGINE_CLASSID, 1);
-  if (--((PetscObject)(*v))->refct > 0) PetscFunctionReturn(0);
+  if (--((PetscObject)(*v))->refct > 0) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscInfo(0, "Stopping MATLAB engine\n"));
   err = engClose((*v)->ep);
   PetscCheck(!err, PETSC_COMM_SELF, PETSC_ERR_LIB, "Error closing Matlab engine");
   PetscCall(PetscInfo(0, "MATLAB engine stopped\n"));
   PetscCall(PetscHeaderDestroy(v));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -160,7 +160,7 @@ PetscErrorCode PetscMatlabEngineEvaluate(PetscMatlabEngine mengine, const char s
      Check for error in MATLAB: indicated by ? as first character in engine->buffer
   */
   PetscCheck(mengine->buffer[4] != '?', PETSC_COMM_SELF, PETSC_ERR_LIB, "Error in evaluating MATLAB command:%s\n%s", string, mengine->buffer);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -186,13 +186,13 @@ PetscErrorCode PetscMatlabEngineGetOutput(PetscMatlabEngine mengine, char **stri
   PetscFunctionBegin;
   PetscCheck(mengine, PETSC_COMM_SELF, PETSC_ERR_ARG_NULL, "Null argument: probably PETSC_MATLAB_ENGINE_() failed");
   *string = mengine->buffer;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscMatlabEnginePrintOutput - prints the output from MATLAB to an ASCII file
 
-    Collective on mengine
+    Collective
 
     Input Parameters:
 +    mengine - the MATLAB engine
@@ -213,14 +213,14 @@ PetscErrorCode PetscMatlabEnginePrintOutput(PetscMatlabEngine mengine, FILE *fd)
   PetscCallMPI(MPI_Comm_rank(PetscObjectComm((PetscObject)mengine), &rank));
   PetscCall(PetscSynchronizedFPrintf(PetscObjectComm((PetscObject)mengine), fd, "[%d]%s", rank, mengine->buffer));
   PetscCall(PetscSynchronizedFlush(PetscObjectComm((PetscObject)mengine), fd));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     PetscMatlabEnginePut - Puts a Petsc object, such as a `Mat` or `Vec` into the MATLAB space. For parallel objects,
       each processor's part is put in a separate  MATLAB process.
 
-    Collective on mengine
+    Collective
 
     Input Parameters:
 +    mengine - the MATLAB engine
@@ -247,13 +247,13 @@ PetscErrorCode PetscMatlabEnginePut(PetscMatlabEngine mengine, PetscObject obj)
   PetscCall(PetscInfo(0, "Putting MATLAB object\n"));
   PetscCall((*put)(obj, mengine->ep));
   PetscCall(PetscInfo(0, "Put MATLAB object: %s\n", obj->name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     PetscMatlabEngineGet - Gets a variable from MATLAB into a PETSc object.
 
-    Collective on mengine
+    Collective
 
     Input Parameters:
 +    mengine - the MATLAB engine
@@ -281,7 +281,7 @@ PetscErrorCode PetscMatlabEngineGet(PetscMatlabEngine mengine, PetscObject obj)
   PetscCall(PetscInfo(0, "Getting MATLAB object\n"));
   PetscCall((*get)(obj, mengine->ep));
   PetscCall(PetscInfo(0, "Got MATLAB object: %s\n", obj->name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -356,7 +356,7 @@ PetscMatlabEngine PETSC_MATLAB_ENGINE_(MPI_Comm comm)
     PetscMatlabEnginePutArray - Puts an array into the MATLAB space, treating it as a Fortran style (column major ordering) array. For parallel objects,
       each processors part is put in a separate  MATLAB process.
 
-    Collective on mengine
+    Collective
 
     Input Parameters:
 +    mengine - the MATLAB engine
@@ -386,7 +386,7 @@ PetscErrorCode PetscMatlabEnginePutArray(PetscMatlabEngine mengine, int m, int n
   engPutVariable(mengine->ep, name, mat);
 
   PetscCall(PetscInfo(0, "Put MATLAB array %s\n", name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -419,5 +419,5 @@ PetscErrorCode PetscMatlabEngineGetArray(PetscMatlabEngine mengine, int m, int n
   PetscCheck(mxGetN(mat) == (size_t)n, PETSC_COMM_SELF, PETSC_ERR_LIB, "Array %s in MATLAB second dimension %d does not match requested size %d", name, (int)mxGetN(mat), m);
   PetscCall(PetscArraycpy(array, mxGetPr(mat), m * n));
   PetscCall(PetscInfo(0, "Got MATLAB array %s\n", name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
