@@ -5,9 +5,9 @@
 /*@C
     PetscViewerSAWsOpen - Opens an SAWs `PetscViewer`.
 
-    Collective
+    Collective; No Fortran Support
 
-    Input Parameters:
+    Input Parameter:
 .   comm - the MPI communicator
 
     Output Parameter:
@@ -16,22 +16,19 @@
     Options Database Keys:
 +   -saws_port <port number> - port number where you are running SAWs client
 .   -xxx_view saws - publish the object xxx
--   -xxx_saws_block - blocks the program at the end of a critical point (for KSP and SNES it is the end of a solve) until
+-   -xxx_saws_block - blocks the program at the end of a critical point (for `KSP` and `SNES` it is the end of a solve) until
                     the user unblocks the problem with an external tool that access the object with SAWS
 
     Level: advanced
 
-    Fortran Note:
-    This routine is not supported in Fortran.
-
-    Note:
+    Notes:
     Unlike other viewers that only access the object being viewed on the call to XXXView(object,viewer) the SAWs viewer allows
     one to view the object asynchronously as the program continues to run. One can remove SAWs access to the object with a call to
     `PetscObjectSAWsViewOff()`.
 
     Information about the SAWs is available via https://bitbucket.org/saws/saws
 
-.seealso: `PetscViewerDestroy()`, `PetscViewerStringSPrintf()`, `PETSC_VIEWER_SAWS_()`, `PetscObjectSAWsBlock()`,
+.seealso: [](sec_viewers), `PetscViewerDestroy()`, `PetscViewerStringSPrintf()`, `PETSC_VIEWER_SAWS_()`, `PetscObjectSAWsBlock()`,
           `PetscObjectSAWsViewOff()`, `PetscObjectSAWsTakeAccess()`, `PetscObjectSAWsGrantAccess()`
 @*/
 PetscErrorCode PetscViewerSAWsOpen(MPI_Comm comm, PetscViewer *lab)
@@ -39,13 +36,13 @@ PetscErrorCode PetscViewerSAWsOpen(MPI_Comm comm, PetscViewer *lab)
   PetscFunctionBegin;
   PetscCall(PetscViewerCreate(comm, lab));
   PetscCall(PetscViewerSetType(*lab, PETSCVIEWERSAWS));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscObjectViewSAWs - View the base portion of any object with an SAWs viewer
 
-   Collective on obj
+   Collective
 
    Input Parameters:
 +  obj - the `PetscObject` variable. Thus must be cast with a (`PetscObject`), for example, `PetscObjectSetName`((`PetscObject`)mat,name);
@@ -60,7 +57,7 @@ PetscErrorCode PetscViewerSAWsOpen(MPI_Comm comm, PetscViewer *lab)
    Developer Note:
    Currently this is called only on rank zero of `PETSC_COMM_WORLD`
 
-.seealso: `PetscViewer`, `PetscObject`, `PetscObjectSetName()`, `PetscObjectSAWsViewOff()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscObject`, `PetscObjectSetName()`, `PetscObjectSAWsViewOff()`
 @*/
 PetscErrorCode PetscObjectViewSAWs(PetscObject obj, PetscViewer viewer)
 {
@@ -69,7 +66,7 @@ PetscErrorCode PetscObjectViewSAWs(PetscObject obj, PetscViewer viewer)
 
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
-  if (obj->amsmem) PetscFunctionReturn(0);
+  if (obj->amsmem) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCallMPI(MPI_Comm_rank(PETSC_COMM_WORLD, &rank));
   PetscCheck(rank == 0, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Should only be being called on rank zero");
   PetscCheck(obj->name, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Object must already have been named");
@@ -81,5 +78,5 @@ PetscErrorCode PetscObjectViewSAWs(PetscObject obj, PetscViewer viewer)
   PetscCallSAWs(SAWs_Register, (dir, &obj->type_name, 1, SAWs_READ, SAWs_STRING));
   PetscCall(PetscSNPrintf(dir, 1024, "/PETSc/Objects/%s/__Id", obj->name));
   PetscCallSAWs(SAWs_Register, (dir, &obj->id, 1, SAWs_READ, SAWs_INT));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
