@@ -32,7 +32,7 @@ static PetscErrorCode PetscViewerFileClose_ASCII(PetscViewer viewer)
     }
   }
   PetscCall(PetscFree(vascii->filename));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ----------------------------------------------------------------------*/
@@ -85,7 +85,7 @@ PetscErrorCode PetscViewerDestroy_ASCII(PetscViewer viewer)
   PetscCall(PetscObjectComposeFunction((PetscObject)viewer, "PetscViewerFileGetName_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)viewer, "PetscViewerFileGetMode_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)viewer, "PetscViewerFileSetMode_C", NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerDestroy_ASCII_SubViewer(PetscViewer viewer)
@@ -94,13 +94,12 @@ PetscErrorCode PetscViewerDestroy_ASCII_SubViewer(PetscViewer viewer)
 
   PetscFunctionBegin;
   PetscCall(PetscViewerRestoreSubViewer(vascii->bviewer, 0, &viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerFlush_ASCII(PetscViewer viewer)
 {
   PetscViewer_ASCII *vascii = (PetscViewer_ASCII *)viewer->data;
-  int                err;
   MPI_Comm           comm;
   PetscMPIInt        rank, size;
   FILE              *fd = vascii->fd;
@@ -111,10 +110,7 @@ PetscErrorCode PetscViewerFlush_ASCII(PetscViewer viewer)
   PetscCallMPI(MPI_Comm_rank(comm, &rank));
   PetscCallMPI(MPI_Comm_size(comm, &size));
 
-  if (!vascii->bviewer && rank == 0 && (vascii->mode != FILE_MODE_READ)) {
-    err = fflush(vascii->fd);
-    PetscCheck(!err, PETSC_COMM_SELF, PETSC_ERR_SYS, "fflush() call failed");
-  }
+  if (!vascii->bviewer && rank == 0 && (vascii->mode != FILE_MODE_READ)) PetscCall(PetscFFlush(vascii->fd));
 
   if (vascii->allowsynchronized) {
     PetscMPIInt tag, i, j, n = 0, dummy = 0;
@@ -176,7 +172,7 @@ PetscErrorCode PetscViewerFlush_ASCII(PetscViewer viewer)
     }
     PetscCall(PetscCommDestroy(&comm));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -185,7 +181,7 @@ PetscErrorCode PetscViewerFlush_ASCII(PetscViewer viewer)
     Not Collective, depending on the viewer the value may be meaningless except for process 0 of the viewer; No Fortran Support
 
     Input Parameter:
-.    viewer - PetscViewer context, obtained from `PetscViewerASCIIOpen()`
+.    viewer - `PetscViewer` context, obtained from `PetscViewerASCIIOpen()`
 
     Output Parameter:
 .    fd - file pointer
@@ -195,8 +191,8 @@ PetscErrorCode PetscViewerFlush_ASCII(PetscViewer viewer)
     Note:
     For the standard `PETSCVIEWERASCII` the value is valid only on process 0 of the viewer
 
-.seealso: [](sec_viewers), `PETSCVIEWERASCII`, `PetscViewerASCIIOpen()`, `PetscViewerDestroy()`, `PetscViewerSetType()`, `PetscViewerCreate()`, `PetscViewerASCIIPrintf()`,
-          `PetscViewerASCIISynchronizedPrintf()`, `PetscViewerFlush()`
+.seealso: [](sec_viewers), `PETSCVIEWERASCII`, `PetscViewerASCIIOpen()`, `PetscViewerDestroy()`, `PetscViewerSetType()`,
+          `PetscViewerCreate()`, `PetscViewerASCIIPrintf()`, `PetscViewerASCIISynchronizedPrintf()`, `PetscViewerFlush()`
 @*/
 PetscErrorCode PetscViewerASCIIGetPointer(PetscViewer viewer, FILE **fd)
 {
@@ -204,7 +200,7 @@ PetscErrorCode PetscViewerASCIIGetPointer(PetscViewer viewer, FILE **fd)
 
   PetscFunctionBegin;
   *fd = vascii->fd;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerFileGetMode_ASCII(PetscViewer viewer, PetscFileMode *mode)
@@ -213,7 +209,7 @@ PetscErrorCode PetscViewerFileGetMode_ASCII(PetscViewer viewer, PetscFileMode *m
 
   PetscFunctionBegin;
   *mode = vascii->mode;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerFileSetMode_ASCII(PetscViewer viewer, PetscFileMode mode)
@@ -222,7 +218,7 @@ PetscErrorCode PetscViewerFileSetMode_ASCII(PetscViewer viewer, PetscFileMode mo
 
   PetscFunctionBegin;
   vascii->mode = mode;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -232,7 +228,7 @@ PetscErrorCode PetscViewerFileSetMode_ASCII(PetscViewer viewer, PetscFileMode mo
 PETSC_INTERN FILE *petsc_history;
 
 /*@
-    PetscViewerASCIISetTab - Causes `PetscViewer` to tab in a number of times
+    PetscViewerASCIISetTab - Causes `PetscViewer` to tab in a number of times before printing
 
     Not Collective, but only first processor in set has any effect; No Fortran Support
 
@@ -242,9 +238,14 @@ PETSC_INTERN FILE *petsc_history;
 
     Level: developer
 
-.seealso: [](sec_viewers), `PetscPrintf()`, `PetscSynchronizedPrintf()`, `PetscViewerASCIIPrintf()`, `PetscViewerASCIIGetTab()`,
+    Note:
+     `PetscViewerASCIIPushTab()` and `PetscViewerASCIIPopTab()` are the preferred usage
+
+.seealso: [](sec_viewers), `PETSCVIEWERASCII`, `PetscPrintf()`, `PetscSynchronizedPrintf()`, `PetscViewerASCIIPrintf()`,
+          `PetscViewerASCIIGetTab()`,
           `PetscViewerASCIIPopTab()`, `PetscViewerASCIISynchronizedPrintf()`, `PetscViewerASCIIOpen()`,
-          `PetscViewerCreate()`, `PetscViewerDestroy()`, `PetscViewerSetType()`, `PetscViewerASCIIGetPointer()`, `PetscViewerASCIIPushTab()`
+          `PetscViewerCreate()`, `PetscViewerDestroy()`, `PetscViewerSetType()`, `PetscViewerASCIIGetPointer()`,
+          `PetscViewerASCIIPushTab()`
 @*/
 PetscErrorCode PetscViewerASCIISetTab(PetscViewer viewer, PetscInt tabs)
 {
@@ -255,7 +256,7 @@ PetscErrorCode PetscViewerASCIISetTab(PetscViewer viewer, PetscInt tabs)
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
   if (iascii) ascii->tab = tabs;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -263,15 +264,16 @@ PetscErrorCode PetscViewerASCIISetTab(PetscViewer viewer, PetscInt tabs)
 
     Not Collective, meaningful on first processor only; No Fortran Support
 
-    Input Parameters:
+    Input Parameter:
 .    viewer - obtained with `PetscViewerASCIIOpen()`
 
-    Output Parameters:
+    Output Parameter:
 .    tabs - number of tabs
 
     Level: developer
 
-.seealso: [](sec_viewers), `PetscPrintf()`, `PetscSynchronizedPrintf()`, `PetscViewerASCIIPrintf()`, `PetscViewerASCIISetTab()`,
+.seealso: [](sec_viewers), `PETSCVIEWERASCII`, `PetscPrintf()`, `PetscSynchronizedPrintf()`, `PetscViewerASCIIPrintf()`,
+          `PetscViewerASCIISetTab()`,
           `PetscViewerASCIIPopTab()`, `PetscViewerASCIISynchronizedPrintf()`, `PetscViewerASCIIOpen()`,
           `PetscViewerCreate()`, `PetscViewerDestroy()`, `PetscViewerSetType()`, `PetscViewerASCIIGetPointer()`, `PetscViewerASCIIPushTab()`
 @*/
@@ -284,11 +286,11 @@ PetscErrorCode PetscViewerASCIIGetTab(PetscViewer viewer, PetscInt *tabs)
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
   if (iascii && tabs) *tabs = ascii->tab;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-    PetscViewerASCIIAddTab - Add to the number of times an ASCII viewer tabs before printing
+    PetscViewerASCIIAddTab - Add to the number of times a `PETSCVIEWERASCII` viewer tabs before printing
 
     Not Collective, but only first processor in set has any effect; No Fortran Support
 
@@ -298,7 +300,10 @@ PetscErrorCode PetscViewerASCIIGetTab(PetscViewer viewer, PetscInt *tabs)
 
     Level: developer
 
-.seealso: [](sec_viewers), `PetscPrintf()`, `PetscSynchronizedPrintf()`, `PetscViewerASCIIPrintf()`,
+    Note:
+     `PetscViewerASCIIPushTab()` and `PetscViewerASCIIPopTab()` are the preferred usage
+
+.seealso: [](sec_viewers), `PETSCVIEWERASCII`, `PetscPrintf()`, `PetscSynchronizedPrintf()`, `PetscViewerASCIIPrintf()`,
           `PetscViewerASCIIPopTab()`, `PetscViewerASCIISynchronizedPrintf()`, `PetscViewerASCIIOpen()`,
           `PetscViewerCreate()`, `PetscViewerDestroy()`, `PetscViewerSetType()`, `PetscViewerASCIIGetPointer()`, `PetscViewerASCIIPushTab()`
 @*/
@@ -311,11 +316,11 @@ PetscErrorCode PetscViewerASCIIAddTab(PetscViewer viewer, PetscInt tabs)
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
   if (iascii) ascii->tab += tabs;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-    PetscViewerASCIISubtractTab - Subtracts from the number of times an ASCII viewer tabs before printing
+    PetscViewerASCIISubtractTab - Subtracts from the number of times a `PETSCVIEWERASCII` viewer tabs before printing
 
     Not Collective, but only first processor in set has any effect; No Fortran Support
 
@@ -325,9 +330,13 @@ PetscErrorCode PetscViewerASCIIAddTab(PetscViewer viewer, PetscInt tabs)
 
     Level: developer
 
-.seealso: [](sec_viewers), `PetscPrintf()`, `PetscSynchronizedPrintf()`, `PetscViewerASCIIPrintf()`,
+    Note:
+     `PetscViewerASCIIPushTab()` and `PetscViewerASCIIPopTab()` are the preferred usage
+
+.seealso: [](sec_viewers), `PETSCVIEWERASCII`, `PetscPrintf()`, `PetscSynchronizedPrintf()`, `PetscViewerASCIIPrintf()`,
           `PetscViewerASCIIPopTab()`, `PetscViewerASCIISynchronizedPrintf()`, `PetscViewerASCIIOpen()`,
-          `PetscViewerCreate()`, `PetscViewerDestroy()`, `PetscViewerSetType()`, `PetscViewerASCIIGetPointer()`, `PetscViewerASCIIPushTab()`
+          `PetscViewerCreate()`, `PetscViewerDestroy()`, `PetscViewerSetType()`, `PetscViewerASCIIGetPointer()`,
+          `PetscViewerASCIIPushTab()`
 @*/
 PetscErrorCode PetscViewerASCIISubtractTab(PetscViewer viewer, PetscInt tabs)
 {
@@ -338,7 +347,7 @@ PetscErrorCode PetscViewerASCIISubtractTab(PetscViewer viewer, PetscInt tabs)
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
   if (iascii) ascii->tab -= tabs;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -346,7 +355,7 @@ PetscErrorCode PetscViewerASCIISubtractTab(PetscViewer viewer, PetscInt tabs)
 
     Collective
 
-    Input Parameters:
+    Input Parameter:
 .    viewer - obtained with `PetscViewerASCIIOpen()`
 
     Level: intermediate
@@ -368,7 +377,7 @@ PetscErrorCode PetscViewerASCIIPushSynchronized(PetscViewer viewer)
   PetscCheck(!ascii->sviewer, PetscObjectComm((PetscObject)viewer), PETSC_ERR_ARG_WRONGSTATE, "Cannot call with outstanding call to PetscViewerRestoreSubViewer()");
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
   if (iascii) ascii->allowsynchronized++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -376,7 +385,7 @@ PetscErrorCode PetscViewerASCIIPushSynchronized(PetscViewer viewer)
 
     Collective
 
-    Input Parameters:
+    Input Parameter:
 .    viewer - obtained with `PetscViewerASCIIOpen()`
 
     Level: intermediate
@@ -401,7 +410,7 @@ PetscErrorCode PetscViewerASCIIPopSynchronized(PetscViewer viewer)
     ascii->allowsynchronized--;
     PetscCheck(ascii->allowsynchronized >= 0, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Called more times than PetscViewerASCIIPushSynchronized()");
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -410,7 +419,7 @@ PetscErrorCode PetscViewerASCIIPopSynchronized(PetscViewer viewer)
 
     Not Collective, but only first processor in set has any effect; No Fortran Support
 
-    Input Parameters:
+    Input Parameter:
 .    viewer - obtained with `PetscViewerASCIIOpen()`
 
     Level: developer
@@ -428,15 +437,16 @@ PetscErrorCode PetscViewerASCIIPushTab(PetscViewer viewer)
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
   if (iascii) ascii->tab++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-    PetscViewerASCIIPopTab - Removes one tab from the amount that `PetscViewerASCIIPrintf()` lines are tabbed that was provided by `PetscViewerASCIIPushTab()`
+    PetscViewerASCIIPopTab - Removes one tab from the amount that `PetscViewerASCIIPrintf()` lines are tabbed that was provided by
+    `PetscViewerASCIIPushTab()`
 
     Not Collective, but only first processor in set has any effect; No Fortran Support
 
-    Input Parameters:
+    Input Parameter:
 .    viewer - obtained with `PetscViewerASCIIOpen()`
 
     Level: developer
@@ -457,7 +467,7 @@ PetscErrorCode PetscViewerASCIIPopTab(PetscViewer viewer)
     PetscCheck(ascii->tab > 0, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONGSTATE, "More tabs popped than pushed");
     ascii->tab--;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -490,14 +500,14 @@ PetscErrorCode PetscViewerASCIIUseTabs(PetscViewer viewer, PetscBool flg)
       ascii->tab       = 0;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ----------------------------------------------------------------------- */
 
 /*@C
     PetscViewerASCIIPrintf - Prints to a file, only from the first
-    processor in the PetscViewer
+    processor in the `PetscViewer` of type `PETSCVIEWERASCII`
 
     Not Collective, but only first processor in set has any effect
 
@@ -522,7 +532,6 @@ PetscErrorCode PetscViewerASCIIPrintf(PetscViewer viewer, const char format[], .
   PetscInt           tab, intab = ascii->tab;
   FILE              *fd = ascii->fd;
   PetscBool          iascii;
-  int                err;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
@@ -531,7 +540,7 @@ PetscErrorCode PetscViewerASCIIPrintf(PetscViewer viewer, const char format[], .
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &iascii));
   PetscCheck(iascii, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONG, "Not ASCII PetscViewer");
   PetscCallMPI(MPI_Comm_rank(PetscObjectComm((PetscObject)viewer), &rank));
-  if (rank) PetscFunctionReturn(0);
+  if (rank) PetscFunctionReturn(PETSC_SUCCESS);
 
   if (ascii->bviewer) { /* pass string up to parent viewer */
     char   *string;
@@ -563,19 +572,18 @@ PetscErrorCode PetscViewerASCIIPrintf(PetscViewer viewer, const char format[], .
 
     va_start(Argp, format);
     PetscCall((*PetscVFPrintf)(fd, format, Argp));
-    err = fflush(fd);
-    PetscCheck(!err, PETSC_COMM_SELF, PETSC_ERR_SYS, "fflush() failed on file");
+    va_end(Argp);
+    PetscCall(PetscFFlush(fd));
     if (petsc_history) {
-      va_start(Argp, format);
       tab = intab;
       while (tab--) PetscCall(PetscFPrintf(PETSC_COMM_SELF, petsc_history, "  "));
+      va_start(Argp, format);
       PetscCall((*PetscVFPrintf)(petsc_history, format, Argp));
-      err = fflush(petsc_history);
-      PetscCheck(!err, PETSC_COMM_SELF, PETSC_ERR_SYS, "fflush() failed on file");
+      va_end(Argp);
+      PetscCall(PetscFFlush(petsc_history));
     }
-    va_end(Argp);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -584,7 +592,7 @@ PetscErrorCode PetscViewerASCIIPrintf(PetscViewer viewer, const char format[], .
     Collective
 
   Input Parameters:
-+  viewer - the PetscViewer; either `PETSCVIEWERASCII` or `PETSCVIEWERBINARY`
++  viewer - the `PetscViewer`; for example, of type `PETSCVIEWERASCII` or `PETSCVIEWERBINARY`
 -  name - the name of the file it should use
 
     Level: advanced
@@ -601,7 +609,7 @@ PetscErrorCode PetscViewerFileSetName(PetscViewer viewer, const char name[])
   PetscValidCharPointer(name, 2);
   PetscCall(PetscStrreplace(PetscObjectComm((PetscObject)viewer), name, filename, sizeof(filename)));
   PetscTryMethod(viewer, "PetscViewerFileSetName_C", (PetscViewer, const char[]), (viewer, filename));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -610,7 +618,7 @@ PetscErrorCode PetscViewerFileSetName(PetscViewer viewer, const char name[])
     Not Collective
 
   Input Parameter:
-.  viewer - the `PetscViewer`; either `PETSCVIEWERASCII` or `PETSCVIEWERBINARY`
+.  viewer - the `PetscViewer`
 
   Output Parameter:
 .  name - the name of the file it is using
@@ -625,7 +633,7 @@ PetscErrorCode PetscViewerFileGetName(PetscViewer viewer, const char **name)
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscValidPointer(name, 2);
   PetscUseMethod(viewer, "PetscViewerFileGetName_C", (PetscViewer, const char **), (viewer, name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerFileGetName_ASCII(PetscViewer viewer, const char **name)
@@ -634,20 +642,20 @@ PetscErrorCode PetscViewerFileGetName_ASCII(PetscViewer viewer, const char **nam
 
   PetscFunctionBegin;
   *name = vascii->filename;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerFileSetName_ASCII(PetscViewer viewer, const char name[])
 {
   size_t             len;
-  char               fname[PETSC_MAX_PATH_LEN], *gz;
+  char               fname[PETSC_MAX_PATH_LEN], *gz = NULL;
   PetscViewer_ASCII *vascii = (PetscViewer_ASCII *)viewer->data;
   PetscBool          isstderr, isstdout;
   PetscMPIInt        rank;
 
   PetscFunctionBegin;
   PetscCall(PetscViewerFileClose_ASCII(viewer));
-  if (!name) PetscFunctionReturn(0);
+  if (!name) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscStrallocpy(name, &vascii->filename));
 
   /* Is this file to be compressed */
@@ -692,7 +700,10 @@ PetscErrorCode PetscViewerFileSetName_ASCII(PetscViewer viewer, const char name[
         */
         vascii->fd = fopen(fname, "r+");
         if (!vascii->fd) vascii->fd = fopen(fname, "w+");
-        else PetscCall(fseek(vascii->fd, 0, SEEK_END));
+        else {
+          int ret = fseek(vascii->fd, 0, SEEK_END);
+          PetscCheck(!ret, PETSC_COMM_SELF, PETSC_ERR_LIB, "fseek() failed with error code %d", ret);
+        }
         break;
       default:
         SETERRQ(PetscObjectComm((PetscObject)viewer), PETSC_ERR_SUP, "Unsupported file mode %s", PetscFileModes[vascii->mode]);
@@ -701,9 +712,9 @@ PetscErrorCode PetscViewerFileSetName_ASCII(PetscViewer viewer, const char name[
     }
   }
 #if defined(PETSC_USE_LOG)
-  PetscLogObjectState((PetscObject)viewer, "File: %s", name);
+  PetscCall(PetscLogObjectState((PetscObject)viewer, "File: %s", name));
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerGetSubViewer_ASCII(PetscViewer viewer, MPI_Comm subcomm, PetscViewer *outviewer)
@@ -734,7 +745,7 @@ PetscErrorCode PetscViewerGetSubViewer_ASCII(PetscViewer viewer, MPI_Comm subcom
   (*outviewer)->format                                 = viewer->format;
   ((PetscViewer_ASCII *)((*outviewer)->data))->bviewer = viewer;
   (*outviewer)->ops->destroy                           = PetscViewerDestroy_ASCII_SubViewer;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerRestoreSubViewer_ASCII(PetscViewer viewer, MPI_Comm comm, PetscViewer *outviewer)
@@ -750,7 +761,7 @@ PetscErrorCode PetscViewerRestoreSubViewer_ASCII(PetscViewer viewer, MPI_Comm co
   (*outviewer)->ops->destroy = PetscViewerDestroy_ASCII;
   PetscCall(PetscViewerDestroy(outviewer));
   PetscCall(PetscViewerASCIIPopSynchronized(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerView_ASCII(PetscViewer v, PetscViewer viewer)
@@ -759,7 +770,7 @@ PetscErrorCode PetscViewerView_ASCII(PetscViewer v, PetscViewer viewer)
 
   PetscFunctionBegin;
   if (ascii->filename) PetscCall(PetscViewerASCIIPrintf(viewer, "Filename: %s\n", ascii->filename));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -801,7 +812,7 @@ PETSC_EXTERN PetscErrorCode PetscViewerCreate_ASCII(PetscViewer viewer)
   PetscCall(PetscObjectComposeFunction((PetscObject)viewer, "PetscViewerFileGetName_C", PetscViewerFileGetName_ASCII));
   PetscCall(PetscObjectComposeFunction((PetscObject)viewer, "PetscViewerFileGetMode_C", PetscViewerFileGetMode_ASCII));
   PetscCall(PetscObjectComposeFunction((PetscObject)viewer, "PetscViewerFileSetMode_C", PetscViewerFileSetMode_ASCII));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -854,7 +865,6 @@ PetscErrorCode PetscViewerASCIISynchronizedPrintf(PetscViewer viewer, const char
   MPI_Comm           comm;
   FILE              *fp;
   PetscBool          iascii, hasbviewer = PETSC_FALSE;
-  int                err;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
@@ -896,13 +906,13 @@ PetscErrorCode PetscViewerASCIISynchronizedPrintf(PetscViewer viewer, const char
 
     va_start(Argp, format);
     PetscCall((*PetscVFPrintf)(fp, format, Argp));
-    err = fflush(fp);
-    PetscCheck(!err, PETSC_COMM_SELF, PETSC_ERR_SYS, "fflush() failed on file");
+    va_end(Argp);
+    PetscCall(PetscFFlush(fp));
     if (petsc_history) {
       va_start(Argp, format);
       PetscCall((*PetscVFPrintf)(petsc_history, format, Argp));
-      err = fflush(petsc_history);
-      PetscCheck(!err, PETSC_COMM_SELF, PETSC_ERR_SYS, "fflush() failed on file");
+      va_end(Argp);
+      PetscCall(PetscFFlush(petsc_history));
     }
     va_end(Argp);
   } else { /* other processors add to queue */
@@ -939,7 +949,7 @@ PetscErrorCode PetscViewerASCIISynchronizedPrintf(PetscViewer viewer, const char
       va_end(Argp);
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -948,13 +958,13 @@ PetscErrorCode PetscViewerASCIISynchronizedPrintf(PetscViewer viewer, const char
    Only process 0 in the `PetscViewer` may call this
 
    Input Parameters:
-+  viewer - the ascii viewer
++  viewer - the `PETSCVIEWERASCII` viewer
 .  data - location to write the data
 .  num - number of items of data to read
 -  datatype - type of data to read
 
-   Output Parameters:
-.  count - number of items of data actually read, or NULL
+   Output Parameter:
+.  count - number of items of data actually read, or `NULL`
 
    Level: beginner
 
@@ -997,5 +1007,5 @@ PetscErrorCode PetscViewerASCIIRead(PetscViewer viewer, void *data, PetscInt num
   }
   if (count) *count = i;
   else PetscCheck(ret >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONG, "Insufficient data, read only %" PetscInt_FMT " < %" PetscInt_FMT " items", i, num);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
