@@ -1,8 +1,6 @@
 
 #include <../src/sys/classes/viewer/impls/ascii/asciiimpl.h> /*I     "petscviewer.h"   I*/
 
-/* ---------------------------------------------------------------------*/
-
 /*
     The variable Petsc_Viewer_Stdout_keyval is used to indicate an MPI attribute that
   is attached to a communicator, in this case the attribute is a PetscViewer.
@@ -21,9 +19,9 @@ PetscMPIInt Petsc_Viewer_Stdout_keyval = MPI_KEYVAL_INVALID;
    Level: beginner
 
    Note:
-     This should be used in all PETSc source code instead of `PETSC_VIEWER_STDOUT_()`
+     This should be used in all PETSc source code instead of `PETSC_VIEWER_STDOUT_()` since it allows error checking
 
-.seealso: `PETSC_VIEWER_DRAW_()`, `PetscViewerASCIIOpen()`, `PETSC_VIEWER_STDERR_`, `PETSC_VIEWER_STDOUT_WORLD`,
+.seealso: [](sec_viewers), `PETSC_VIEWER_DRAW_()`, `PetscViewerASCIIOpen()`, `PETSC_VIEWER_STDERR_`, `PETSC_VIEWER_STDOUT_WORLD`,
           `PETSC_VIEWER_STDOUT_SELF`
 @*/
 PetscErrorCode PetscViewerASCIIGetStdout(MPI_Comm comm, PetscViewer *viewer)
@@ -43,7 +41,7 @@ PetscErrorCode PetscViewerASCIIGetStdout(MPI_Comm comm, PetscViewer *viewer)
   }
   PetscCall(PetscCommDestroy(&ncomm));
   PetscCall(PetscSpinlockUnlock(&PetscViewerASCIISpinLockStdout));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -62,7 +60,7 @@ PetscErrorCode PetscViewerASCIIGetStdout(MPI_Comm comm, PetscViewer *viewer)
    an error code. Usually used in the form
 $      XXXView(XXX object,PETSC_VIEWER_STDOUT_(comm));
 
-.seealso: `PETSC_VIEWER_DRAW_()`, `PetscViewerASCIIOpen()`, `PETSC_VIEWER_STDERR_`, `PETSC_VIEWER_STDOUT_WORLD`,
+.seealso: [](sec_viewers), `PETSC_VIEWER_DRAW_()`, `PetscViewerASCIIOpen()`, `PETSC_VIEWER_STDERR_`, `PETSC_VIEWER_STDOUT_WORLD`,
           `PETSC_VIEWER_STDOUT_SELF`
 @*/
 PetscViewer PETSC_VIEWER_STDOUT_(MPI_Comm comm)
@@ -73,14 +71,12 @@ PetscViewer PETSC_VIEWER_STDOUT_(MPI_Comm comm)
   PetscFunctionBegin;
   ierr = PetscViewerASCIIGetStdout(comm, &viewer);
   if (ierr) {
-    PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_STDOUT_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
+    ierr = PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_STDOUT_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
     PetscFunctionReturn(NULL);
   }
   PetscFunctionReturn(viewer);
 }
 
-/* ---------------------------------------------------------------------*/
-
 /*
     The variable Petsc_Viewer_Stderr_keyval is used to indicate an MPI attribute that
   is attached to a communicator, in this case the attribute is a PetscViewer.
@@ -99,9 +95,9 @@ PetscMPIInt Petsc_Viewer_Stderr_keyval = MPI_KEYVAL_INVALID;
    Level: beginner
 
    Note:
-     This should be used in all PETSc source code instead of `PETSC_VIEWER_STDERR_()`
+     This should be used in all PETSc source code instead of `PETSC_VIEWER_STDERR_()` since it allows error checking
 
-.seealso: `PETSC_VIEWER_DRAW_()`, `PetscViewerASCIIOpen()`, `PETSC_VIEWER_STDERR_`, `PETSC_VIEWER_STDERR_WORLD`,
+.seealso: [](sec_viewers), `PETSC_VIEWER_DRAW_()`, `PetscViewerASCIIOpen()`, `PETSC_VIEWER_STDERR_`, `PETSC_VIEWER_STDERR_WORLD`,
           `PETSC_VIEWER_STDERR_SELF`
 @*/
 PetscErrorCode PetscViewerASCIIGetStderr(MPI_Comm comm, PetscViewer *viewer)
@@ -121,7 +117,7 @@ PetscErrorCode PetscViewerASCIIGetStderr(MPI_Comm comm, PetscViewer *viewer)
   }
   PetscCall(PetscCommDestroy(&ncomm));
   PetscCall(PetscSpinlockUnlock(&PetscViewerASCIISpinLockStderr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -135,12 +131,14 @@ PetscErrorCode PetscViewerASCIIGetStderr(MPI_Comm comm, PetscViewer *viewer)
 
    Level: beginner
 
-   Note:
+   Notes:
    Unlike almost all other PETSc routines, this does not return
    an error code. Usually used in the form
 $      XXXView(XXX object,PETSC_VIEWER_STDERR_(comm));
 
-.seealso: `PETSC_VIEWER_DRAW_`, `PetscViewerASCIIOpen()`, `PETSC_VIEWER_STDOUT_`, `PETSC_VIEWER_STDOUT_WORLD`,
+   `PetscViewerASCIIGetStderr()` is preferred  since it allows error checking
+
+.seealso: [](sec_viewers), `PETSC_VIEWER_DRAW_`, `PetscViewerASCIIOpen()`, `PETSC_VIEWER_STDOUT_`, `PETSC_VIEWER_STDOUT_WORLD`,
           `PETSC_VIEWER_STDOUT_SELF`, `PETSC_VIEWER_STDERR_WORLD`, `PETSC_VIEWER_STDERR_SELF`
 @*/
 PetscViewer PETSC_VIEWER_STDERR_(MPI_Comm comm)
@@ -151,7 +149,7 @@ PetscViewer PETSC_VIEWER_STDERR_(MPI_Comm comm)
   PetscFunctionBegin;
   ierr = PetscViewerASCIIGetStderr(comm, &viewer);
   if (ierr) {
-    PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_STDERR_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
+    ierr = PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_STDERR_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
     PetscFunctionReturn(NULL);
   }
   PetscFunctionReturn(viewer);
@@ -159,8 +157,8 @@ PetscViewer PETSC_VIEWER_STDERR_(MPI_Comm comm)
 
 PetscMPIInt Petsc_Viewer_keyval = MPI_KEYVAL_INVALID;
 /*
-   Called with MPI_Comm_free() is called on a communicator that has a viewer as an attribute. The viewer is not actually destroyed because that is managed by
-   PetscObjectDestroyRegisterAll(). PetscViewerASCIIGetStdout() registers the viewer with PetscObjectDestroyRegister() to be destroyed when PetscFinalize() is called.
+   Called with MPI_Comm_free() is called on a communicator that has a viewer as an attribute. The viewer is not actually destroyed
+   because that is managed by PetscObjectDestroyRegisterAll(). PetscViewerASCIIGetStdout() registers the viewer with PetscObjectDestroyRegister() to be destroyed when PetscFinalize() is called.
 
   This is called by MPI, not by users.
 
@@ -182,7 +180,7 @@ PETSC_EXTERN PetscMPIInt MPIAPI Petsc_DelViewer(MPI_Comm comm, PetscMPIInt keyva
 -  name - the file name
 
    Output Parameter:
-.  lab - the PetscViewer to use with the specified file
+.  lab - the `PetscViewer` to use with the specified file
 
    Level: beginner
 
@@ -207,7 +205,7 @@ PETSC_EXTERN PetscMPIInt MPIAPI Petsc_DelViewer(MPI_Comm comm, PetscMPIInt keyva
      MatView(matrix,viewer);
 .ve
 
-.seealso: `MatView()`, `VecView()`, `PetscViewerDestroy()`, `PetscViewerBinaryOpen()`, `PetscViewerASCIIRead()`, `PETSCVIEWERASCII`
+.seealso: [](sec_viewers), `MatView()`, `VecView()`, `PetscViewerDestroy()`, `PetscViewerBinaryOpen()`, `PetscViewerASCIIRead()`, `PETSCVIEWERASCII`
           `PetscViewerASCIIGetPointer()`, `PetscViewerPushFormat()`, `PETSC_VIEWER_STDOUT_`, `PETSC_VIEWER_STDERR_`,
           `PETSC_VIEWER_STDOUT_WORLD`, `PETSC_VIEWER_STDOUT_SELF`,
 @*/
@@ -222,7 +220,7 @@ PetscErrorCode PetscViewerASCIIOpen(MPI_Comm comm, const char name[], PetscViewe
   if (!len) {
     PetscCall(PetscViewerASCIIGetStdout(comm, lab));
     PetscCall(PetscObjectReference((PetscObject)*lab));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCall(PetscSpinlockLock(&PetscViewerASCIISpinLockOpen));
   if (Petsc_Viewer_keyval == MPI_KEYVAL_INVALID) PetscCallMPI(MPI_Comm_create_keyval(MPI_COMM_NULL_COPY_FN, Petsc_DelViewer, &Petsc_Viewer_keyval, (void *)0));
@@ -245,7 +243,7 @@ PetscErrorCode PetscViewerASCIIOpen(MPI_Comm comm, const char name[], PetscViewe
         *lab = vlink->viewer;
         PetscCall(PetscCommDestroy(&comm));
         PetscCall(PetscSpinlockUnlock(&PetscViewerASCIISpinLockOpen));
-        PetscFunctionReturn(0);
+        PetscFunctionReturn(PETSC_SUCCESS);
       }
       vlink = vlink->next;
     }
@@ -269,17 +267,17 @@ PetscErrorCode PetscViewerASCIIOpen(MPI_Comm comm, const char name[], PetscViewe
   }
   PetscCall(PetscCommDestroy(&comm));
   PetscCall(PetscSpinlockUnlock(&PetscViewerASCIISpinLockOpen));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscViewerASCIIOpenWithFILE - Given an open file creates an ASCII viewer that prints to it.
+   PetscViewerASCIIOpenWithFILE - Given an open file creates an `PETSCVIEWERASCII` viewer that prints to it.
 
    Collective
 
    Input Parameters:
 +  comm - the communicator
--  fd - the FILE pointer
+-  fd - the `FILE` pointer
 
    Output Parameter:
 .  lab - the `PetscViewer` to use with the specified file
@@ -293,7 +291,7 @@ PetscErrorCode PetscViewerASCIIOpen(MPI_Comm comm, const char name[], PetscViewe
    then only the first processor in the group uses the file.  All other
    processors send their data to the first processor to print.
 
-.seealso: `MatView()`, `VecView()`, `PetscViewerDestroy()`, `PetscViewerBinaryOpen()`,
+.seealso: [](sec_viewers), `MatView()`, `VecView()`, `PetscViewerDestroy()`, `PetscViewerBinaryOpen()`,
           `PetscViewerASCIIGetPointer()`, `PetscViewerPushFormat()`, `PETSC_VIEWER_STDOUT_`, `PETSC_VIEWER_STDERR_`,
           `PETSC_VIEWER_STDOUT_WORLD`, `PETSC_VIEWER_STDOUT_SELF`, `PetscViewerASCIIOpen()`, `PetscViewerASCIISetFILE()`, `PETSCVIEWERASCII`
 @*/
@@ -303,17 +301,17 @@ PetscErrorCode PetscViewerASCIIOpenWithFILE(MPI_Comm comm, FILE *fd, PetscViewer
   PetscCall(PetscViewerCreate(comm, lab));
   PetscCall(PetscViewerSetType(*lab, PETSCVIEWERASCII));
   PetscCall(PetscViewerASCIISetFILE(*lab, fd));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscViewerASCIISetFILE - Given an open file sets the ASCII viewer to use the file for output
+   PetscViewerASCIISetFILE - Given an open file sets the `PETSCVIEWERASCII` viewer to use the file for output
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  viewer - the `PetscViewer` to use with the specified file
--  fd - the FILE pointer
+-  fd - the `FILE` pointer
 
    Level: beginner
 
@@ -335,5 +333,5 @@ PetscErrorCode PetscViewerASCIISetFILE(PetscViewer viewer, FILE *fd)
   PetscFunctionBegin;
   vascii->fd        = fd;
   vascii->closefile = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
