@@ -20,7 +20,7 @@ static PetscErrorCode PetscViewerDestroy_Draw(PetscViewer v)
   PetscCall(PetscFree(vdraw->bounds));
   PetscCall(PetscFree(vdraw->drawtype));
   PetscCall(PetscFree(v->data));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PetscViewerFlush_Draw(PetscViewer v)
@@ -32,7 +32,7 @@ static PetscErrorCode PetscViewerFlush_Draw(PetscViewer v)
   for (i = 0; i < vdraw->draw_max; i++) {
     if (vdraw->draw[i]) PetscCall(PetscDrawFlush(vdraw->draw[i]));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -40,7 +40,7 @@ static PetscErrorCode PetscViewerFlush_Draw(PetscViewer v)
     This `PetscDraw` object may then be used to perform graphics using
     `PetscDraw` commands.
 
-    Collective on viewer
+    Collective
 
     Input Parameters:
 +   viewer - the `PetscViewer` (created with `PetscViewerDrawOpen()` of type `PETSCVIEWERDRAW`)
@@ -51,7 +51,7 @@ static PetscErrorCode PetscViewerFlush_Draw(PetscViewer v)
 
     Level: intermediate
 
-.seealso: `PETSCVIEWERDRAW`, `PetscViewerDrawGetLG()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`
+.seealso: [](sec_viewers), `PETSCVIEWERDRAW`, `PetscViewerDrawGetLG()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`
 @*/
 PetscErrorCode PetscViewerDrawGetDraw(PetscViewer viewer, PetscInt windownumber, PetscDraw *draw)
 {
@@ -98,13 +98,13 @@ PetscErrorCode PetscViewerDrawGetDraw(PetscViewer viewer, PetscInt windownumber,
   }
   if (draw) *draw = vdraw->draw[windownumber];
   if (draw) PetscValidHeaderSpecific(*draw, PETSC_DRAW_CLASSID, 3);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscViewerDrawBaseAdd - add to the base integer that is added to the windownumber passed to `PetscViewerDrawGetDraw()`
 
-    Logically Collective on viewer
+    Logically Collective
 
     Input Parameters:
 +  viewer - the `PetscViewer` (created with `PetscViewerDrawOpen()`)
@@ -115,7 +115,7 @@ PetscErrorCode PetscViewerDrawGetDraw(PetscViewer viewer, PetscInt windownumber,
     Note:
     A `PETSCVIEWERDRAW` may have multiple `PetscDraw` subwindows, this increases the number of the subwindow that is returned with `PetscViewerDrawGetDraw()`
 
-.seealso: `PetscViewerDrawGetLG()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`, `PetscViewerDrawBaseSet()`
+.seealso: [](sec_viewers), `PetscViewerDrawGetLG()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`, `PetscViewerDrawBaseSet()`
 @*/
 PetscErrorCode PetscViewerDrawBaseAdd(PetscViewer viewer, PetscInt windownumber)
 {
@@ -131,13 +131,13 @@ PetscErrorCode PetscViewerDrawBaseAdd(PetscViewer viewer, PetscInt windownumber)
 
   PetscCheck(windownumber + vdraw->draw_base >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Resulting base %" PetscInt_FMT " cannot be negative", windownumber + vdraw->draw_base);
   vdraw->draw_base += windownumber;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscViewerDrawBaseSet - sets the base integer that is added to the windownumber passed to `PetscViewerDrawGetDraw()`
 
-    Logically Collective on viewer
+    Logically Collective
 
     Input Parameters:
 +   viewer - the `PetscViewer` (created with `PetscViewerDrawOpen()`)
@@ -148,7 +148,7 @@ PetscErrorCode PetscViewerDrawBaseAdd(PetscViewer viewer, PetscInt windownumber)
     Note:
     A `PETSCVIEWERDRAW` may have multiple `PetscDraw` subwindows, this increases the number of the subwindow that is returned with `PetscViewerDrawGetDraw()`
 
-.seealso: `PetscViewerDrawGetLG()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`, `PetscViewerDrawBaseAdd()`
+.seealso: [](sec_viewers), `PetscViewerDrawGetLG()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`, `PetscViewerDrawBaseAdd()`
 @*/
 PetscErrorCode PetscViewerDrawBaseSet(PetscViewer viewer, PetscInt windownumber)
 {
@@ -164,17 +164,17 @@ PetscErrorCode PetscViewerDrawBaseSet(PetscViewer viewer, PetscInt windownumber)
 
   PetscCheck(windownumber >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Resulting base %" PetscInt_FMT " cannot be negative", windownumber);
   vdraw->draw_base = windownumber;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscViewerDrawGetDrawLG - Returns a `PetscDrawLG` object from `PetscViewer` object of type `PETSCVIEWERDRAW`.
     This `PetscDrawLG` object may then be used to perform graphics using `PetscDrawLG` commands.
 
-    Collective on viewer
+    Collective
 
     Input Parameters:
-+   PetscViewer - the `PetscViewer` (created with `PetscViewerDrawOpen()`)
++   viewer - the `PetscViewer` (created with `PetscViewerDrawOpen()`)
 -   windownumber - indicates which subwindow (usually 0)
 
     Output Parameter:
@@ -185,7 +185,7 @@ PetscErrorCode PetscViewerDrawBaseSet(PetscViewer viewer, PetscInt windownumber)
     Note:
     A `PETSCVIEWERDRAW` may have multiple `PetscDraw` subwindows
 
-.seealso: `PetscDrawLG`, `PetscViewerDrawGetDraw()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`
+.seealso: [](sec_viewers), `PetscDrawLG`, `PetscViewerDrawGetDraw()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`
 @*/
 PetscErrorCode PetscViewerDrawGetDrawLG(PetscViewer viewer, PetscInt windownumber, PetscDrawLG *drawlg)
 {
@@ -207,14 +207,14 @@ PetscErrorCode PetscViewerDrawGetDrawLG(PetscViewer viewer, PetscInt windownumbe
     PetscCall(PetscDrawLGSetFromOptions(vdraw->drawlg[windownumber + vdraw->draw_base]));
   }
   *drawlg = vdraw->drawlg[windownumber + vdraw->draw_base];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscViewerDrawGetDrawAxis - Returns a `PetscDrawAxis` object from a `PetscViewer` object of type `PETSCVIEWERDRAW`.
     This `PetscDrawAxis` object may then be used to perform graphics using `PetscDrawAxis` commands.
 
-    Collective on viewer
+    Collective
 
     Input Parameters:
 +   viewer - the `PetscViewer` (created with `PetscViewerDrawOpen()`)
@@ -228,7 +228,7 @@ PetscErrorCode PetscViewerDrawGetDrawLG(PetscViewer viewer, PetscInt windownumbe
     Note:
     A `PETSCVIEWERDRAW` may have multiple `PetscDraw` subwindows
 
-.seealso: `PetscViewerDrawGetDraw()`, `PetscViewerDrawGetLG()`, `PetscViewerDrawOpen()`
+.seealso: [](sec_viewers), `PetscViewerDrawGetDraw()`, `PetscViewerDrawGetLG()`, `PetscViewerDrawOpen()`
 @*/
 PetscErrorCode PetscViewerDrawGetDrawAxis(PetscViewer viewer, PetscInt windownumber, PetscDrawAxis *drawaxis)
 {
@@ -247,7 +247,7 @@ PetscErrorCode PetscViewerDrawGetDrawAxis(PetscViewer viewer, PetscInt windownum
   if (windownumber + vdraw->draw_base >= vdraw->draw_max || !vdraw->draw[windownumber + vdraw->draw_base]) PetscCall(PetscViewerDrawGetDraw(viewer, windownumber, NULL));
   if (!vdraw->drawaxis[windownumber + vdraw->draw_base]) PetscCall(PetscDrawAxisCreate(vdraw->draw[windownumber + vdraw->draw_base], &vdraw->drawaxis[windownumber + vdraw->draw_base]));
   *drawaxis = vdraw->drawaxis[windownumber + vdraw->draw_base];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerDrawResize(PetscViewer v, int w, int h)
@@ -258,12 +258,12 @@ PetscErrorCode PetscViewerDrawResize(PetscViewer v, int w, int h)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(v, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)v, PETSCVIEWERDRAW, &isdraw));
-  if (!isdraw) PetscFunctionReturn(0);
+  if (!isdraw) PetscFunctionReturn(PETSC_SUCCESS);
   vdraw = (PetscViewer_Draw *)v->data;
 
   if (w >= 1) vdraw->w = w;
   if (h >= 1) vdraw->h = h;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerDrawSetInfo(PetscViewer v, const char display[], const char title[], int x, int y, int w, int h)
@@ -274,14 +274,14 @@ PetscErrorCode PetscViewerDrawSetInfo(PetscViewer v, const char display[], const
   PetscFunctionBegin;
   PetscValidHeaderSpecific(v, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)v, PETSCVIEWERDRAW, &isdraw));
-  if (!isdraw) PetscFunctionReturn(0);
+  if (!isdraw) PetscFunctionReturn(PETSC_SUCCESS);
   vdraw = (PetscViewer_Draw *)v->data;
 
   PetscCall(PetscStrallocpy(display, &vdraw->display));
   PetscCall(PetscStrallocpy(title, &vdraw->title));
   if (w >= 1) vdraw->w = w;
   if (h >= 1) vdraw->h = h;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerDrawSetDrawType(PetscViewer v, PetscDrawType drawtype)
@@ -292,12 +292,12 @@ PetscErrorCode PetscViewerDrawSetDrawType(PetscViewer v, PetscDrawType drawtype)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(v, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)v, PETSCVIEWERDRAW, &isdraw));
-  if (!isdraw) PetscFunctionReturn(0);
+  if (!isdraw) PetscFunctionReturn(PETSC_SUCCESS);
   vdraw = (PetscViewer_Draw *)v->data;
 
   PetscCall(PetscFree(vdraw->drawtype));
   PetscCall(PetscStrallocpy(drawtype, (char **)&vdraw->drawtype));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerDrawGetDrawType(PetscViewer v, PetscDrawType *drawtype)
@@ -312,7 +312,7 @@ PetscErrorCode PetscViewerDrawGetDrawType(PetscViewer v, PetscDrawType *drawtype
   vdraw = (PetscViewer_Draw *)v->data;
 
   *drawtype = vdraw->drawtype;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerDrawSetTitle(PetscViewer v, const char title[])
@@ -323,12 +323,12 @@ PetscErrorCode PetscViewerDrawSetTitle(PetscViewer v, const char title[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(v, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)v, PETSCVIEWERDRAW, &isdraw));
-  if (!isdraw) PetscFunctionReturn(0);
+  if (!isdraw) PetscFunctionReturn(PETSC_SUCCESS);
   vdraw = (PetscViewer_Draw *)v->data;
 
   PetscCall(PetscFree(vdraw->title));
   PetscCall(PetscStrallocpy(title, &vdraw->title));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerDrawGetTitle(PetscViewer v, const char *title[])
@@ -343,7 +343,7 @@ PetscErrorCode PetscViewerDrawGetTitle(PetscViewer v, const char *title[])
   vdraw = (PetscViewer_Draw *)v->data;
 
   *title = vdraw->title;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -355,11 +355,12 @@ PetscErrorCode PetscViewerDrawGetTitle(PetscViewer v, const char *title[])
 
    Input Parameters:
 +  comm - communicator that will share window
-.  display - the X display on which to open, or null for the local machine
-.  title - the title to put in the title bar, or null for no title
-.  x, y - the screen coordinates of the upper left corner of window, or use `PETSC_DECIDE`
--  w, h - window width and height in pixels, or may use `PETSC_DECIDE` or `PETSC_DRAW_FULL_SIZE`, `PETSC_DRAW_HALF_SIZE`,
-          `PETSC_DRAW_THIRD_SIZE`, `PETSC_DRAW_QUARTER_SIZE`
+.  display - the X display on which to open, or `NULL` for the local machine
+.  title - the title to put in the title bar, or `NULL` for no title
+.  x - horizontal screen coordinate of the upper left corner of window, or use `PETSC_DECIDE`
+.  y - vertical screen coordinate of the upper left corner of window, or use `PETSC_DECIDE`
+.  w - window width in pixels, or may use `PETSC_DECIDE` or `PETSC_DRAW_FULL_SIZE`, `PETSC_DRAW_HALF_SIZE`,`PETSC_DRAW_THIRD_SIZE`, `PETSC_DRAW_QUARTER_SIZE`
+-  h - window height in pixels, or may use `PETSC_DECIDE` or `PETSC_DRAW_FULL_SIZE`, `PETSC_DRAW_HALF_SIZE`,`PETSC_DRAW_THIRD_SIZE`, `PETSC_DRAW_QUARTER_SIZE`
 
    Output Parameter:
 . viewer - the `PetscViewer`
@@ -379,13 +380,13 @@ PetscErrorCode PetscViewerDrawGetTitle(PetscViewer v, const char *title[])
 
    Level: beginner
 
-   Note for Fortran Programmers:
+   Fortran Note:
    Whenever indicating null character data in a Fortran code,
    `PETSC_NULL_CHARACTER` must be employed; using NULL is not
    correct for character data!  Thus, `PETSC_NULL_CHARACTER` can be
    used for the display and title input parameters.
 
-.seealso: `PETSCVIEWERDRAW`, `PetscDrawCreate()`, `PetscViewerDestroy()`, `PetscViewerDrawGetDraw()`, `PetscViewerCreate()`, `PETSC_VIEWER_DRAW_`,
+.seealso: [](sec_viewers), `PETSCVIEWERDRAW`, `PetscDrawCreate()`, `PetscViewerDestroy()`, `PetscViewerDrawGetDraw()`, `PetscViewerCreate()`, `PETSC_VIEWER_DRAW_`,
           `PETSC_VIEWER_DRAW_WORLD`, `PETSC_VIEWER_DRAW_SELF`
 @*/
 PetscErrorCode PetscViewerDrawOpen(MPI_Comm comm, const char display[], const char title[], int x, int y, int w, int h, PetscViewer *viewer)
@@ -394,7 +395,7 @@ PetscErrorCode PetscViewerDrawOpen(MPI_Comm comm, const char display[], const ch
   PetscCall(PetscViewerCreate(comm, viewer));
   PetscCall(PetscViewerSetType(*viewer, PETSCVIEWERDRAW));
   PetscCall(PetscViewerDrawSetInfo(*viewer, display, title, x, y, w, h));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #include <petsc/private/drawimpl.h>
@@ -439,7 +440,7 @@ PetscErrorCode PetscViewerGetSubViewer_Draw(PetscViewer viewer, MPI_Comm comm, P
     PetscCall(PetscViewerDrawGetDraw(viewer, 0, &draw));
   }
   vdraw->singleton_made = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerRestoreSubViewer_Draw(PetscViewer viewer, MPI_Comm comm, PetscViewer *sviewer)
@@ -475,7 +476,7 @@ PetscErrorCode PetscViewerRestoreSubViewer_Draw(PetscViewer viewer, MPI_Comm com
   }
 
   vdraw->singleton_made = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerSetFromOptions_Draw(PetscViewer v, PetscOptionItems *PetscOptionsObject)
@@ -489,7 +490,7 @@ PetscErrorCode PetscViewerSetFromOptions_Draw(PetscViewer v, PetscOptionItems *P
   PetscCall(PetscOptionsRealArray("-draw_bounds", "Bounds to put on plots axis", "PetscViewerDrawSetBounds", bounds, &nbounds, &flg));
   if (flg) PetscCall(PetscViewerDrawSetBounds(v, nbounds / 2, bounds));
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerView_Draw(PetscViewer viewer, PetscViewer v)
@@ -497,8 +498,11 @@ PetscErrorCode PetscViewerView_Draw(PetscViewer viewer, PetscViewer v)
   PetscDraw         draw;
   PetscInt          i;
   PetscViewer_Draw *vdraw = (PetscViewer_Draw *)viewer->data;
+  PetscBool         iascii;
 
   PetscFunctionBegin;
+  PetscCall(PetscObjectTypeCompare((PetscObject)v, PETSCVIEWERASCII, &iascii));
+  if (iascii) PetscCall(PetscViewerASCIIPrintf(v, "Draw viewer is of type %s\n", vdraw->drawtype));
   /*  If the PetscViewer has just been created then no vdraw->draw yet
       exists so this will not actually call the viewer on any draws. */
   for (i = 0; i < vdraw->draw_base; i++) {
@@ -507,7 +511,7 @@ PetscErrorCode PetscViewerView_Draw(PetscViewer viewer, PetscViewer v)
       PetscCall(PetscDrawView(draw, v));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -515,7 +519,7 @@ PetscErrorCode PetscViewerView_Draw(PetscViewer viewer, PetscViewer v)
 
   Level: beginner
 
-.seealso: `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`, `PETSC_VIEWER_DRAW_()`, `PETSC_VIEWER_DRAW_SELF`, `PETSC_VIEWER_DRAW_WORLD`,
+.seealso: [](sec_viewers), `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`, `PETSC_VIEWER_DRAW_()`, `PETSC_VIEWER_DRAW_SELF`, `PETSC_VIEWER_DRAW_WORLD`,
           `PetscViewerCreate()`, `PetscViewerASCIIOpen()`, `PetscViewerBinaryOpen()`, `PETSCVIEWERBINARY`,
           `PetscViewerMatlabOpen()`, `VecView()`, `DMView()`, `PetscViewerMatlabPutArray()`, `PETSCVIEWERASCII`, `PETSCVIEWERMATLAB`,
           `PetscViewerFileSetName()`, `PetscViewerFileSetMode()`, `PetscViewerFormat`, `PetscViewerType`, `PetscViewerSetType()`
@@ -543,7 +547,7 @@ PETSC_EXTERN PetscErrorCode PetscViewerCreate_Draw(PetscViewer viewer)
 
   PetscCall(PetscCalloc3(vdraw->draw_max, &vdraw->draw, vdraw->draw_max, &vdraw->drawlg, vdraw->draw_max, &vdraw->drawaxis));
   vdraw->singleton_made = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -556,7 +560,7 @@ PETSC_EXTERN PetscErrorCode PetscViewerCreate_Draw(PetscViewer viewer)
 
     Level: intermediate
 
-.seealso: `PETSCVIEWERDRAW`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`,
+.seealso: [](sec_viewers), `PETSCVIEWERDRAW`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`,
 @*/
 PetscErrorCode PetscViewerDrawClear(PetscViewer viewer)
 {
@@ -567,13 +571,13 @@ PetscErrorCode PetscViewerDrawClear(PetscViewer viewer)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERDRAW, &isdraw));
-  if (!isdraw) PetscFunctionReturn(0);
+  if (!isdraw) PetscFunctionReturn(PETSC_SUCCESS);
   vdraw = (PetscViewer_Draw *)viewer->data;
 
   for (i = 0; i < vdraw->draw_max; i++) {
     if (vdraw->draw[i]) PetscCall(PetscDrawClear(vdraw->draw[i]));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -589,7 +593,7 @@ PetscErrorCode PetscViewerDrawClear(PetscViewer viewer)
 
     Level: intermediate
 
-.seealso: `PETSCVIEWERDRAW`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`,
+.seealso: [](sec_viewers), `PETSCVIEWERDRAW`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`,
 @*/
 PetscErrorCode PetscViewerDrawGetPause(PetscViewer viewer, PetscReal *pause)
 {
@@ -603,20 +607,20 @@ PetscErrorCode PetscViewerDrawGetPause(PetscViewer viewer, PetscReal *pause)
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERDRAW, &isdraw));
   if (!isdraw) {
     *pause = 0.0;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   vdraw = (PetscViewer_Draw *)viewer->data;
 
   for (i = 0; i < vdraw->draw_max; i++) {
     if (vdraw->draw[i]) {
       PetscCall(PetscDrawGetPause(vdraw->draw[i], pause));
-      PetscFunctionReturn(0);
+      PetscFunctionReturn(PETSC_SUCCESS);
     }
   }
   /* none exist yet so create one and get its pause */
   PetscCall(PetscViewerDrawGetDraw(viewer, 0, &draw));
   PetscCall(PetscDrawGetPause(draw, pause));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -630,7 +634,7 @@ PetscErrorCode PetscViewerDrawGetPause(PetscViewer viewer, PetscReal *pause)
 
     Level: intermediate
 
-.seealso: `PETSCVIEWERDRAW`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`,
+.seealso: [](sec_viewers), `PETSCVIEWERDRAW`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`,
 @*/
 PetscErrorCode PetscViewerDrawSetPause(PetscViewer viewer, PetscReal pause)
 {
@@ -641,14 +645,14 @@ PetscErrorCode PetscViewerDrawSetPause(PetscViewer viewer, PetscReal pause)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERDRAW, &isdraw));
-  if (!isdraw) PetscFunctionReturn(0);
+  if (!isdraw) PetscFunctionReturn(PETSC_SUCCESS);
   vdraw = (PetscViewer_Draw *)viewer->data;
 
   vdraw->pause = pause;
   for (i = 0; i < vdraw->draw_max; i++) {
     if (vdraw->draw[i]) PetscCall(PetscDrawSetPause(vdraw->draw[i], pause));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -662,7 +666,7 @@ PetscErrorCode PetscViewerDrawSetPause(PetscViewer viewer, PetscReal pause)
 
     Level: intermediate
 
-.seealso: `PETSCVIEWERDRAW`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`,
+.seealso: [](sec_viewers), `PETSCVIEWERDRAW`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`,
 @*/
 PetscErrorCode PetscViewerDrawSetHold(PetscViewer viewer, PetscBool hold)
 {
@@ -672,11 +676,11 @@ PetscErrorCode PetscViewerDrawSetHold(PetscViewer viewer, PetscBool hold)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERDRAW, &isdraw));
-  if (!isdraw) PetscFunctionReturn(0);
+  if (!isdraw) PetscFunctionReturn(PETSC_SUCCESS);
   vdraw = (PetscViewer_Draw *)viewer->data;
 
   vdraw->hold = hold;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -692,7 +696,7 @@ PetscErrorCode PetscViewerDrawSetHold(PetscViewer viewer, PetscBool hold)
 
     Level: intermediate
 
-.seealso: `PETSCVIEWERDRAW`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`,
+.seealso: [](sec_viewers), `PETSCVIEWERDRAW`, `PetscViewerDrawOpen()`, `PetscViewerDrawGetDraw()`,
 @*/
 PetscErrorCode PetscViewerDrawGetHold(PetscViewer viewer, PetscBool *hold)
 {
@@ -704,15 +708,14 @@ PetscErrorCode PetscViewerDrawGetHold(PetscViewer viewer, PetscBool *hold)
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERDRAW, &isdraw));
   if (!isdraw) {
     *hold = PETSC_FALSE;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   vdraw = (PetscViewer_Draw *)viewer->data;
 
   *hold = vdraw->hold;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* ---------------------------------------------------------------------*/
 /*
     The variable Petsc_Viewer_Draw_keyval is used to indicate an MPI attribute that
   is attached to a communicator, in this case the attribute is a PetscViewer.
@@ -735,53 +738,53 @@ PetscMPIInt Petsc_Viewer_Draw_keyval = MPI_KEYVAL_INVALID;
      an error code.  The window is usually used in the form
 $       XXXView(XXX object,PETSC_VIEWER_DRAW_(comm));
 
-.seealso: `PETSCVIEWERDRAW`, `PetscViewer`, `PETSC_VIEWER_DRAW_WORLD`, `PETSC_VIEWER_DRAW_SELF`, `PetscViewerDrawOpen()`,
+.seealso: [](sec_viewers), `PETSCVIEWERDRAW`, `PetscViewer`, `PETSC_VIEWER_DRAW_WORLD`, `PETSC_VIEWER_DRAW_SELF`, `PetscViewerDrawOpen()`,
 @*/
 PetscViewer PETSC_VIEWER_DRAW_(MPI_Comm comm)
 {
   PetscErrorCode ierr;
-  PetscMPIInt    flag;
+  PetscMPIInt    flag, mpi_ierr;
   PetscViewer    viewer;
   MPI_Comm       ncomm;
 
   PetscFunctionBegin;
   ierr = PetscCommDuplicate(comm, &ncomm, NULL);
   if (ierr) {
-    PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
+    ierr = PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
     PetscFunctionReturn(NULL);
   }
   if (Petsc_Viewer_Draw_keyval == MPI_KEYVAL_INVALID) {
-    ierr = MPI_Comm_create_keyval(MPI_COMM_NULL_COPY_FN, MPI_COMM_NULL_DELETE_FN, &Petsc_Viewer_Draw_keyval, NULL);
-    if (ierr) {
-      PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
+    mpi_ierr = MPI_Comm_create_keyval(MPI_COMM_NULL_COPY_FN, MPI_COMM_NULL_DELETE_FN, &Petsc_Viewer_Draw_keyval, NULL);
+    if (mpi_ierr) {
+      ierr = PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
       PetscFunctionReturn(NULL);
     }
   }
-  ierr = MPI_Comm_get_attr(ncomm, Petsc_Viewer_Draw_keyval, (void **)&viewer, &flag);
-  if (ierr) {
-    PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
+  mpi_ierr = MPI_Comm_get_attr(ncomm, Petsc_Viewer_Draw_keyval, (void **)&viewer, &flag);
+  if (mpi_ierr) {
+    ierr = PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
     PetscFunctionReturn(NULL);
   }
   if (!flag) { /* PetscViewer not yet created */
     ierr = PetscViewerDrawOpen(ncomm, NULL, NULL, PETSC_DECIDE, PETSC_DECIDE, 300, 300, &viewer);
     if (ierr) {
-      PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_REPEAT, " ");
+      ierr = PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_REPEAT, " ");
       PetscFunctionReturn(NULL);
     }
     ierr = PetscObjectRegisterDestroy((PetscObject)viewer);
     if (ierr) {
-      PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_REPEAT, " ");
+      ierr = PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_REPEAT, " ");
       PetscFunctionReturn(NULL);
     }
-    ierr = MPI_Comm_set_attr(ncomm, Petsc_Viewer_Draw_keyval, (void *)viewer);
-    if (ierr) {
-      PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
+    mpi_ierr = MPI_Comm_set_attr(ncomm, Petsc_Viewer_Draw_keyval, (void *)viewer);
+    if (mpi_ierr) {
+      ierr = PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_INITIAL, " ");
       PetscFunctionReturn(NULL);
     }
   }
   ierr = PetscCommDestroy(&ncomm);
   if (ierr) {
-    PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_REPEAT, " ");
+    ierr = PetscError(PETSC_COMM_SELF, __LINE__, "PETSC_VIEWER_DRAW_", __FILE__, PETSC_ERR_PLIB, PETSC_ERROR_REPEAT, " ");
     PetscFunctionReturn(NULL);
   }
   PetscFunctionReturn(viewer);
@@ -790,7 +793,7 @@ PetscViewer PETSC_VIEWER_DRAW_(MPI_Comm comm)
 /*@
     PetscViewerDrawSetBounds - sets the upper and lower bounds to be used in plotting
 
-    Collective on viewer
+    Collective
 
     Input Parameters:
 +   viewer - the Petsc`Viewer` (created with `PetscViewerDrawOpen()`)
@@ -807,7 +810,7 @@ PetscViewer PETSC_VIEWER_DRAW_(MPI_Comm comm)
       bounds are moved to the bound value before plotting. In this way the color index from color to physical value remains the same for all plots generated with
       this viewer. Otherwise the color to physical value meaning changes with each new image if this is not set.
 
-.seealso: `PETSCVIEWERDRAW`, `PetscViewerDrawGetLG()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`
+.seealso: [](sec_viewers), `PETSCVIEWERDRAW`, `PetscViewerDrawGetLG()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`
 @*/
 PetscErrorCode PetscViewerDrawSetBounds(PetscViewer viewer, PetscInt nbounds, const PetscReal *bounds)
 {
@@ -817,20 +820,20 @@ PetscErrorCode PetscViewerDrawSetBounds(PetscViewer viewer, PetscInt nbounds, co
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERDRAW, &isdraw));
-  if (!isdraw) PetscFunctionReturn(0);
+  if (!isdraw) PetscFunctionReturn(PETSC_SUCCESS);
   vdraw = (PetscViewer_Draw *)viewer->data;
 
   vdraw->nbounds = nbounds;
   PetscCall(PetscFree(vdraw->bounds));
   PetscCall(PetscMalloc1(2 * nbounds, &vdraw->bounds));
   PetscCall(PetscArraycpy(vdraw->bounds, bounds, 2 * nbounds));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscViewerDrawGetBounds - gets the upper and lower bounds to be used in plotting set with `PetscViewerDrawSetBounds()`
 
-    Collective on viewer
+    Collective
 
     Input Parameter:
 .   viewer - the `PetscViewer` (created with `PetscViewerDrawOpen()`)
@@ -841,7 +844,7 @@ PetscErrorCode PetscViewerDrawSetBounds(PetscViewer viewer, PetscInt nbounds, co
 
     Level: intermediate
 
-.seealso: `PETSCVIEWERDRAW`, `PetscViewerDrawGetLG()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`, `PetscViewerDrawSetBounds()`
+.seealso: [](sec_viewers), `PETSCVIEWERDRAW`, `PetscViewerDrawGetLG()`, `PetscViewerDrawGetAxis()`, `PetscViewerDrawOpen()`, `PetscViewerDrawSetBounds()`
 @*/
 PetscErrorCode PetscViewerDrawGetBounds(PetscViewer viewer, PetscInt *nbounds, const PetscReal **bounds)
 {
@@ -854,11 +857,11 @@ PetscErrorCode PetscViewerDrawGetBounds(PetscViewer viewer, PetscInt *nbounds, c
   if (!isdraw) {
     if (nbounds) *nbounds = 0;
     if (bounds) *bounds = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   vdraw = (PetscViewer_Draw *)viewer->data;
 
   if (nbounds) *nbounds = vdraw->nbounds;
   if (bounds) *bounds = vdraw->bounds;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
