@@ -3,9 +3,9 @@
 
 /*@C
    PetscViewerGetSubViewer - Creates a new `PetscViewer` (same type as the old)
-    that lives on a subcommunicator
+    that lives on a subcommunicator of the original viewers communicator
 
-    Collective on viewer
+    Collective
 
    Input Parameter:
 .  viewer - the `PetscViewer` to be reproduced
@@ -41,7 +41,7 @@
     It would be nice if the call to `PetscViewerFlush()` was not required and was handled by
     `PetscViewerRestoreSubViewer()`
 
-.seealso: `PetscViewerSocketOpen()`, `PetscViewerASCIIOpen()`, `PetscViewerDrawOpen()`, `PetscViewerRestoreSubViewer()`
+.seealso: [](sec_viewers), `PetscViewerSocketOpen()`, `PetscViewerASCIIOpen()`, `PetscViewerDrawOpen()`, `PetscViewerRestoreSubViewer()`
 @*/
 PetscErrorCode PetscViewerGetSubViewer(PetscViewer viewer, MPI_Comm comm, PetscViewer *outviewer)
 {
@@ -49,13 +49,13 @@ PetscErrorCode PetscViewerGetSubViewer(PetscViewer viewer, MPI_Comm comm, PetscV
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscValidPointer(outviewer, 3);
   PetscUseTypeMethod(viewer, getsubviewer, comm, outviewer);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscViewerRestoreSubViewer - Restores a new `PetscViewer` obtained with `PetscViewerGetSubViewer()`.
 
-    Collective on viewer
+    Collective
 
    Input Parameters:
 +  viewer - the `PetscViewer` that was reproduced
@@ -63,7 +63,7 @@ PetscErrorCode PetscViewerGetSubViewer(PetscViewer viewer, MPI_Comm comm, PetscV
 
    Level: advanced
 
-.seealso: `PetscViewerSocketOpen()`, `PetscViewerASCIIOpen()`, `PetscViewerDrawOpen()`, `PetscViewerGetSubViewer()`
+.seealso: [](sec_viewers), `PetscViewerSocketOpen()`, `PetscViewerASCIIOpen()`, `PetscViewerDrawOpen()`, `PetscViewerGetSubViewer()`
 @*/
 PetscErrorCode PetscViewerRestoreSubViewer(PetscViewer viewer, MPI_Comm comm, PetscViewer *outviewer)
 {
@@ -71,5 +71,5 @@ PetscErrorCode PetscViewerRestoreSubViewer(PetscViewer viewer, MPI_Comm comm, Pe
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
 
   PetscUseTypeMethod(viewer, restoresubviewer, comm, outviewer);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
