@@ -11,7 +11,7 @@ static PetscBool PetscViewerPackageInitialized = PETSC_FALSE;
 
   Level: developer
 
-.seealso: `PetscFinalize()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscFinalize()`, `PetscViewerInitializePackage()`
 @*/
 PetscErrorCode PetscViewerFinalizePackage(void)
 {
@@ -30,7 +30,7 @@ PetscErrorCode PetscViewerFinalizePackage(void)
   PetscCall(PetscFunctionListDestroy(&PetscViewerList));
   PetscViewerPackageInitialized = PETSC_FALSE;
   PetscViewerRegisterAllCalled  = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -38,7 +38,7 @@ PetscErrorCode PetscViewerFinalizePackage(void)
 
   Level: developer
 
-.seealso: `PetscInitialize()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscInitialize()`, `PetscViewerFinalizePackage()`
 @*/
 PetscErrorCode PetscViewerInitializePackage(void)
 {
@@ -46,7 +46,7 @@ PetscErrorCode PetscViewerInitializePackage(void)
   PetscBool opt, pkg;
 
   PetscFunctionBegin;
-  if (PetscViewerPackageInitialized) PetscFunctionReturn(0);
+  if (PetscViewerPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   PetscViewerPackageInitialized = PETSC_TRUE;
   /* Register Classes */
   PetscCall(PetscClassIdRegister("Viewer", &PETSC_VIEWER_CLASSID));
@@ -70,43 +70,43 @@ PetscErrorCode PetscViewerInitializePackage(void)
 #endif
   /* Register package finalizer */
   PetscCall(PetscRegisterFinalize(PetscViewerFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PetscViewerDestroy - Destroys a `PetscViewer`.
 
-   Collective on viewer
+   Collective
 
-   Input Parameters:
+   Input Parameter:
 .  viewer - the `PetscViewer` to be destroyed.
 
    Level: beginner
 
-.seealso: `PetscViewer`, `PetscViewerSocketOpen()`, `PetscViewerASCIIOpen()`, `PetscViewerCreate()`, `PetscViewerDrawOpen()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerSocketOpen()`, `PetscViewerASCIIOpen()`, `PetscViewerCreate()`, `PetscViewerDrawOpen()`
 @*/
 PetscErrorCode PetscViewerDestroy(PetscViewer *viewer)
 {
   PetscFunctionBegin;
-  if (!*viewer) PetscFunctionReturn(0);
+  if (!*viewer) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*viewer, PETSC_VIEWER_CLASSID, 1);
 
   PetscCall(PetscViewerFlush(*viewer));
   if (--((PetscObject)(*viewer))->refct > 0) {
     *viewer = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(PetscObjectSAWsViewOff((PetscObject)*viewer));
   if ((*viewer)->ops->destroy) PetscCall((*(*viewer)->ops->destroy)(*viewer));
   PetscCall(PetscHeaderDestroy(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscViewerAndFormatCreate - Creates a `PetscViewerAndFormat` struct.
 
-   Collective on viewer
+   Collective
 
    Input Parameters:
 +  viewer - the viewer
@@ -118,11 +118,17 @@ PetscErrorCode PetscViewerDestroy(PetscViewer *viewer)
    Level: developer
 
    Notes:
-   This increases the reference count of the viewer so you can destroy the viewer object after this call
+   This increases the reference count of the viewer.
+
+   Use `PetscViewerAndFormatDestroy()` to free the struct
 
    This is used as the context variable for many of the `TS`, `SNES`, and `KSP` monitor functions
 
-.seealso: `PetscViewerSocketOpen()`, `PetscViewerASCIIOpen()`, `PetscViewerCreate()`, `PetscViewerDrawOpen()`, `PetscViewerAndFormatDestroy()`
+   This construct exists because it allows one to keep track of the use of a `PetscViewerFormat` without requiring the
+   format in the viewer to be permanently changed.
+
+.seealso: [](sec_viewers), `PetscViewerFormat`, `PetscViewerSocketOpen()`, `PetscViewerASCIIOpen()`, `PetscViewerCreate()`,
+          `PetscViewerDrawOpen()`, `PetscViewerAndFormatDestroy()`
 @*/
 PetscErrorCode PetscViewerAndFormatCreate(PetscViewer viewer, PetscViewerFormat format, PetscViewerAndFormat **vf)
 {
@@ -133,20 +139,21 @@ PetscErrorCode PetscViewerAndFormatCreate(PetscViewer viewer, PetscViewerFormat
   (*vf)->format = format;
   (*vf)->lg     = NULL;
   (*vf)->data   = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscViewerAndFormatDestroy - Destroys a `PetscViewerAndFormat` struct.
+   PetscViewerAndFormatDestroy - Destroys a `PetscViewerAndFormat` struct created with `PetscViewerAndFormatCreate()`
 
-   Collective on vf
+   Collective
 
-   Input Parameters:
+   Input Parameter:
 .  vf - the `PetscViewerAndFormat` to be destroyed.
 
    Level: developer
 
-.seealso: `PetscViewerSocketOpen()`, `PetscViewerASCIIOpen()`, `PetscViewerCreate()`, `PetscViewerDrawOpen()`, `PetscViewerAndFormatCreate()`
+.seealso: [](sec_viewers), `PetscViewerAndFormatCreate()`, `PetscViewerSocketOpen()`, `PetscViewerASCIIOpen()`, `PetscViewerCreate()`,
+          `PetscViewerDrawOpen()`, `PetscViewerAndFormatDestroy()`
 @*/
 PetscErrorCode PetscViewerAndFormatDestroy(PetscViewerAndFormat **vf)
 {
@@ -154,7 +161,7 @@ PetscErrorCode PetscViewerAndFormatDestroy(PetscViewerAndFormat **vf)
   PetscCall(PetscViewerDestroy(&(*vf)->viewer));
   PetscCall(PetscDrawLGDestroy(&(*vf)->lg));
   PetscCall(PetscFree(*vf));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -166,7 +173,7 @@ PetscErrorCode PetscViewerAndFormatDestroy(PetscViewerAndFormat **vf)
 .   viewer - the `PetscViewer`
 
    Output Parameter:
-.  type - PetscViewer type (see below)
+.  type - `PetscViewerType`
 
    Available Types Include:
 +  `PETSCVIEWERSOCKET` - Socket PetscViewer
@@ -178,11 +185,9 @@ PetscErrorCode PetscViewerAndFormatDestroy(PetscViewerAndFormat **vf)
    Level: intermediate
 
    Note:
-   See include/petscviewer.h for a complete list of `PetscViewer`s.
-
    `PetscViewerType` is actually a string
 
-.seealso: `PetscViewerType`, `PetscViewer`, `PetscViewerCreate()`, `PetscViewerSetType()`, `PetscViewerType`
+.seealso: [](sec_viewers), `PetscViewerType`, `PetscViewer`, `PetscViewerCreate()`, `PetscViewerSetType()`, `PetscViewerType`
 @*/
 PetscErrorCode PetscViewerGetType(PetscViewer viewer, PetscViewerType *type)
 {
@@ -190,14 +195,14 @@ PetscErrorCode PetscViewerGetType(PetscViewer viewer, PetscViewerType *type)
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscValidPointer(type, 2);
   *type = ((PetscObject)viewer)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscViewerSetOptionsPrefix - Sets the prefix used for searching for all
    `PetscViewer` options in the database.
 
-   Logically Collective on viewer
+   Logically Collective
 
    Input Parameters:
 +  viewer - the `PetscViewer` context
@@ -209,45 +214,45 @@ PetscErrorCode PetscViewerGetType(PetscViewer viewer, PetscViewerType *type)
 
    Level: advanced
 
-.seealso: `PetscViewer`, `PetscViewerSetFromOptions()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerSetFromOptions()`
 @*/
 PetscErrorCode PetscViewerSetOptionsPrefix(PetscViewer viewer, const char prefix[])
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)viewer, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscViewerAppendOptionsPrefix - Appends to the prefix used for searching for all
    `PetscViewer` options in the database.
 
-   Logically Collective on viewer
+   Logically Collective
 
    Input Parameters:
-+  viewer - the PetscViewer context
++  viewer - the `PetscViewer` context
 -  prefix - the prefix to prepend to all option names
 
+   Level: advanced
+
    Note:
    A hyphen (-) must NOT be given at the beginning of the prefix name.
    The first character of all runtime options is AUTOMATICALLY the hyphen.
 
-   Level: advanced
-
-.seealso: `PetscViewer`, `PetscViewerGetOptionsPrefix()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerGetOptionsPrefix()`
 @*/
 PetscErrorCode PetscViewerAppendOptionsPrefix(PetscViewer viewer, const char prefix[])
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectAppendOptionsPrefix((PetscObject)viewer, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscViewerGetOptionsPrefix - Sets the prefix used for searching for all
-   PetscViewer options in the database.
+   `PetscViewer` options in the database.
 
    Not Collective
 
@@ -257,51 +262,51 @@ PetscErrorCode PetscViewerAppendOptionsPrefix(PetscViewer viewer, const char pre
    Output Parameter:
 .  prefix - pointer to the prefix string used
 
+   Level: advanced
+
    Fortran Note:
    The user should pass in a string 'prefix' of sufficient length to hold the prefix.
 
-   Level: advanced
-
-.seealso: `PetscViewer`, `PetscViewerAppendOptionsPrefix()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerAppendOptionsPrefix()`
 @*/
 PetscErrorCode PetscViewerGetOptionsPrefix(PetscViewer viewer, const char *prefix[])
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectGetOptionsPrefix((PetscObject)viewer, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PetscViewerSetUp - Sets up the internal viewer data structures for the later use.
 
-   Collective on viewer
+   Collective
 
-   Input Parameters:
+   Input Parameter:
 .  viewer - the `PetscViewer` context
 
+   Level: advanced
+
    Note:
    For basic use of the `PetscViewer` classes the user need not explicitly call
    `PetscViewerSetUp()`, since these actions will happen automatically.
 
-   Level: advanced
-
-.seealso: `PetscViewer`, `PetscViewerCreate()`, `PetscViewerDestroy()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerCreate()`, `PetscViewerDestroy()`
 @*/
 PetscErrorCode PetscViewerSetUp(PetscViewer viewer)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
-  if (viewer->setupcalled) PetscFunctionReturn(0);
+  if (viewer->setupcalled) PetscFunctionReturn(PETSC_SUCCESS);
   PetscTryTypeMethod(viewer, setup);
   viewer->setupcalled = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscViewerViewFromOptions - View from the viewer based on the options database values
+   PetscViewerViewFromOptions - View from the viewer based on options in the options database
 
-   Collective on A
+   Collective
 
    Input Parameters:
 +  A - the `PetscViewer` context
@@ -310,36 +315,31 @@ PetscErrorCode PetscViewerSetUp(PetscViewer viewer)
 
    Level: intermediate
 
-.seealso: `PetscViewer`, `PetscViewerView`, `PetscObjectViewFromOptions()`, `PetscViewerCreate()`
+   Note:
+   See `PetscObjectViewFromOptions()` for details on the viewers and formats support via this interface
+
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerView`, `PetscObjectViewFromOptions()`, `PetscViewerCreate()`
 @*/
 PetscErrorCode PetscViewerViewFromOptions(PetscViewer A, PetscObject obj, const char name[])
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)A, obj, name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscViewerView - Visualizes a viewer object.
 
-   Collective on v
+   Collective
 
    Input Parameters:
 +  v - the viewer to be viewed
 -  viewer - visualization context
 
-  Note:
-  The available visualization contexts include
-.vb
-  PETSC_VIEWER_STDOUT_SELF - standard output (default)
-  PETSC_VIEWER_STDOUT_WORLD - synchronized standard output where only the first rank opens the file. Other processors send their data to the first rank
-  PETSC_VIEWER_DRAW_WORLD - graphical display of nonzero structure
-.ve
-
    Level: beginner
 
-.seealso: `PetscViewer`, `PetscViewerPushFormat()`, `PetscViewerASCIIOpen()`, `PetscViewerDrawOpen()`,
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerPushFormat()`, `PetscViewerASCIIOpen()`, `PetscViewerDrawOpen()`,
           `PetscViewerSocketOpen()`, `PetscViewerBinaryOpen()`, `PetscViewerLoad()`
 @*/
 PetscErrorCode PetscViewerView(PetscViewer v, PetscViewer viewer)
@@ -378,7 +378,7 @@ PetscErrorCode PetscViewerView(PetscViewer v, PetscViewer viewer)
     }
 #endif
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -392,17 +392,19 @@ PetscErrorCode PetscViewerView(PetscViewer v, PetscViewer viewer)
 .  num      - Number of items of data to read
 -  datatype - Type of data to read
 
-   Output Parameters:
-.  count - number of items of data actually read, or NULL
-
-   Note:
-   If datatype is `PETSC_STRING` and num is negative, reads until a newline character is found,
-   until a maximum of (-num - 1) chars.
+   Output Parameter:
+.  count - number of items of data actually read, or `NULL`
 
    Level: beginner
 
-.seealso: `PetscViewer`, `PetscViewerASCIIOpen()`, `PetscViewerPushFormat()`, `PetscViewerDestroy()`,
-          `VecView()`, `MatView()`, `VecLoad()`, `MatLoad()`, `PetscViewerBinaryGetDescriptor()`,
+   Notes:
+   If datatype is `PETSC_STRING` and num is negative, reads until a newline character is found,
+   until a maximum of (-num - 1) chars.
+
+   Only certain viewers, such as `PETSCVIEWERBINARY` can be read from, see `PetscViewerReadable()`
+
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerASCIIOpen()`, `PetscViewerPushFormat()`, `PetscViewerDestroy()`,
+          `PetscViewerReadable()`, `PetscViewerBinaryGetDescriptor()`,
           `PetscViewerBinaryGetInfoPointer()`, `PetscFileMode`, `PetscViewer`
 @*/
 PetscErrorCode PetscViewerRead(PetscViewer viewer, void *data, PetscInt num, PetscInt *count, PetscDataType dtype)
@@ -441,7 +443,7 @@ PetscErrorCode PetscViewerRead(PetscViewer viewer, void *data, PetscInt num, Pet
     if (count) *count = c;
     else PetscCheck(c >= num, PetscObjectComm((PetscObject)viewer), PETSC_ERR_FILE_READ, "Insufficient data, only read %" PetscInt_FMT " < %" PetscInt_FMT " strings", c, num);
   } else PetscUseTypeMethod(viewer, read, data, num, count, dtype);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -449,20 +451,20 @@ PetscErrorCode PetscViewerRead(PetscViewer viewer, void *data, PetscInt num, Pet
 
    Not Collective
 
-   Input Parameters:
+   Input Parameter:
 .  viewer - the `PetscViewer` context
 
-   Output Parameters:
+   Output Parameter:
 .  flg - `PETSC_TRUE` if the viewer is readable, `PETSC_FALSE` otherwise
 
+   Level: intermediate
+
    Note:
    `PETSC_TRUE` means that viewer's `PetscViewerType` supports reading (this holds e.g. for `PETSCVIEWERBINARY`)
    and viewer is in a mode allowing reading, i.e. `PetscViewerFileGetMode()`
    returns one of `FILE_MODE_READ`, `FILE_MODE_UPDATE`, `FILE_MODE_APPEND_UPDATE`.
 
-   Level: intermediate
-
-.seealso: `PetscViewer`, `PetscViewerWritable()`, `PetscViewerCheckReadable()`, `PetscViewerCreate()`, `PetscViewerFileSetMode()`, `PetscViewerFileSetType()`
+.seealso: [](sec_viewers), `PetscViewerRead()`, `PetscViewer`, `PetscViewerWritable()`, `PetscViewerCheckReadable()`, `PetscViewerCreate()`, `PetscViewerFileSetMode()`, `PetscViewerFileSetType()`
 @*/
 PetscErrorCode PetscViewerReadable(PetscViewer viewer, PetscBool *flg)
 {
@@ -474,7 +476,7 @@ PetscErrorCode PetscViewerReadable(PetscViewer viewer, PetscBool *flg)
   PetscValidBoolPointer(flg, 2);
   PetscCall(PetscObjectQueryFunction((PetscObject)viewer, "PetscViewerFileGetMode_C", &f));
   *flg = PETSC_FALSE;
-  if (!f) PetscFunctionReturn(0);
+  if (!f) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall((*f)(viewer, &mode));
   switch (mode) {
   case FILE_MODE_READ:
@@ -484,7 +486,7 @@ PetscErrorCode PetscViewerReadable(PetscViewer viewer, PetscBool *flg)
   default:
     break;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -492,19 +494,19 @@ PetscErrorCode PetscViewerReadable(PetscViewer viewer, PetscBool *flg)
 
    Not Collective
 
-   Input Parameters:
+   Input Parameter:
 .  viewer - the `PetscViewer` context
 
-   Output Parameters:
+   Output Parameter:
 .  flg - `PETSC_TRUE` if the viewer is writable, `PETSC_FALSE` otherwise
 
+   Level: intermediate
+
    Note:
    `PETSC_TRUE` means viewer is in a mode allowing writing, i.e. `PetscViewerFileGetMode()`
    returns one of `FILE_MODE_WRITE`, `FILE_MODE_APPEND`, `FILE_MODE_UPDATE`, `FILE_MODE_APPEND_UPDATE`.
 
-   Level: intermediate
-
-.seealso: `PetscViewer`, `PetscViewerReadable()`, `PetscViewerCheckWritable()`, `PetscViewerCreate()`, `PetscViewerFileSetMode()`, `PetscViewerFileSetType()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerReadable()`, `PetscViewerCheckWritable()`, `PetscViewerCreate()`, `PetscViewerFileSetMode()`, `PetscViewerFileSetType()`
 @*/
 PetscErrorCode PetscViewerWritable(PetscViewer viewer, PetscBool *flg)
 {
@@ -516,10 +518,10 @@ PetscErrorCode PetscViewerWritable(PetscViewer viewer, PetscBool *flg)
   PetscValidBoolPointer(flg, 2);
   PetscCall(PetscObjectQueryFunction((PetscObject)viewer, "PetscViewerFileGetMode_C", &f));
   *flg = PETSC_TRUE;
-  if (!f) PetscFunctionReturn(0);
+  if (!f) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall((*f)(viewer, &mode));
   if (mode == FILE_MODE_READ) *flg = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -527,12 +529,12 @@ PetscErrorCode PetscViewerWritable(PetscViewer viewer, PetscBool *flg)
 
    Collective
 
-   Input Parameters:
+   Input Parameter:
 .  viewer - the `PetscViewer` context
 
    Level: intermediate
 
-.seealso: `PetscViewer`, `PetscViewerReadable()`, `PetscViewerCheckWritable()`, `PetscViewerCreate()`, `PetscViewerFileSetMode()`, `PetscViewerFileSetType()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerReadable()`, `PetscViewerCheckWritable()`, `PetscViewerCreate()`, `PetscViewerFileSetMode()`, `PetscViewerFileSetType()`
 @*/
 PetscErrorCode PetscViewerCheckReadable(PetscViewer viewer)
 {
@@ -542,7 +544,7 @@ PetscErrorCode PetscViewerCheckReadable(PetscViewer viewer)
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscViewerReadable(viewer, &flg));
   PetscCheck(flg, PetscObjectComm((PetscObject)viewer), PETSC_ERR_SUP, "Viewer doesn't support reading, or is not in reading mode (FILE_MODE_READ, FILE_MODE_UPDATE, FILE_MODE_APPEND_UPDATE)");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -550,12 +552,12 @@ PetscErrorCode PetscViewerCheckReadable(PetscViewer viewer)
 
    Collective
 
-   Input Parameters:
+   Input Parameter:
 .  viewer - the `PetscViewer` context
 
    Level: intermediate
 
-.seealso: `PetscViewer`, `PetscViewerWritable()`, `PetscViewerCheckReadable()`, `PetscViewerCreate()`, `PetscViewerFileSetMode()`, `PetscViewerFileSetType()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerWritable()`, `PetscViewerCheckReadable()`, `PetscViewerCreate()`, `PetscViewerFileSetMode()`, `PetscViewerFileSetType()`
 @*/
 PetscErrorCode PetscViewerCheckWritable(PetscViewer viewer)
 {
@@ -565,5 +567,5 @@ PetscErrorCode PetscViewerCheckWritable(PetscViewer viewer)
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscCall(PetscViewerWritable(viewer, &flg));
   PetscCheck(flg, PetscObjectComm((PetscObject)viewer), PETSC_ERR_SUP, "Viewer doesn't support writing, or is in FILE_MODE_READ mode");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
