@@ -17,18 +17,18 @@ struct _n_PetscOptionsHelpPrinted {
 PetscErrorCode PetscOptionsHelpPrintedDestroy(PetscOptionsHelpPrinted *hp)
 {
   PetscFunctionBegin;
-  if (!*hp) PetscFunctionReturn(0);
+  if (!*hp) PetscFunctionReturn(PETSC_SUCCESS);
   kh_destroy(HTPrinted, (*hp)->printed);
   PetscCall(PetscSegBufferDestroy(&(*hp)->strings));
   PetscCall(PetscFree(*hp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
       PetscOptionsHelpPrintedCreate - Creates an object used to manage tracking which help messages have
          been printed so they will not be printed again.
 
-     Not collective
+     Not Collective
 
     Level: developer
 
@@ -40,21 +40,21 @@ PetscErrorCode PetscOptionsHelpPrintedCreate(PetscOptionsHelpPrinted *hp)
   PetscCall(PetscNew(hp));
   (*hp)->printed = kh_init(HTPrinted);
   PetscCall(PetscSegBufferCreate(sizeof(char), 10000, &(*hp)->strings));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
       PetscOptionsHelpPrintedCheck - Checks if a particular pre, name pair has previous been entered (meaning the help message was printed)
 
-     Not collective
+     Not Collective
 
     Input Parameters:
 +     hp - the object used to manage tracking what help messages have been printed
-.     pre - the prefix part of the string, many be NULL
--     name - the string to look for (cannot be NULL)
+.     pre - the prefix part of the string, many be `NULL`
+-     name - the string to look for (cannot be `NULL`)
 
     Output Parameter:
-.     found - PETSC_TRUE if the string was already set
+.     found - `PETSC_TRUE` if the string was already set
 
     Level: intermediate
 
@@ -73,19 +73,20 @@ PetscErrorCode PetscOptionsHelpPrintedCheck(PetscOptionsHelpPrinted hp, const ch
   PetscCall(PetscStrlen(name, &l2));
   if (l1 + l2 == 0) {
     *found = PETSC_FALSE;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 #if !defined(PETSC_HAVE_THREADSAFETY)
-  PetscCall(PetscSegBufferGet(hp->strings, l1 + l2 + 1, &both));
-  PetscCall(PetscStrcpy(both, pre));
-  PetscCall(PetscStrcat(both, name));
+  size_t lboth = l1 + l2 + 1;
+  PetscCall(PetscSegBufferGet(hp->strings, lboth, &both));
+  PetscCall(PetscStrncpy(both, pre, lboth));
+  PetscCall(PetscStrncpy(both + l1, name, l2 + 1));
   kh_put(HTPrinted, hp->printed, both, &newitem);
-  if (!newitem) PetscCall(PetscSegBufferUnuse(hp->strings, l1 + l2 + 1));
+  if (!newitem) PetscCall(PetscSegBufferUnuse(hp->strings, lboth));
   *found = newitem ? PETSC_FALSE : PETSC_TRUE;
 #else
   *found = PETSC_FALSE;
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscBool noviewer = PETSC_FALSE;
@@ -106,7 +107,7 @@ static PetscInt  inoviewers = 0;
     Calling XXXViewFromOptions in an inner loop can be very expensive.  This can appear, for example, when using
    many small subsolves.  Call this function to control viewer creation in `PetscOptionsGetViewer()`, thus removing the expensive XXXViewFromOptions calls.
 
-.seealso: `PetscOptionsGetViewer()`, `PetscOptionsPopGetViewerOff()`
+.seealso: [](sec_viewers), `PetscOptionsGetViewer()`, `PetscOptionsPopGetViewerOff()`
 @*/
 PetscErrorCode PetscOptionsPushGetViewerOff(PetscBool flg)
 {
@@ -115,7 +116,7 @@ PetscErrorCode PetscOptionsPushGetViewerOff(PetscBool flg)
 
   noviewers[inoviewers++] = noviewer;
   noviewer                = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -129,14 +130,14 @@ PetscErrorCode PetscOptionsPushGetViewerOff(PetscBool flg)
     Calling XXXViewFromOptions in an inner loop can be very expensive.  This can appear, for example, when using
    many small subsolves.  Call this function to control viewer creation in `PetscOptionsGetViewer()`, thus removing the expensive XXXViewFromOptions calls.
 
-.seealso: `PetscOptionsGetViewer()`, `PetscOptionsPushGetViewerOff()`
+.seealso: [](sec_viewers), `PetscOptionsGetViewer()`, `PetscOptionsPushGetViewerOff()`
 @*/
 PetscErrorCode PetscOptionsPopGetViewerOff(void)
 {
   PetscFunctionBegin;
   PetscCheck(inoviewers, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Too many PetscOptionsPopGetViewerOff(), perhaps you forgot PetscOptionsPushGetViewerOff()?");
   noviewer = noviewers[--inoviewers];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -153,14 +154,14 @@ PetscErrorCode PetscOptionsPopGetViewerOff(void)
     Calling XXXViewFromOptions in an inner loop can be very expensive.  This can appear, for example, when using
    many small subsolves.
 
-.seealso: `PetscOptionsGetViewer()`, `PetscOptionsPushGetViewerOff()`, `PetscOptionsPopGetViewerOff()`
+.seealso: [](sec_viewers), `PetscOptionsGetViewer()`, `PetscOptionsPushGetViewerOff()`, `PetscOptionsPopGetViewerOff()`
 @*/
 PetscErrorCode PetscOptionsGetViewerOff(PetscBool *flg)
 {
   PetscFunctionBegin;
   PetscValidBoolPointer(flg, 1);
   *flg = noviewer;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -170,13 +171,13 @@ PetscErrorCode PetscOptionsGetViewerOff(PetscBool *flg)
 
    Input Parameters:
 +  comm - the communicator to own the viewer
-.  options - options database, use NULL for default global database
-.  pre - the string to prepend to the name or NULL
+.  options - options database, use `NULL` for default global database
+.  pre - the string to prepend to the name or `NULL`
 -  name - the option one is seeking
 
    Output Parameters:
-+  viewer - the viewer, pass NULL if not needed
-.  format - the `PetscViewerFormat` requested by the user, pass NULL if not needed
++  viewer - the viewer, pass `NULL` if not needed
+.  format - the `PetscViewerFormat` requested by the user, pass `NULL` if not needed
 -  set - `PETSC_TRUE` if found, else `PETSC_FALSE`
 
    Level: intermediate
@@ -197,9 +198,9 @@ PetscErrorCode PetscOptionsGetViewerOff(PetscBool *flg)
    `PetscOptionsPushGetViewerOff()`.  This is useful if calling many small subsolves, in which case XXXViewFromOptions can take
    an appreciable fraction of the runtime.
 
-   If PETSc is configured with --with-viewfromoptions=0 this function always returns with *set of `PETSC_FALSE`
+   If PETSc is configured with `--with-viewfromoptions=0` this function always returns with *set of `PETSC_FALSE`
 
-.seealso: `PetscOptionsGetReal()`, `PetscOptionsHasName()`, `PetscOptionsGetString()`,
+.seealso: [](sec_viewers), `PetscOptionsGetReal()`, `PetscOptionsHasName()`, `PetscOptionsGetString()`,
           `PetscOptionsGetIntArray()`, `PetscOptionsGetRealArray()`, `PetscOptionsBool()`
           `PetscOptionsInt()`, `PetscOptionsString()`, `PetscOptionsReal()`, `PetscOptionsBool()`,
           `PetscOptionsName()`, `PetscOptionsBegin()`, `PetscOptionsEnd()`, `PetscOptionsHeadBegin()`,
@@ -220,7 +221,7 @@ PetscErrorCode PetscOptionsGetViewer(MPI_Comm comm, PetscOptions options, const
   if (format) *format = PETSC_VIEWER_DEFAULT;
   if (set) *set = PETSC_FALSE;
   PetscCall(PetscOptionsGetViewerOff(&flag));
-  if (flag) PetscFunctionReturn(0);
+  if (flag) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscOptionsHasHelp(NULL, &hashelp));
   if (hashelp) {
@@ -248,7 +249,7 @@ PetscErrorCode PetscOptionsGetViewer(MPI_Comm comm, PetscOptions options, const
         PetscCall(PetscObjectReference((PetscObject)*viewer));
       }
     } else {
-      char       *loc0_vtype, *loc1_fname, *loc2_fmt = NULL, *loc3_fmode = NULL;
+      char       *loc0_vtype = NULL, *loc1_fname = NULL, *loc2_fmt = NULL, *loc3_fmode = NULL;
       PetscInt    cnt;
       const char *viewers[] = {PETSCVIEWERASCII, PETSCVIEWERBINARY, PETSCVIEWERDRAW, PETSCVIEWERSOCKET, PETSCVIEWERMATLAB, PETSCVIEWERSAWS, PETSCVIEWERVTK, PETSCVIEWERHDF5, PETSCVIEWERGLVIS, PETSCVIEWEREXODUSII, NULL};
 
@@ -351,7 +352,7 @@ PetscErrorCode PetscOptionsGetViewer(MPI_Comm comm, PetscOptions options, const
       PetscCall(PetscFree(loc0_vtype));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -367,7 +368,7 @@ PetscErrorCode PetscOptionsGetViewer(MPI_Comm comm, PetscOptions options, const
 
    Level: advanced
 
-.seealso: `PetscViewer`, `PetscViewerDestroy()`, `PetscViewerSetType()`, `PetscViewerType`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerDestroy()`, `PetscViewerSetType()`, `PetscViewerType`
 @*/
 PetscErrorCode PetscViewerCreate(MPI_Comm comm, PetscViewer *inviewer)
 {
@@ -379,13 +380,13 @@ PetscErrorCode PetscViewerCreate(MPI_Comm comm, PetscViewer *inviewer)
   PetscCall(PetscHeaderCreate(viewer, PETSC_VIEWER_CLASSID, "PetscViewer", "PetscViewer", "Viewer", comm, PetscViewerDestroy, PetscViewerView));
   *inviewer    = viewer;
   viewer->data = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscViewerSetType - Builds `PetscViewer` for a particular implementation.
 
-   Collective on viewer
+   Collective
 
    Input Parameters:
 +  viewer      - the `PetscViewer` context obtained with `PetscViewerCreate()`
@@ -397,10 +398,9 @@ PetscErrorCode PetscViewerCreate(MPI_Comm comm, PetscViewer *inviewer)
    Level: advanced
 
    Note:
-   See "include/petscviewer.h" for available methods (for instance,
-   `PETSCVIEWERSOCKET`)
+   See `PetscViewerType` for possible values
 
-.seealso: `PetscViewer`, `PetscViewerCreate()`, `PetscViewerGetType()`, `PetscViewerType`, `PetscViewerPushFormat()`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerCreate()`, `PetscViewerGetType()`, `PetscViewerType`, `PetscViewerPushFormat()`
 @*/
 PetscErrorCode PetscViewerSetType(PetscViewer viewer, PetscViewerType type)
 {
@@ -411,7 +411,7 @@ PetscErrorCode PetscViewerSetType(PetscViewer viewer, PetscViewerType type)
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 1);
   PetscValidCharPointer(type, 2);
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, type, &match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* cleanup any old type that may be there */
   PetscTryTypeMethod(viewer, destroy);
@@ -425,7 +425,7 @@ PetscErrorCode PetscViewerSetType(PetscViewer viewer, PetscViewerType type)
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)viewer, type));
   PetscCall((*r)(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -434,8 +434,8 @@ PetscErrorCode PetscViewerSetType(PetscViewer viewer, PetscViewerType type)
    Not Collective
 
    Input Parameters:
-+  name_solver - name of a new user-defined viewer
--  routine_create - routine to create method context
++  sname - name of a new user-defined viewer
+-  function - routine to create method context
 
    Level: developer
 
@@ -452,20 +452,20 @@ $     PetscViewerSetType(viewer,"my_viewer_type")
    or at runtime via the option
 $     -viewer_type my_viewer_type
 
-.seealso: `PetscViewerRegisterAll()`
+.seealso: [](sec_viewers), `PetscViewerRegisterAll()`
  @*/
 PetscErrorCode PetscViewerRegister(const char *sname, PetscErrorCode (*function)(PetscViewer))
 {
   PetscFunctionBegin;
   PetscCall(PetscViewerInitializePackage());
   PetscCall(PetscFunctionListAdd(&PetscViewerList, sname, function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PetscViewerSetFromOptions - Sets various options for a viewer from the options database.
+   PetscViewerSetFromOptions - Sets various options for a viewer based on values in the options database.
 
-   Collective on viewer
+   Collective
 
    Input Parameter:
 .     viewer - the viewer context
@@ -473,9 +473,9 @@ PetscErrorCode PetscViewerRegister(const char *sname, PetscErrorCode (*function)
    Level: intermediate
 
    Note:
-    Must be called after PetscViewerCreate() before the PetscViewer is used.
+    Must be called after `PetscViewerCreate()` before the `PetscViewer` is used.
 
-.seealso: `PetscViewer`, `PetscViewerCreate()`, `PetscViewerSetType()`, `PetscViewerType`
+.seealso: [](sec_viewers), `PetscViewer`, `PetscViewerCreate()`, `PetscViewerSetType()`, `PetscViewerType`
 @*/
 PetscErrorCode PetscViewerSetFromOptions(PetscViewer viewer)
 {
@@ -497,7 +497,7 @@ PetscErrorCode PetscViewerSetFromOptions(PetscViewer viewer)
   PetscCall(PetscObjectProcessOptionsHandlers((PetscObject)viewer, PetscOptionsObject));
   PetscCall(PetscViewerViewFromOptions(viewer, NULL, "-viewer_view"));
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerFlowControlStart(PetscViewer viewer, PetscInt *mcnt, PetscInt *cnt)
@@ -505,7 +505,7 @@ PetscErrorCode PetscViewerFlowControlStart(PetscViewer viewer, PetscInt *mcnt, P
   PetscFunctionBegin;
   PetscCall(PetscViewerBinaryGetFlowControl(viewer, mcnt));
   PetscCall(PetscViewerBinaryGetFlowControl(viewer, cnt));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerFlowControlStepMain(PetscViewer viewer, PetscInt i, PetscInt *mcnt, PetscInt cnt)
@@ -518,7 +518,7 @@ PetscErrorCode PetscViewerFlowControlStepMain(PetscViewer viewer, PetscInt i, Pe
     *mcnt += cnt;
     PetscCallMPI(MPI_Bcast(mcnt, 1, MPIU_INT, 0, comm));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerFlowControlEndMain(PetscViewer viewer, PetscInt *mcnt)
@@ -528,7 +528,7 @@ PetscErrorCode PetscViewerFlowControlEndMain(PetscViewer viewer, PetscInt *mcnt)
   PetscCall(PetscObjectGetComm((PetscObject)viewer, &comm));
   *mcnt = 0;
   PetscCallMPI(MPI_Bcast(mcnt, 1, MPIU_INT, 0, comm));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerFlowControlStepWorker(PetscViewer viewer, PetscMPIInt rank, PetscInt *mcnt)
@@ -540,7 +540,7 @@ PetscErrorCode PetscViewerFlowControlStepWorker(PetscViewer viewer, PetscMPIInt
     if (rank < *mcnt) break;
     PetscCallMPI(MPI_Bcast(mcnt, 1, MPIU_INT, 0, comm));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscViewerFlowControlEndWorker(PetscViewer viewer, PetscInt *mcnt)
@@ -552,5 +552,5 @@ PetscErrorCode PetscViewerFlowControlEndWorker(PetscViewer viewer, PetscInt *mcn
     PetscCallMPI(MPI_Bcast(mcnt, 1, MPIU_INT, 0, comm));
     if (!*mcnt) break;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
