@@ -19,10 +19,10 @@ PetscErrorCode PetscDLLibraryPrintPath(PetscDLLibrary libs)
 {
   PetscFunctionBegin;
   while (libs) {
-    PetscErrorPrintf("  %s\n", libs->libname);
+    PetscCall(PetscErrorPrintf("  %s\n", libs->libname));
     libs = libs->next;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -50,8 +50,8 @@ PetscErrorCode PetscDLLibraryPrintPath(PetscDLLibrary libs)
 @*/
 PetscErrorCode PetscDLLibraryRetrieve(MPI_Comm comm, const char libname[], char *lname, size_t llen, PetscBool *found)
 {
-  char  *buf, *par2, suffix[16], *gz, *so;
-  size_t len;
+  char  *buf, *par2, *gz = NULL, *so = NULL;
+  size_t len, blen;
 
   PetscFunctionBegin;
   /*
@@ -59,10 +59,10 @@ PetscErrorCode PetscDLLibraryRetrieve(MPI_Comm comm, const char libname[], char
      so we can add to the end of it to look for something like .so.1.0 etc.
   */
   PetscCall(PetscStrlen(libname, &len));
-  len = PetscMax(4 * len, PETSC_MAX_PATH_LEN);
-  PetscCall(PetscMalloc1(len, &buf));
+  blen = PetscMax(4 * len, PETSC_MAX_PATH_LEN);
+  PetscCall(PetscMalloc1(blen, &buf));
   par2 = buf;
-  PetscCall(PetscStrreplace(comm, libname, par2, len));
+  PetscCall(PetscStrreplace(comm, libname, par2, blen));
 
   /* temporarily remove .gz if it ends library name */
   PetscCall(PetscStrrstr(par2, ".gz", &gz));
@@ -77,22 +77,22 @@ PetscErrorCode PetscDLLibraryRetrieve(MPI_Comm comm, const char libname[], char
 
   PetscCall(PetscFileRetrieve(comm, par2, lname, llen, found));
   if (!(*found)) {
+    const char suffix[] = "." PETSC_SLSUFFIX;
+
     /* see if library name does already not have suffix attached */
-    PetscCall(PetscStrncpy(suffix, ".", sizeof(suffix)));
-    PetscCall(PetscStrlcat(suffix, PETSC_SLSUFFIX, sizeof(suffix)));
     PetscCall(PetscStrrstr(par2, suffix, &so));
     /* and attach the suffix if it is not there */
-    if (!so) PetscCall(PetscStrcat(par2, suffix));
+    if (!so) PetscCall(PetscStrlcat(par2, suffix, blen));
 
     /* restore the .gz suffix if it was there */
-    if (gz) PetscCall(PetscStrcat(par2, ".gz"));
+    if (gz) PetscCall(PetscStrlcat(par2, ".gz", blen));
 
     /* and finally retrieve the file */
     PetscCall(PetscFileRetrieve(comm, par2, lname, llen, found));
   }
 
   PetscCall(PetscFree(buf));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -123,7 +123,8 @@ PetscErrorCode PetscDLLibraryRetrieve(MPI_Comm comm, const char libname[], char
 PetscErrorCode PetscDLLibraryOpen(MPI_Comm comm, const char path[], PetscDLLibrary *entry)
 {
   PetscBool     foundlibrary, match;
-  char          libname[PETSC_MAX_PATH_LEN], par2[PETSC_MAX_PATH_LEN], suffix[16], *s;
+  const char    suffix[] = "." PETSC_SLSUFFIX;
+  char          libname[PETSC_MAX_PATH_LEN], par2[PETSC_MAX_PATH_LEN], *s;
   char         *basename, registername[128];
   PetscDLHandle handle;
   PetscErrorCode (*func)(void) = NULL;
@@ -146,9 +147,7 @@ PetscErrorCode PetscDLLibraryOpen(MPI_Comm comm, const char path[], PetscDLLibra
 #endif
 
   /* copy path and setup shared library suffix  */
-  PetscCall(PetscStrncpy(libname, path, PETSC_MAX_PATH_LEN));
-  PetscCall(PetscStrncpy(suffix, ".", sizeof(suffix)));
-  PetscCall(PetscStrlcat(suffix, PETSC_SLSUFFIX, sizeof(suffix)));
+  PetscCall(PetscStrncpy(libname, path, sizeof(libname)));
   /* remove wrong suffixes from libname */
   PetscCall(PetscStrrstr(libname, ".gz", &s));
   if (s && s[3] == 0) s[0] = 0;
@@ -183,8 +182,8 @@ PetscErrorCode PetscDLLibraryOpen(MPI_Comm comm, const char path[], PetscDLLibra
   PetscCall(PetscNew(entry));
   (*entry)->next   = NULL;
   (*entry)->handle = handle;
-  PetscCall(PetscStrcpy((*entry)->libname, libname));
-  PetscFunctionReturn(0);
+  PetscCall(PetscStrncpy((*entry)->libname, libname, sizeof((*entry)->libname)));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -212,8 +211,9 @@ PetscErrorCode PetscDLLibraryOpen(MPI_Comm comm, const char path[], PetscDLLibra
 @*/
 PetscErrorCode PetscDLLibrarySym(MPI_Comm comm, PetscDLLibrary *outlist, const char path[], const char insymbol[], void **value)
 {
-  char           libname[PETSC_MAX_PATH_LEN], suffix[16], *symbol, *s;
-  PetscDLLibrary nlist, prev, list = NULL;
+  char           libname[PETSC_MAX_PATH_LEN], suffix[16];
+  char          *symbol = NULL, *s = NULL;
+  PetscDLLibrary list = NULL, nlist, prev;
 
   PetscFunctionBegin;
   if (outlist) PetscValidPointer(outlist, 2);
@@ -286,11 +286,11 @@ PetscErrorCode PetscDLLibrarySym(MPI_Comm comm, PetscDLLibrary *outlist, const c
   }
 
   if (symbol != insymbol) PetscCall(PetscFree(symbol));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-     PetscDLLibraryAppend - Appends another dynamic link library to the seach list, to the end
+     PetscDLLibraryAppend - Appends another dynamic link library to the search list, to the end
                 of the search path.
 
      Collective
@@ -318,7 +318,7 @@ PetscErrorCode PetscDLLibraryAppend(MPI_Comm comm, PetscDLLibrary *outlist, cons
   size_t         len;
   PetscBool      match, dir;
   char           program[PETSC_MAX_PATH_LEN], found[8 * PETSC_MAX_PATH_LEN];
-  char          *libname, suffix[16], *s;
+  char          *libname, suffix[16], *s = NULL;
   PetscToken     token;
 
   PetscFunctionBegin;
@@ -338,7 +338,7 @@ PetscErrorCode PetscDLLibraryAppend(MPI_Comm comm, PetscDLLibrary *outlist, cons
     PetscCall(PetscStrlcat(program, PETSC_SLSUFFIX, sizeof(program)));
 
     PetscCall(PetscLs(comm, program, found, 8 * PETSC_MAX_PATH_LEN, &dir));
-    if (!dir) PetscFunctionReturn(0);
+    if (!dir) PetscFunctionReturn(PETSC_SUCCESS);
   } else {
     PetscCall(PetscStrncpy(found, path, PETSC_MAX_PATH_LEN));
   }
@@ -372,7 +372,7 @@ PetscErrorCode PetscDLLibraryAppend(MPI_Comm comm, PetscDLLibrary *outlist, cons
     PetscCall(PetscTokenFind(token, &libname));
   }
   PetscCall(PetscTokenDestroy(&token));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -400,7 +400,7 @@ PetscErrorCode PetscDLLibraryPrepend(MPI_Comm comm, PetscDLLibrary *outlist, con
   size_t         len;
   PetscBool      match, dir;
   char           program[PETSC_MAX_PATH_LEN], found[8 * PETSC_MAX_PATH_LEN];
-  char          *libname, suffix[16], *s;
+  char          *libname, suffix[16], *s = NULL;
   PetscToken     token;
 
   PetscFunctionBegin;
@@ -420,7 +420,7 @@ PetscErrorCode PetscDLLibraryPrepend(MPI_Comm comm, PetscDLLibrary *outlist, con
     PetscCall(PetscStrlcat(program, PETSC_SLSUFFIX, sizeof(program)));
 
     PetscCall(PetscLs(comm, program, found, 8 * PETSC_MAX_PATH_LEN, &dir));
-    if (!dir) PetscFunctionReturn(0);
+    if (!dir) PetscFunctionReturn(PETSC_SUCCESS);
   } else {
     PetscCall(PetscStrncpy(found, path, PETSC_MAX_PATH_LEN));
   }
@@ -462,13 +462,13 @@ PetscErrorCode PetscDLLibraryPrepend(MPI_Comm comm, PetscDLLibrary *outlist, con
     PetscCall(PetscTokenFind(token, &libname));
   }
   PetscCall(PetscTokenDestroy(&token));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
      PetscDLLibraryClose - Destroys the search path of dynamic libraries and closes the libraries.
 
-    Collective on list
+    Collective
 
     Input Parameter:
 .     head - library list
@@ -482,7 +482,7 @@ PetscErrorCode PetscDLLibraryClose(PetscDLLibrary list)
   PetscDLLibrary prev, tail;
 
   PetscFunctionBegin;
-  if (!list) PetscFunctionReturn(0);
+  if (!list) PetscFunctionReturn(PETSC_SUCCESS);
   /* traverse the list in reverse order */
   while (!done) {
     if (!list->next) done = PETSC_TRUE;
@@ -497,5 +497,5 @@ PetscErrorCode PetscDLLibraryClose(PetscDLLibrary list)
     PetscCall(PetscDLClose(&tail->handle));
     PetscCall(PetscFree(tail));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
