@@ -20,7 +20,7 @@ PetscBool        petscindebugger     = PETSC_FALSE;
 /*@C
    PetscSetDebugTerminal - Sets the terminal to use for debugging.
 
-   Not Collective
+   Not Collective; No Fortran Support
 
    Input Parameter:
 .  terminal - name of terminal and any flags required to execute a program.
@@ -41,9 +41,6 @@ PetscBool        petscindebugger     = PETSC_FALSE;
 
    The default on Apple is Terminal, on other systems the default is xterm
 
-   Fortran Note:
-   This routine is not supported in Fortran.
-
 .seealso: `PetscSetDebugger()`
 @*/
 PetscErrorCode PetscSetDebugTerminal(const char terminal[])
@@ -54,13 +51,13 @@ PetscErrorCode PetscSetDebugTerminal(const char terminal[])
   PetscCall(PetscStrncpy(DebugTerminal, terminal, sizeof(DebugTerminal)));
   PetscCall(PetscStrcmp(terminal, "xterm", &xterm));
   if (xterm) PetscCall(PetscStrlcat(DebugTerminal, " -e", sizeof(DebugTerminal)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscSetDebugger - Sets options associated with the debugger.
 
-   Not Collective
+   Not Collective; No Fortran Support
 
    Input Parameters:
 +  debugger - name of debugger, which should be in your path,
@@ -74,9 +71,6 @@ PetscErrorCode PetscSetDebugTerminal(const char terminal[])
 
    Level: developer
 
-   Fortran Note:
-   This routine is not supported in Fortran.
-
 .seealso: `PetscAttachDebugger()`, `PetscAttachDebuggerErrorHandler()`, `PetscSetDebugTerminal()`
 @*/
 PetscErrorCode PetscSetDebugger(const char debugger[], PetscBool usedebugterminal)
@@ -84,13 +78,13 @@ PetscErrorCode PetscSetDebugger(const char debugger[], PetscBool usedebugtermina
   PetscFunctionBegin;
   if (debugger) PetscCall(PetscStrncpy(PetscDebugger, debugger, sizeof(PetscDebugger)));
   if (UseDebugTerminal) UseDebugTerminal = usedebugterminal;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscSetDefaultDebugger - Causes PETSc to use its default debugger and output terminal
 
-   Not collective
+   Not Collective
 
     Level: developer
 
@@ -107,29 +101,30 @@ PetscErrorCode PetscSetDefaultDebugger(void)
 #else
   PetscCall(PetscSetDebugTerminal("xterm"));
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PetscCheckDebugger_Private(const char defaultDbg[], const char string[], const char *debugger[])
 {
-  PetscBool exists;
-  char     *f;
+  char *f = NULL;
 
   PetscFunctionBegin;
   PetscCall(PetscStrstr(string, defaultDbg, &f));
   if (f) {
+    PetscBool exists;
+
     PetscCall(PetscTestFile(string, 'x', &exists));
     if (exists) *debugger = string;
     else *debugger = defaultDbg;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscSetDebuggerFromString - Set the complete path for the
        debugger for PETSc to use.
 
-   Not collective
+   Not Collective
 
    Level: developer
 
@@ -139,7 +134,7 @@ PetscErrorCode PetscSetDebuggerFromString(const char *string)
 {
   const char *debugger    = NULL;
   PetscBool   useterminal = PETSC_TRUE;
-  char       *f;
+  char       *f           = NULL;
 
   PetscFunctionBegin;
   PetscCall(PetscStrstr(string, "noxterm", &f));
@@ -163,7 +158,7 @@ PetscErrorCode PetscSetDebuggerFromString(const char *string)
   PetscCall(PetscCheckDebugger_Private("pathdb", string, &debugger));
   PetscCall(PetscCheckDebugger_Private("lldb", string, &debugger));
   PetscCall(PetscSetDebugger(debugger, useterminal));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -183,7 +178,7 @@ PetscErrorCode PetscSetDebuggerFromString(const char *string)
 PetscErrorCode PetscWaitOnError(void)
 {
   petscwaitonerrorflg = PETSC_TRUE;
-  return 0;
+  return PETSC_SUCCESS;
 }
 
 /*@
@@ -204,6 +199,7 @@ PetscErrorCode PetscWaitOnError(void)
 @*/
 PetscErrorCode PetscAttachDebugger(void)
 {
+  PetscErrorCode PETSC_UNUSED ierr;
 #if !defined(PETSC_CANNOT_START_DEBUGGER) && defined(PETSC_HAVE_FORK)
   int       child     = 0;
   PetscReal sleeptime = 0;
@@ -211,26 +207,26 @@ PetscErrorCode PetscAttachDebugger(void)
 #endif
 
 #if defined(PETSC_CANNOT_START_DEBUGGER) || !defined(PETSC_HAVE_FORK)
-  (*PetscErrorPrintf)("System cannot start debugger\n");
-  (*PetscErrorPrintf)("On Cray run program in Totalview debugger\n");
-  (*PetscErrorPrintf)("On Windows use Developer Studio(MSDEV)\n");
+  ierr = (*PetscErrorPrintf)("System cannot start debugger\n");
+  ierr = (*PetscErrorPrintf)("On Cray run program in Totalview debugger\n");
+  ierr = (*PetscErrorPrintf)("On Windows use Developer Studio(MSDEV)\n");
   PETSCABORT(PETSC_COMM_WORLD, PETSC_ERR_SUP_SYS);
 #else
   if (PetscUnlikely(PetscGetDisplay(display, sizeof(display)))) {
-    (*PetscErrorPrintf)("Cannot determine display\n");
+    ierr = (*PetscErrorPrintf)("Cannot determine display\n");
     return PETSC_ERR_SYS;
   }
   if (PetscUnlikely(PetscGetProgramName(program, sizeof(program)))) {
-    (*PetscErrorPrintf)("Cannot determine program name needed to attach debugger\n");
+    ierr = (*PetscErrorPrintf)("Cannot determine program name needed to attach debugger\n");
     return PETSC_ERR_SYS;
   }
   if (PetscUnlikely(!program[0])) {
-    (*PetscErrorPrintf)("Cannot determine program name needed to attach debugger\n");
+    ierr = (*PetscErrorPrintf)("Cannot determine program name needed to attach debugger\n");
     return PETSC_ERR_SYS;
   }
   child = (int)fork();
   if (PetscUnlikely(child < 0)) {
-    (*PetscErrorPrintf)("Error in fork() prior to attaching debugger\n");
+    ierr = (*PetscErrorPrintf)("Error in fork() prior to attaching debugger\n");
     return PETSC_ERR_SYS;
   }
   petscindebugger = PETSC_TRUE;
@@ -257,7 +253,7 @@ PetscErrorCode PetscAttachDebugger(void)
   #if defined(PETSC_NEED_KILL_FOR_DEBUGGER)
     kill(child, SIGCONT);
   #endif
-    sprintf(pid, "%d", child);
+    PetscCall(PetscSNPrintf(pid, PETSC_STATIC_ARRAY_LENGTH(pid), "%d", child));
 
     PetscCall(PetscStrcmp(PetscDebugger, "xxgdb", &isxxgdb));
     PetscCall(PetscStrcmp(PetscDebugger, "ddd", &isddd));
@@ -327,7 +323,7 @@ PetscErrorCode PetscAttachDebugger(void)
       j = 0;
       if (UseDebugTerminal) {
         PetscBool cmp;
-        char     *tmp, *tmp1;
+        char     *tmp, *tmp1 = NULL;
         PetscCall(PetscStrncmp(DebugTerminal, "Terminal", 8, &cmp));
         if (cmp) {
           char command[1024];
@@ -337,7 +333,11 @@ PetscErrorCode PetscAttachDebugger(void)
             PetscCall(PetscGetFullPath(program, fullprogram, sizeof(fullprogram)));
             PetscCall(PetscSNPrintf(command, sizeof(command), "osascript -e 'tell app \"Terminal\" to do script \"%s  %s %s \"'\n", PetscDebugger, fullprogram, pid));
           }
+  #if defined(PETSC_HAVE_POPEN)
           PetscCall(PetscPOpen(PETSC_COMM_SELF, NULL, command, "r", NULL));
+  #else
+          printf("-debug_terminal Terminal is not available on this system since PETSC_HAVE_POPEN is not defined in this configuration\n");
+  #endif
           exit(0);
         }
 
@@ -441,11 +441,11 @@ PetscErrorCode PetscAttachDebugger(void)
       while (left > 0) left = PetscSleep(left) - 1;
     }
   #else
-    PetscSleep(sleeptime);
+    PetscCall(PetscSleep(sleeptime));
   #endif
   }
 #endif
-  return 0;
+  return PETSC_SUCCESS;
 }
 
 /*@C
@@ -482,10 +482,12 @@ $     SETERRQ(PETSC_COMM_SELF,number,p,message)
    Notes for experienced users:
    Use `PetscPushErrorHandler()` to set the desired error handler.  The
    currently available PETSc error handlers are
-$    PetscTraceBackErrorHandler()
-$    PetscAttachDebuggerErrorHandler()
-$    PetscAbortErrorHandler()
-   or you may write your own.
+.vb
+    PetscTraceBackErrorHandler()
+    PetscAttachDebuggerErrorHandler()
+    PetscAbortErrorHandler()
+.ve
+  or you may write your own.
 
    Developer Note:
      This routine calls abort instead of returning because if it returned then `MPI_Abort()` would get called which can generate an exception
@@ -496,14 +498,16 @@ $    PetscAbortErrorHandler()
 @*/
 PetscErrorCode PetscAttachDebuggerErrorHandler(MPI_Comm comm, int line, const char *fun, const char *file, PetscErrorCode num, PetscErrorType p, const char *mess, void *ctx)
 {
+  PetscErrorCode ierr;
   if (!mess) mess = " ";
 
-  if (fun) (*PetscErrorPrintf)("%s() at %s:%d %s\n", fun, file, line, mess);
-  else (*PetscErrorPrintf)("%s:%d %s\n", file, line, mess);
+  if (fun) ierr = (*PetscErrorPrintf)("%s() at %s:%d %s\n", fun, file, line, mess);
+  else ierr = (*PetscErrorPrintf)("%s:%d %s\n", file, line, mess);
 
-  PetscAttachDebugger();
+  ierr = PetscAttachDebugger();
+  (void)ierr;
   abort(); /* call abort because don't want to kill other MPI ranks that may successfully attach to debugger */
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -539,24 +543,23 @@ PetscErrorCode PetscStopForDebugger(void)
 
   PetscFunctionBegin;
 #if defined(PETSC_CANNOT_START_DEBUGGER)
-  (*PetscErrorPrintf)("System cannot start debugger; just continuing program\n");
+  PetscCall((*PetscErrorPrintf)("System cannot start debugger; just continuing program\n"));
 #else
-  ierr = MPI_Comm_rank(PETSC_COMM_WORLD, &rank);
-  if (ierr) rank = 0; /* ignore error since this may be already in error handler */
+  if (MPI_Comm_rank(PETSC_COMM_WORLD, &rank)) rank = 0; /* ignore error since this may be already in error handler */
   ierr = PetscGetHostName(hostname, sizeof(hostname));
   if (ierr) {
-    (*PetscErrorPrintf)("Cannot determine hostname; just continuing program\n");
-    PetscFunctionReturn(0);
+    PetscCall((*PetscErrorPrintf)("Cannot determine hostname; just continuing program\n"));
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   ierr = PetscGetProgramName(program, sizeof(program));
   if (ierr) {
-    (*PetscErrorPrintf)("Cannot determine program name; just continuing program\n");
-    PetscFunctionReturn(0);
+    PetscCall((*PetscErrorPrintf)("Cannot determine program name; just continuing program\n"));
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if (!program[0]) {
-    (*PetscErrorPrintf)("Cannot determine program name; just continuing program\n");
-    PetscFunctionReturn(0);
+    PetscCall((*PetscErrorPrintf)("Cannot determine program name; just continuing program\n"));
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   ppid = getpid();
@@ -590,14 +593,15 @@ PetscErrorCode PetscStopForDebugger(void)
 
   fflush(stdout); /* ignore error because may already be in error handler */
 
-  sleeptime = 25;                                                      /* default to sleep waiting for debugger */
-  PetscOptionsGetInt(NULL, NULL, "-debugger_pause", &sleeptime, NULL); /* ignore error because may already be in error handler */
+  sleeptime = 25;                                                                         /* default to sleep waiting for debugger */
+  PetscCallContinue(PetscOptionsGetInt(NULL, NULL, "-debugger_pause", &sleeptime, NULL)); /* ignore error because may already be in error handler */
   if (sleeptime < 0) sleeptime = -sleeptime;
 #if defined(PETSC_NEED_DEBUGGER_NO_SLEEP)
   /*
       HP cannot attach process to sleeping debugger, hence count instead
   */
   {
+    // this *will* get optimized away by any compiler known to man
     PetscReal x = 1.0;
     int       i = 10000000;
     while (i--) x++; /* cannot attach to sleeper */
@@ -611,7 +615,7 @@ PetscErrorCode PetscStopForDebugger(void)
     while (left > 0) left = sleep(left) - 1;
   }
 #else
-  PetscSleep(sleeptime);
+  PetscCall(PetscSleep(sleeptime));
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
