@@ -55,7 +55,8 @@ PetscErrorCode PetscEmacsClientErrorHandler(MPI_Comm comm, int line, const char
 
   ierr = PetscGetPetscDir(&pdir);
   if (ierr) return ierr;
-  sprintf(command, "cd %s; emacsclient --no-wait +%d %s\n", pdir, line, file);
+  ierr = PetscSNPrintf(command, PETSC_STATIC_ARRAY_LENGTH(command), "cd %s; emacsclient --no-wait +%d %s\n", pdir, line, file);
+  if (ierr) return ierr;
 #if defined(PETSC_HAVE_POPEN)
   ierr = PetscPOpen(MPI_COMM_WORLD, (char *)ctx, command, "r", &fp);
   if (ierr) return ierr;
@@ -73,7 +74,7 @@ PetscErrorCode PetscEmacsClientErrorHandler(MPI_Comm comm, int line, const char
     ierr = (*eh->handler)(comm, line, fun, file, n, p, mess, eh->ctx);
     if (ierr) return ierr;
   }
-  return 0;
+  return PETSC_SUCCESS;
 }
 
 /*@C
@@ -86,14 +87,13 @@ PetscErrorCode PetscEmacsClientErrorHandler(MPI_Comm comm, int line, const char
 -  ctx - optional handler context that contains information needed by the handler (for
          example file pointers for error messages etc.)
 
-   Calling sequence of handler:
-$    int handler(MPI_Comm comm,int line,char *func,char *file,PetscErrorCode n,int p,char *mess,void *ctx);
-
+   Calling sequence of `handler`:
+$  PetscErrorCode handler(MPI_Comm comm, int line, char *func, char *file, PetscErrorCode n, int p, char *mess, void *ctx);
 +  comm - communicator over which error occurred
 .  line - the line number of the error (indicated by __LINE__)
 .  file - the file in which the error was detected (indicated by __FILE__)
 .  n - the generic error number (see list defined in include/petscerror.h)
-.  p - PETSC_ERROR_INITIAL if error just detected, otherwise PETSC_ERROR_REPEAT
+.  p - `PETSC_ERROR_INITIAL` if error just detected, otherwise `PETSC_ERROR_REPEAT`
 .  mess - an error text string, usually just printed to the screen
 -  ctx - the error handler context
 
@@ -108,7 +108,7 @@ $    int handler(MPI_Comm comm,int line,char *func,char *file,PetscErrorCode n,i
    `PetscAttachDebuggerErrorHandler()`, `PetscAbortErrorHandler()`, and `PetscMPIAbortErrorHandler()`, `PetscReturnErrorHandler()`.
 
    Fortran Note:
-    You can only push one error handler from Fortran before poping it.
+    You can only push one error handler from Fortran before popping it.
 
 .seealso: `PetscPopErrorHandler()`, `PetscAttachDebuggerErrorHandler()`, `PetscAbortErrorHandler()`, `PetscTraceBackErrorHandler()`, `PetscPushSignalHandler()`
 @*/
@@ -123,7 +123,7 @@ PetscErrorCode PetscPushErrorHandler(PetscErrorCode (*handler)(MPI_Comm comm, in
   neweh->handler = handler;
   neweh->ctx     = ctx;
   eh             = neweh;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -141,11 +141,11 @@ PetscErrorCode PetscPopErrorHandler(void)
   EH tmp;
 
   PetscFunctionBegin;
-  if (!eh) PetscFunctionReturn(0);
+  if (!eh) PetscFunctionReturn(PETSC_SUCCESS);
   tmp = eh;
   eh  = eh->previous;
   PetscCall(PetscFree(tmp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -235,35 +235,51 @@ static const char *PetscErrorStrings[] = {
   /*99 */ "PetscError() incorrectly returned an error code of 0"};
 
 /*@C
-   PetscErrorMessage - returns the text string associated with a PETSc error code.
+  PetscErrorMessage - Returns the text string associated with a PETSc error code.
 
-   Not Collective
+  Not Collective
 
-   Input Parameter:
-.   errnum - the error code
+  Input Parameter:
+. errnum - the error code
 
-   Output Parameters:
-+  text - the error message (NULL if not desired)
--  specific - the specific error message that was set with `SETERRQ()` or `PetscError()`.  (NULL if not desired)
+  Output Parameters:
++ text - the error message (`NULL` if not desired)
+- specific - the specific error message that was set with `SETERRQ()` or
+             `PetscError()`. (`NULL` if not desired)
 
-   Level: developer
+  Level: developer
 
-.seealso: `PetscPushErrorHandler()`, `PetscAttachDebuggerErrorHandler()`, `PetscError()`, `SETERRQ()`, `PetscCall()`
-          `PetscAbortErrorHandler()`, `PetscTraceBackErrorHandler()`
- @*/
-PetscErrorCode PetscErrorMessage(int errnum, const char *text[], char **specific)
+.seealso: `PetscErrorCode`, `PetscPushErrorHandler()`, `PetscAttachDebuggerErrorHandler()`,
+`PetscError()`, `SETERRQ()`, `PetscCall()` `PetscAbortErrorHandler()`,
+`PetscTraceBackErrorHandler()`
+@*/
+PetscErrorCode PetscErrorMessage(PetscErrorCode errnum, const char *text[], char **specific)
 {
-  size_t len;
-
   PetscFunctionBegin;
-  if (text && errnum > PETSC_ERR_MIN_VALUE && errnum < PETSC_ERR_MAX_VALUE) {
-    *text = PetscErrorStrings[errnum - PETSC_ERR_MIN_VALUE - 1];
-    PetscCall(PetscStrlen(*text, &len));
-    if (!len) *text = NULL;
-  } else if (text) *text = NULL;
+  if (text) {
+    if (errnum > PETSC_ERR_MIN_VALUE && errnum < PETSC_ERR_MAX_VALUE) {
+      size_t len;
 
+      *text = PetscErrorStrings[errnum - PETSC_ERR_MIN_VALUE - 1];
+      PetscCall(PetscStrlen(*text, &len));
+      if (!len) *text = NULL;
+    } else if (errnum == PETSC_ERR_BOOLEAN_MACRO_FAILURE) {
+      /* this "error code" arises from failures in boolean macros, where the || operator is
+         used to short-circuit the macro call in case of error. This has the side effect of
+         "returning" either 0 (PETSC_SUCCESS) or 1 (PETSC_ERR_UNKNONWN):
+
+         #define PETSC_FOO(x) ((PetscErrorCode)(PetscBar(x) || PetscBaz(x)))
+
+         If PetscBar() fails (returns nonzero) PetscBaz() is not executed but the result of
+         this expression is boolean false, hence PETSC_ERR_UNNOWN
+       */
+      *text = "Error occurred in boolean shortcuit in macro";
+    } else {
+      *text = NULL;
+    }
+  }
   if (specific) *specific = PetscErrorBaseMessage;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_CLANGUAGE_CXX)
@@ -362,28 +378,28 @@ PetscErrorCode PetscError(MPI_Comm comm, int line, const char *func, const char
   /* Compose the message evaluating the print format */
   if (mess) {
     va_start(Argp, mess);
-    PetscVSNPrintf(buf, 2048, mess, &fullLength, Argp);
+    ierr = PetscVSNPrintf(buf, 2048, mess, &fullLength, Argp);
     va_end(Argp);
     lbuf = buf;
-    if (p == PETSC_ERROR_INITIAL) PetscStrncpy(PetscErrorBaseMessage, lbuf, 1023);
+    if (p == PETSC_ERROR_INITIAL) ierr = PetscStrncpy(PetscErrorBaseMessage, lbuf, sizeof(PetscErrorBaseMessage));
   }
 
-  if (p == PETSC_ERROR_INITIAL && n != PETSC_ERR_MEMC) PetscMallocValidate(__LINE__, PETSC_FUNCTION_NAME, __FILE__);
+  if (p == PETSC_ERROR_INITIAL && n != PETSC_ERR_MEMC) ierr = PetscMallocValidate(__LINE__, PETSC_FUNCTION_NAME, __FILE__);
 
   if (!eh) ierr = PetscTraceBackErrorHandler(comm, line, func, file, n, p, lbuf, NULL);
   else ierr = (*eh->handler)(comm, line, func, file, n, p, lbuf, eh->ctx);
   PetscStackClearTop;
 
   /*
-      If this is called from the main() routine we call MPI_Abort() instead of
-    return to allow the parallel program to be properly shutdown.
-
-    Does not call PETSCABORT() since that would provide the wrong source file and line number information
+      If this is called from the main() routine we abort the program.
+      We cannot just return because them some MPI processes may continue to attempt to run
+      while this process simply exits.
   */
   if (func) {
-    PetscStrncmp(func, "main", 4, &ismain);
+    PetscErrorCode cmp_ierr = PetscStrncmp(func, "main", 4, &ismain);
     if (ismain) {
-      if (petscwaitonerrorflg) PetscSleep(1000);
+      if (petscwaitonerrorflg) cmp_ierr = PetscSleep(1000);
+      (void)cmp_ierr;
       PETSCABORT(comm, ierr);
     }
   }
@@ -398,7 +414,7 @@ PetscErrorCode PetscError(MPI_Comm comm, int line, const char *func, const char
 /*@C
     PetscIntView - Prints an array of integers; useful for debugging.
 
-    Collective on viewer
+    Collective
 
     Input Parameters:
 +   N - number of integers in array
@@ -489,13 +505,13 @@ PetscErrorCode PetscIntView(PetscInt N, const PetscInt idx[], PetscViewer viewer
     PetscCall(PetscObjectGetName((PetscObject)viewer, &tname));
     SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Cannot handle that PetscViewer of type %s", tname);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscRealView - Prints an array of doubles; useful for debugging.
 
-    Collective on viewer
+    Collective
 
     Input Parameters:
 +   N - number of `PetscReal` in array
@@ -594,13 +610,13 @@ PetscErrorCode PetscRealView(PetscInt N, const PetscReal idx[], PetscViewer view
     PetscCall(PetscObjectGetName((PetscObject)viewer, &tname));
     SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Cannot handle that PetscViewer of type %s", tname);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscScalarView - Prints an array of `PetscScalar`; useful for debugging.
 
-    Collective on viewer
+    Collective
 
     Input Parameters:
 +   N - number of scalars in array
@@ -703,7 +719,7 @@ PetscErrorCode PetscScalarView(PetscInt N, const PetscScalar idx[], PetscViewer
     PetscCall(PetscObjectGetName((PetscObject)viewer, &tname));
     SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP, "Cannot handle that PetscViewer of type %s", tname);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_HAVE_CUDA)
