@@ -4,21 +4,21 @@
 */
 #include <petscsys.h>
 #if defined(PETSC_HAVE_PWD_H)
-#include <pwd.h>
+  #include <pwd.h>
 #endif
 #include <ctype.h>
 #include <sys/stat.h>
 #if defined(PETSC_HAVE_UNISTD_H)
-#include <unistd.h>
+  #include <unistd.h>
 #endif
 #if defined(PETSC_HAVE_SYS_UTSNAME_H)
-#include <sys/utsname.h>
+  #include <sys/utsname.h>
 #endif
 #if defined(PETSC_HAVE_DIRECT_H)
-#include <direct.h>
+  #include <direct.h>
 #endif
 #if defined(PETSC_HAVE_SYS_SYSTEMINFO_H)
-#include <sys/systeminfo.h>
+  #include <sys/systeminfo.h>
 #endif
 
 /*@C
@@ -26,7 +26,7 @@
 
    Not Collective
 
-   Input Parameters:
+   Input Parameter:
 .  len  - maximum length of path
 
    Output Parameter:
@@ -35,19 +35,19 @@
 
    Level: developer
 
+.seealso: `PetscGetTmp()`, `PetscSharedTmp()`, `PetscSharedWorkingDirectory()`, `PetscGetHomeDirectory()`
 @*/
-PetscErrorCode  PetscGetWorkingDirectory(char path[],size_t len)
+PetscErrorCode PetscGetWorkingDirectory(char path[], size_t len)
 {
   PetscFunctionBegin;
 #if defined(PETSC_HAVE_GETCWD)
-  PetscCheckFalse(!getcwd(path,len),PETSC_COMM_SELF,PETSC_ERR_LIB,"getcwd()");
+  PetscCheck(getcwd(path, len), PETSC_COMM_SELF, PETSC_ERR_LIB, "getcwd()");
 #elif defined(PETSC_HAVE__GETCWD)
-  _getcwd(path,len);
+  _getcwd(path, len);
 #elif defined(PETSC_HAVE_GETWD)
   getwd(path);
 #else
-  SETERRQ(PETSC_COMM_SELF,PETSC_ERR_SUP_SYS, "Could not find getcwd() or getwd()");
+  SETERRQ(PETSC_COMM_SELF, PETSC_ERR_SUP_SYS, "Could not find getcwd() or getwd()");
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
-
