@@ -10,34 +10,35 @@
    Not Collective
 
    Input Parameter:
-.  maxlen - maximum lengh allowed
+.  maxlen - maximum length allowed
 
    Output Parameter:
 .  dir - contains the home directory. Must be long enough to hold the name.
 
    Level: developer
 
-   Note:
-   If PETSc cannot determine the home directory it makes dir a null string
+   Notes:
+   If PETSc cannot determine the home directory it makes `dir` an empty string
 
-   On Windows machines the enviornmental variable HOME specifies the home directory.
+   On Microsoft Windows machines the environmental variable `HOME` specifies the home directory.
 
+.seealso: `PetscGetTmp()`, `PetscSharedTmp()`, `PetscGetWorkingDirectory()`
 @*/
-PetscErrorCode  PetscGetHomeDirectory(char dir[],size_t maxlen)
+PetscErrorCode PetscGetHomeDirectory(char dir[], size_t maxlen)
 {
-  const char     *d1;
+  const char *d1;
 
   PetscFunctionBegin;
   d1 = getenv("HOME");
   if (d1) {
-    PetscCall(PetscStrncpy(dir,d1,maxlen));
+    PetscCall(PetscStrncpy(dir, d1, maxlen));
   } else if (maxlen > 0) dir[0] = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscFixFilename - Fixes a file name so that it is correct for both Unix and
-    Windows by using the correct / or \ to separate directories.
+    Microsoft Windows by using the correct / or \ to separate directories.
 
    Not Collective
 
@@ -49,21 +50,21 @@ PetscErrorCode  PetscGetHomeDirectory(char dir[],size_t maxlen)
 
    Level: advanced
 
-   Notes:
-   Call PetscFixFilename() just before calling fopen().
+   Note:
+   Call `PetscFixFilename()` just before calling `fopen()`.
 @*/
-PetscErrorCode  PetscFixFilename(const char filein[],char fileout[])
+PetscErrorCode PetscFixFilename(const char filein[], char fileout[])
 {
-  size_t         i,n;
+  size_t i, n;
 
   PetscFunctionBegin;
-  if (!filein || !fileout) PetscFunctionReturn(0);
+  if (!filein || !fileout) PetscFunctionReturn(PETSC_SUCCESS);
 
-  PetscCall(PetscStrlen(filein,&n));
-  for (i=0; i<n; i++) {
+  PetscCall(PetscStrlen(filein, &n));
+  for (i = 0; i < n; i++) {
     if (filein[i] == PETSC_REPLACE_DIR_SEPARATOR) fileout[i] = PETSC_DIR_SEPARATOR;
     else fileout[i] = filein[i];
   }
   fileout[n] = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
