@@ -1,5 +1,5 @@
 /*
-      Utilites routines to add simple ASCII IO capability.
+      Utilities routines to add simple ASCII IO capability.
 */
 #include <../src/sys/fileio/mprint.h>
 #include <errno.h>
@@ -22,9 +22,9 @@ FILE *PETSC_STDOUT = NULL;
 FILE *PETSC_STDERR = NULL;
 
 /*@C
-     PetscFormatConvertGetSize - Gets the length of a string needed to hold format converted with `PetscFormatConvert()`
+     PetscFormatConvertGetSize - Gets the length of a string needed to hold data converted with `PetscFormatConvert()` based on format
 
-   Deprecated
+   No Fortran Support
 
    Input Parameter:
 .   format - the PETSc format string
@@ -32,7 +32,7 @@ FILE *PETSC_STDERR = NULL;
    Output Parameter:
 .   size - the needed length of the new format
 
- Level: developer
+   Level: developer
 
 .seealso: `PetscFormatConvert()`, `PetscVSNPrintf()`, `PetscVFPrintf()`
 @*/
@@ -72,23 +72,25 @@ PetscErrorCode PetscFormatConvertGetSize(const char *format, size_t *size)
     ++sz;
   }
   *size = sz + 1; /* space for NULL character */
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-     PetscFormatConvert - Takes a PETSc format string and converts the %D to %d for 32 bit PETSc indices and %lld for 64 bit PETSc indices. Also
-                        converts %g to [|%g|] so that PetscVSNPrintf() can easily insure all %g formatted numbers have a decimal point when printed.
+     PetscFormatConvert - converts %g to [|%g|] so that `PetscVSNPrintf()` can ensure all %g formatted numbers have a decimal point when printed. The
+     decimal point is then used by the `petscdiff` script so that differences in floating point number output is ignored in the test harness.
 
-   Deprecated
+   No Fortran Support
 
    Input Parameters:
 +   format - the PETSc format string
 .   newformat - the location to put the new format
 -   size - the length of newformat, you can use `PetscFormatConvertGetSize()` to compute the needed size
 
-    Note: this exists so we can have the same code when `PetscInt` is either int or long long int
+   Level: developer
 
- Level: developer
+    Note:
+    Deprecated usage also converts the %D to %d for 32 bit PETSc indices and %lld for 64 bit PETSc indices. This feature is no
+    longer used in PETSc code instead use %" PetscInt_FMT " in the format string
 
 .seealso: `PetscFormatConvertGetSize()`, `PetscVSNPrintf()`, `PetscVFPrintf()`
 @*/
@@ -137,14 +139,14 @@ PetscErrorCode PetscFormatConvert(const char *format, char *newformat)
     } else newformat[j++] = format[i++];
   }
   newformat[j] = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #define PETSCDEFAULTBUFFERSIZE 8 * 1024
 
 /*@C
-     PetscVSNPrintf - The PETSc version of vsnprintf(). Converts a PETSc format string into a standard C format string and then puts all the
-       function arguments into a string using the format statement.
+     PetscVSNPrintf - The PETSc version of `vsnprintf()`. Ensures that all `%g` formatted arguments' output contains the decimal point (which
+     is used by the test harness)
 
    Input Parameters:
 +   str - location to put result
@@ -152,13 +154,15 @@ PetscErrorCode PetscFormatConvert(const char *format, char *newformat)
 +   format - the PETSc format string
 -   fullLength - the amount of space in str actually used.
 
-    Developer Note:
-    this function may be called from an error handler, if an error occurs when it is called by the error handler than likely
-      a recursion will occur and possible crash.
+   Level: developer
 
- Level: developer
+   Developer Note:
+   This function may be called from an error handler, if an error occurs when it is called by the error handler than likely
+   a recursion will occur resulting in a crash of the program.
 
-.seealso: `PetscVSNPrintf()`, `PetscErrorPrintf()`, `PetscVPrintf()`
+   If the length of the format string `format` is on the order of `PETSCDEFAULTBUFFERSIZE` (8 * 1024 bytes), this function will call `PetscMalloc()`
+
+.seealso: `PetscFormatConvert()`, `PetscFormatConvertGetSize()`, `PetscVSNPrintf()`, `PetscErrorPrintf()`, `PetscVPrintf()`
 @*/
 PetscErrorCode PetscVSNPrintf(char *str, size_t len, const char *format, size_t *fullLength, va_list Argp)
 {
@@ -248,7 +252,40 @@ PetscErrorCode PetscVSNPrintf(char *str, size_t len, const char *format, size_t
   }
 #endif
   if (fullLength) *fullLength = 1 + (size_t)flen;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@C
+  PetscFFlush - Flush a file stream
+
+  Input Parameter:
+. fd - The file stream handle
+
+  Level: intermediate
+
+  Notes:
+  For output streams (and for update streams on which the last operation was output), writes
+  any unwritten data from the stream's buffer to the associated output device.
+
+  For input streams (and for update streams on which the last operation was input), the
+  behavior is undefined.
+
+  If `fd` is `NULL`, all open output streams are flushed, including ones not directly
+  accessible to the program.
+
+.seealso: `PetscPrintf()`, `PetscFPrintf()`, `PetscVFPrintf()`, `PetscVSNPrintf()`
+@*/
+PetscErrorCode PetscFFlush(FILE *fd)
+{
+  int ret;
+
+  PetscFunctionBegin;
+  if (fd) PetscValidPointer(fd, 1);
+  ret = fflush(fd);
+  // could also use PetscCallExternal() here, but since we can get additional error explanation
+  // from strerror() we opted for a manual check
+  PetscCheck(ret == 0, PETSC_COMM_SELF, PETSC_ERR_FILE_WRITE, "Error in fflush(): error code %d (%s)", ret, strerror(errno));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -256,35 +293,36 @@ PetscErrorCode PetscVSNPrintf(char *str, size_t len, const char *format, size_t
         can be replaced with something that does not simply write to a file.
 
       To use, write your own function for example,
-$PetscErrorCode mypetscvfprintf(FILE *fd,const char format[],va_list Argp)
-${
-$  PetscErrorCode ierr;
-$
-$  PetscFunctionBegin;
-$   if (fd != stdout && fd != stderr) {  handle regular files
-$      CHKERR(PetscVFPrintfDefault(fd,format,Argp));
-$  } else {
-$     char   buff[BIG];
-$     size_t length;
-$     PetscCall(PetscVSNPrintf(buff,BIG,format,&length,Argp));
-$     now send buff to whatever stream or whatever you want
-$ }
-$ PetscFunctionReturn(0);
-$}
-then before the call to PetscInitialize() do the assignment
-$    PetscVFPrintf = mypetscvfprintf;
+.vb
+   PetscErrorCode mypetscvfprintf(FILE *fd, const char format[], va_list Argp)
+   {
+     PetscErrorCode ierr;
 
-      Note:
-    For error messages this may be called by any process, for regular standard out it is
-          called only by process 0 of a given communicator
-
-      Developer Note:
-    this could be called by an error handler, if that happens then a recursion of the error handler may occur
-                       and a crash
+     PetscFunctionBegin;
+      if (fd != stdout && fd != stderr) {  handle regular files
+         CHKERR(PetscVFPrintfDefault(fd,format,Argp));
+     } else {
+        char   buff[BIG];
+        size_t length;
+        PetscCall(PetscVSNPrintf(buff,BIG,format,&length,Argp));
+        now send buff to whatever stream or whatever you want
+    }
+    PetscFunctionReturn(PETSC_SUCCESS);
+   }
+.ve
+   then before the call to `PetscInitialize()` do the assignment `PetscVFPrintf = mypetscvfprintf`;
 
   Level:  developer
 
-.seealso: `PetscVSNPrintf()`, `PetscErrorPrintf()`
+   Note:
+   For error messages this may be called by any process, for regular standard out it is
+   called only by process 0 of a given communicator
+
+   Developer Note:
+   This could be called by an error handler, if that happens then a recursion of the error handler may occur
+   and a resulting crash
+
+.seealso: `PetscVSNPrintf()`, `PetscErrorPrintf()`, `PetscFFlush()`
 @*/
 PetscErrorCode PetscVFPrintfDefault(FILE *fd, const char *format, va_list Argp)
 {
@@ -308,10 +346,18 @@ PetscErrorCode PetscVFPrintfDefault(FILE *fd, const char *format, va_list Argp)
     SETERRQ(PETSC_COMM_SELF, PETSC_ERR_LIB, "C89 does not support va_copy() hence cannot print long strings with PETSc printing routines");
 #endif
   }
-  fprintf(fd, "%s", buff);
-  fflush(fd);
+#if defined(PETSC_HAVE_VA_COPY)
+  va_end(Argpcopy);
+#endif
+  {
+    const int err = fprintf(fd, "%s", buff);
+    // cannot use PetscCallExternal() for fprintf since the return value is "number of
+    // characters transmitted to the output stream" on success
+    PetscCheck(err >= 0, PETSC_COMM_SELF, PETSC_ERR_FILE_WRITE, "fprintf() returned error code %d", err);
+  }
+  PetscCall(PetscFFlush(fd));
   if (buff != str) PetscCall(PetscFree(buff));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -321,14 +367,15 @@ PetscErrorCode PetscVFPrintfDefault(FILE *fd, const char *format, va_list Argp)
 
     Input Parameters:
 +   str - the string to print to
-.   len - the length of str
-.   format - the usual printf() format string
+.   len - the length of `str`
+.   format - the usual `printf()` format string
 -   ... - any arguments that are to be printed, each much have an appropriate symbol in the format argument
 
    Level: intermediate
 
 .seealso: `PetscSynchronizedFlush()`, `PetscSynchronizedFPrintf()`, `PetscFPrintf()`, `PetscVSNPrintf()`,
-          `PetscPrintf()`, `PetscViewerASCIIPrintf()`, `PetscViewerASCIISynchronizedPrintf()`, `PetscVFPrintf()`
+          `PetscPrintf()`, `PetscViewerASCIIPrintf()`, `PetscViewerASCIISynchronizedPrintf()`,
+          `PetscVFPrintf()`, `PetscFFlush()`
 @*/
 PetscErrorCode PetscSNPrintf(char *str, size_t len, const char format[], ...)
 {
@@ -338,22 +385,23 @@ PetscErrorCode PetscSNPrintf(char *str, size_t len, const char format[], ...)
   PetscFunctionBegin;
   va_start(Argp, format);
   PetscCall(PetscVSNPrintf(str, len, format, &fullLength, Argp));
-  PetscFunctionReturn(0);
+  va_end(Argp);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-    PetscSNPrintfCount - Prints to a string of given length, returns count
+    PetscSNPrintfCount - Prints to a string of given length, returns count of characters printed
 
     Not Collective
 
     Input Parameters:
 +   str - the string to print to
-.   len - the length of str
-.   format - the usual printf() format string
+.   len - the length of `str`
+.   format - the usual `printf()` format string
 -   ... - any arguments that are to be printed, each much have an appropriate symbol in the format argument
 
     Output Parameter:
-.   countused - number of characters used
+.   countused - number of characters printed
 
    Level: intermediate
 
@@ -367,57 +415,47 @@ PetscErrorCode PetscSNPrintfCount(char *str, size_t len, const char format[], si
   PetscFunctionBegin;
   va_start(Argp, countused);
   PetscCall(PetscVSNPrintf(str, len, format, countused, Argp));
-  PetscFunctionReturn(0);
+  va_end(Argp);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* ----------------------------------------------------------------------- */
-
 PrintfQueue petsc_printfqueue = NULL, petsc_printfqueuebase = NULL;
 int         petsc_printfqueuelength = 0;
 
-/*@C
-    PetscSynchronizedPrintf - Prints synchronized output from several processors.
-    Output of the first processor is followed by that of the second, etc.
-
-    Not Collective
-
-    Input Parameters:
-+   comm - the communicator
--   format - the usual printf() format string
-
-   Level: intermediate
-
-    Note:
-    REQUIRES a call to `PetscSynchronizedFlush()` by all the processes after the completion of the calls to `PetscSynchronizedPrintf()` for the information
-    from all the processors to be printed.
-
-    Fortran Note:
-    The call sequence is `PetscSynchronizedPrintf`(MPI_Comm, character(*), PetscErrorCode ierr) from Fortran.
-    That is, you can only pass a single character string from Fortran.
-
-.seealso: `PetscSynchronizedFlush()`, `PetscSynchronizedFPrintf()`, `PetscFPrintf()`,
-          `PetscPrintf()`, `PetscViewerASCIIPrintf()`, `PetscViewerASCIISynchronizedPrintf()`
-@*/
-PetscErrorCode PetscSynchronizedPrintf(MPI_Comm comm, const char format[], ...)
+static inline PetscErrorCode PetscVFPrintf_Private(MPI_Comm comm, FILE *fd, const char format[], va_list Argp)
 {
-  PetscMPIInt rank;
+  const PetscBool tee = (PetscBool)(petsc_history && (fd != petsc_history));
+  PetscMPIInt     rank;
+  va_list         cpy;
 
   PetscFunctionBegin;
   PetscCheck(comm != MPI_COMM_NULL, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Called with MPI_COMM_NULL, likely PetscObjectComm() failed");
   PetscCallMPI(MPI_Comm_rank(comm, &rank));
+  if (PetscLikely(rank != 0)) PetscFunctionReturn(PETSC_SUCCESS);
+  // must do this before we possibly consume Argp
+  if (tee) va_copy(cpy, Argp);
+  PetscCall((*PetscVFPrintf)(fd, format, Argp));
+  if (tee) {
+    PetscCall((*PetscVFPrintf)(petsc_history, format, cpy));
+    va_end(cpy);
+  }
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
 
-  /* First processor prints immediately to stdout */
+static inline PetscErrorCode PetscSynchronizedFPrintf_Private(MPI_Comm comm, FILE *fp, const char format[], va_list Argp)
+{
+  PetscMPIInt rank;
+  va_list     cpy;
+
+  PetscFunctionBegin;
+  PetscCheck(comm != MPI_COMM_NULL, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Called with MPI_COMM_NULL, likely PetscObjectComm() failed");
+  PetscCallMPI(MPI_Comm_rank(comm, &rank));
+  /* First processor prints immediately to fp */
   if (rank == 0) {
-    va_list Argp;
-    va_start(Argp, format);
-    PetscCall((*PetscVFPrintf)(PETSC_STDOUT, format, Argp));
-    if (petsc_history) {
-      va_start(Argp, format);
-      PetscCall((*PetscVFPrintf)(petsc_history, format, Argp));
-    }
-    va_end(Argp);
+    va_copy(cpy, Argp);
+    PetscCall(PetscVFPrintf_Private(comm, fp, format, cpy));
+    va_end(cpy);
   } else { /* other processors add to local queue */
-    va_list     Argp;
     PrintfQueue next;
     size_t      fullLength = PETSCDEFAULTBUFFERSIZE;
 
@@ -434,13 +472,48 @@ PetscErrorCode PetscSynchronizedPrintf(MPI_Comm comm, const char format[], ...)
       next->size = fullLength + 1;
       PetscCall(PetscFree(next->string));
       PetscCall(PetscMalloc1(next->size, &next->string));
-      va_start(Argp, format);
       PetscCall(PetscArrayzero(next->string, next->size));
-      PetscCall(PetscVSNPrintf(next->string, next->size, format, &fullLength, Argp));
-      va_end(Argp);
+      va_copy(cpy, Argp);
+      PetscCall(PetscVSNPrintf(next->string, next->size, format, &fullLength, cpy));
+      va_end(cpy);
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@C
+    PetscSynchronizedPrintf - Prints synchronized output from several processors.
+    Output of the first processor is followed by that of the second, etc.
+
+    Not Collective
+
+    Input Parameters:
++   comm - the MPI communicator
+-   format - the usual `printf()` format string
+
+   Level: intermediate
+
+    Note:
+    REQUIRES a call to `PetscSynchronizedFlush()` by all the processes after the completion of the calls to `PetscSynchronizedPrintf()` for the information
+    from all the processors to be printed.
+
+    Fortran Note:
+    The call sequence is `PetscSynchronizedPrintf`(`MPI_Comm`, `character`(*), `PetscErrorCode` ierr).
+    That is, you can only pass a single character string from Fortran.
+
+.seealso: `PetscSynchronizedFlush()`, `PetscSynchronizedFPrintf()`, `PetscFPrintf()`,
+          `PetscPrintf()`, `PetscViewerASCIIPrintf()`, `PetscViewerASCIISynchronizedPrintf()`,
+          `PetscFFlush()`
+@*/
+PetscErrorCode PetscSynchronizedPrintf(MPI_Comm comm, const char format[], ...)
+{
+  va_list Argp;
+
+  PetscFunctionBegin;
+  va_start(Argp, format);
+  PetscCall(PetscSynchronizedFPrintf_Private(comm, PETSC_STDOUT, format, Argp));
+  va_end(Argp);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -451,9 +524,9 @@ PetscErrorCode PetscSynchronizedPrintf(MPI_Comm comm, const char format[], ...)
     Not Collective
 
     Input Parameters:
-+   comm - the communicator
++   comm - the MPI communicator
 .   fd - the file pointer
--   format - the usual printf() format string
+-   format - the usual `printf()` format string
 
     Level: intermediate
 
@@ -462,51 +535,18 @@ PetscErrorCode PetscSynchronizedPrintf(MPI_Comm comm, const char format[], ...)
     from all the processors to be printed.
 
 .seealso: `PetscSynchronizedPrintf()`, `PetscSynchronizedFlush()`, `PetscFPrintf()`,
-          `PetscFOpen()`, `PetscViewerASCIISynchronizedPrintf()`, `PetscViewerASCIIPrintf()`
+          `PetscFOpen()`, `PetscViewerASCIISynchronizedPrintf()`, `PetscViewerASCIIPrintf()`,
+          `PetscFFlush()`
 @*/
 PetscErrorCode PetscSynchronizedFPrintf(MPI_Comm comm, FILE *fp, const char format[], ...)
 {
-  PetscMPIInt rank;
+  va_list Argp;
 
   PetscFunctionBegin;
-  PetscCheck(comm != MPI_COMM_NULL, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Called with MPI_COMM_NULL, likely PetscObjectComm() failed");
-  PetscCallMPI(MPI_Comm_rank(comm, &rank));
-
-  /* First processor prints immediately to fp */
-  if (rank == 0) {
-    va_list Argp;
-    va_start(Argp, format);
-    PetscCall((*PetscVFPrintf)(fp, format, Argp));
-    if (petsc_history && (fp != petsc_history)) {
-      va_start(Argp, format);
-      PetscCall((*PetscVFPrintf)(petsc_history, format, Argp));
-    }
-    va_end(Argp);
-  } else { /* other processors add to local queue */
-    va_list     Argp;
-    PrintfQueue next;
-    size_t      fullLength = PETSCDEFAULTBUFFERSIZE;
-
-    PetscCall(PetscNew(&next));
-    if (petsc_printfqueue) {
-      petsc_printfqueue->next = next;
-      petsc_printfqueue       = next;
-      petsc_printfqueue->next = NULL;
-    } else petsc_printfqueuebase = petsc_printfqueue = next;
-    petsc_printfqueuelength++;
-    next->size   = 0;
-    next->string = NULL;
-    while (fullLength >= next->size) {
-      next->size = fullLength + 1;
-      PetscCall(PetscFree(next->string));
-      PetscCall(PetscMalloc1(next->size, &next->string));
-      va_start(Argp, format);
-      PetscCall(PetscArrayzero(next->string, next->size));
-      PetscCall(PetscVSNPrintf(next->string, next->size, format, &fullLength, Argp));
-      va_end(Argp);
-    }
-  }
-  PetscFunctionReturn(0);
+  va_start(Argp, format);
+  PetscCall(PetscSynchronizedFPrintf_Private(comm, fp, format, Argp));
+  va_end(Argp);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -516,7 +556,7 @@ PetscErrorCode PetscSynchronizedFPrintf(MPI_Comm comm, FILE *fp, const char form
     Collective
 
     Input Parameters:
-+   comm - the communicator
++   comm - the MPI communicator
 -   fd - the file pointer (valid on process 0 of the communicator)
 
     Level: intermediate
@@ -576,48 +616,38 @@ PetscErrorCode PetscSynchronizedFlush(MPI_Comm comm, FILE *fd)
     petsc_printfqueuelength = 0;
   }
   PetscCall(PetscCommDestroy(&comm));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* ---------------------------------------------------------------------------------------*/
-
 /*@C
     PetscFPrintf - Prints to a file, only from the first
     processor in the communicator.
 
-    Not Collective
+    Not Collective; No Fortran Support
 
     Input Parameters:
-+   comm - the communicator
++   comm - the MPI communicator
 .   fd - the file pointer
--   format - the usual printf() format string
+-   format - the usual `printf()` format string
 
     Level: intermediate
 
-    Fortran Note:
-    This routine is not supported in Fortran.
+    Developer Note:
+    This maybe, and is, called from PETSc error handlers and `PetscMallocValidate()` hence it does not use `PetscCallMPI()` which
+    could recursively restart the malloc validation.
 
 .seealso: `PetscPrintf()`, `PetscSynchronizedPrintf()`, `PetscViewerASCIIPrintf()`,
-          `PetscViewerASCIISynchronizedPrintf()`, `PetscSynchronizedFlush()`
+          `PetscViewerASCIISynchronizedPrintf()`, `PetscSynchronizedFlush()`, `PetscFFlush()`
 @*/
 PetscErrorCode PetscFPrintf(MPI_Comm comm, FILE *fd, const char format[], ...)
 {
-  PetscMPIInt rank;
+  va_list Argp;
 
   PetscFunctionBegin;
-  PetscCheck(comm != MPI_COMM_NULL, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Called with MPI_COMM_NULL, likely PetscObjectComm() failed");
-  PetscCallMPI(MPI_Comm_rank(comm, &rank));
-  if (rank == 0) {
-    va_list Argp;
-    va_start(Argp, format);
-    PetscCall((*PetscVFPrintf)(fd, format, Argp));
-    if (petsc_history && (fd != petsc_history)) {
-      va_start(Argp, format);
-      PetscCall((*PetscVFPrintf)(petsc_history, format, Argp));
-    }
-    va_end(Argp);
-  }
-  PetscFunctionReturn(0);
+  va_start(Argp, format);
+  PetscCall(PetscVFPrintf_Private(comm, fd, format, Argp));
+  va_end(Argp);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -628,7 +658,7 @@ PetscErrorCode PetscFPrintf(MPI_Comm comm, FILE *fd, const char format[], ...)
 
     Input Parameters:
 +   comm - the communicator
--   format - the usual printf() format string
+-   format - the usual `printf()` format string
 
     Level: intermediate
 
@@ -640,50 +670,30 @@ PetscErrorCode PetscFPrintf(MPI_Comm comm, FILE *fd, const char format[], ...)
     The call sequence is `PetscPrintf`(MPI_Comm, character(*), `PetscErrorCode` ierr) from Fortran.
     That is, you can only pass a single character string from Fortran.
 
-.seealso: `PetscFPrintf()`, `PetscSynchronizedPrintf()`, `PetscFormatConvert()`
+.seealso: `PetscFPrintf()`, `PetscSynchronizedPrintf()`, `PetscFormatConvert()`, `PetscFFlush()`
 @*/
 PetscErrorCode PetscPrintf(MPI_Comm comm, const char format[], ...)
 {
-  PetscMPIInt rank;
+  va_list Argp;
 
   PetscFunctionBegin;
-  PetscCheck(comm != MPI_COMM_NULL, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Called with MPI_COMM_NULL, likely PetscObjectComm() failed");
-  PetscCallMPI(MPI_Comm_rank(comm, &rank));
-  if (rank == 0) {
-    va_list Argp;
-    va_start(Argp, format);
-    PetscCall((*PetscVFPrintf)(PETSC_STDOUT, format, Argp));
-    if (petsc_history) {
-      va_start(Argp, format);
-      PetscCall((*PetscVFPrintf)(petsc_history, format, Argp));
-    }
-    va_end(Argp);
-  }
-  PetscFunctionReturn(0);
+  va_start(Argp, format);
+  PetscCall(PetscVFPrintf_Private(comm, PETSC_STDOUT, format, Argp));
+  va_end(Argp);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscHelpPrintfDefault(MPI_Comm comm, const char format[], ...)
 {
-  PetscMPIInt rank;
+  va_list Argp;
 
   PetscFunctionBegin;
-  PetscCheck(comm != MPI_COMM_NULL, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Called with MPI_COMM_NULL, likely PetscObjectComm() failed");
-  PetscCallMPI(MPI_Comm_rank(comm, &rank));
-  if (rank == 0) {
-    va_list Argp;
-    va_start(Argp, format);
-    PetscCall((*PetscVFPrintf)(PETSC_STDOUT, format, Argp));
-    if (petsc_history) {
-      va_start(Argp, format);
-      PetscCall((*PetscVFPrintf)(petsc_history, format, Argp));
-    }
-    va_end(Argp);
-  }
-  PetscFunctionReturn(0);
+  va_start(Argp, format);
+  PetscCall(PetscVFPrintf_Private(comm, PETSC_STDOUT, format, Argp));
+  va_end(Argp);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* ---------------------------------------------------------------------------------------*/
-
 /*@C
     PetscSynchronizedFGets - Several processors all get the same line from a file.
 
@@ -708,23 +718,19 @@ PetscErrorCode PetscSynchronizedFGets(MPI_Comm comm, FILE *fp, size_t len, char
 
   PetscFunctionBegin;
   PetscCallMPI(MPI_Comm_rank(comm, &rank));
-
-  if (rank == 0) {
-    char *ptr = fgets(string, len, fp);
-
-    if (!ptr) {
-      string[0] = 0;
-      PetscCheck(feof(fp), PETSC_COMM_SELF, PETSC_ERR_FILE_READ, "Error reading from file: %d", errno);
-    }
+  if (rank != 0) PetscFunctionReturn(PETSC_SUCCESS);
+  if (!fgets(string, len, fp)) {
+    string[0] = 0;
+    PetscCheck(feof(fp), PETSC_COMM_SELF, PETSC_ERR_FILE_READ, "Error reading from file: %d", errno);
   }
   PetscCallMPI(MPI_Bcast(string, len, MPI_BYTE, 0, comm));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
      PetscFormatStrip - Takes a PETSc format string and removes all numerical modifiers to % operations
 
-   Input Parameters:
+   Input Parameter:
 .   format - the PETSc format string
 
  Level: developer
@@ -742,7 +748,7 @@ PetscErrorCode PetscFormatStrip(char *format)
     }
     format[loc1++] = format[loc2++];
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscFormatRealArray(char buf[], size_t len, const char *fmt, PetscInt n, const PetscReal x[])
@@ -760,5 +766,5 @@ PetscErrorCode PetscFormatRealArray(char buf[], size_t len, const char *fmt, Pet
     *p++ = ' ';
   }
   p[i ? 0 : -1] = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
