@@ -1,25 +1,25 @@
 
 #include <petscsys.h>
 #if defined(PETSC_HAVE_PWD_H)
-#include <pwd.h>
+  #include <pwd.h>
 #endif
 #include <ctype.h>
 #include <sys/stat.h>
 #if defined(PETSC_HAVE_UNISTD_H)
-#include <unistd.h>
+  #include <unistd.h>
 #endif
 #if defined(PETSC_HAVE_SYS_UTSNAME_H)
-#include <sys/utsname.h>
+  #include <sys/utsname.h>
 #endif
 #if defined(PETSC_HAVE_SYS_SYSTEMINFO_H)
-#include <sys/systeminfo.h>
+  #include <sys/systeminfo.h>
 #endif
 
 /*@C
    PetscGetRelativePath - Given a filename, returns the relative path (removes
    all directory specifiers).
 
-   Not Collective
+   Not Collective; No Fortran Support
 
    Input parameters:
 +  fullpath  - full pathname
@@ -28,15 +28,15 @@
 
    Level: developer
 
-.seealso: PetscGetFullPath()
+.seealso: `PetscGetFullPath()`
 @*/
-PetscErrorCode  PetscGetRelativePath(const char fullpath[],char path[],size_t flen)
+PetscErrorCode PetscGetRelativePath(const char fullpath[], char path[], size_t flen)
 {
-  char           *p;
+  char *p = NULL;
 
   PetscFunctionBegin;
   /* Find string after last / or entire string if no / */
-  PetscCall(PetscStrrchr(fullpath,'/',&p));
-  PetscCall(PetscStrncpy(path,p,flen));
-  PetscFunctionReturn(0);
+  PetscCall(PetscStrrchr(fullpath, '/', &p));
+  PetscCall(PetscStrncpy(path, p, flen));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
