@@ -34,18 +34,18 @@ FILE                    *PetscInfoFile
 
     Not Collective
 
-    Input Parameters:
+    Input Parameter:
 .   classid - `PetscClassid` retrieved from a `PetscObject` e.g. `VEC_CLASSID`
 
     Output Parameter:
 .   enabled - `PetscBool` indicating whether this classid is allowed to print
 
+    Level: advanced
+
     Note:
     Use `PETSC_SMALLEST_CLASSID` to check if "sys" `PetscInfo()` calls are enabled. When PETSc is configured with debugging
     support this function checks if classid >= `PETSC_SMALLEST_CLASSID`, otherwise it assumes valid classid.
 
-    Level: advanced
-
 .seealso: `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoGetInfo()`, `PetscObjectGetClassid()`
 @*/
 PetscErrorCode PetscInfoEnabled(PetscClassId classid, PetscBool *enabled)
@@ -54,7 +54,7 @@ PetscErrorCode PetscInfoEnabled(PetscClassId classid, PetscBool *enabled)
   PetscValidBoolPointer(enabled, 2);
   PetscCheck(classid >= PETSC_SMALLEST_CLASSID, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Classid (current: %d) must be equal to or greater than PETSC_SMALLEST_CLASSID", classid);
   *enabled = (PetscBool)(PetscLogPrintInfo && PetscInfoFlags[classid - PETSC_SMALLEST_CLASSID]);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -73,7 +73,7 @@ PetscErrorCode PetscInfoAllow(PetscBool flag)
 {
   PetscFunctionBegin;
   PetscLogPrintInfo = flag;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -83,13 +83,13 @@ PetscErrorCode PetscInfoAllow(PetscBool flag)
 
     Input Parameters:
 +   filename - Name of the file where `PetscInfo()` will print to
--   mode - Write mode passed to PetscFOpen()`
-
-    Note:
-    Use filename = NULL to set `PetscInfo()` to write to `PETSC_STDOUT`.
+-   mode - Write mode passed to `PetscFOpen()`
 
     Level: advanced
 
+    Note:
+    Use `filename = NULL` to set `PetscInfo()` to write to `PETSC_STDOUT`.
+
 .seealso: `PetscInfo()`, `PetscInfoSetFile()`, `PetscInfoSetFromOptions()`, `PetscFOpen()`
 @*/
 PetscErrorCode PetscInfoSetFile(const char filename[], const char mode[])
@@ -121,26 +121,23 @@ PetscErrorCode PetscInfoSetFile(const char filename[], const char mode[])
     }
     PetscCall(PetscInfo(NULL, "Opened PetscInfo file %s\n", fname));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-    PetscInfoGetFile - Gets the name and FILE pointer of the file where `PetscInfo()` prints to
+    PetscInfoGetFile - Gets the `filename` and `FILE` pointer of the file where `PetscInfo()` prints to
 
-    Not Collective
+    Not Collective; No Fortran Support
 
     Output Parameters:
 +   filename - The name of the output file
--   InfoFile - The FILE pointer for the output file
+-   InfoFile - The `FILE` pointer for the output file
 
     Level: advanced
 
     Note:
-    This routine allocates and copies the filename so that the filename survives `PetscInfoDestroy()`. The user is
-    therefore responsible for freeing the allocated filename pointer afterwards.
-
-    Fortran Note:
-    This routine is not supported in Fortran.
+    This routine allocates and copies the `filename` so that the `filename` survives `PetscInfoDestroy()`. The user is
+    therefore responsible for freeing the allocated `filename` pointer afterwards.
 
 .seealso: `PetscInfo()`, `PetscInfoSetFile()`, `PetscInfoSetFromOptions()`, `PetscInfoDestroy()`
 @*/
@@ -151,35 +148,32 @@ PetscErrorCode PetscInfoGetFile(char **filename, FILE **InfoFile)
   PetscValidPointer(InfoFile, 2);
   PetscCall(PetscStrallocpy(PetscInfoFilename, filename));
   *InfoFile = PetscInfoFile;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     PetscInfoSetClasses - Sets the classes which `PetscInfo()` is filtered for/against
 
-    Not Collective
+    Not Collective; No Fortran Support
 
     Input Parameters:
 +   exclude - Whether or not to invert the filter, i.e. if exclude is true, `PetscInfo()` will print from every class that
     is NOT one of the classes specified
-.   n - Number of classes to filter for (size of classnames)
+.   n - Number of classes to filter for (size of `classnames`)
 -   classnames - String array containing the names of classes to filter for, e.g. "vec"
 
+    Level: developer
+
     Notes:
     This function CANNOT be called after `PetscInfoGetClass()` or `PetscInfoProcessClass()` has been called.
 
-    Names in the classnames list should correspond to the names returned by `PetscObjectGetClassName()`.
+    Names in the `classnames` list should correspond to the names returned by `PetscObjectGetClassName()`.
 
     This function only sets the list of class names.
     The actual filtering is deferred to `PetscInfoProcessClass()`, except of sys which is processed right away.
     The reason for this is that we need to set the list of included/excluded classes before their classids are known.
     Typically the classid is assigned and `PetscInfoProcessClass()` called in <Class>InitializePackage() (e.g. `VecInitializePackage()`).
 
-    Fortran Note:
-    Not for use in Fortran
-
-    Level: developer
-
 .seealso: `PetscInfo()`, `PetscInfoGetClass()`, `PetscInfoProcessClass()`, `PetscInfoSetFromOptions()`, `PetscStrToArray()`, `PetscObjectGetName()`
 @*/
 PetscErrorCode PetscInfoSetClasses(PetscBool exclude, PetscInt n, const char *const *classnames)
@@ -197,11 +191,11 @@ PetscErrorCode PetscInfoSetClasses(PetscBool exclude, PetscInt n, const char *co
     PetscCall(PetscInfoProcessClass("sys", 1, &id));
   }
   PetscInfoClassesSet = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-    PetscInfoGetClass - Indicates whether the provided classname is marked as a filter in `PetscInfo()` as set by `PetscInfoSetClasses()`
+    PetscInfoGetClass - Indicates whether the provided `classname` is marked as a filter in `PetscInfo()` as set by `PetscInfoSetClasses()`
 
     Not Collective
 
@@ -211,11 +205,11 @@ PetscErrorCode PetscInfoSetClasses(PetscBool exclude, PetscInt n, const char *co
     Output Parameter:
 .   found - `PetscBool` indicating whether the classname was found
 
+    Level: developer
+
     Note:
     Use `PetscObjectGetName()` to retrieve an appropriate classname
 
-    Level: developer
-
 .seealso: `PetscInfo()`, `PetscInfoSetClasses()`, `PetscInfoSetFromOptions()`, `PetscObjectGetName()`
 @*/
 PetscErrorCode PetscInfoGetClass(const char *classname, PetscBool *found)
@@ -227,7 +221,7 @@ PetscErrorCode PetscInfoGetClass(const char *classname, PetscBool *found)
   PetscValidBoolPointer(found, 2);
   PetscCall(PetscEListFind(PetscInfoNumClasses, (const char *const *)PetscInfoClassnames, classname ? classname : "sys", &unused, found));
   PetscInfoClassesLocked = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -243,11 +237,11 @@ PetscErrorCode PetscInfoGetClass(const char *classname, PetscBool *found)
 -   commSelfFlag - Enum indicating whether `PetscInfo()` will print for communicators of size 1, any size != 1, or all
     communicators
 
+    Level: developer
+
     Note:
     Initially commSelfFlag = `PETSC_INFO_COMM_ALL`
 
-    Level: developer
-
 .seealso: `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFilterCommSelf`, `PetscInfoSetFromOptions()`
 @*/
 PetscErrorCode PetscInfoGetInfo(PetscBool *infoEnabled, PetscBool *classesSet, PetscBool *exclude, PetscBool *locked, PetscInfoCommFlag *commSelfFlag)
@@ -263,7 +257,7 @@ PetscErrorCode PetscInfoGetInfo(PetscBool *infoEnabled, PetscBool *classesSet, P
   if (exclude) *exclude = PetscInfoInvertClasses;
   if (locked) *locked = PetscInfoClassesLocked;
   if (commSelfFlag) *commSelfFlag = PetscInfoCommFilter;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -273,8 +267,11 @@ PetscErrorCode PetscInfoGetInfo(PetscBool *infoEnabled, PetscBool *classesSet, P
 
     Input Parameters:
 +   classname - Name of the class to activate/deactivate `PetscInfo()` for
-.   numClassID - Number of entries in classIDs
--   classIDs - Array containing all of the PetscClassids associated with classname
+.   numClassID - Number of entries in `classIDs`
+-   classIDs - Array containing all of the `PetscClassId`s associated with `classname`
+
+      Options Database Key:
+.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, see `PetscInfo()`.
 
     Level: developer
 
@@ -290,7 +287,7 @@ PetscErrorCode PetscInfoProcessClass(const char classname[], PetscInt numClassID
   PetscAssert(numClassID > 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Number of classids %" PetscInt_FMT " <= 0", numClassID);
   if (numClassID) PetscValidPointer(classIDs, 3);
   PetscCall(PetscInfoGetInfo(&enabled, NULL, &exclude, NULL, NULL));
-  /* -info_exclude is DEPRECATED */
+  PetscCall(PetscOptionsDeprecated_Private(NULL, "-info_exclude", NULL, "3.13", "Use ~ with -info to indicate classes to exclude"));
   PetscCall(PetscOptionsGetString(NULL, NULL, "-info_exclude", logList, sizeof(logList), &opt));
   if (opt) {
     PetscBool pkg;
@@ -315,7 +312,7 @@ PetscErrorCode PetscInfoProcessClass(const char classname[], PetscInt numClassID
   } else {
     for (PetscInt i = 0; i < numClassID; ++i) PetscCall(PetscInfoActivateClass(classIDs[i]));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -326,6 +323,9 @@ PetscErrorCode PetscInfoProcessClass(const char classname[], PetscInt numClassID
     Input Parameter:
 .   commSelfFlag - Enum value indicating method with which to filter `PetscInfo()` based on the size of the communicator of the object calling `PetscInfo()`
 
+    Options Database Key:
+.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
+
     Level: advanced
 
 .seealso: `PetscInfo()`, `PetscInfoGetInfo()`
@@ -334,7 +334,7 @@ PetscErrorCode PetscInfoSetFilterCommSelf(PetscInfoCommFlag commSelfFlag)
 {
   PetscFunctionBegin;
   PetscInfoCommFilter = commSelfFlag;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -343,16 +343,16 @@ PetscErrorCode PetscInfoSetFilterCommSelf(PetscInfoCommFlag commSelfFlag)
     Not Collective
 
     Input Parameter:
-.   options - Options database, use NULL for default global database
+.   options - Options database, use `NULL` for default global database
 
-    Options Database Keys:
-.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See PetscInfo().
+    Options Database Key:
+.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
+
+    Level: advanced
 
     Note:
     This function is called automatically during `PetscInitialize()` so users usually do not need to call it themselves.
 
-    Level: advanced
-
 .seealso: `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFile()`, `PetscInfoSetClasses()`, `PetscInfoSetFilterCommSelf()`, `PetscInfoDestroy()`
 @*/
 PetscErrorCode PetscInfoSetFromOptions(PetscOptions options)
@@ -361,7 +361,6 @@ PetscErrorCode PetscInfoSetFromOptions(PetscOptions options)
   PetscBool set;
 
   PetscFunctionBegin;
-  PetscCall(PetscOptionsDeprecated_Private(NULL, "-info_exclude", NULL, "3.13", "Use -info instead"));
   PetscCall(PetscOptionsGetString(options, NULL, "-info", optstring, PETSC_STATIC_ARRAY_LENGTH(optstring), &set));
   if (set) {
     size_t            size_loc0_, size_loc1_, size_loc2_;
@@ -410,7 +409,7 @@ PetscErrorCode PetscInfoSetFromOptions(PetscOptions options)
     PetscCall(PetscStrToArrayDestroy(nLoc1_, loc1_array));
     PetscCall(PetscFree(loc0_));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -418,23 +417,20 @@ PetscErrorCode PetscInfoSetFromOptions(PetscOptions options)
 
   Not Collective
 
+  Level: developer
+
   Note:
   This is automatically called in `PetscFinalize()`. Useful for changing filters mid-program, or culling subsequent
   `PetscInfo()` calls down the line.
 
-  Level: developer
-
 .seealso: `PetscInfo()`, `PetscInfoSetFromOptions()`
 @*/
 PetscErrorCode PetscInfoDestroy(void)
 {
-  int err;
-
   PetscFunctionBegin;
   PetscCall(PetscInfoAllow(PETSC_FALSE));
   PetscCall(PetscStrNArrayDestroy(PetscInfoNumClasses, &PetscInfoClassnames));
-  err = fflush(PetscInfoFile);
-  PetscCheck(!err, PETSC_COMM_SELF, PETSC_ERR_SYS, "fflush() failed on file");
+  PetscCall(PetscFFlush(PetscInfoFile));
   if (PetscInfoFilename) PetscCall(PetscFClose(PETSC_COMM_SELF, PetscInfoFile));
   PetscCall(PetscFree(PetscInfoFilename));
   PetscAssert(PETSC_STATIC_ARRAY_LENGTH(PetscInfoFlags) == PETSC_STATIC_ARRAY_LENGTH(PetscInfoNames), PETSC_COMM_SELF, PETSC_ERR_PLIB, "PetscInfoFlags and PetscInfoNames must be the same size");
@@ -448,7 +444,7 @@ PetscErrorCode PetscInfoDestroy(void)
   PetscInfoClassesSet    = PETSC_FALSE;
   PetscInfoNumClasses    = -1;
   PetscInfoCommFilter    = PETSC_INFO_COMM_ALL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode PetscInfoSetClassActivation_Private(PetscClassId classid, int value)
@@ -456,7 +452,7 @@ static PetscErrorCode PetscInfoSetClassActivation_Private(PetscClassId classid,
   PetscFunctionBegin;
   if (!classid) classid = PETSC_SMALLEST_CLASSID;
   PetscInfoFlags[classid - PETSC_SMALLEST_CLASSID] = value;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -467,18 +463,21 @@ static PetscErrorCode PetscInfoSetClassActivation_Private(PetscClassId classid,
   Input Parameter:
 . classid - The object class,  e.g., `MAT_CLASSID`, `SNES_CLASSID`, etc.
 
-  Note:
-  One can pass 0 to deactivate all messages that are not associated with an object.
+    Options Database Key:
+.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
 
   Level: developer
 
+  Note:
+  One can pass 0 to deactivate all messages that are not associated with an object.
+
 .seealso: `PetscInfoActivateClass()`, `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFromOptions()`
 @*/
 PetscErrorCode PetscInfoDeactivateClass(PetscClassId classid)
 {
   PetscFunctionBegin;
   PetscCall(PetscInfoSetClassActivation_Private(classid, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -489,18 +488,21 @@ PetscErrorCode PetscInfoDeactivateClass(PetscClassId classid)
   Input Parameter:
 . classid - The object class, e.g., `MAT_CLASSID`, `SNES_CLASSID`, etc.
 
-  Note:
-  One can pass 0 to activate all messages that are not associated with an object.
+    Options Database Key:
+.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
 
   Level: developer
 
+  Note:
+  One can pass 0 to activate all messages that are not associated with an object.
+
 .seealso: `PetscInfoDeactivateClass()`, `PetscInfo()`, `PetscInfoAllow()`, `PetscInfoSetFromOptions()`
 @*/
 PetscErrorCode PetscInfoActivateClass(PetscClassId classid)
 {
   PetscFunctionBegin;
   PetscCall(PetscInfoSetClassActivation_Private(classid, 1));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -520,60 +522,60 @@ PETSC_INTERN FILE *petsc_history;
        PetscErrorCode PetscInfo(PetscObject obj, const char formatmessage[],arg1,arg2)
        ...
 
-    Collective on obj
+    Collective
 
     Input Parameters:
-+   obj - object most closely associated with the logging statement or NULL
++   obj - object most closely associated with the logging statement or `NULL`
 .   message - logging message
 .   formatmessage - logging message using standard "printf" format
 -   arg1, arg2, ... - arguments of the format
 
+      Options Database Key:
+.   -info [filename][:[~]<list,of,classnames>[:[~]self]] - specify which informative messages are printed, See `PetscInfo()`.
+
+    Level: intermediate
+
     Notes:
     `PetscInfo()` prints only from the first processor in the communicator of obj.
     If obj is NULL, the `PETSC_COMM_SELF` communicator is used, i.e. every rank of `PETSC_COMM_WORLD` prints the message.
 
-    Extent of the printed messages can be controlled using the option database key -info as follows.
-
-$   -info [filename][:[~]<list,of,classnames>[:[~]self]]
-
-    No filename means standard output `PETSC_STDOUT` is used.
-
     The optional <list,of,classnames> is a comma separated list of enabled classes, e.g. vec,mat,ksp.
     If this list is not specified, all classes are enabled.
     Prepending the list with ~ means inverted selection, i.e. all classes except the listed are enabled.
-    A special classname sys relates to PetscInfo() with obj being NULL.
+    A special classname `sys` relates to `PetscInfo()` with obj being `NULL`.
 
-    The optional self keyword specifies that PetscInfo() is enabled only for communicator size = 1 (e.g. `PETSC_COMM_SELF`), i.e. only `PetscInfo()` calls which print from every rank of `PETSC_COMM_WORLD` are enabled.
-    By contrast, ~self means that PetscInfo() is enabled only for communicator size > 1 (e.g. `PETSC_COMM_WORLD`), i.e. those `PetscInfo()` calls which print from every rank of `PETSC_COMM_WORLD` are disabled.
+    The optional keyword `self` specifies that `PetscInfo()` is enabled only for a communicator size of 1 (e.g. `PETSC_COMM_SELF`).
+    By contrast, ~self means that `PetscInfo()` is enabled only for communicator size > 1 (e.g. `PETSC_COMM_WORLD`), i.e. those `PetscInfo()` calls which print from every rank of `PETSC_COMM_WORLD` are disabled.
 
     All classname/self matching is case insensitive. Filename is case sensitive.
 
     Example of Usage:
-$     Mat A;
-$     PetscInt alpha;
-$     ...
-$     PetscInfo(A,"Matrix uses parameter alpha=%" PetscInt_FMT "\n",alpha);
+.vb
+     Mat A;
+     PetscInt alpha;
+     ...
+     PetscInfo(A,"Matrix uses parameter alpha=%" PetscInt_FMT "\n",alpha);
+.ve
 
     Options Examples:
     Each call of the form
-$     PetscInfo(obj, msg);
-$     PetscInfo(obj, msg, arg1);
-$     PetscInfo(obj, msg, arg1, arg2);
+.vb
+     PetscInfo(obj, msg);
+     PetscInfo(obj, msg, arg1);
+     PetscInfo(obj, msg, arg1, arg2);
+.ve
     is evaluated as follows.
-$     -info or -info :: prints msg to PETSC_STDOUT, for any obj regardless class or communicator
-$     -info :mat:self prints msg to PETSC_STDOUT only if class of obj is Mat, and its communicator has size = 1
-$     -info myInfoFileName:~vec:~self prints msg to file named myInfoFileName, only if the obj's class is NULL or other than Vec, and obj's communicator has size > 1
-$     -info :sys prints to PETSC_STDOUT only if obj is NULL
-    Note that
-$     -info :sys:~self
-    deactivates all info messages because sys means obj = NULL which implies PETSC_COMM_SELF but ~self filters out everything on PETSC_COMM_SELF.
-
+.vb
+    -info or -info :: prints msg to PETSC_STDOUT, for any obj regardless class or communicator
+    -info :mat:self prints msg to PETSC_STDOUT only if class of obj is Mat, and its communicator has size = 1
+    -info myInfoFileName:~vec:~self prints msg to file named myInfoFileName, only if the obj's class is NULL or other than Vec, and obj's communicator has size > 1
+    -info :sys prints to PETSC_STDOUT only if obj is NULL
+    -info :sys:~self deactivates all info messages because sys means obj = NULL which implies PETSC_COMM_SELF but ~self filters out everything on PETSC_COMM_SELF.
+.ve
     Fortran Note:
-    This function does not take the obj argument, there is only the `PetscInfo()`
+    This function does not take the `obj` argument, there is only the `PetscInfo()`
      version, not `PetscInfo()` etc.
 
-    Level: intermediate
-
 .seealso: `PetscInfoAllow()`, `PetscInfoSetFromOptions()`
 M*/
 PetscErrorCode PetscInfo_Private(const char func[], PetscObject obj, const char message[], ...)
@@ -590,44 +592,43 @@ PetscErrorCode PetscInfo_Private(const char func[], PetscObject obj, const char
   }
   PetscValidCharPointer(message, 3);
   PetscCall(PetscInfoEnabled(classid, &enabled));
-  if (!enabled) PetscFunctionReturn(0);
+  if (!enabled) PetscFunctionReturn(PETSC_SUCCESS);
   if (obj) PetscCall(PetscObjectGetComm(obj, &comm));
   PetscCallMPI(MPI_Comm_rank(comm, &rank));
   /* rank > 0 always jumps out */
-  if (rank) PetscFunctionReturn(0);
+  if (rank) PetscFunctionReturn(PETSC_SUCCESS);
   else {
     PetscMPIInt size;
 
     PetscCallMPI(MPI_Comm_size(comm, &size));
     /* If no self printing is allowed, and size too small, get out */
-    if ((PetscInfoCommFilter == PETSC_INFO_COMM_NO_SELF) && (size < 2)) PetscFunctionReturn(0);
+    if ((PetscInfoCommFilter == PETSC_INFO_COMM_NO_SELF) && (size < 2)) PetscFunctionReturn(PETSC_SUCCESS);
     /* If ONLY self printing, and size too big, get out */
-    if ((PetscInfoCommFilter == PETSC_INFO_COMM_ONLY_SELF) && (size > 1)) PetscFunctionReturn(0);
+    if ((PetscInfoCommFilter == PETSC_INFO_COMM_ONLY_SELF) && (size > 1)) PetscFunctionReturn(PETSC_SUCCESS);
   }
   /* Mute info messages within this function */
   {
     const PetscBool oldflag = PetscLogPrintInfo;
     va_list         Argp;
     PetscMPIInt     urank;
-    int             err;
     char            string[8 * 1024];
     size_t          fullLength, len;
 
     PetscLogPrintInfo = PETSC_FALSE;
     PetscCallMPI(MPI_Comm_rank(MPI_COMM_WORLD, &urank));
-    va_start(Argp, message);
     PetscCall(PetscSNPrintf(string, PETSC_STATIC_ARRAY_LENGTH(string), "[%d] <%s> %s(): ", urank, PetscInfoNames[classid - PETSC_SMALLEST_CLASSID], func));
     PetscCall(PetscStrlen(string, &len));
+    va_start(Argp, message);
     PetscCall(PetscVSNPrintf(string + len, 8 * 1024 - len, message, &fullLength, Argp));
+    va_end(Argp);
     PetscCall(PetscFPrintf(PETSC_COMM_SELF, PetscInfoFile, "%s", string));
-    err = fflush(PetscInfoFile);
-    PetscCheck(!err, PETSC_COMM_SELF, PETSC_ERR_SYS, "fflush() failed on file");
+    PetscCall(PetscFFlush(PetscInfoFile));
     if (petsc_history) {
       va_start(Argp, message);
       PetscCall((*PetscVFPrintf)(petsc_history, message, Argp));
+      va_end(Argp);
     }
-    va_end(Argp);
     PetscLogPrintInfo = oldflag;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
