@@ -40,7 +40,7 @@ PetscErrorCode PetscOptionsBegin_Private(PetscOptionItems *PetscOptionsObject, M
   if (PetscOptionsObject->printhelp && PetscOptionsObject->count == 1) {
     if (!PetscOptionsObject->alreadyprinted) PetscCall((*PetscHelpPrintf)(comm, "----------------------------------------\n%s:\n", title));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -61,13 +61,13 @@ PetscErrorCode PetscObjectOptionsBegin_Private(PetscObject obj, PetscOptionItems
   if (flg) PetscCall(PetscSNPrintf(title, sizeof(title), "%s options", obj->class_name));
   else PetscCall(PetscSNPrintf(title, sizeof(title), "%s (%s) options", obj->description, obj->class_name));
   PetscCall(PetscOptionsBegin_Private(PetscOptionsObject, obj->comm, obj->prefix, title, obj->mansec));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
      Handles adding another option to the list of options within this particular PetscOptionsBegin() PetscOptionsEnd()
 */
-static int PetscOptionItemCreate_Private(PetscOptionItems *PetscOptionsObject, const char opt[], const char text[], const char man[], PetscOptionType t, PetscOptionItem *amsopt)
+static PetscErrorCode PetscOptionItemCreate_Private(PetscOptionItems *PetscOptionsObject, const char opt[], const char text[], const char man[], PetscOptionType t, PetscOptionItem *amsopt)
 {
   PetscOptionItem next;
   PetscBool       valid;
@@ -92,7 +92,7 @@ static int PetscOptionItemCreate_Private(PetscOptionItems *PetscOptionsObject, c
     while (next->next) next = next->next;
     next->next = *amsopt;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -127,7 +127,7 @@ static PetscErrorCode PetscScanString(MPI_Comm comm, size_t n, char str[])
   }
   PetscCall(PetscMPIIntCast(n, &nm));
   PetscCallMPI(MPI_Bcast(str, nm, MPI_CHAR, 0, comm));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -144,10 +144,10 @@ static PetscErrorCode PetscStrdup(const char s[], char *t[])
     PetscCall(PetscStrlen(s, &len));
     tmp = (char *)malloc((len + 1) * sizeof(*tmp));
     PetscCheck(tmp, PETSC_COMM_SELF, PETSC_ERR_MEM, "No memory to duplicate string");
-    PetscCall(PetscStrcpy(tmp, s));
+    PetscCall(PetscArraycpy(tmp, s, len + 1));
   }
   *t = tmp;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -340,7 +340,7 @@ PetscErrorCode PetscOptionsGetFromTextInput(PetscOptionItems *PetscOptionsObject
     }
     next = next->next;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_HAVE_SAWS)
@@ -351,7 +351,7 @@ static int count = 0;
 PetscErrorCode PetscOptionsSAWsDestroy(void)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static const char *OptionsHeader = "<head>\n"
@@ -389,7 +389,7 @@ PetscErrorCode PetscOptionsSAWsInput(PetscOptionItems *PetscOptionsObject)
 
   PetscFunctionBegin;
   /* the next line is a bug, this will only work if all processors are here, the comm passed in is ignored!!! */
-  sprintf(options, "Options_%d", count++);
+  PetscCall(PetscSNPrintf(options, PETSC_STATIC_ARRAY_LENGTH(options), "Options_%d", count++));
 
   PetscOptionsObject->pprefix = PetscOptionsObject->prefix; /* SAWs will change this, so cannot pass prefix directly */
 
@@ -401,10 +401,10 @@ PetscErrorCode PetscOptionsSAWsInput(PetscOptionItems *PetscOptionsObject)
   PetscCallSAWs(SAWs_Register, ("/PETSc/Options/StopAsking", &stopasking, 1, SAWs_WRITE, SAWs_BOOLEAN));
 
   while (next) {
-    sprintf(manname, "_man_%d", mancount);
+    PetscCall(PetscSNPrintf(manname, PETSC_STATIC_ARRAY_LENGTH(manname), "_man_%d", mancount));
     PetscCall(PetscSNPrintf(dir, 1024, "/PETSc/Options/%s", manname));
     PetscCallSAWs(SAWs_Register, (dir, &next->man, 1, SAWs_READ, SAWs_STRING));
-    sprintf(textname, "_text_%d", mancount++);
+    PetscCall(PetscSNPrintf(textname, PETSC_STATIC_ARRAY_LENGTH(textname), "_text_%d", mancount++));
     PetscCall(PetscSNPrintf(dir, 1024, "/PETSc/Options/%s", textname));
     PetscCallSAWs(SAWs_Register, (dir, &next->text, 1, SAWs_READ, SAWs_STRING));
 
@@ -488,7 +488,7 @@ PetscErrorCode PetscOptionsSAWsInput(PetscOptionItems *PetscOptionsObject)
   }
 
   PetscCallSAWs(SAWs_Delete, ("/PETSc/Options"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
 
@@ -521,70 +521,70 @@ PetscErrorCode PetscOptionsEnd_Private(PetscOptionItems *PetscOptionsObject)
   while (PetscOptionsObject->next) {
     if (PetscOptionsObject->next->set) {
       if (PetscOptionsObject->prefix) {
-        PetscCall(PetscStrcpy(option, "-"));
-        PetscCall(PetscStrcat(option, PetscOptionsObject->prefix));
-        PetscCall(PetscStrcat(option, PetscOptionsObject->next->option + 1));
-      } else PetscCall(PetscStrcpy(option, PetscOptionsObject->next->option));
+        PetscCall(PetscStrncpy(option, "-", sizeof(option)));
+        PetscCall(PetscStrlcat(option, PetscOptionsObject->prefix, sizeof(option)));
+        PetscCall(PetscStrlcat(option, PetscOptionsObject->next->option + 1, sizeof(option)));
+      } else PetscCall(PetscStrncpy(option, PetscOptionsObject->next->option, sizeof(option)));
 
       switch (PetscOptionsObject->next->type) {
       case OPTION_HEAD:
         break;
       case OPTION_INT_ARRAY:
-        sprintf(value, "%d", (int)((PetscInt *)PetscOptionsObject->next->data)[0]);
+        PetscCall(PetscSNPrintf(value, PETSC_STATIC_ARRAY_LENGTH(value), "%d", (int)((PetscInt *)PetscOptionsObject->next->data)[0]));
         for (j = 1; j < PetscOptionsObject->next->arraylength; j++) {
-          sprintf(tmp, "%d", (int)((PetscInt *)PetscOptionsObject->next->data)[j]);
-          PetscCall(PetscStrcat(value, ","));
-          PetscCall(PetscStrcat(value, tmp));
+          PetscCall(PetscSNPrintf(tmp, PETSC_STATIC_ARRAY_LENGTH(tmp), "%d", (int)((PetscInt *)PetscOptionsObject->next->data)[j]));
+          PetscCall(PetscStrlcat(value, ",", sizeof(value)));
+          PetscCall(PetscStrlcat(value, tmp, sizeof(value)));
         }
         break;
       case OPTION_INT:
-        sprintf(value, "%d", (int)*(PetscInt *)PetscOptionsObject->next->data);
+        PetscCall(PetscSNPrintf(value, PETSC_STATIC_ARRAY_LENGTH(value), "%d", (int)*(PetscInt *)PetscOptionsObject->next->data));
         break;
       case OPTION_REAL:
-        sprintf(value, "%g", (double)*(PetscReal *)PetscOptionsObject->next->data);
+        PetscCall(PetscSNPrintf(value, PETSC_STATIC_ARRAY_LENGTH(value), "%g", (double)*(PetscReal *)PetscOptionsObject->next->data));
         break;
       case OPTION_REAL_ARRAY:
-        sprintf(value, "%g", (double)((PetscReal *)PetscOptionsObject->next->data)[0]);
+        PetscCall(PetscSNPrintf(value, PETSC_STATIC_ARRAY_LENGTH(value), "%g", (double)((PetscReal *)PetscOptionsObject->next->data)[0]));
         for (j = 1; j < PetscOptionsObject->next->arraylength; j++) {
-          sprintf(tmp, "%g", (double)((PetscReal *)PetscOptionsObject->next->data)[j]);
-          PetscCall(PetscStrcat(value, ","));
-          PetscCall(PetscStrcat(value, tmp));
+          PetscCall(PetscSNPrintf(tmp, PETSC_STATIC_ARRAY_LENGTH(tmp), "%g", (double)((PetscReal *)PetscOptionsObject->next->data)[j]));
+          PetscCall(PetscStrlcat(value, ",", sizeof(value)));
+          PetscCall(PetscStrlcat(value, tmp, sizeof(value)));
         }
         break;
       case OPTION_SCALAR_ARRAY:
-        sprintf(value, "%g+%gi", (double)PetscRealPart(((PetscScalar *)PetscOptionsObject->next->data)[0]), (double)PetscImaginaryPart(((PetscScalar *)PetscOptionsObject->next->data)[0]));
+        PetscCall(PetscSNPrintf(value, PETSC_STATIC_ARRAY_LENGTH(value), "%g+%gi", (double)PetscRealPart(((PetscScalar *)PetscOptionsObject->next->data)[0]), (double)PetscImaginaryPart(((PetscScalar *)PetscOptionsObject->next->data)[0])));
         for (j = 1; j < PetscOptionsObject->next->arraylength; j++) {
-          sprintf(tmp, "%g+%gi", (double)PetscRealPart(((PetscScalar *)PetscOptionsObject->next->data)[j]), (double)PetscImaginaryPart(((PetscScalar *)PetscOptionsObject->next->data)[j]));
-          PetscCall(PetscStrcat(value, ","));
-          PetscCall(PetscStrcat(value, tmp));
+          PetscCall(PetscSNPrintf(tmp, PETSC_STATIC_ARRAY_LENGTH(tmp), "%g+%gi", (double)PetscRealPart(((PetscScalar *)PetscOptionsObject->next->data)[j]), (double)PetscImaginaryPart(((PetscScalar *)PetscOptionsObject->next->data)[j])));
+          PetscCall(PetscStrlcat(value, ",", sizeof(value)));
+          PetscCall(PetscStrlcat(value, tmp, sizeof(value)));
         }
         break;
       case OPTION_BOOL:
-        sprintf(value, "%d", *(int *)PetscOptionsObject->next->data);
+        PetscCall(PetscSNPrintf(value, PETSC_STATIC_ARRAY_LENGTH(value), "%d", *(int *)PetscOptionsObject->next->data));
         break;
       case OPTION_BOOL_ARRAY:
-        sprintf(value, "%d", (int)((PetscBool *)PetscOptionsObject->next->data)[0]);
+        PetscCall(PetscSNPrintf(value, PETSC_STATIC_ARRAY_LENGTH(value), "%d", (int)((PetscBool *)PetscOptionsObject->next->data)[0]));
         for (j = 1; j < PetscOptionsObject->next->arraylength; j++) {
-          sprintf(tmp, "%d", (int)((PetscBool *)PetscOptionsObject->next->data)[j]);
-          PetscCall(PetscStrcat(value, ","));
-          PetscCall(PetscStrcat(value, tmp));
+          PetscCall(PetscSNPrintf(tmp, PETSC_STATIC_ARRAY_LENGTH(tmp), "%d", (int)((PetscBool *)PetscOptionsObject->next->data)[j]));
+          PetscCall(PetscStrlcat(value, ",", sizeof(value)));
+          PetscCall(PetscStrlcat(value, tmp, sizeof(value)));
         }
         break;
       case OPTION_FLIST:
-        PetscCall(PetscStrcpy(value, (char *)PetscOptionsObject->next->data));
+        PetscCall(PetscStrncpy(value, (char *)PetscOptionsObject->next->data, sizeof(value)));
         break;
       case OPTION_ELIST:
-        PetscCall(PetscStrcpy(value, (char *)PetscOptionsObject->next->data));
+        PetscCall(PetscStrncpy(value, (char *)PetscOptionsObject->next->data, sizeof(value)));
         break;
       case OPTION_STRING:
-        PetscCall(PetscStrcpy(value, (char *)PetscOptionsObject->next->data));
+        PetscCall(PetscStrncpy(value, (char *)PetscOptionsObject->next->data, sizeof(value)));
         break;
       case OPTION_STRING_ARRAY:
-        sprintf(value, "%s", ((char **)PetscOptionsObject->next->data)[0]);
+        PetscCall(PetscSNPrintf(value, PETSC_STATIC_ARRAY_LENGTH(value), "%s", ((char **)PetscOptionsObject->next->data)[0]));
         for (j = 1; j < PetscOptionsObject->next->arraylength; j++) {
-          sprintf(tmp, "%s", ((char **)PetscOptionsObject->next->data)[j]);
-          PetscCall(PetscStrcat(value, ","));
-          PetscCall(PetscStrcat(value, tmp));
+          PetscCall(PetscSNPrintf(tmp, PETSC_STATIC_ARRAY_LENGTH(tmp), "%s", ((char **)PetscOptionsObject->next->data)[j]));
+          PetscCall(PetscStrlcat(value, ",", sizeof(value)));
+          PetscCall(PetscStrlcat(value, tmp, sizeof(value)));
         }
         break;
       }
@@ -608,7 +608,7 @@ PetscErrorCode PetscOptionsEnd_Private(PetscOptionItems *PetscOptionsObject)
   }
   PetscCall(PetscFree(PetscOptionsObject->prefix));
   PetscOptionsObject->next = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -626,10 +626,12 @@ PetscErrorCode PetscOptionsEnd_Private(PetscOptionItems *PetscOptionsObject)
 .  man - manual page with additional information on option
 .  list - array containing the list of choices, followed by the enum name, followed by the enum prefix, followed by a null
 -  currentvalue - the current value; caller is responsible for setting this value correctly. Normally this is done with either
-$                 PetscOptionsEnum(..., obj->value,&object->value,...) or
-$                 value = defaultvalue
-$                 PetscOptionsEnum(..., value,&value,&flg);
-$                 if (flg) {
+.vb
+                 PetscOptionsEnum(..., obj->value,&object->value,...) or
+                 value = defaultvalue
+                 PetscOptionsEnum(..., value,&value,&flg);
+                 if (flg) {
+.ve
 
    Output Parameters:
 +  value - the  value to return
@@ -670,7 +672,7 @@ PetscErrorCode PetscOptionsEnum_Private(PetscOptionItems *PetscOptionsObject, co
   /* with PETSC_USE_64BIT_INDICES sizeof(PetscInt) != sizeof(PetscEnum) */
   if (tflg) *value = (PetscEnum)tval;
   if (set) *set = tflg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -739,7 +741,7 @@ PetscErrorCode PetscOptionsEnumArray_Private(PetscOptionItems *PetscOptionsObjec
     for (i = 0; i < nlist; i++) PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, " %s", list[i]));
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, " (%s)\n", ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -749,23 +751,30 @@ PetscErrorCode PetscOptionsEnumArray_Private(PetscOptionItems *PetscOptionsObjec
 
    Synopsis:
    #include "petscsys.h"
-   PetscErrorCode  PetscOptionsBoundInt(const char opt[],const char text[],const char man[],PetscInt currentvalue,PetscInt *value,PetscBool *flg,PetscInt bound)
+   PetscErrorCode  PetscOptionsBoundedInt(const char opt[],const char text[],const char man[],PetscInt currentvalue,PetscInt *value,PetscBool *flg,PetscInt bound)
 
    Input Parameters:
 +  opt - option name
 .  text - short string that describes the option
 .  man - manual page with additional information on option
 .  currentvalue - the current value; caller is responsible for setting this value correctly. Normally this is done with either
-$                 PetscOptionsInt(..., obj->value,&obj->value,...) or
-$                 value = defaultvalue
-$                 PetscOptionsInt(..., value,&value,&flg);
-$                 if (flg) {
+.vb
+  PetscOptionsInt(..., obj->value,&obj->value,...)
+.ve
+or
+.vb
+  value = defaultvalue
+  PetscOptionsInt(..., value,&value,&flg);
+  if (flg) {
+.ve
 -  bound - the requested value should be greater than or equal this bound or an error is generated
 
    Output Parameters:
 +  value - the integer value to return
 -  flg - `PETSC_TRUE` if found, else `PETSC_FALSE`
 
+   Level: beginner
+
    Notes:
     If the user does not supply the option at all value is NOT changed. Thus
     you should ALWAYS initialize value if you access it without first checking if the set flag is true.
@@ -774,8 +783,6 @@ $                 if (flg) {
 
     Must be between a `PetscOptionsBegin()` and a `PetscOptionsEnd()`
 
-   Level: beginner
-
 .seealso: `PetscOptionsInt()`, `PetscOptionsGetReal()`, `PetscOptionsHasName()`, `PetscOptionsGetString()`, `PetscOptionsGetInt()`,
           `PetscOptionsGetIntArray()`, `PetscOptionsGetRealArray()`, `PetscOptionsGetBool()`, `PetscOptionsRangeInt()`
           `PetscOptionsInt()`, `PetscOptionsString()`, `PetscOptionsReal()`, `PetscOptionsBool()`,
@@ -799,10 +806,12 @@ M*/
 .  text - short string that describes the option
 .  man - manual page with additional information on option
 .  currentvalue - the current value; caller is responsible for setting this value correctly. Normally this is done with either
-$                 PetscOptionsInt(..., obj->value,&obj->value,...) or
-$                 value = defaultvalue
-$                 PetscOptionsInt(..., value,&value,&flg);
-$                 if (flg) {
+.vb
+                 PetscOptionsInt(..., obj->value,&obj->value,...) or
+                 value = defaultvalue
+                 PetscOptionsInt(..., value,&value,&flg);
+                 if (flg) {
+.ve
 .  lb - the lower bound, provided value must be greater than or equal to this value or an error is generated
 -  ub - the upper bound, provided value must be less than or equal to this value or an error is generated
 
@@ -810,6 +819,8 @@ $                 if (flg) {
 +  value - the integer value to return
 -  flg - `PETSC_TRUE` if found, else `PETSC_FALSE`
 
+   Level: beginner
+
    Notes:
     If the user does not supply the option at all value is NOT changed. Thus
     you should ALWAYS initialize value if you access it without first checking if the set flag is true.
@@ -818,8 +829,6 @@ $                 if (flg) {
 
     Must be between a `PetscOptionsBegin()` and a `PetscOptionsEnd()`
 
-   Level: beginner
-
 .seealso: `PetscOptionsInt()`, `PetscOptionsGetReal()`, `PetscOptionsHasName()`, `PetscOptionsGetString()`, `PetscOptionsGetInt()`,
           `PetscOptionsGetIntArray()`, `PetscOptionsGetRealArray()`, `PetscOptionsGetBool()`, `PetscOptionsBoundedInt()`
           `PetscOptionsInt()`, `PetscOptionsString()`, `PetscOptionsReal()`, `PetscOptionsBool()`,
@@ -843,10 +852,12 @@ M*/
 .  text - short string that describes the option
 .  man - manual page with additional information on option
 -  currentvalue - the current value; caller is responsible for setting this value correctly. Normally this is done with either
-$                 PetscOptionsInt(..., obj->value,&obj->value,...) or
-$                 value = defaultvalue
-$                 PetscOptionsInt(..., value,&value,&flg);
-$                 if (flg) {
+.vb
+                 PetscOptionsInt(..., obj->value,&obj->value,...) or
+                 value = defaultvalue
+                 PetscOptionsInt(..., value,&value,&flg);
+                 if (flg) {
+.ve
 
    Output Parameters:
 +  value - the integer value to return
@@ -894,7 +905,7 @@ PetscErrorCode PetscOptionsInt_Private(PetscOptionItems *PetscOptionsObject, con
   if (PetscOptionsObject->printhelp && PetscOptionsObject->count == 1 && !PetscOptionsObject->alreadyprinted) {
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "  -%s%s <now %" PetscInt_FMT " : formerly %" PetscInt_FMT ">: %s (%s)\n", PetscOptionsObject->prefix ? PetscOptionsObject->prefix : "", opt + 1, wasset && value ? *value : currentvalue, currentvalue, text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -954,7 +965,7 @@ PetscErrorCode PetscOptionsString_Private(PetscOptionItems *PetscOptionsObject,
   if (PetscOptionsObject->printhelp && PetscOptionsObject->count == 1 && !PetscOptionsObject->alreadyprinted) {
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "  -%s%s <now %s : formerly %s>: %s (%s)\n", PetscOptionsObject->prefix ? PetscOptionsObject->prefix : "", opt + 1, lset && value ? value : currentvalue, currentvalue, text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -971,10 +982,12 @@ PetscErrorCode PetscOptionsString_Private(PetscOptionItems *PetscOptionsObject,
 .  text - short string that describes the option
 .  man - manual page with additional information on option
 -  currentvalue - the current value; caller is responsible for setting this value correctly. Normally this is done with either
-$                 PetscOptionsReal(..., obj->value,&obj->value,...) or
-$                 value = defaultvalue
-$                 PetscOptionsReal(..., value,&value,&flg);
-$                 if (flg) {
+.vb
+                 PetscOptionsReal(..., obj->value,&obj->value,...) or
+                 value = defaultvalue
+                 PetscOptionsReal(..., value,&value,&flg);
+                 if (flg) {
+.ve
 
    Output Parameters:
 +  value - the value to return
@@ -1016,7 +1029,7 @@ PetscErrorCode PetscOptionsReal_Private(PetscOptionItems *PetscOptionsObject, co
   if (PetscOptionsObject->printhelp && PetscOptionsObject->count == 1 && !PetscOptionsObject->alreadyprinted) {
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "  -%s%s <%g : %g>: %s (%s)\n", PetscOptionsObject->prefix ? PetscOptionsObject->prefix : "", opt + 1, lset && value ? (double)*value : (double)currentvalue, (double)currentvalue, text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1033,10 +1046,12 @@ PetscErrorCode PetscOptionsReal_Private(PetscOptionItems *PetscOptionsObject, co
 .  text - short string that describes the option
 .  man - manual page with additional information on option
 -  currentvalue - the current value; caller is responsible for setting this value correctly. Normally this is done with either
-$                 PetscOptionsScalar(..., obj->value,&obj->value,...) or
-$                 value = defaultvalue
-$                 PetscOptionsScalar(..., value,&value,&flg);
-$                 if (flg) {
+.vb
+                 PetscOptionsScalar(..., obj->value,&obj->value,...) or
+                 value = defaultvalue
+                 PetscOptionsScalar(..., value,&value,&flg);
+                 if (flg) {
+.ve
 
    Output Parameters:
 +  value - the value to return
@@ -1069,7 +1084,7 @@ PetscErrorCode PetscOptionsScalar_Private(PetscOptionItems *PetscOptionsObject,
 #else
   PetscCall(PetscOptionsGetScalar(PetscOptionsObject->options, PetscOptionsObject->prefix, opt, value, set));
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1119,7 +1134,7 @@ PetscErrorCode PetscOptionsName_Private(PetscOptionItems *PetscOptionsObject, co
   if (PetscOptionsObject->printhelp && PetscOptionsObject->count == 1 && !PetscOptionsObject->alreadyprinted) {
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "  -%s%s: %s (%s)\n", PetscOptionsObject->prefix ? PetscOptionsObject->prefix : "", opt + 1, text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1137,8 +1152,10 @@ PetscErrorCode PetscOptionsName_Private(PetscOptionItems *PetscOptionsObject, co
 .  man - manual page with additional information on option
 .  list - the possible choices
 .  currentvalue - the current value; caller is responsible for setting this value correctly. Normally this is done with
-$                 PetscOptionsFlist(..., obj->value,value,len,&flg);
-$                 if (flg) {
+.vb
+                 PetscOptionsFlist(..., obj->value,value,len,&flg);
+                 if (flg) {
+.ve
 -  len - the length of the character array value
 
    Output Parameters:
@@ -1188,7 +1205,7 @@ PetscErrorCode PetscOptionsFList_Private(PetscOptionItems *PetscOptionsObject, c
   if (PetscOptionsObject->printhelp && PetscOptionsObject->count == 1 && !PetscOptionsObject->alreadyprinted) {
     PetscCall(PetscFunctionListPrintTypes(PetscOptionsObject->comm, stdout, PetscOptionsObject->prefix, opt, ltext, man, list, currentvalue, lset && value ? value : currentvalue));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1207,8 +1224,9 @@ PetscErrorCode PetscOptionsFList_Private(PetscOptionItems *PetscOptionsObject, c
 .  list - the possible choices (one of these must be selected, anything else is invalid)
 .  ntext - number of choices
 -  currentvalue - the current value; caller is responsible for setting this value correctly. Normally this is done with
-$                 PetscOptionsElist(..., obj->value,&value,&flg);
-$                 if (flg) {
+.vb
+                 PetscOptionsEList(..., obj->value,&value,&flg);
+.ve                 if (flg) {
 
    Output Parameters:
 +  value - the index of the value to return
@@ -1253,7 +1271,7 @@ PetscErrorCode PetscOptionsEList_Private(PetscOptionItems *PetscOptionsObject, c
     for (i = 0; i < ntext; i++) PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, " %s", list[i]));
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, " (%s)\n", ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1306,7 +1324,7 @@ PetscErrorCode PetscOptionsBoolGroupBegin_Private(PetscOptionItems *PetscOptions
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "  Pick at most one of -------------\n"));
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "    -%s%s: %s (%s)\n", PetscOptionsObject->prefix ? PetscOptionsObject->prefix : "", opt + 1, text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1358,7 +1376,7 @@ PetscErrorCode PetscOptionsBoolGroup_Private(PetscOptionItems *PetscOptionsObjec
   if (PetscOptionsObject->printhelp && PetscOptionsObject->count == 1 && !PetscOptionsObject->alreadyprinted) {
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "    -%s%s: %s (%s)\n", PetscOptionsObject->prefix ? PetscOptionsObject->prefix : "", opt + 1, text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1410,7 +1428,7 @@ PetscErrorCode PetscOptionsBoolGroupEnd_Private(PetscOptionItems *PetscOptionsOb
   if (PetscOptionsObject->printhelp && PetscOptionsObject->count == 1 && !PetscOptionsObject->alreadyprinted) {
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "    -%s%s: %s (%s)\n", PetscOptionsObject->prefix ? PetscOptionsObject->prefix : "", opt + 1, text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1473,7 +1491,7 @@ PetscErrorCode PetscOptionsBool_Private(PetscOptionItems *PetscOptionsObject, co
     const char *v = PetscBools[currentvalue], *vn = PetscBools[iset && flg ? *flg : currentvalue];
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "  -%s%s: <%s : %s> %s (%s)\n", PetscOptionsObject->prefix ? PetscOptionsObject->prefix : "", opt + 1, v, vn, text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1531,7 +1549,7 @@ PetscErrorCode PetscOptionsRealArray_Private(PetscOptionItems *PetscOptionsObjec
     for (i = 1; i < *n; i++) PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, ",%g", (double)value[i]));
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, ">: %s (%s)\n", text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1589,7 +1607,7 @@ PetscErrorCode PetscOptionsScalarArray_Private(PetscOptionItems *PetscOptionsObj
     for (i = 1; i < *n; i++) PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, ",%g+%gi", (double)PetscRealPart(value[i]), (double)PetscImaginaryPart(value[i])));
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, ">: %s (%s)\n", text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1655,7 +1673,7 @@ PetscErrorCode PetscOptionsIntArray_Private(PetscOptionItems *PetscOptionsObject
     for (i = 1; i < *n; i++) PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, ",%" PetscInt_FMT, value[i]));
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, ">: %s (%s)\n", text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1663,7 +1681,7 @@ PetscErrorCode PetscOptionsIntArray_Private(PetscOptionItems *PetscOptionsObject
    option in the database. The values must be separated with commas with
    no intervening spaces.
 
-   Logically Collective on the communicator passed in `PetscOptionsBegin()`
+   Logically Collective on the communicator passed in `PetscOptionsBegin()`; No Fortran Support
 
    Synopsis:
    #include "petscsys.h"
@@ -1687,7 +1705,7 @@ PetscErrorCode PetscOptionsIntArray_Private(PetscOptionItems *PetscOptionsObject
    strings returned by this function.
 
    The user is responsible for deallocating the strings that are
-   returned. The Fortran interface for this routine is not supported.
+   returned.
 
    Must be between a `PetscOptionsBegin()` and a `PetscOptionsEnd()`
 
@@ -1714,7 +1732,7 @@ PetscErrorCode PetscOptionsStringArray_Private(PetscOptionItems *PetscOptionsObj
   if (PetscOptionsObject->printhelp && PetscOptionsObject->count == 1 && !PetscOptionsObject->alreadyprinted) {
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "  -%s%s <string1,string2,...>: %s (%s)\n", PetscOptionsObject->prefix ? PetscOptionsObject->prefix : "", opt + 1, text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1775,7 +1793,7 @@ PetscErrorCode PetscOptionsBoolArray_Private(PetscOptionItems *PetscOptionsObjec
     for (i = 1; i < *n; i++) PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, ",%d", value[i]));
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, ">: %s (%s)\n", text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -1827,5 +1845,5 @@ PetscErrorCode PetscOptionsViewer_Private(PetscOptionItems *PetscOptionsObject,
   if (PetscOptionsObject->printhelp && PetscOptionsObject->count == 1 && !PetscOptionsObject->alreadyprinted) {
     PetscCall((*PetscHelpPrintf)(PetscOptionsObject->comm, "  -%s%s <%s>: %s (%s)\n", PetscOptionsObject->prefix ? PetscOptionsObject->prefix : "", opt + 1, "", text, ManSection(man)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
