@@ -57,11 +57,10 @@ PetscErrorCode PetscHeaderCreate_Private(PetscObject h, PetscClassId classid, co
 
   /* Increment and store current object creation index */
   PetscCallMPI(MPI_Comm_get_attr(h->comm, Petsc_CreationIdx_keyval, &get_tmp, &flg));
-  if (flg) {
-    cidx    = (PetscInt64 *)get_tmp;
-    h->cidx = (*cidx)++;
-    PetscCallMPI(MPI_Comm_set_attr(h->comm, Petsc_CreationIdx_keyval, cidx));
-  } else SETERRQ(h->comm, PETSC_ERR_ARG_CORRUPT, "MPI_Comm does not have an object creation index");
+  PetscCheck(flg, h->comm, PETSC_ERR_ARG_CORRUPT, "MPI_Comm does not have an object creation index");
+  cidx    = (PetscInt64 *)get_tmp;
+  h->cidx = (*cidx)++;
+  PetscCallMPI(MPI_Comm_set_attr(h->comm, Petsc_CreationIdx_keyval, cidx));
 
 #if defined(PETSC_USE_LOG)
   /* Keep a record of object created */
@@ -73,7 +72,7 @@ PetscErrorCode PetscHeaderCreate_Private(PetscObject h, PetscClassId classid, co
     for (PetscInt i = 0; i < PetscObjectsMaxCounts; ++i) {
       if (!PetscObjects[i]) {
         PetscObjects[i] = h;
-        PetscFunctionReturn(0);
+        PetscFunctionReturn(PETSC_SUCCESS);
       }
     }
     /* Need to increase the space for storing PETSc objects */
@@ -88,7 +87,7 @@ PetscErrorCode PetscHeaderCreate_Private(PetscObject h, PetscClassId classid, co
     PetscObjectsMaxCounts               = newPetscObjectsMaxCounts;
   }
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_INTERN PetscBool      PetscMemoryCollectMaximumUsage;
@@ -178,7 +177,7 @@ PetscErrorCode PetscHeaderDestroy_Private(PetscObject obj, PetscBool clear_for_r
     }
 #endif
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -203,13 +202,13 @@ PetscErrorCode PetscHeaderReset_Internal(PetscObject obj)
 {
   PetscFunctionBegin;
   PetscCall(PetscHeaderDestroy_Private(obj, PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscObjectCopyFortranFunctionPointers - Copy function pointers to another object
 
-   Logically Collective on src
+   Logically Collective
 
    Input Parameters:
 +  src - source object
@@ -244,7 +243,7 @@ PetscErrorCode PetscObjectCopyFortranFunctionPointers(PetscObject src, PetscObje
     PetscCall(PetscMemcpy(dest->fortrancallback[cbtype], src->fortrancallback[cbtype], src->num_fortrancallback[cbtype] * sizeof(PetscFortranCallback)));
     dest->num_fortrancallback[cbtype] = src->num_fortrancallback[cbtype];
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -287,7 +286,7 @@ PetscErrorCode PetscObjectSetFortranCallback(PetscObject obj, PetscFortranCallba
   }
   obj->fortrancallback[cbtype][*cid - PETSC_SMALLEST_FORTRAN_CALLBACK].func = func;
   obj->fortrancallback[cbtype][*cid - PETSC_SMALLEST_FORTRAN_CALLBACK].ctx  = ctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -322,7 +321,7 @@ PetscErrorCode PetscObjectGetFortranCallback(PetscObject obj, PetscFortranCallba
   cb = &obj->fortrancallback[cbtype][cid - PETSC_SMALLEST_FORTRAN_CALLBACK];
   if (func) *func = cb->func;
   if (ctx) *ctx = cb->ctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if defined(PETSC_USE_LOG)
@@ -343,10 +342,7 @@ PetscErrorCode PetscObjectGetFortranCallback(PetscObject obj, PetscFortranCallba
 @*/
 PetscErrorCode PetscObjectsDump(FILE *fd, PetscBool all)
 {
-  PetscInt i;
-  #if defined(PETSC_USE_DEBUG)
-  PetscInt j, k = 0;
-  #endif
+  PetscInt    i, j, k = 0;
   PetscObject h;
 
   PetscFunctionBegin;
@@ -357,9 +353,8 @@ PetscErrorCode PetscObjectsDump(FILE *fd, PetscBool all)
       if ((h = PetscObjects[i])) {
         PetscCall(PetscObjectName(h));
         {
-  #if defined(PETSC_USE_DEBUG)
-          PetscStack *stack = NULL;
-          char       *create, *rclass;
+          PetscStack *stack  = NULL;
+          char       *create = NULL, *rclass = NULL;
 
           /* if the PETSc function the user calls is not a create then this object was NOT directly created by them */
           PetscCall(PetscMallocGetStack(h, &stack));
@@ -375,30 +370,24 @@ PetscErrorCode PetscObjectsDump(FILE *fd, PetscBool all)
               if (!rclass) continue;
             }
           }
-  #endif
 
           PetscCall(PetscFPrintf(PETSC_COMM_WORLD, fd, "[%d] %s %s %s\n", PetscGlobalRank, h->class_name, h->type_name, h->name));
 
-  #if defined(PETSC_USE_DEBUG)
           PetscCall(PetscMallocGetStack(h, &stack));
           if (stack) {
             for (j = k; j >= 0; j--) fprintf(fd, "      [%d]  %s() in %s\n", PetscGlobalRank, stack->function[j], stack->file[j]);
           }
-  #endif
         }
       }
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
-#endif
-
-#if defined(PETSC_USE_LOG)
 
 /*@C
    PetscObjectsView - Prints the currently existing objects.
 
-   Logically Collective on viewer
+   Logically Collective
 
    Input Parameter:
 .  viewer - must be an `PETSCVIEWERASCII` viewer
@@ -417,13 +406,13 @@ PetscErrorCode PetscObjectsView(PetscViewer viewer)
   PetscCheck(isascii, PetscObjectComm((PetscObject)viewer), PETSC_ERR_SUP, "Only supports ASCII viewer");
   PetscCall(PetscViewerASCIIGetPointer(viewer, &fd));
   PetscCall(PetscObjectsDump(fd, PETSC_TRUE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscObjectsGetObject - Get a pointer to a named object
 
-   Not collective
+   Not Collective
 
    Input Parameter:
 .  name - the name of an object
@@ -452,18 +441,18 @@ PetscErrorCode PetscObjectsGetObject(const char *name, PetscObject *obj, char **
       if (flg) {
         *obj = h;
         if (classname) *classname = h->class_name;
-        PetscFunctionReturn(0);
+        PetscFunctionReturn(PETSC_SUCCESS);
       }
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
 
 /*@
    PetscObjectSetPrintedOptions - indicate to an object that it should behave as if it has already printed the help for its options so it will not display the help message
 
-   Input Parameters:
+   Input Parameter:
 .  obj  - the `PetscObject`
 
    Level: developer
@@ -479,7 +468,7 @@ PetscErrorCode PetscObjectSetPrintedOptions(PetscObject obj)
   PetscFunctionBegin;
   PetscValidPointer(obj, 1);
   obj->optionsprinted = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -509,7 +498,7 @@ PetscErrorCode PetscObjectInheritPrintedOptions(PetscObject pobj, PetscObject ob
   PetscCallMPI(MPI_Comm_rank(pobj->comm, &prank));
   PetscCallMPI(MPI_Comm_size(obj->comm, &size));
   if (size == 1 && prank > 0) obj->optionsprinted = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -535,7 +524,7 @@ PetscErrorCode PetscObjectAddOptionsHandler(PetscObject obj, PetscErrorCode (*ha
   obj->optionhandler[obj->noptionhandler] = handle;
   obj->optiondestroy[obj->noptionhandler] = destroy;
   obj->optionctx[obj->noptionhandler++]   = ctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -556,7 +545,7 @@ PetscErrorCode PetscObjectProcessOptionsHandlers(PetscObject obj, PetscOptionIte
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
   for (PetscInt i = 0; i < obj->noptionhandler; i++) PetscCall((*obj->optionhandler[i])(obj, PetscOptionsObject, obj->optionctx[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -579,7 +568,7 @@ PetscErrorCode PetscObjectDestroyOptionsHandlers(PetscObject obj)
     if (obj->optiondestroy[i]) PetscCall((*obj->optiondestroy[i])(obj, obj->optionctx[i]));
   }
   obj->noptionhandler = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -587,7 +576,7 @@ PetscErrorCode PetscObjectDestroyOptionsHandlers(PetscObject obj)
    referenced by another `PetscObject`. This increases the reference
    count for that object by one.
 
-   Logically Collective on obj
+   Logically Collective
 
    Input Parameter:
 .  obj - the PETSc object. This must be cast with (`PetscObject`), for example,
@@ -600,10 +589,10 @@ PetscErrorCode PetscObjectDestroyOptionsHandlers(PetscObject obj)
 PetscErrorCode PetscObjectReference(PetscObject obj)
 {
   PetscFunctionBegin;
-  if (!obj) PetscFunctionReturn(0);
+  if (!obj) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeader(obj, 1);
   obj->refct++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -629,7 +618,7 @@ PetscErrorCode PetscObjectGetReference(PetscObject obj, PetscInt *cnt)
   PetscValidHeader(obj, 1);
   PetscValidIntPointer(cnt, 2);
   *cnt = obj->refct;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -643,21 +632,21 @@ PetscErrorCode PetscObjectGetReference(PetscObject obj, PetscInt *cnt)
 .  obj - the PETSc object; this must be cast with (`PetscObject`), for example,
          `PetscObjectDereference`((`PetscObject`)mat);
 
+   Level: advanced
+
    Note:
     `PetscObjectDestroy()` sets the obj pointer to null after the call, this routine does not.
 
-   Level: advanced
-
 .seealso: `PetscObjectCompose()`, `PetscObjectReference()`, `PetscObjectDestroy()`
 @*/
 PetscErrorCode PetscObjectDereference(PetscObject obj)
 {
   PetscFunctionBegin;
-  if (!obj) PetscFunctionReturn(0);
+  if (!obj) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeader(obj, 1);
   if (obj->bops->destroy) PetscCall((*obj->bops->destroy)(&obj));
   else PetscCheck(--(obj->refct), PETSC_COMM_SELF, PETSC_ERR_SUP, "This PETSc object does not have a generic destroy routine");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ----------------------------------------------------------------------- */
@@ -670,7 +659,7 @@ PetscErrorCode PetscObjectRemoveReference(PetscObject obj, const char name[])
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
   PetscCall(PetscObjectListRemoveReference(&obj->olist, name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscObjectCompose_Petsc(PetscObject obj, const char name[], PetscObject ptr)
@@ -684,7 +673,7 @@ PetscErrorCode PetscObjectCompose_Petsc(PetscObject obj, const char name[], Pets
     if (tname) PetscCheck(skipreference, PETSC_COMM_SELF, PETSC_ERR_ARG_INCOMP, "An object cannot be composed with an object that was composed with it");
   }
   PetscCall(PetscObjectListAdd(&obj->olist, name, ptr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscObjectQuery_Petsc(PetscObject obj, const char name[], PetscObject *ptr)
@@ -692,7 +681,7 @@ PetscErrorCode PetscObjectQuery_Petsc(PetscObject obj, const char name[], PetscO
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
   PetscCall(PetscObjectListFind(obj->olist, name, ptr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscObjectComposeFunction_Petsc(PetscObject obj, const char name[], void (*ptr)(void))
@@ -700,7 +689,7 @@ PetscErrorCode PetscObjectComposeFunction_Petsc(PetscObject obj, const char name
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
   PetscCall(PetscFunctionListAdd(&obj->qlist, name, ptr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscObjectQueryFunction_Petsc(PetscObject obj, const char name[], void (**ptr)(void))
@@ -708,7 +697,7 @@ PetscErrorCode PetscObjectQueryFunction_Petsc(PetscObject obj, const char name[]
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
   PetscCall(PetscFunctionListFind(obj->qlist, name, ptr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -751,7 +740,7 @@ PetscErrorCode PetscObjectCompose(PetscObject obj, const char name[], PetscObjec
   if (ptr) PetscValidHeader(ptr, 3);
   PetscCheck(obj != ptr, PetscObjectComm((PetscObject)obj), PETSC_ERR_SUP, "Cannot compose object with itself");
   PetscCall((*obj->bops->compose)(obj, name, ptr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -782,7 +771,7 @@ PetscErrorCode PetscObjectQuery(PetscObject obj, const char name[], PetscObject
   PetscValidCharPointer(name, 2);
   PetscValidPointer(ptr, 3);
   PetscCall((*obj->bops->query)(obj, name, ptr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -790,32 +779,31 @@ PetscErrorCode PetscObjectQuery(PetscObject obj, const char name[], PetscObject
 
     Synopsis:
     #include <petscsys.h>
-    PetscErrorCode PetscObjectComposeFunction(PetscObject obj,const char name[],void (*fptr)(void))
+    PetscErrorCode PetscObjectComposeFunction(PetscObject obj, const char name[], void (*fptr)(void))
 
-   Logically Collective on obj
+   Logically Collective
 
    Input Parameters:
 +  obj - the PETSc object; this must be cast with a (`PetscObject`), for example,
          `PetscObjectCompose`((`PetscObject`)mat,...);
 .  name - name associated with the child function
-.  fname - name of the function
 -  fptr - function pointer
 
    Level: advanced
 
    Notes:
-   When the first argument of the function is the object within which it has been composed then `PetscTryMethod()` and `PetscUseMethod()`
+   When the first argument of `fptr` is (or is derived from) a `PetscObject` then `PetscTryMethod()` and `PetscUseMethod()`
    can be used to call the function directly with error checking.
 
-   To remove a registered routine, pass in NULL for fptr().
+   To remove a registered routine, pass in `NULL` for `fptr`.
 
-   PetscObjectComposeFunction() can be used with any PETSc object (such as
+   `PetscObjectComposeFunction()` can be used with any PETSc object (such as
    `Mat`, `Vec`, `KSP`, `SNES`, etc.) or any user-provided object.
 
-   `PetscCallMethod()` is used to call a function that is stored in the objects obj->ops table.
+   `PetscUseTypeMethod()` and `PetscTryTypeMethod()` are used to call a function that is stored in the objects `obj->ops` table.
 
 .seealso: `PetscObjectQueryFunction()`, `PetscContainerCreate()` `PetscObjectCompose()`, `PetscObjectQuery()`, `PetscTryMethod()`, `PetscUseMethod()`,
-          `PetscCallMethod()`
+          `PetscUseTypeMethod()`, `PetscTryTypeMethod()`
 M*/
 
 PetscErrorCode PetscObjectComposeFunction_Private(PetscObject obj, const char name[], void (*fptr)(void))
@@ -824,7 +812,7 @@ PetscErrorCode PetscObjectComposeFunction_Private(PetscObject obj, const char na
   PetscValidHeader(obj, 1);
   PetscValidCharPointer(name, 2);
   PetscCall((*obj->bops->composefunction)(obj, name, fptr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -834,7 +822,7 @@ PetscErrorCode PetscObjectComposeFunction_Private(PetscObject obj, const char na
     #include <petscsys.h>
     PetscErrorCode PetscObjectQueryFunction(PetscObject obj,const char name[],void (**fptr)(void))
 
-   Logically Collective on obj
+   Logically Collective
 
    Input Parameters:
 +  obj - the PETSc object; this must be cast with (`PetscObject`), for example,
@@ -854,7 +842,7 @@ PETSC_EXTERN PetscErrorCode PetscObjectQueryFunction_Private(PetscObject obj, co
   PetscValidHeader(obj, 1);
   PetscValidCharPointer(name, 2);
   PetscCall((*obj->bops->queryfunction)(obj, name, ptr));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 struct _p_PetscContainer {
@@ -880,7 +868,7 @@ PetscErrorCode PetscContainerUserDestroyDefault(void *ctx)
 {
   PetscFunctionBegin;
   PetscCall(PetscFree(ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -905,13 +893,13 @@ PetscErrorCode PetscContainerGetPointer(PetscContainer obj, void **ptr)
   PetscValidHeaderSpecific(obj, PETSC_CONTAINER_CLASSID, 1);
   PetscValidPointer(ptr, 2);
   *ptr = obj->ptr;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscContainerSetPointer - Sets the pointer value contained in the container.
 
-   Logically Collective on obj
+   Logically Collective
 
    Input Parameters:
 +  obj - the object created with `PetscContainerCreate()`
@@ -928,13 +916,13 @@ PetscErrorCode PetscContainerSetPointer(PetscContainer obj, void *ptr)
   PetscValidHeaderSpecific(obj, PETSC_CONTAINER_CLASSID, 1);
   if (ptr) PetscValidPointer(ptr, 2);
   obj->ptr = ptr;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscContainerDestroy - Destroys a PETSc container object.
 
-   Collective on obj
+   Collective
 
    Input Parameter:
 .  obj - an object that was created with `PetscContainerCreate()`
@@ -950,31 +938,31 @@ PetscErrorCode PetscContainerSetPointer(PetscContainer obj, void *ptr)
 PetscErrorCode PetscContainerDestroy(PetscContainer *obj)
 {
   PetscFunctionBegin;
-  if (!*obj) PetscFunctionReturn(0);
+  if (!*obj) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*obj, PETSC_CONTAINER_CLASSID, 1);
   if (--((PetscObject)(*obj))->refct > 0) {
     *obj = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if ((*obj)->userdestroy) PetscCall((*(*obj)->userdestroy)((*obj)->ptr));
   PetscCall(PetscHeaderDestroy(obj));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PetscContainerSetUserDestroy - Sets name of the user destroy function for the data provided to the `PetscContainer` with `PetscContainerSetPointer()`
 
-   Logically Collective on obj
+   Logically Collective
 
    Input Parameters:
 +  obj - an object that was created with `PetscContainerCreate()`
 -  des - name of the user destroy function
 
+   Level: advanced
+
    Note:
    Use `PetscContainerUserDestroyDefault()` if the memory was obtained by calling `PetscMalloc()` or one of its variants for single memory allocation.
 
-   Level: advanced
-
 .seealso: `PetscContainerDestroy()`, `PetscContainerUserDestroyDefault()`, `PetscMalloc()`, `PetscMalloc1()`, `PetscCalloc()`, `PetscCalloc1()`
 @*/
 PetscErrorCode PetscContainerSetUserDestroy(PetscContainer obj, PetscErrorCode (*des)(void *))
@@ -982,7 +970,7 @@ PetscErrorCode PetscContainerSetUserDestroy(PetscContainer obj, PetscErrorCode (
   PetscFunctionBegin;
   PetscValidHeaderSpecific(obj, PETSC_CONTAINER_CLASSID, 1);
   obj->userdestroy = des;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscClassId PETSC_CONTAINER_CLASSID;
@@ -995,10 +983,10 @@ PetscClassId PETSC_CONTAINER_CLASSID;
 
    Collective
 
-   Input Parameters:
+   Input Parameter:
 .  comm - MPI communicator that shares the object
 
-   Output Parameters:
+   Output Parameter:
 .  container - the container created
 
    Level: advanced
@@ -1012,49 +1000,49 @@ PetscErrorCode PetscContainerCreate(MPI_Comm comm, PetscContainer *container)
   PetscValidPointer(container, 2);
   PetscCall(PetscSysInitializePackage());
   PetscCall(PetscHeaderCreate(*container, PETSC_CONTAINER_CLASSID, "PetscContainer", "Container", "Sys", comm, PetscContainerDestroy, NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PetscObjectSetFromOptions - Sets generic parameters from user options.
 
-   Collective on obj
+   Collective
 
    Input Parameter:
 .  obj - the `PetscObject`
 
+   Level: beginner
+
    Note:
    We have no generic options at present, so this does nothing
 
-   Level: beginner
-
 .seealso: `PetscObjectSetOptionsPrefix()`, `PetscObjectGetOptionsPrefix()`
 @*/
 PetscErrorCode PetscObjectSetFromOptions(PetscObject obj)
 {
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PetscObjectSetUp - Sets up the internal data structures for the later use.
 
-   Collective on obj
+   Collective
 
-   Input Parameters:
+   Input Parameter:
 .  obj - the `PetscObject`
 
+   Level: advanced
+
    Note:
    This does nothing at present.
 
-   Level: advanced
-
 .seealso: `PetscObjectDestroy()`
 @*/
 PetscErrorCode PetscObjectSetUp(PetscObject obj)
 {
   PetscFunctionBegin;
   PetscValidHeader(obj, 1);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
