@@ -14,7 +14,7 @@
   #include <petsc/private/fortranimpl.h>
 #endif
 
-#if defined(PETSC_USE_GCOV)
+#if PetscDefined(USE_COVERAGE)
 EXTERN_C_BEGIN
   #if defined(PETSC_HAVE___GCOV_DUMP)
     #define __gcov_flush(x) __gcov_dump(x)
@@ -57,6 +57,9 @@ PetscMPIInt Petsc_ShmComm_keyval      = MPI_KEYVAL_INVALID;
 PetscMPIInt Petsc_CreationIdx_keyval  = MPI_KEYVAL_INVALID;
 PetscMPIInt Petsc_Garbage_HMap_keyval = MPI_KEYVAL_INVALID;
 
+PetscMPIInt Petsc_SharedWD_keyval  = MPI_KEYVAL_INVALID;
+PetscMPIInt Petsc_SharedTmp_keyval = MPI_KEYVAL_INVALID;
+
 /*
      Declare and set all the string names of the PETSc enums
 */
@@ -102,7 +105,7 @@ PetscErrorCode PetscInitializeNoPointers(int argc, char **args, const char *file
   PetscCall(PetscInitialize(&myargc, &myargs, filename, help));
   PetscCall(PetscPopSignalHandler());
   PetscBeganMPI = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -113,7 +116,7 @@ PetscErrorCode PetscGetPETSC_COMM_SELF(MPI_Comm *comm)
   PetscFunctionBegin;
   if (PetscInitializeCalled) PetscValidPointer(comm, 1);
   *comm = PETSC_COMM_SELF;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -133,7 +136,7 @@ PetscErrorCode PetscInitializeNoArguments(void)
 
   PetscFunctionBegin;
   PetscCall(PetscInitialize(&argc, &args, NULL, NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -148,7 +151,7 @@ PetscErrorCode PetscInitialized(PetscBool *isInitialized)
   PetscFunctionBegin;
   if (PetscInitializeCalled) PetscValidBoolPointer(isInitialized, 1);
   *isInitialized = PetscInitializeCalled;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -163,7 +166,7 @@ PetscErrorCode PetscFinalized(PetscBool *isFinalized)
   PetscFunctionBegin;
   if (!PetscFinalizeCalled) PetscValidBoolPointer(isFinalized, 1);
   *isFinalized = PetscFinalizeCalled;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_INTERN PetscErrorCode PetscOptionsCheckInitial_Private(const char[]);
@@ -181,7 +184,8 @@ PETSC_INTERN void MPIAPI MPIU_MaxSum_Local(void *in, void *out, int *cnt, MPI_Da
 
   PetscFunctionBegin;
   if (*datatype != MPIU_2INT) {
-    (*PetscErrorPrintf)("Can only handle MPIU_2INT data types");
+    PetscErrorCode ierr = (*PetscErrorPrintf)("Can only handle MPIU_2INT data types");
+    (void)ierr;
     PETSCABORT(MPI_COMM_SELF, PETSC_ERR_ARG_WRONG);
   }
 
@@ -227,7 +231,7 @@ PetscErrorCode PetscMaxSum(MPI_Comm comm, const PetscInt sizes[], PetscInt *max,
     PetscCall(PetscFree(work));
   }
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ----------------------------------------------------------------------------*/
@@ -260,9 +264,11 @@ PETSC_EXTERN void MPIAPI PetscSum_Local(void *in, void *out, PetscMPIInt *cnt, M
   else if (*datatype == MPIU___FLOAT128) {
     __float128 *xin = (__float128 *)in, *xout = (__float128 *)out;
     for (i = 0; i < count; i++) xout[i] += xin[i];
+    #if defined(PETSC_HAVE_COMPLEX)
   } else if (*datatype == MPIU___COMPLEX128) {
     __complex128 *xin = (__complex128 *)in, *xout = (__complex128 *)out;
     for (i = 0; i < count; i++) xout[i] += xin[i];
+    #endif
   }
   #endif
   #if defined(PETSC_HAVE_REAL___FP16)
@@ -273,13 +279,13 @@ PETSC_EXTERN void MPIAPI PetscSum_Local(void *in, void *out, PetscMPIInt *cnt, M
   #endif
   else {
   #if !defined(PETSC_HAVE_REAL___FLOAT128) && !defined(PETSC_HAVE_REAL___FP16)
-    (*PetscErrorPrintf)("Can only handle MPIU_REAL or MPIU_COMPLEX data types");
+    PetscCallAbort(MPI_COMM_SElF, (*PetscErrorPrintf)("Can only handle MPIU_REAL or MPIU_COMPLEX data types"));
   #elif !defined(PETSC_HAVE_REAL___FP16)
-    (*PetscErrorPrintf)("Can only handle MPIU_REAL, MPIU_COMPLEX, MPIU___FLOAT128, or MPIU___COMPLEX128 data types");
+    PetscCallAbort(MPI_COMM_SELF, (*PetscErrorPrintf)("Can only handle MPIU_REAL, MPIU_COMPLEX, MPIU___FLOAT128, or MPIU___COMPLEX128 data types"));
   #elif !defined(PETSC_HAVE_REAL___FLOAT128)
-    (*PetscErrorPrintf)("Can only handle MPIU_REAL, MPIU_COMPLEX, or MPIU___FP16 data types");
+    PetscCallAbort(MPI_COMM_SELF, (*PetscErrorPrintf)("Can only handle MPIU_REAL, MPIU_COMPLEX, or MPIU___FP16 data types"));
   #else
-    (*PetscErrorPrintf)("Can only handle MPIU_REAL, MPIU_COMPLEX, MPIU___FLOAT128, MPIU___COMPLEX128, or MPIU___FP16 data types");
+    PetscCallAbort(MPI_COMM_SELF, (*PetscErrorPrintf)("Can only handle MPIU_REAL, MPIU_COMPLEX, MPIU___FLOAT128, MPIU___COMPLEX128, or MPIU___FP16 data types"));
   #endif
     PETSCABORT(MPI_COMM_SELF, PETSC_ERR_ARG_WRONG);
   }
@@ -307,7 +313,7 @@ PETSC_EXTERN void MPIAPI PetscMax_Local(void *in, void *out, PetscMPIInt *cnt, M
   }
   #endif
   else {
-    (*PetscErrorPrintf)("Can only handle MPIU_REAL or MPIU_COMPLEX data types");
+    PetscCallAbort(MPI_COMM_SELF, (*PetscErrorPrintf)("Can only handle MPIU_REAL or MPIU_COMPLEX data types"));
     PETSCABORT(MPI_COMM_SELF, PETSC_ERR_ARG_WRONG);
   }
   PetscFunctionReturnVoid();
@@ -329,7 +335,7 @@ PETSC_EXTERN void MPIAPI PetscMin_Local(void *in, void *out, PetscMPIInt *cnt, M
   }
   #endif
   else {
-    (*PetscErrorPrintf)("Can only handle MPIU_REAL or MPIU_SCALAR data (i.e. double or complex) types");
+    PetscCallAbort(MPI_COMM_SELF, (*PetscErrorPrintf)("Can only handle MPIU_REAL or MPIU_SCALAR data (i.e. double or complex) types"));
     PETSCABORT(MPI_COMM_SELF, PETSC_ERR_ARG_WRONG);
   }
   PetscFunctionReturnVoid();
@@ -441,9 +447,9 @@ PetscErrorCode PetscCitationsInitialize(void)
     and Jose~E. Roman and Karl Rupp and Patrick Sanan and Jason Sarich and Barry~F. Smith\n\
     and Stefano Zampini and Hong Zhang and Hong Zhang and Junchao Zhang},\n\
   Title = {{PETSc/TAO} Users Manual},\n\
-  Number = {ANL-21/39 - Revision 3.18},\n\
+  Number = {ANL-21/39 - Revision 3.19},\n\
   Institution = {Argonne National Laboratory},\n\
-  Year = {2022}\n}\n",
+  Year = {2023}\n}\n",
                                    NULL));
 
   PetscCall(PetscCitationsRegister("@InProceedings{petsc-efficient,\n\
@@ -456,7 +462,7 @@ PetscErrorCode PetscCitationsInitialize(void)
   Year = {1997}\n}\n",
                                    NULL));
 
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static char programname[PETSC_MAX_PATH_LEN] = ""; /* HP includes entire path in name */
@@ -465,7 +471,7 @@ PetscErrorCode PetscSetProgramName(const char name[])
 {
   PetscFunctionBegin;
   PetscCall(PetscStrncpy(programname, name, sizeof(programname)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -486,7 +492,7 @@ PetscErrorCode PetscGetProgramName(char name[], size_t len)
 {
   PetscFunctionBegin;
   PetscCall(PetscStrncpy(name, programname, len));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -515,7 +521,7 @@ PetscErrorCode PetscGetArgs(int *argc, char ***args)
   PetscCheck(PetscInitializeCalled || !PetscFinalizeCalled, PETSC_COMM_SELF, PETSC_ERR_ORDER, "You must call after PetscInitialize() but before PetscFinalize()");
   *argc = PetscGlobalArgc;
   *args = PetscGlobalArgs;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -524,7 +530,7 @@ PetscErrorCode PetscGetArgs(int *argc, char ***args)
 
    Not Collective
 
-   Output Parameters:
+   Output Parameter:
 .  args - the command line arguments
 
    Level: intermediate
@@ -542,12 +548,12 @@ PetscErrorCode PetscGetArguments(char ***args)
   PetscCheck(PetscInitializeCalled || !PetscFinalizeCalled, PETSC_COMM_SELF, PETSC_ERR_ORDER, "You must call after PetscInitialize() but before PetscFinalize()");
   if (!argc) {
     *args = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCall(PetscMalloc1(argc, args));
   for (i = 0; i < argc - 1; i++) PetscCall(PetscStrallocpy(PetscGlobalArgs[i + 1], &(*args)[i]));
   (*args)[argc - 1] = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -555,7 +561,7 @@ PetscErrorCode PetscGetArguments(char ***args)
 
    Not Collective
 
-   Output Parameters:
+   Output Parameter:
 .  args - the command line arguments
 
    Level: intermediate
@@ -571,7 +577,7 @@ PetscErrorCode PetscFreeArguments(char **args)
     while (args[i]) PetscCall(PetscFree(args[i++]));
     PetscCall(PetscFree(args));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if PetscDefined(HAVE_SAWS)
@@ -682,7 +688,7 @@ PETSC_INTERN PetscErrorCode PetscInitializeSAWs(const char help[])
                                      "  Year   = 2013\n}\n",
                                      NULL));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 #endif
 
@@ -694,7 +700,7 @@ PETSC_INTERN PetscErrorCode PetscPreMPIInit_Private(void)
   /* see MPI.py for details on this bug */
   (void)setenv("HWLOC_COMPONENTS", "-x86", 1);
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if PetscDefined(HAVE_ADIOS)
@@ -748,7 +754,7 @@ PETSC_INTERN PetscErrorCode PetscInitialize_Common(const char *prog, const char
   char        hostname[256];
 
   PetscFunctionBegin;
-  if (PetscInitializeCalled) PetscFunctionReturn(0);
+  if (PetscInitializeCalled) PetscFunctionReturn(PETSC_SUCCESS);
   /* these must be initialized in a routine, not as a constant declaration */
   PETSC_STDOUT = stdout;
   PETSC_STDERR = stderr;
@@ -825,7 +831,7 @@ PETSC_INTERN PetscErrorCode PetscInitialize_Common(const char *prog, const char
         }
       }
       if (!flg) {
-        PetscInfo(NULL, "PETSc warning --- Open MPI library version \n%s does not match what PETSc was compiled with %d.%d.\n", mpilibraryversion, OMPI_MAJOR_VERSION, OMPI_MINOR_VERSION);
+        PetscCall(PetscInfo(NULL, "PETSc warning --- Open MPI library version \n%s does not match what PETSc was compiled with %d.%d.\n", mpilibraryversion, OMPI_MAJOR_VERSION, OMPI_MINOR_VERSION));
         flg = PETSC_TRUE;
       }
     }
@@ -902,8 +908,10 @@ PETSC_INTERN PetscErrorCode PetscInitialize_Common(const char *prog, const char
 #if defined(PETSC_HAVE_REAL___FLOAT128)
   PetscCallMPI(MPI_Type_contiguous(2, MPI_DOUBLE, &MPIU___FLOAT128));
   PetscCallMPI(MPI_Type_commit(&MPIU___FLOAT128));
+  #if defined(PETSC_HAVE_COMPLEX)
   PetscCallMPI(MPI_Type_contiguous(4, MPI_DOUBLE, &MPIU___COMPLEX128));
   PetscCallMPI(MPI_Type_commit(&MPIU___COMPLEX128));
+  #endif
 #endif
 #if defined(PETSC_HAVE_REAL___FP16)
   PetscCallMPI(MPI_Type_contiguous(2, MPI_CHAR, &MPIU___FP16));
@@ -1081,10 +1089,10 @@ PETSC_INTERN PetscErrorCode PetscInitialize_Common(const char *prog, const char
   if (!flg) PetscCall(PetscOptionsPushGetViewerOff(PETSC_TRUE));
 
 #if defined(PETSC_HAVE_ADIOS)
-  PetscCall(adios_init_noxml(PETSC_COMM_WORLD));
-  PetscCall(adios_declare_group(&Petsc_adios_group, "PETSc", "", adios_stat_default));
-  PetscCall(adios_select_method(Petsc_adios_group, "MPI", "", ""));
-  PetscCall(adios_read_init_method(ADIOS_READ_METHOD_BP, PETSC_COMM_WORLD, ""));
+  PetscCallExternal(adios_init_noxml, PETSC_COMM_WORLD);
+  PetscCallExternal(adios_declare_group, &Petsc_adios_group, "PETSc", "", adios_stat_default);
+  PetscCallExternal(adios_select_method, Petsc_adios_group, "MPI", "", "");
+  PetscCallExternal(adios_read_init_method, ADIOS_READ_METHOD_BP, PETSC_COMM_WORLD, "");
 #endif
 
 #if defined(__VALGRIND_H)
@@ -1104,7 +1112,7 @@ PETSC_INTERN PetscErrorCode PetscInitialize_Common(const char *prog, const char
   PetscCall(PetscOptionsHasName(NULL, NULL, "-mpi_linear_solver_server", &flg));
   if (PetscDefined(USE_SINGLE_LIBRARY) && flg) PetscCall(PCMPIServerBegin());
   else PetscCheck(!flg, PETSC_COMM_WORLD, PETSC_ERR_SUP, "PETSc configured using -with-single-library=0; -mpi_linear_solver_server not supported in that case");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1225,6 +1233,10 @@ PETSC_INTERN PetscErrorCode PetscInitialize_Common(const char *prog, const char
    If your main program is C but you call Fortran code that also uses PETSc you need to call `PetscInitializeFortran()` soon after
    calling `PetscInitialize()`.
 
+   Options Database Key for Developers:
+.  -checkfunctionlist - automatically checks that function lists associated with objects are correctly cleaned up. Produces messages of the form:
+    "function name: MatInodeGetInodeSizes_C" if they are not cleaned up. This flag is always set for the test harness (in framework.py)
+
 .seealso: `PetscFinalize()`, `PetscInitializeFortran()`, `PetscGetArgs()`, `PetscInitializeNoArguments()`, `PetscLogGpuTime()`
 @*/
 PetscErrorCode PetscInitialize(int *argc, char ***args, const char file[], const char help[])
@@ -1233,7 +1245,7 @@ PetscErrorCode PetscInitialize(int *argc, char ***args, const char file[], const
   const char *prog = "Unknown Name", *mpienv;
 
   PetscFunctionBegin;
-  if (PetscInitializeCalled) PetscFunctionReturn(0);
+  if (PetscInitializeCalled) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCallMPI(MPI_Initialized(&flag));
   if (!flag) {
     PetscCheck(PETSC_COMM_WORLD == MPI_COMM_NULL, PETSC_COMM_SELF, PETSC_ERR_SUP, "You cannot set PETSC_COMM_WORLD if you have not initialized MPI first");
@@ -1265,7 +1277,7 @@ PetscErrorCode PetscInitialize(int *argc, char ***args, const char file[], const
     PetscGlobalArgs = *args;
   }
   PetscCall(PetscInitialize_Common(prog, file, help, PETSC_FALSE, PETSC_FALSE, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if PetscDefined(USE_LOG)
@@ -1283,7 +1295,9 @@ PetscErrorCode PetscFreeMPIResources(void)
   PetscFunctionBegin;
 #if defined(PETSC_HAVE_REAL___FLOAT128)
   PetscCallMPI(MPI_Type_free(&MPIU___FLOAT128));
+  #if defined(PETSC_HAVE_COMPLEX)
   PetscCallMPI(MPI_Type_free(&MPIU___COMPLEX128));
+  #endif
 #endif
 #if defined(PETSC_HAVE_REAL___FP16)
   PetscCallMPI(MPI_Type_free(&MPIU___FP16));
@@ -1307,7 +1321,7 @@ PetscErrorCode PetscFreeMPIResources(void)
   PetscCallMPI(MPI_Type_free(&MPIU_4INT));
   PetscCallMPI(MPI_Op_free(&MPIU_MAXSUM_OP));
   PetscCallMPI(MPI_Op_free(&Petsc_Garbage_SetIntersectOp));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #if PetscDefined(USE_LOG)
@@ -1374,8 +1388,8 @@ PetscErrorCode PetscFinalize(void)
 
   PetscCallMPI(MPI_Comm_rank(PETSC_COMM_WORLD, &rank));
 #if defined(PETSC_HAVE_ADIOS)
-  PetscCall(adios_read_finalize_method(ADIOS_READ_METHOD_BP_AGGREGATE));
-  PetscCall(adios_finalize(rank));
+  PetscCallExternal(adios_read_finalize_method, ADIOS_READ_METHOD_BP_AGGREGATE);
+  PetscCallExternal(adios_finalize, rank);
 #endif
   PetscCall(PetscOptionsHasName(NULL, NULL, "-citations", &flg));
   if (flg) {
@@ -1406,9 +1420,10 @@ PetscErrorCode PetscFinalize(void)
     if (flg1) {
       PetscCheck(nmax, PETSC_COMM_WORLD, PETSC_ERR_USER, "-textbelt requires either the phone number or number,\"message\"");
       if (nmax == 1) {
-        PetscCall(PetscMalloc1(128, &buffs[1]));
+        size_t len = 128;
+        PetscCall(PetscMalloc1(len, &buffs[1]));
         PetscCall(PetscGetProgramName(buffs[1], 32));
-        PetscCall(PetscStrcat(buffs[1], " has completed"));
+        PetscCall(PetscStrlcat(buffs[1], " has completed", len));
       }
       PetscCall(PetscTextBelt(PETSC_COMM_WORLD, buffs[0], buffs[1], NULL));
       PetscCall(PetscFree(buffs[0]));
@@ -1424,9 +1439,10 @@ PetscErrorCode PetscFinalize(void)
     if (flg1) {
       PetscCheck(nmax, PETSC_COMM_WORLD, PETSC_ERR_USER, "-tellmycell requires either the phone number or number,\"message\"");
       if (nmax == 1) {
-        PetscCall(PetscMalloc1(128, &buffs[1]));
+        size_t len = 128;
+        PetscCall(PetscMalloc1(len, &buffs[1]));
         PetscCall(PetscGetProgramName(buffs[1], 32));
-        PetscCall(PetscStrcat(buffs[1], " has completed"));
+        PetscCall(PetscStrlcat(buffs[1], " has completed", len));
       }
       PetscCall(PetscTellMyCell(PETSC_COMM_WORLD, buffs[0], buffs[1], NULL));
       PetscCall(PetscFree(buffs[0]));
@@ -1642,7 +1658,7 @@ PetscErrorCode PetscFinalize(void)
     fname[0] = 0;
     PetscCall(PetscOptionsGetString(NULL, NULL, "-malloc_dump", fname, sizeof(fname), &flg1));
     if (flg1 && fname[0]) {
-      PetscSNPrintf(sname, sizeof(sname), "%s_%d", fname, rank);
+      PetscCall(PetscSNPrintf(sname, sizeof(sname), "%s_%d", fname, rank));
       fd = fopen(sname, "w");
       PetscCheck(fd, PETSC_COMM_SELF, PETSC_ERR_FILE_OPEN, "Cannot open log file: %s", sname);
       PetscCall(PetscMallocDump(fd));
@@ -1660,7 +1676,7 @@ PetscErrorCode PetscFinalize(void)
     fname[0] = 0;
     PetscCall(PetscOptionsGetString(NULL, NULL, "-malloc_view", fname, sizeof(fname), &flg1));
     if (flg1 && fname[0]) {
-      PetscSNPrintf(sname, sizeof(sname), "%s_%d", fname, rank);
+      PetscCall(PetscSNPrintf(sname, sizeof(sname), "%s_%d", fname, rank));
       fd = fopen(sname, "w");
       PetscCheck(fd, PETSC_COMM_SELF, PETSC_ERR_FILE_OPEN, "Cannot open log file: %s", sname);
       PetscCall(PetscMallocView(fd));
@@ -1751,6 +1767,10 @@ PetscErrorCode PetscFinalize(void)
   PetscCallMPI(MPI_Comm_free_keyval(&Petsc_CreationIdx_keyval));
   PetscCallMPI(MPI_Comm_free_keyval(&Petsc_Garbage_HMap_keyval));
 
+  // Free keyvals which may be silently created by some routines
+  if (Petsc_SharedWD_keyval != MPI_KEYVAL_INVALID) PetscCallMPI(MPI_Comm_free_keyval(&Petsc_SharedWD_keyval));
+  if (Petsc_SharedTmp_keyval != MPI_KEYVAL_INVALID) PetscCallMPI(MPI_Comm_free_keyval(&Petsc_SharedTmp_keyval));
+
   PetscCall(PetscSpinlockDestroy(&PetscViewerASCIISpinLockOpen));
   PetscCall(PetscSpinlockDestroy(&PetscViewerASCIISpinLockStdout));
   PetscCall(PetscSpinlockDestroy(&PetscViewerASCIISpinLockStderr));
@@ -1781,7 +1801,7 @@ PetscErrorCode PetscFinalize(void)
 
   PetscInitializeCalled = PETSC_FALSE;
   PetscFinalizeCalled   = PETSC_TRUE;
-#if defined(PETSC_USE_GCOV)
+#if defined(PETSC_USE_COVERAGE)
   /*
      flush gcov, otherwise during CI the flushing continues into the next pipeline resulting in git not being able to delete directories since the
      gcov files are still being added to the directories as git tries to remove the directories.
@@ -1790,7 +1810,7 @@ PetscErrorCode PetscFinalize(void)
 #endif
   /* To match PetscFunctionBegin() at the beginning of this function */
   PetscStackClearTop;
-  return 0;
+  return PETSC_SUCCESS;
 }
 
 #if defined(PETSC_MISSING_LAPACK_lsame_)
