@@ -3,14 +3,15 @@
 /*@
   TaoSetSolution - Sets the vector holding the initial guess for the solve
 
-  Logically collective on tao
+  Logically Collective
 
   Input Parameters:
-+ tao - the Tao context
++ tao - the `Tao` context
 - x0  - the initial guess
 
   Level: beginner
-.seealso: `Tao`, `TaoCreate()`, `TaoSolve()`, `TaoGetSolution()`
+
+.seealso: [](chapter_tao), `Tao`, `TaoCreate()`, `TaoSolve()`, `TaoGetSolution()`
 @*/
 PetscErrorCode TaoSetSolution(Tao tao, Vec x0)
 {
@@ -20,7 +21,7 @@ PetscErrorCode TaoSetSolution(Tao tao, Vec x0)
   PetscCall(PetscObjectReference((PetscObject)x0));
   PetscCall(VecDestroy(&tao->solution));
   tao->solution = x0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TaoTestGradient(Tao tao, Vec x, Vec g1)
@@ -42,7 +43,7 @@ PetscErrorCode TaoTestGradient(Tao tao, Vec x, Vec g1)
   PetscOptionsEnd();
   if (!test) {
     if (complete_print) PetscCall(PetscViewerDestroy(&mviewer));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(PetscObjectGetComm((PetscObject)tao, &comm));
@@ -96,16 +97,16 @@ PetscErrorCode TaoTestGradient(Tao tao, Vec x, Vec g1)
     PetscCall(PetscViewerDestroy(&mviewer));
   }
   PetscCall(PetscViewerASCIISetTab(viewer, tabs));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   TaoComputeGradient - Computes the gradient of the objective function
 
-  Collective on tao
+  Collective
 
   Input Parameters:
-+ tao - the Tao context
++ tao - the `Tao` context
 - X - input vector
 
   Output Parameter:
@@ -115,13 +116,13 @@ PetscErrorCode TaoTestGradient(Tao tao, Vec x, Vec g1)
 +    -tao_test_gradient - compare the user provided gradient with one compute via finite differences to check for errors
 -    -tao_test_gradient_view - display the user provided gradient, the finite difference gradient and the difference between them to help users detect the location of errors in the user provided gradient
 
+  Level: developer
+
   Note:
     `TaoComputeGradient()` is typically used within the implementation of the optimization method,
   so most users would not generally call this routine themselves.
 
-  Level: developer
-
-.seealso: `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetGradient()`
+.seealso: [](chapter_tao), `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetGradient()`
 @*/
 PetscErrorCode TaoComputeGradient(Tao tao, Vec X, Vec G)
 {
@@ -148,28 +149,28 @@ PetscErrorCode TaoComputeGradient(Tao tao, Vec X, Vec G)
   PetscCall(VecLockReadPop(X));
 
   PetscCall(TaoTestGradient(tao, X, G));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   TaoComputeObjective - Computes the objective function value at a given point
 
-  Collective on tao
+  Collective
 
   Input Parameters:
-+ tao - the Tao context
++ tao - the `Tao` context
 - X - input vector
 
   Output Parameter:
 . f - Objective value at X
 
+  Level: developer
+
   Note:
     `TaoComputeObjective()` is typically used within the implementation of the optimization algorithm
   so most users would not generally call this routine themselves.
 
-  Level: developer
-
-.seealso: `Tao`, `TaoComputeGradient()`, `TaoComputeObjectiveAndGradient()`, `TaoSetObjective()`
+.seealso: [](chapter_tao), `Tao`, `TaoComputeGradient()`, `TaoComputeObjectiveAndGradient()`, `TaoSetObjective()`
 @*/
 PetscErrorCode TaoComputeObjective(Tao tao, Vec X, PetscReal *f)
 {
@@ -196,29 +197,29 @@ PetscErrorCode TaoComputeObjective(Tao tao, Vec X, PetscReal *f)
   } else SETERRQ(PetscObjectComm((PetscObject)tao), PETSC_ERR_ARG_WRONGSTATE, "TaoSetObjective() has not been called");
   PetscCall(PetscInfo(tao, "TAO Function evaluation: %20.19e\n", (double)(*f)));
   PetscCall(VecLockReadPop(X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   TaoComputeObjectiveAndGradient - Computes the objective function value at a given point
 
-  Collective on tao
+  Collective
 
   Input Parameters:
-+ tao - the Tao context
++ tao - the `Tao` context
 - X - input vector
 
   Output Parameters:
-+ f - Objective value at X
-- g - Gradient vector at X
++ f - Objective value at `X`
+- g - Gradient vector at `X`
+
+  Level: developer
 
   Note:
     `TaoComputeObjectiveAndGradient()` is typically used within the implementation of the optimization algorithm,
   so most users would not generally call this routine themselves.
 
-  Level: developer
-
-.seealso: `TaoComputeGradient()`, `TaoComputeObjectiveAndGradient()`, `TaoSetObjective()`
+.seealso: [](chapter_tao), `TaoComputeGradient()`, `TaoComputeObjectiveAndGradient()`, `TaoSetObjective()`
 @*/
 PetscErrorCode TaoComputeObjectiveAndGradient(Tao tao, Vec X, PetscReal *f, Vec G)
 {
@@ -251,30 +252,30 @@ PetscErrorCode TaoComputeObjectiveAndGradient(Tao tao, Vec X, PetscReal *f, Vec
   PetscCall(VecLockReadPop(X));
 
   PetscCall(TaoTestGradient(tao, X, G));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TaoSetObjective - Sets the function evaluation routine for minimization
 
-  Logically collective on tao
+  Logically Collective
 
   Input Parameters:
-+ tao - the Tao context
++ tao - the `Tao` context
 . func - the objective function
 - ctx - [optional] user-defined context for private data for the function evaluation
-        routine (may be NULL)
+        routine (may be `NULL`)
 
-  Calling sequence of func:
-$      func (Tao tao, Vec x, PetscReal *f, void *ctx);
-
-+ x - input vector
+  Calling sequence of `func`:
+$ PetscErrorCode func(Tao tao, Vec x, PetscReal *f, void *ctx);
++ tao - the optimizer
+. x - input vector
 . f - function value
 - ctx - [optional] user-defined function context
 
   Level: beginner
 
-.seealso: `TaoSetGradient()`, `TaoSetHessian()`, `TaoSetObjectiveAndGradient()`, `TaoGetObjective()`
+.seealso: [](chapter_tao), `TaoSetGradient()`, `TaoSetHessian()`, `TaoSetObjectiveAndGradient()`, `TaoGetObjective()`
 @*/
 PetscErrorCode TaoSetObjective(Tao tao, PetscErrorCode (*func)(Tao, Vec, PetscReal *, void *), void *ctx)
 {
@@ -282,31 +283,31 @@ PetscErrorCode TaoSetObjective(Tao tao, PetscErrorCode (*func)(Tao, Vec, PetscRe
   PetscValidHeaderSpecific(tao, TAO_CLASSID, 1);
   if (ctx) tao->user_objP = ctx;
   if (func) tao->ops->computeobjective = func;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TaoGetObjective - Gets the function evaluation routine for the function to be minimized
 
-  Not collective
+  Not Collective
 
   Input Parameter:
-. tao - the Tao context
+. tao - the `Tao` context
 
-  Output Parameters
+  Output Parameters:
 + func - the objective function
 - ctx - the user-defined context for private data for the function evaluation
 
-  Calling sequence of func:
-$      func (Tao tao, Vec x, PetscReal *f, void *ctx);
-
-+ x - input vector
+  Calling sequence of `func`:
+$ PetscErrorCode func(Tao tao, Vec x, PetscReal *f, void *ctx)
++ tao - the optimizer
+. x - input vector
 . f - function value
 - ctx - [optional] user-defined function context
 
   Level: beginner
 
-.seealso: `Tao`, `TaoSetGradient()`, `TaoSetHessian()`, `TaoSetObjective()`
+.seealso: [](chapter_tao), `Tao`, `TaoSetGradient()`, `TaoSetHessian()`, `TaoSetObjective()`
 @*/
 PetscErrorCode TaoGetObjective(Tao tao, PetscErrorCode (**func)(Tao, Vec, PetscReal *, void *), void **ctx)
 {
@@ -314,30 +315,30 @@ PetscErrorCode TaoGetObjective(Tao tao, PetscErrorCode (**func)(Tao, Vec, PetscR
   PetscValidHeaderSpecific(tao, TAO_CLASSID, 1);
   if (func) *func = tao->ops->computeobjective;
   if (ctx) *ctx = tao->user_objP;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TaoSetResidualRoutine - Sets the residual evaluation routine for least-square applications
 
-  Logically collective on tao
+  Logically Collective
 
   Input Parameters:
-+ tao - the Tao context
++ tao - the `Tao` context
 . func - the residual evaluation routine
 - ctx - [optional] user-defined context for private data for the function evaluation
-        routine (may be NULL)
+        routine (may be `NULL`)
 
-  Calling sequence of func:
-$      func (Tao tao, Vec x, Vec f, void *ctx);
-
-+ x - input vector
+  Calling sequence of `func`:
+$ PetscErrorCode func(Tao tao, Vec x, Vec f, void *ctx);
++ tao - the optimizer
+. x - input vector
 . f - function value vector
 - ctx - [optional] user-defined function context
 
   Level: beginner
 
-.seealso: `Tao`, `TaoSetObjective()`, `TaoSetJacobianRoutine()`
+.seealso: [](chapter_tao), `Tao`, `TaoSetObjective()`, `TaoSetJacobianRoutine()`
 @*/
 PetscErrorCode TaoSetResidualRoutine(Tao tao, Vec res, PetscErrorCode (*func)(Tao, Vec, Vec, void *), void *ctx)
 {
@@ -350,28 +351,29 @@ PetscErrorCode TaoSetResidualRoutine(Tao tao, Vec res, PetscErrorCode (*func)(Ta
   tao->user_lsresP          = ctx;
   tao->ops->computeresidual = func;
 
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   TaoSetResidualWeights - Give weights for the residual values. A vector can be used if only diagonal terms are used, otherwise a matrix can be give.
-   If this function is not provided, or if sigma_v and sigma_w are both NULL, then the identity matrix will be used for weights.
+   If this function is not provided, or if `sigma_v` and `vals` are both `NULL`, then the identity matrix will be used for weights.
 
-  Collective on tao
+  Collective
 
   Input Parameters:
-+ tao - the Tao context
++ tao - the `Tao` context
 . sigma_v - vector of weights (diagonal terms only)
 . n       - the number of weights (if using off-diagonal)
-. rows    - index list of rows for sigma_w
-. cols    - index list of columns for sigma_w
+. rows    - index list of rows for `sigma_v`
+. cols    - index list of columns for `sigma_v`
 - vals - array of weights
 
-  Note: Either sigma_v or sigma_w (or both) should be NULL
-
   Level: intermediate
 
-.seealso: `Tao`, `TaoSetResidualRoutine()`
+  Note:
+  Either `sigma_v` or `vals` should be `NULL`
+
+.seealso: [](chapter_tao), `Tao`, `TaoSetResidualRoutine()`
 @*/
 PetscErrorCode TaoSetResidualWeights(Tao tao, Vec sigma_v, PetscInt n, PetscInt *rows, PetscInt *cols, PetscReal *vals)
 {
@@ -401,28 +403,28 @@ PetscErrorCode TaoSetResidualWeights(Tao tao, Vec sigma_v, PetscInt n, PetscInt
     tao->res_weights_rows = NULL;
     tao->res_weights_cols = NULL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   TaoComputeResidual - Computes a least-squares residual vector at a given point
 
-  Collective on tao
+  Collective
 
   Input Parameters:
-+ tao - the Tao context
++ tao - the `Tao` context
 - X - input vector
 
   Output Parameter:
-. f - Objective vector at X
+. f - Objective vector at `X`
+
+  Level: advanced
 
   Notes:
     `TaoComputeResidual()` is typically used within the implementation of the optimization algorithm,
   so most users would not generally call this routine themselves.
 
-  Level: advanced
-
-.seealso: `Tao`, `TaoSetResidualRoutine()`
+.seealso: [](chapter_tao), `Tao`, `TaoSetResidualRoutine()`
 @*/
 PetscErrorCode TaoComputeResidual(Tao tao, Vec X, Vec F)
 {
@@ -439,31 +441,31 @@ PetscErrorCode TaoComputeResidual(Tao tao, Vec X, Vec F)
     tao->nfuncs++;
   } else SETERRQ(PetscObjectComm((PetscObject)tao), PETSC_ERR_ARG_WRONGSTATE, "TaoSetResidualRoutine() has not been called");
   PetscCall(PetscInfo(tao, "TAO least-squares residual evaluation.\n"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TaoSetGradient - Sets the gradient evaluation routine for the function to be optimized
 
-  Logically collective on tao
+  Logically Collective
 
   Input Parameters:
-+ tao - the Tao context
++ tao - the `Tao` context
 . g - [optional] the vector to internally hold the gradient computation
 . func - the gradient function
 - ctx - [optional] user-defined context for private data for the gradient evaluation
-        routine (may be NULL)
+        routine (may be `NULL`)
 
-  Calling sequence of func:
-$      func (Tao tao, Vec x, Vec g, void *ctx);
-
-+ x - input vector
+  Calling sequence of `func`:
+$ PetscErrorCode func(Tao tao, Vec x, Vec g, void *ctx);
++ tao - the optimization solver
+. x - input vector
 . g - gradient value (output)
 - ctx - [optional] user-defined function context
 
   Level: beginner
 
-.seealso: `Tao`, `TaoSolve()`, `TaoSetObjective()`, `TaoSetHessian()`, `TaoSetObjectiveAndGradient()`, `TaoGetGradient()`
+.seealso: [](chapter_tao), `Tao`, `TaoSolve()`, `TaoSetObjective()`, `TaoSetHessian()`, `TaoSetObjectiveAndGradient()`, `TaoGetGradient()`
 @*/
 PetscErrorCode TaoSetGradient(Tao tao, Vec g, PetscErrorCode (*func)(Tao, Vec, Vec, void *), void *ctx)
 {
@@ -478,32 +480,32 @@ PetscErrorCode TaoSetGradient(Tao tao, Vec g, PetscErrorCode (*func)(Tao, Vec, V
   }
   if (func) tao->ops->computegradient = func;
   if (ctx) tao->user_gradP = ctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TaoGetGradient - Gets the gradient evaluation routine for the function being optimized
 
-  Not collective
+  Not Collective
 
   Input Parameter:
-. tao - the Tao context
+. tao - the `Tao` context
 
   Output Parameters:
 + g - the vector to internally hold the gradient computation
 . func - the gradient function
 - ctx - user-defined context for private data for the gradient evaluation routine
 
-  Calling sequence of func:
-$      func (Tao tao, Vec x, Vec g, void *ctx);
-
-+ x - input vector
+  Calling sequence of `func`:
+$ PetscErrorCode func(Tao tao, Vec x, Vec g, void *ctx);
++ tao - the optimizer
+. x - input vector
 . g - gradient value (output)
 - ctx - [optional] user-defined function context
 
   Level: beginner
 
-.seealso: `Tao`, `TaoSetObjective()`, `TaoSetHessian()`, `TaoSetObjectiveAndGradient()`, `TaoSetGradient()`
+.seealso: [](chapter_tao), `Tao`, `TaoSetObjective()`, `TaoSetHessian()`, `TaoSetObjectiveAndGradient()`, `TaoSetGradient()`
 @*/
 PetscErrorCode TaoGetGradient(Tao tao, Vec *g, PetscErrorCode (**func)(Tao, Vec, Vec, void *), void **ctx)
 {
@@ -512,25 +514,25 @@ PetscErrorCode TaoGetGradient(Tao tao, Vec *g, PetscErrorCode (**func)(Tao, Vec,
   if (g) *g = tao->gradient;
   if (func) *func = tao->ops->computegradient;
   if (ctx) *ctx = tao->user_gradP;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TaoSetObjectiveAndGradient - Sets a combined objective function and gradient evaluation routine for the function to be optimized
 
-  Logically collective on tao
+  Logically Collective
 
   Input Parameters:
-+ tao - the Tao context
++ tao - the `Tao` context
 . g - [optional] the vector to internally hold the gradient computation
 . func - the gradient function
 - ctx - [optional] user-defined context for private data for the gradient evaluation
-        routine (may be NULL)
+        routine (may be `NULL`)
 
-  Calling sequence of func:
-$      func (Tao tao, Vec x, PetscReal *f, Vec g, void *ctx);
-
-+ x - input vector
+  Calling sequence of `func`:
+$ PetscErrorCode func(Tao tao, Vec x, PetscReal *f, Vec g, void *ctx);
++ tao - the optimization object
+. x - input vector
 . f - objective value (output)
 . g - gradient value (output)
 - ctx - [optional] user-defined function context
@@ -540,7 +542,7 @@ $      func (Tao tao, Vec x, PetscReal *f, Vec g, void *ctx);
   Note:
   For some optimization methods using a combined function can be more eifficient.
 
-.seealso: `Tao`, `TaoSolve()`, `TaoSetObjective()`, `TaoSetHessian()`, `TaoSetGradient()`, `TaoGetObjectiveAndGradient()`
+.seealso: [](chapter_tao), `Tao`, `TaoSolve()`, `TaoSetObjective()`, `TaoSetHessian()`, `TaoSetGradient()`, `TaoGetObjectiveAndGradient()`
 @*/
 PetscErrorCode TaoSetObjectiveAndGradient(Tao tao, Vec g, PetscErrorCode (*func)(Tao, Vec, PetscReal *, Vec, void *), void *ctx)
 {
@@ -555,33 +557,33 @@ PetscErrorCode TaoSetObjectiveAndGradient(Tao tao, Vec g, PetscErrorCode (*func)
   }
   if (ctx) tao->user_objgradP = ctx;
   if (func) tao->ops->computeobjectiveandgradient = func;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TaoGetObjectiveAndGradient - Gets the combined objective function and gradient evaluation routine for the function to be optimized
 
-  Not collective
+  Not Collective
 
   Input Parameter:
-. tao - the Tao context
+. tao - the `Tao` context
 
   Output Parameters:
 + g - the vector to internally hold the gradient computation
 . func - the gradient function
 - ctx - user-defined context for private data for the gradient evaluation routine
 
-  Calling sequence of func:
-$      func (Tao tao, Vec x, PetscReal *f, Vec g, void *ctx);
-
-+ x - input vector
+  Calling sequence of `func`:
+$ PetscErrorCode func(Tao tao, Vec x, PetscReal *f, Vec g, void *ctx);
++ tao - the optimizer
+. x - input vector
 . f - objective value (output)
 . g - gradient value (output)
 - ctx - [optional] user-defined function context
 
   Level: beginner
 
-.seealso: `Tao`, `TaoSolve()`, `TaoSetObjective()`, `TaoSetGradient()`, `TaoSetHessian()`, `TaoSetObjectiveAndGradient()`
+.seealso: [](chapter_tao), `Tao`, `TaoSolve()`, `TaoSetObjective()`, `TaoSetGradient()`, `TaoSetHessian()`, `TaoSetObjectiveAndGradient()`
 @*/
 PetscErrorCode TaoGetObjectiveAndGradient(Tao tao, Vec *g, PetscErrorCode (**func)(Tao, Vec, PetscReal *, Vec, void *), void **ctx)
 {
@@ -590,7 +592,7 @@ PetscErrorCode TaoGetObjectiveAndGradient(Tao tao, Vec *g, PetscErrorCode (**fun
   if (g) *g = tao->gradient;
   if (func) *func = tao->ops->computeobjectiveandgradient;
   if (ctx) *ctx = tao->user_objgradP;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -599,17 +601,17 @@ PetscErrorCode TaoGetObjectiveAndGradient(Tao tao, Vec *g, PetscErrorCode (**fun
   it is appropriate to call `TaoComputeObjective()` or
   `TaoComputeObjectiveAndGradient()`
 
-  Not collective
+  Not Collective
 
   Input Parameter:
-. tao - the Tao context
+. tao - the `Tao` context
 
   Output Parameter:
 . flg - `PETSC_TRUE` if function routine is set by user, `PETSC_FALSE` otherwise
 
   Level: developer
 
-.seealso: `Tao`, `TaoSetObjective()`, `TaoIsGradientDefined()`, `TaoIsObjectiveAndGradientDefined()`
+.seealso: [](chapter_tao), `Tao`, `TaoSetObjective()`, `TaoIsGradientDefined()`, `TaoIsObjectiveAndGradientDefined()`
 @*/
 PetscErrorCode TaoIsObjectiveDefined(Tao tao, PetscBool *flg)
 {
@@ -617,7 +619,7 @@ PetscErrorCode TaoIsObjectiveDefined(Tao tao, PetscBool *flg)
   PetscValidHeaderSpecific(tao, TAO_CLASSID, 1);
   if (tao->ops->computeobjective == NULL) *flg = PETSC_FALSE;
   else *flg = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -629,14 +631,14 @@ PetscErrorCode TaoIsObjectiveDefined(Tao tao, PetscBool *flg)
   Not Collective
 
   Input Parameter:
-. tao - the Tao context
+. tao - the `Tao` context
 
   Output Parameter:
 . flg - `PETSC_TRUE` if function routine is set by user, `PETSC_FALSE` otherwise
 
   Level: developer
 
-.seealso: `TaoSetGradient()`, `TaoIsObjectiveDefined()`, `TaoIsObjectiveAndGradientDefined()`
+.seealso: [](chapter_tao), `TaoSetGradient()`, `TaoIsObjectiveDefined()`, `TaoIsObjectiveAndGradientDefined()`
 @*/
 PetscErrorCode TaoIsGradientDefined(Tao tao, PetscBool *flg)
 {
@@ -644,7 +646,7 @@ PetscErrorCode TaoIsGradientDefined(Tao tao, PetscBool *flg)
   PetscValidHeaderSpecific(tao, TAO_CLASSID, 1);
   if (tao->ops->computegradient == NULL) *flg = PETSC_FALSE;
   else *flg = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -656,14 +658,14 @@ PetscErrorCode TaoIsGradientDefined(Tao tao, PetscBool *flg)
   Not Collective
 
   Input Parameter:
-. tao - the Tao context
+. tao - the `Tao` context
 
   Output Parameter:
 . flg - `PETSC_TRUE` if function routine is set by user, `PETSC_FALSE` otherwise
 
   Level: developer
 
-.seealso: `TaoSetObjectiveAndGradient()`, `TaoIsObjectiveDefined()`, `TaoIsGradientDefined()`
+.seealso: [](chapter_tao), `TaoSetObjectiveAndGradient()`, `TaoIsObjectiveDefined()`, `TaoIsGradientDefined()`
 @*/
 PetscErrorCode TaoIsObjectiveAndGradientDefined(Tao tao, PetscBool *flg)
 {
@@ -671,5 +673,5 @@ PetscErrorCode TaoIsObjectiveAndGradientDefined(Tao tao, PetscBool *flg)
   PetscValidHeaderSpecific(tao, TAO_CLASSID, 1);
   if (tao->ops->computeobjectiveandgradient == NULL) *flg = PETSC_FALSE;
   else *flg = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
