@@ -3,28 +3,27 @@
 /*@C
    TaoSetHessian - Sets the function to compute the Hessian as well as the location to store the matrix.
 
-   Logically collective on tao
+   Logically Collective
 
    Input Parameters:
-+  tao  - the Tao context
++  tao  - the `Tao` context
 .  H    - Matrix used for the hessian
-.  Hpre - Matrix that will be used operated on by preconditioner, can be same as H
+.  Hpre - Matrix that will be used to construct the preconditioner, can be same as `H`
 .  func - Hessian evaluation routine
 -  ctx  - [optional] user-defined context for private data for the
-         Hessian evaluation routine (may be NULL)
-
-   Calling sequence of func:
-$    func(Tao tao,Vec x,Mat H,Mat Hpre,void *ctx);
+         Hessian evaluation routine (may be `NULL`)
 
+   Calling sequence of `func`:
+$  PetscErrorCode func(Tao tao, Vec x, Mat H, Mat Hpre, void *ctx);
 +  tao  - the Tao  context
 .  x    - input vector
 .  H    - Hessian matrix
-.  Hpre - preconditioner matrix, usually the same as H
+.  Hpre - matrix used to construct the preconditioner, usually the same as `H`
 -  ctx  - [optional] user-defined Hessian context
 
    Level: beginner
 
-.seealso: `Tao`, `TaoTypes`, `TaoSetObjective()`, `TaoSetGradient()`, `TaoSetObjectiveAndGradient()`, `TaoGetHessian()`
+.seealso: [](chapter_tao), `Tao`, `TaoTypes`, `TaoSetObjective()`, `TaoSetGradient()`, `TaoSetObjectiveAndGradient()`, `TaoGetHessian()`
 @*/
 PetscErrorCode TaoSetHessian(Tao tao, Mat H, Mat Hpre, PetscErrorCode (*func)(Tao, Vec, Mat, Mat, void *), void *ctx)
 {
@@ -50,35 +49,34 @@ PetscErrorCode TaoSetHessian(Tao tao, Mat H, Mat Hpre, PetscErrorCode (*func)(Ta
     PetscCall(MatDestroy(&tao->hessian_pre));
     tao->hessian_pre = Hpre;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TaoGetHessian - Gets the function to compute the Hessian as well as the location to store the matrix.
 
-   Not collective
+   Not Collective
 
    Input Parameter:
-.  tao  - the Tao context
+.  tao  - the `Tao` context
 
    OutputParameters:
 +  H    - Matrix used for the hessian
-.  Hpre - Matrix that will be used operated on by preconditioner, can be the same as H
+.  Hpre - Matrix that will be used to construct the preconditioner, can be the same as `H`
 .  func - Hessian evaluation routine
 -  ctx  - user-defined context for private data for the Hessian evaluation routine
 
-   Calling sequence of func:
-$    func(Tao tao,Vec x,Mat H,Mat Hpre,void *ctx);
-
+   Calling sequence of `func`:
+$  PetscErrorCode func(Tao tao, Vec x, Mat H, Mat Hpre, void *ctx);
 +  tao  - the Tao  context
 .  x    - input vector
 .  H    - Hessian matrix
-.  Hpre - preconditioner matrix, usually the same as H
+.  Hpre - matrix used to construct the preconditioner, usually the same as `H`
 -  ctx  - [optional] user-defined Hessian context
 
    Level: beginner
 
-.seealso: `Tao`, TaoType`, `TaoGetObjective()`, `TaoGetGradient()`, `TaoGetObjectiveAndGradient()`, `TaoSetHessian()`
+.seealso: [](chapter_tao), `Tao`, TaoType`, `TaoGetObjective()`, `TaoGetGradient()`, `TaoGetObjectiveAndGradient()`, `TaoSetHessian()`
 @*/
 PetscErrorCode TaoGetHessian(Tao tao, Mat *H, Mat *Hpre, PetscErrorCode (**func)(Tao, Vec, Mat, Mat, void *), void **ctx)
 {
@@ -88,7 +86,7 @@ PetscErrorCode TaoGetHessian(Tao tao, Mat *H, Mat *Hpre, PetscErrorCode (**func)
   if (Hpre) *Hpre = tao->hessian_pre;
   if (ctx) *ctx = tao->user_hessP;
   if (func) *func = tao->ops->computehessian;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TaoTestHessian(Tao tao)
@@ -111,7 +109,7 @@ PetscErrorCode TaoTestHessian(Tao tao)
   PetscCall(PetscOptionsReal("-tao_test_hessian", "Threshold for element difference between hand-coded and finite difference being meaningful", "None", threshold, &threshold, NULL));
   PetscCall(PetscOptionsViewer("-tao_test_hessian_view", "View difference between hand-coded and finite difference Hessians element entries", "None", &mviewer, &format, &complete_print));
   PetscOptionsEnd();
-  if (!test) PetscFunctionReturn(0);
+  if (!test) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscObjectGetComm((PetscObject)tao, &comm));
   PetscCall(PetscViewerASCIIGetStdout(comm, &viewer));
@@ -214,14 +212,14 @@ PetscErrorCode TaoTestHessian(Tao tao)
     PetscCall(PetscViewerDestroy(&mviewer));
   }
   PetscCall(PetscViewerASCIISetTab(viewer, tabs));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TaoComputeHessian - Computes the Hessian matrix that has been
    set with `TaoSetHessian()`.
 
-   Collective on tao
+   Collective
 
    Input Parameters:
 +  tao - the Tao solver context
@@ -236,6 +234,8 @@ PetscErrorCode TaoTestHessian(Tao tao)
 .     -tao_test_hessian <numerical value>  - display entries in the difference between the user provided Hessian and finite difference Hessian that are greater than a certain value to help users detect errors
 -     -tao_test_hessian_view - display the user provided Hessian, the finite difference Hessian and the difference between them to help users detect the location of errors in the user provided Hessian
 
+   Level: developer
+
    Notes:
    Most users should not need to explicitly call this routine, as it
    is used internally within the minimization solvers.
@@ -247,9 +247,7 @@ PetscErrorCode TaoTestHessian(Tao tao)
    Developer Note:
    The Hessian test mechanism follows `SNESTestJacobian()`.
 
-   Level: developer
-
-.seealso: `Tao`, `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetHessian()`
+.seealso: [](chapter_tao), `Tao`, `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetHessian()`
 @*/
 PetscErrorCode TaoComputeHessian(Tao tao, Vec X, Mat H, Mat Hpre)
 {
@@ -267,14 +265,14 @@ PetscErrorCode TaoComputeHessian(Tao tao, Vec X, Mat H, Mat Hpre)
   PetscCall(VecLockReadPop(X));
 
   PetscCall(TaoTestHessian(tao));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TaoComputeJacobian - Computes the Jacobian matrix that has been
    set with TaoSetJacobianRoutine().
 
-   Collective on tao
+   Collective
 
    Input Parameters:
 +  tao - the Tao solver context
@@ -284,6 +282,8 @@ PetscErrorCode TaoComputeHessian(Tao tao, Vec X, Mat H, Mat Hpre)
 +  J    - Jacobian matrix
 -  Jpre - Preconditioning matrix
 
+   Level: developer
+
    Notes:
    Most users should not need to explicitly call this routine, as it
    is used internally within the minimization solvers.
@@ -292,9 +292,7 @@ PetscErrorCode TaoComputeHessian(Tao tao, Vec X, Mat H, Mat Hpre)
    implementations, so most users would not generally call this routine
    themselves.
 
-   Level: developer
-
-.seealso: `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetJacobianRoutine()`
+.seealso: [](chapter_tao), `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetJacobianRoutine()`
 @*/
 PetscErrorCode TaoComputeJacobian(Tao tao, Vec X, Mat J, Mat Jpre)
 {
@@ -308,14 +306,14 @@ PetscErrorCode TaoComputeJacobian(Tao tao, Vec X, Mat J, Mat Jpre)
   PetscCallBack("Tao callback Jacobian", (*tao->ops->computejacobian)(tao, X, J, Jpre, tao->user_jacP));
   PetscCall(PetscLogEventEnd(TAO_JacobianEval, tao, X, J, Jpre));
   PetscCall(VecLockReadPop(X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TaoComputeResidualJacobian - Computes the least-squares residual Jacobian matrix that has been
    set with `TaoSetJacobianResidual()`.
 
-   Collective on tao
+   Collective
 
    Input Parameters:
 +  tao - the Tao solver context
@@ -325,6 +323,8 @@ PetscErrorCode TaoComputeJacobian(Tao tao, Vec X, Mat J, Mat Jpre)
 +  J    - Jacobian matrix
 -  Jpre - Preconditioning matrix
 
+   Level: developer
+
    Notes:
    Most users should not need to explicitly call this routine, as it
    is used internally within the minimization solvers.
@@ -333,9 +333,7 @@ PetscErrorCode TaoComputeJacobian(Tao tao, Vec X, Mat J, Mat Jpre)
    implementations, so most users would not generally call this routine
    themselves.
 
-   Level: developer
-
-.seealso: `Tao`, `TaoComputeResidual()`, `TaoSetJacobianResidual()`
+.seealso: [](chapter_tao), `Tao`, `TaoComputeResidual()`, `TaoSetJacobianResidual()`
 @*/
 PetscErrorCode TaoComputeResidualJacobian(Tao tao, Vec X, Mat J, Mat Jpre)
 {
@@ -349,31 +347,31 @@ PetscErrorCode TaoComputeResidualJacobian(Tao tao, Vec X, Mat J, Mat Jpre)
   PetscCallBack("Tao callback least-squares residual Jacobian", (*tao->ops->computeresidualjacobian)(tao, X, J, Jpre, tao->user_lsjacP));
   PetscCall(PetscLogEventEnd(TAO_JacobianEval, tao, X, J, Jpre));
   PetscCall(VecLockReadPop(X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TaoComputeJacobianState - Computes the Jacobian matrix that has been
    set with `TaoSetJacobianStateRoutine()`.
 
-   Collective on tao
+   Collective
 
    Input Parameters:
-+  tao - the Tao solver context
++  tao - the `Tao` solver context
 -  X   - input vector
 
    Output Parameters:
 +  J    - Jacobian matrix
-.  Jpre - Preconditioning matrix
+.  Jpre - matrix used to construct the preconditioner, often the same as `J`
 -  Jinv - unknown
 
-   Notes:
-   Most users should not need to explicitly call this routine, as it
-   is used internally within the optimization algorithms.
-
    Level: developer
 
-.seealso: `Tao`, `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetJacobianStateRoutine()`, `TaoComputeJacobianDesign()`, `TaoSetStateDesignIS()`
+   Note:
+   Most users should not need to explicitly call this routine, as it
+   is used internally within the optimization algorithms.
+
+.seealso: [](chapter_tao), `Tao`, `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetJacobianStateRoutine()`, `TaoComputeJacobianDesign()`, `TaoSetStateDesignIS()`
 @*/
 PetscErrorCode TaoComputeJacobianState(Tao tao, Vec X, Mat J, Mat Jpre, Mat Jinv)
 {
@@ -387,29 +385,29 @@ PetscErrorCode TaoComputeJacobianState(Tao tao, Vec X, Mat J, Mat Jpre, Mat Jinv
   PetscCallBack("Tao callback Jacobian(state)", (*tao->ops->computejacobianstate)(tao, X, J, Jpre, Jinv, tao->user_jac_stateP));
   PetscCall(PetscLogEventEnd(TAO_JacobianEval, tao, X, J, Jpre));
   PetscCall(VecLockReadPop(X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TaoComputeJacobianDesign - Computes the Jacobian matrix that has been
    set with `TaoSetJacobianDesignRoutine()`.
 
-   Collective on tao
+   Collective
 
    Input Parameters:
 +  tao - the Tao solver context
 -  X   - input vector
 
-   Output Parameters:
+   Output Parameter:
 .  J - Jacobian matrix
 
-   Notes:
-   Most users should not need to explicitly call this routine, as it
-   is used internally within the optimization algorithms.
-
    Level: developer
 
-.seealso: `Tao`, `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetJacobianDesignRoutine()`, `TaoComputeJacobianDesign()`, `TaoSetStateDesignIS()`
+   Note:
+   Most users should not need to explicitly call this routine, as it
+   is used internally within the optimization algorithms.
+
+.seealso: [](chapter_tao), `Tao`, `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetJacobianDesignRoutine()`, `TaoComputeJacobianDesign()`, `TaoSetStateDesignIS()`
 @*/
 PetscErrorCode TaoComputeJacobianDesign(Tao tao, Vec X, Mat J)
 {
@@ -423,34 +421,33 @@ PetscErrorCode TaoComputeJacobianDesign(Tao tao, Vec X, Mat J)
   PetscCallBack("Tao callback Jacobian(design)", (*tao->ops->computejacobiandesign)(tao, X, J, tao->user_jac_designP));
   PetscCall(PetscLogEventEnd(TAO_JacobianEval, tao, X, J, NULL));
   PetscCall(VecLockReadPop(X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TaoSetJacobianRoutine - Sets the function to compute the Jacobian as well as the location to store the matrix.
 
-   Logically collective on tao
+   Logically Collective
 
    Input Parameters:
-+  tao  - the Tao context
-.  J    - Matrix used for the jacobian
-.  Jpre - Matrix that will be used operated on by preconditioner, can be same as J
++  tao  - the `Tao` context
+.  J    - Matrix used for the Jacobian
+.  Jpre - Matrix that will be used to construct the preconditioner, can be same as `J`
 .  func - Jacobian evaluation routine
 -  ctx  - [optional] user-defined context for private data for the
-          Jacobian evaluation routine (may be NULL)
+          Jacobian evaluation routine (may be `NULL`)
 
-   Calling sequence of func:
-$    func(Tao tao,Vec x,Mat J,Mat Jpre,void *ctx);
-
-+  tao  - the Tao  context
+   Calling sequence of `func`:
+$  PetscErrorCode func(Tao tao, Vec x, Mat J, Mat Jpre, void *ctx);
++  tao  - the `Tao` context
 .  x    - input vector
 .  J    - Jacobian matrix
-.  Jpre - preconditioning matrix, usually the same as J
+.  Jpre - matrix used to construct the preconditioner, usually the same as `J`
 -  ctx  - [optional] user-defined Jacobian context
 
    Level: intermediate
 
-.seealso: `Tao`, `TaoSetGradient()`, `TaoSetObjective()`
+.seealso: [](chapter_tao), `Tao`, `TaoSetGradient()`, `TaoSetObjective()`
 @*/
 PetscErrorCode TaoSetJacobianRoutine(Tao tao, Mat J, Mat Jpre, PetscErrorCode (*func)(Tao, Vec, Mat, Mat, void *), void *ctx)
 {
@@ -476,35 +473,34 @@ PetscErrorCode TaoSetJacobianRoutine(Tao tao, Mat J, Mat Jpre, PetscErrorCode (*
     PetscCall(MatDestroy(&tao->jacobian_pre));
     tao->jacobian_pre = Jpre;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TaoSetJacobianResidualRoutine - Sets the function to compute the least-squares residual Jacobian as well as the
    location to store the matrix.
 
-   Logically collective on tao
+   Logically Collective
 
    Input Parameters:
-+  tao  - the Tao context
++  tao  - the `Tao` context
 .  J    - Matrix used for the jacobian
-.  Jpre - Matrix that will be used operated on by preconditioner, can be same as J
+.  Jpre - Matrix that will be used to construct the preconditioner, can be same as `J`
 .  func - Jacobian evaluation routine
 -  ctx  - [optional] user-defined context for private data for the
-          Jacobian evaluation routine (may be NULL)
+          Jacobian evaluation routine (may be `NULL`)
 
-   Calling sequence of func:
-$    func(Tao tao,Vec x,Mat J,Mat Jpre,void *ctx);
-
-+  tao  - the Tao  context
+   Calling sequence of `func`:
+$  PetscErrorCode func(Tao tao, Vec x, Mat J, Mat Jpre, void *ctx);
++  tao  - the `Tao`  context
 .  x    - input vector
 .  J    - Jacobian matrix
-.  Jpre - preconditioning matrix, usually the same as J
+.  Jpre - matrix used to construct the preconditioner, usually the same as `J`
 -  ctx  - [optional] user-defined Jacobian context
 
    Level: intermediate
 
-.seealso: `Tao`, `TaoSetGradient()`, `TaoSetObjective()`
+.seealso: [](chapter_tao), `Tao`, `TaoSetGradient()`, `TaoSetObjective()`
 @*/
 PetscErrorCode TaoSetJacobianResidualRoutine(Tao tao, Mat J, Mat Jpre, PetscErrorCode (*func)(Tao, Vec, Mat, Mat, void *), void *ctx)
 {
@@ -530,7 +526,7 @@ PetscErrorCode TaoSetJacobianResidualRoutine(Tao tao, Mat J, Mat Jpre, PetscErro
     PetscCall(MatDestroy(&tao->ls_jac_pre));
     tao->ls_jac_pre = Jpre;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -538,30 +534,29 @@ PetscErrorCode TaoSetJacobianResidualRoutine(Tao tao, Mat J, Mat Jpre, PetscErro
    (and its inverse) of the constraint function with respect to the state variables.
    Used only for PDE-constrained optimization.
 
-   Logically collective on tao
+   Logically Collective
 
    Input Parameters:
-+  tao  - the Tao context
-.  J    - Matrix used for the jacobian
-.  Jpre - Matrix that will be used operated on by PETSc preconditioner, can be same as J.  Only used if Jinv is NULL
-.  Jinv - [optional] Matrix used to apply the inverse of the state jacobian. Use NULL to default to PETSc KSP solvers to apply the inverse.
++  tao  - the `Tao` context
+.  J    - Matrix used for the Jacobian
+.  Jpre - Matrix that will be used to construct the preconditioner, can be same as `J`.  Only used if `Jinv` is `NULL`
+.  Jinv - [optional] Matrix used to apply the inverse of the state Jacobian. Use `NULL` to default to PETSc `KSP` solvers to apply the inverse.
 .  func - Jacobian evaluation routine
 -  ctx  - [optional] user-defined context for private data for the
-          Jacobian evaluation routine (may be NULL)
+          Jacobian evaluation routine (may be `NULL`)
 
-   Calling sequence of func:
-$    func(Tao tao,Vec x,Mat J,Mat Jpre,Mat Jinv,void *ctx);
-
-+  tao  - the Tao  context
+   Calling sequence of `func`:
+$   PetscErrorCode func(Tao tao, Vec x, Mat J, Mat Jpre, Mat Jinv, void *ctx);
++  tao  - the `Tao` context
 .  x    - input vector
 .  J    - Jacobian matrix
-.  Jpre - preconditioner matrix, usually the same as J
-.  Jinv - inverse of J
+.  Jpre - matrix used to construct the preconditioner, usually the same as `J`
+.  Jinv - inverse of `J`
 -  ctx  - [optional] user-defined Jacobian context
 
    Level: intermediate
 
-.seealso: `Tao`, `TaoComputeJacobianState()`, `TaoSetJacobianDesignRoutine()`, `TaoSetStateDesignIS()`
+.seealso: [](chapter_tao), `Tao`, `TaoComputeJacobianState()`, `TaoSetJacobianDesignRoutine()`, `TaoSetStateDesignIS()`
 @*/
 PetscErrorCode TaoSetJacobianStateRoutine(Tao tao, Mat J, Mat Jpre, Mat Jinv, PetscErrorCode (*func)(Tao, Vec, Mat, Mat, Mat, void *), void *ctx)
 {
@@ -596,7 +591,7 @@ PetscErrorCode TaoSetJacobianStateRoutine(Tao tao, Mat J, Mat Jpre, Mat Jinv, Pe
     PetscCall(MatDestroy(&tao->jacobian_state_inv));
     tao->jacobian_state_inv = Jinv;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -604,26 +599,25 @@ PetscErrorCode TaoSetJacobianStateRoutine(Tao tao, Mat J, Mat Jpre, Mat Jinv, Pe
    the constraint function with respect to the design variables.  Used only for
    PDE-constrained optimization.
 
-   Logically collective on tao
+   Logically Collective
 
    Input Parameters:
-+  tao  - the Tao context
-.  J    - Matrix used for the jacobian
++  tao  - the `Tao` context
+.  J    - Matrix used for the Jacobian
 .  func - Jacobian evaluation routine
 -  ctx  - [optional] user-defined context for private data for the
-          Jacobian evaluation routine (may be NULL)
+          Jacobian evaluation routine (may be `NULL`)
 
-   Calling sequence of func:
-$    func(Tao tao,Vec x,Mat J,void *ctx);
-
-+  tao - the Tao  context
+   Calling sequence of `func`:
+$  PetscErrorCode func(Tao tao, Vec x, Mat J, void *ctx);
++  tao - the `Tao` context
 .  x   - input vector
 .  J   - Jacobian matrix
 -  ctx - [optional] user-defined Jacobian context
 
    Level: intermediate
 
-.seealso: `Tao`, `TaoComputeJacobianDesign()`, `TaoSetJacobianStateRoutine()`, `TaoSetStateDesignIS()`
+.seealso: [](chapter_tao), `Tao`, `TaoComputeJacobianDesign()`, `TaoSetJacobianStateRoutine()`, `TaoSetStateDesignIS()`
 @*/
 PetscErrorCode TaoSetJacobianDesignRoutine(Tao tao, Mat J, PetscErrorCode (*func)(Tao, Vec, Mat, void *), void *ctx)
 {
@@ -640,24 +634,24 @@ PetscErrorCode TaoSetJacobianDesignRoutine(Tao tao, Mat J, PetscErrorCode (*func
     PetscCall(MatDestroy(&tao->jacobian_design));
     tao->jacobian_design = J;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   TaoSetStateDesignIS - Indicate to the Tao which variables in the
+   TaoSetStateDesignIS - Indicate to the `Tao` object which variables in the
    solution vector are state variables and which are design.  Only applies to
    PDE-constrained optimization.
 
-   Logically Collective on Tao
+   Logically Collective
 
    Input Parameters:
-+  tao  - The Tao context
++  tao  - The `Tao` context
 .  s_is - the index set corresponding to the state variables
 -  d_is - the index set corresponding to the design variables
 
    Level: intermediate
 
-.seealso: `Tao`, `TaoSetJacobianStateRoutine()`, `TaoSetJacobianDesignRoutine()`
+.seealso: [](chapter_tao), `Tao`, `TaoSetJacobianStateRoutine()`, `TaoSetJacobianDesignRoutine()`
 @*/
 PetscErrorCode TaoSetStateDesignIS(Tao tao, IS s_is, IS d_is)
 {
@@ -668,30 +662,30 @@ PetscErrorCode TaoSetStateDesignIS(Tao tao, IS s_is, IS d_is)
   PetscCall(PetscObjectReference((PetscObject)(d_is)));
   PetscCall(ISDestroy(&tao->design_is));
   tao->design_is = d_is;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TaoComputeJacobianEquality - Computes the Jacobian matrix that has been
    set with `TaoSetJacobianEqualityRoutine()`.
 
-   Collective on tao
+   Collective
 
    Input Parameters:
-+  tao - the Tao solver context
++  tao - the `Tao` solver context
 -  X   - input vector
 
    Output Parameters:
 +  J    - Jacobian matrix
--  Jpre - Preconditioning matrix
+-  Jpre - matrix used to construct the preconditioner, often the same as `J`
+
+   Level: developer
 
    Notes:
    Most users should not need to explicitly call this routine, as it
    is used internally within the optimization algorithms.
 
-   Level: developer
-
-.seealso: `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetJacobianStateRoutine()`, `TaoComputeJacobianDesign()`, `TaoSetStateDesignIS()`
+.seealso: [](chapter_tao), `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetJacobianStateRoutine()`, `TaoComputeJacobianDesign()`, `TaoSetStateDesignIS()`
 @*/
 PetscErrorCode TaoComputeJacobianEquality(Tao tao, Vec X, Mat J, Mat Jpre)
 {
@@ -705,30 +699,30 @@ PetscErrorCode TaoComputeJacobianEquality(Tao tao, Vec X, Mat J, Mat Jpre)
   PetscCallBack("Tao callback Jacobian(equality)", (*tao->ops->computejacobianequality)(tao, X, J, Jpre, tao->user_jac_equalityP));
   PetscCall(PetscLogEventEnd(TAO_JacobianEval, tao, X, J, Jpre));
   PetscCall(VecLockReadPop(X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TaoComputeJacobianInequality - Computes the Jacobian matrix that has been
    set with `TaoSetJacobianInequalityRoutine()`.
 
-   Collective on tao
+   Collective
 
    Input Parameters:
-+  tao - the Tao solver context
++  tao - the `Tao` solver context
 -  X   - input vector
 
    Output Parameters:
 +  J    - Jacobian matrix
--  Jpre - Preconditioning matrix
-
-   Notes:
-   Most users should not need to explicitly call this routine, as it
-   is used internally within the minimization solvers.
+-  Jpre - matrix used to construct the preconditioner
 
    Level: developer
 
-.seealso: `Tao`, `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetJacobianStateRoutine()`, `TaoComputeJacobianDesign()`, `TaoSetStateDesignIS()`
+   Note:
+   Most users should not need to explicitly call this routine, as it
+   is used internally within the minimization solvers.
+
+.seealso: [](chapter_tao), `Tao`, `TaoComputeObjective()`, `TaoComputeObjectiveAndGradient()`, `TaoSetJacobianStateRoutine()`, `TaoComputeJacobianDesign()`, `TaoSetStateDesignIS()`
 @*/
 PetscErrorCode TaoComputeJacobianInequality(Tao tao, Vec X, Mat J, Mat Jpre)
 {
@@ -742,7 +736,7 @@ PetscErrorCode TaoComputeJacobianInequality(Tao tao, Vec X, Mat J, Mat Jpre)
   PetscCallBack("Tao callback Jacobian (inequality)", (*tao->ops->computejacobianinequality)(tao, X, J, Jpre, tao->user_jac_inequalityP));
   PetscCall(PetscLogEventEnd(TAO_JacobianEval, tao, X, J, Jpre));
   PetscCall(VecLockReadPop(X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -750,28 +744,27 @@ PetscErrorCode TaoComputeJacobianInequality(Tao tao, Vec X, Mat J, Mat Jpre)
    (and its inverse) of the constraint function with respect to the equality variables.
    Used only for PDE-constrained optimization.
 
-   Logically collective on tao
+   Logically Collective
 
    Input Parameters:
-+  tao  - the Tao context
-.  J    - Matrix used for the jacobian
-.  Jpre - Matrix that will be used operated on by PETSc preconditioner, can be same as J.
++  tao  - the `Tao` context
+.  J    - Matrix used for the Jacobian
+.  Jpre - Matrix that will be used to construct the preconditioner, can be same as `J`.
 .  func - Jacobian evaluation routine
 -  ctx  - [optional] user-defined context for private data for the
-          Jacobian evaluation routine (may be NULL)
+          Jacobian evaluation routine (may be `NULL`)
 
-   Calling sequence of func:
-$    func(Tao tao,Vec x,Mat J,Mat Jpre,void *ctx);
-
-+  tao  - the Tao  context
+   Calling sequence of `func`:
+$  PetscErrorCode func(Tao tao, Vec x, Mat J, Mat Jpre, void *ctx)
++  tao  - the `Tao` context
 .  x    - input vector
 .  J    - Jacobian matrix
-.  Jpre - preconditioner matrix, usually the same as J
+.  Jpre - matrix used to construct the preconditioner, usually the same as `J`
 -  ctx  - [optional] user-defined Jacobian context
 
    Level: intermediate
 
-.seealso: `Tao`, `TaoComputeJacobianEquality()`, `TaoSetJacobianDesignRoutine()`, `TaoSetEqualityDesignIS()`
+.seealso: [](chapter_tao), `Tao`, `TaoComputeJacobianEquality()`, `TaoSetJacobianDesignRoutine()`, `TaoSetEqualityDesignIS()`
 @*/
 PetscErrorCode TaoSetJacobianEqualityRoutine(Tao tao, Mat J, Mat Jpre, PetscErrorCode (*func)(Tao, Vec, Mat, Mat, void *), void *ctx)
 {
@@ -797,7 +790,7 @@ PetscErrorCode TaoSetJacobianEqualityRoutine(Tao tao, Mat J, Mat Jpre, PetscErro
     PetscCall(MatDestroy(&tao->jacobian_equality_pre));
     tao->jacobian_equality_pre = Jpre;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -805,28 +798,27 @@ PetscErrorCode TaoSetJacobianEqualityRoutine(Tao tao, Mat J, Mat Jpre, PetscErro
    (and its inverse) of the constraint function with respect to the inequality variables.
    Used only for PDE-constrained optimization.
 
-   Logically collective on tao
+   Logically Collective
 
    Input Parameters:
-+  tao  - the Tao context
-.  J    - Matrix used for the jacobian
-.  Jpre - Matrix that will be used operated on by PETSc preconditioner, can be same as J.
++  tao  - the `Tao` context
+.  J    - Matrix used for the Jacobian
+.  Jpre - Matrix that will be used to construct the preconditioner, can be same as `J`.
 .  func - Jacobian evaluation routine
 -  ctx  - [optional] user-defined context for private data for the
-          Jacobian evaluation routine (may be NULL)
+          Jacobian evaluation routine (may be `NULL`)
 
-   Calling sequence of func:
-$    func(Tao tao,Vec x,Mat J,Mat Jpre,void *ctx);
-
-+  tao  - the Tao  context
+   Calling sequence of `func`:
+$  PetscErrorCode func(Tao tao, Vec x, Mat J, Mat Jpre, void *ctx);
++  tao  - the `Tao` context
 .  x    - input vector
 .  J    - Jacobian matrix
-.  Jpre - preconditioner matrix, usually the same as J
+.  Jpre - matrix used to construct the preconditioner, usually the same as `J`
 -  ctx  - [optional] user-defined Jacobian context
 
    Level: intermediate
 
-.seealso: `Tao`, `TaoComputeJacobianInequality()`, `TaoSetJacobianDesignRoutine()`, `TaoSetInequalityDesignIS()`
+.seealso: [](chapter_tao), `Tao`, `TaoComputeJacobianInequality()`, `TaoSetJacobianDesignRoutine()`, `TaoSetInequalityDesignIS()`
 @*/
 PetscErrorCode TaoSetJacobianInequalityRoutine(Tao tao, Mat J, Mat Jpre, PetscErrorCode (*func)(Tao, Vec, Mat, Mat, void *), void *ctx)
 {
@@ -852,5 +844,5 @@ PetscErrorCode TaoSetJacobianInequalityRoutine(Tao tao, Mat J, Mat Jpre, PetscEr
     PetscCall(MatDestroy(&tao->jacobian_inequality_pre));
     tao->jacobian_inequality_pre = Jpre;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
