@@ -20,8 +20,8 @@ PETSC_EXTERN PetscErrorCode TSAdaptCreate_History(TSAdapt);
    Not Collective
 
    Input Parameters:
-+  name_scheme - name of user-defined adaptivity scheme
--  routine_create - routine to create method context
++  sname - name of user-defined adaptivity scheme
+-  function - routine to create method context
 
    Level: advanced
 
@@ -45,11 +45,11 @@ PetscErrorCode TSAdaptRegister(const char sname[], PetscErrorCode (*function)(TS
   PetscFunctionBegin;
   PetscCall(TSAdaptInitializePackage());
   PetscCall(PetscFunctionListAdd(&TSAdaptList, sname, function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  TSAdaptRegisterAll - Registers all of the adaptivity schemes in TSAdapt
+  TSAdaptRegisterAll - Registers all of the adaptivity schemes in `TSAdapt`
 
   Not Collective
 
@@ -60,7 +60,7 @@ PetscErrorCode TSAdaptRegister(const char sname[], PetscErrorCode (*function)(TS
 PetscErrorCode TSAdaptRegisterAll(void)
 {
   PetscFunctionBegin;
-  if (TSAdaptRegisterAllCalled) PetscFunctionReturn(0);
+  if (TSAdaptRegisterAllCalled) PetscFunctionReturn(PETSC_SUCCESS);
   TSAdaptRegisterAllCalled = PETSC_TRUE;
   PetscCall(TSAdaptRegister(TSADAPTNONE, TSAdaptCreate_None));
   PetscCall(TSAdaptRegister(TSADAPTBASIC, TSAdaptCreate_Basic));
@@ -68,12 +68,12 @@ PetscErrorCode TSAdaptRegisterAll(void)
   PetscCall(TSAdaptRegister(TSADAPTCFL, TSAdaptCreate_CFL));
   PetscCall(TSAdaptRegister(TSADAPTGLEE, TSAdaptCreate_GLEE));
   PetscCall(TSAdaptRegister(TSADAPTHISTORY, TSAdaptCreate_History));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  TSAdaptFinalizePackage - This function destroys everything in the TS package. It is
-  called from PetscFinalize().
+  TSAdaptFinalizePackage - This function destroys everything in the `TS` package. It is
+  called from `PetscFinalize()`.
 
   Level: developer
 
@@ -85,12 +85,12 @@ PetscErrorCode TSAdaptFinalizePackage(void)
   PetscCall(PetscFunctionListDestroy(&TSAdaptList));
   TSAdaptPackageInitialized = PETSC_FALSE;
   TSAdaptRegisterAllCalled  = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  TSAdaptInitializePackage - This function initializes everything in the TSAdapt package. It is
-  called from TSInitializePackage().
+  TSAdaptInitializePackage - This function initializes everything in the `TSAdapt` package. It is
+  called from `TSInitializePackage()`.
 
   Level: developer
 
@@ -99,18 +99,18 @@ PetscErrorCode TSAdaptFinalizePackage(void)
 PetscErrorCode TSAdaptInitializePackage(void)
 {
   PetscFunctionBegin;
-  if (TSAdaptPackageInitialized) PetscFunctionReturn(0);
+  if (TSAdaptPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   TSAdaptPackageInitialized = PETSC_TRUE;
   PetscCall(PetscClassIdRegister("TSAdapt", &TSADAPT_CLASSID));
   PetscCall(TSAdaptRegisterAll());
   PetscCall(PetscRegisterFinalize(TSAdaptFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TSAdaptSetType - sets the approach used for the error adapter
 
-  Logicially Collective onadapt
+  Logicially Collective
 
   Input Parameters:
 + adapt - the `TS` adapter, most likely obtained with `TSGetAdapt()`
@@ -132,14 +132,14 @@ PetscErrorCode TSAdaptSetType(TSAdapt adapt, TSAdaptType type)
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscValidCharPointer(type, 2);
   PetscCall(PetscObjectTypeCompare((PetscObject)adapt, type, &match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscFunctionListFind(TSAdaptList, type, &r));
   PetscCheck(r, PETSC_COMM_SELF, PETSC_ERR_ARG_UNKNOWN_TYPE, "Unknown TSAdapt type \"%s\" given", type);
   PetscTryTypeMethod(adapt, destroy);
   PetscCall(PetscMemzero(adapt->ops, sizeof(struct _TSAdaptOps)));
   PetscCall(PetscObjectChangeTypeName((PetscObject)adapt, type));
   PetscCall((*r)(adapt));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -163,7 +163,7 @@ PetscErrorCode TSAdaptGetType(TSAdapt adapt, TSAdaptType *type)
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscValidPointer(type, 2);
   *type = ((PetscObject)adapt)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSAdaptSetOptionsPrefix(TSAdapt adapt, const char prefix[])
@@ -171,13 +171,13 @@ PetscErrorCode TSAdaptSetOptionsPrefix(TSAdapt adapt, const char prefix[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscCall(PetscObjectSetOptionsPrefix((PetscObject)adapt, prefix));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  TSAdaptLoad - Loads a TSAdapt that has been stored in binary  with TSAdaptView().
+  TSAdaptLoad - Loads a TSAdapt that has been stored in binary with `TSAdaptView()`.
 
-  Collective on adapt
+  Collective
 
   Input Parameters:
 + newdm - the newly loaded `TSAdapt`, this needs to have been created with `TSAdaptCreate()` or
@@ -206,7 +206,7 @@ PetscErrorCode TSAdaptLoad(TSAdapt adapt, PetscViewer viewer)
   PetscCall(PetscViewerBinaryRead(viewer, type, 256, NULL, PETSC_CHAR));
   PetscCall(TSAdaptSetType(adapt, type));
   PetscTryTypeMethod(adapt, load, viewer);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSAdaptView(TSAdapt adapt, PetscViewer viewer)
@@ -251,13 +251,13 @@ PetscErrorCode TSAdaptView(TSAdapt adapt, PetscViewer viewer)
     PetscCall(PetscStrncpy(type, ((PetscObject)adapt)->type_name, 256));
     PetscCall(PetscViewerBinaryWrite(viewer, type, 256, PETSC_CHAR));
   } else PetscTryTypeMethod(adapt, view, viewer);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptReset - Resets a `TSAdapt` context to its defaults
 
-   Collective on adapt
+   Collective
 
    Input Parameter:
 .  adapt - the `TSAdapt` context obtained from `TSGetAdapt()` or `TSAdaptCreate()`
@@ -271,17 +271,17 @@ PetscErrorCode TSAdaptReset(TSAdapt adapt)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscTryTypeMethod(adapt, reset);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSAdaptDestroy(TSAdapt *adapt)
 {
   PetscFunctionBegin;
-  if (!*adapt) PetscFunctionReturn(0);
+  if (!*adapt) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(*adapt, TSADAPT_CLASSID, 1);
   if (--((PetscObject)(*adapt))->refct > 0) {
     *adapt = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(TSAdaptReset(*adapt));
@@ -289,13 +289,13 @@ PetscErrorCode TSAdaptDestroy(TSAdapt *adapt)
   PetscTryTypeMethod((*adapt), destroy);
   PetscCall(PetscViewerDestroy(&(*adapt)->monitor));
   PetscCall(PetscHeaderDestroy(adapt));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptSetMonitor - Monitor the choices made by the adaptive controller
 
-   Collective on adapt
+   Collective
 
    Input Parameters:
 +  adapt - adaptive controller context
@@ -318,21 +318,20 @@ PetscErrorCode TSAdaptSetMonitor(TSAdapt adapt, PetscBool flg)
   } else {
     PetscCall(PetscViewerDestroy(&adapt->monitor));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSAdaptSetCheckStage - Set a callback to check convergence for a stage
 
-   Logically collective on adapt
+   Logically Collective
 
    Input Parameters:
 +  adapt - adaptive controller context
 -  func - stage check function
 
-   Arguments of func:
+  Calling Sequence of `func`:
 $  PetscErrorCode func(TSAdapt adapt,TS ts,PetscBool *accept)
-
 +  adapt - adaptive controller context
 .  ts - time stepping context
 -  accept - pending choice of whether to accept, can be modified by this routine
@@ -346,14 +345,14 @@ PetscErrorCode TSAdaptSetCheckStage(TSAdapt adapt, PetscErrorCode (*func)(TSAdap
   PetscFunctionBegin;
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   adapt->checkstage = func;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptSetAlwaysAccept - Set whether to always accept steps regardless of
    any error or stability condition not meeting the prescribed goal.
 
-   Logically collective on adapt
+   Logically Collective
 
    Input Parameters:
 +  adapt - time step adaptivity context, usually gotten with `TSGetAdapt()`
@@ -372,13 +371,13 @@ PetscErrorCode TSAdaptSetAlwaysAccept(TSAdapt adapt, PetscBool flag)
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscValidLogicalCollectiveBool(adapt, flag, 2);
   adapt->always_accept = flag;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptSetSafety - Set safety factors for time step adaptor
 
-   Logically collective on adapt
+   Logically Collective
 
    Input Parameters:
 +  adapt - adaptive controller context
@@ -399,13 +398,13 @@ PetscErrorCode TSAdaptSetSafety(TSAdapt adapt, PetscReal safety, PetscReal rejec
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscValidLogicalCollectiveReal(adapt, safety, 2);
   PetscValidLogicalCollectiveReal(adapt, reject_safety, 3);
-  PetscCheck(safety == PETSC_DEFAULT || safety >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Safety factor %g must be non negative", (double)safety);
-  PetscCheck(safety == PETSC_DEFAULT || safety <= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Safety factor %g must be less than one", (double)safety);
-  PetscCheck(reject_safety == PETSC_DEFAULT || reject_safety >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Reject safety factor %g must be non negative", (double)reject_safety);
-  PetscCheck(reject_safety == PETSC_DEFAULT || reject_safety <= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Reject safety factor %g must be less than one", (double)reject_safety);
-  if (safety != PETSC_DEFAULT) adapt->safety = safety;
-  if (reject_safety != PETSC_DEFAULT) adapt->reject_safety = reject_safety;
-  PetscFunctionReturn(0);
+  PetscCheck(safety == (PetscReal)PETSC_DEFAULT || safety >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Safety factor %g must be non negative", (double)safety);
+  PetscCheck(safety == (PetscReal)PETSC_DEFAULT || safety <= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Safety factor %g must be less than one", (double)safety);
+  PetscCheck(reject_safety == (PetscReal)PETSC_DEFAULT || reject_safety >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Reject safety factor %g must be non negative", (double)reject_safety);
+  PetscCheck(reject_safety == (PetscReal)PETSC_DEFAULT || reject_safety <= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Reject safety factor %g must be less than one", (double)reject_safety);
+  if (safety != (PetscReal)PETSC_DEFAULT) adapt->safety = safety;
+  if (reject_safety != (PetscReal)PETSC_DEFAULT) adapt->reject_safety = reject_safety;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -432,14 +431,14 @@ PetscErrorCode TSAdaptGetSafety(TSAdapt adapt, PetscReal *safety, PetscReal *rej
   if (reject_safety) PetscValidRealPointer(reject_safety, 3);
   if (safety) *safety = adapt->safety;
   if (reject_safety) *reject_safety = adapt->reject_safety;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptSetMaxIgnore - Set error estimation threshold. Solution components below this threshold value will not be considered when computing error norms
    for time step adaptivity (in absolute value). A negative value (default) of the threshold leads to considering all solution components.
 
-   Logically collective on adapt
+   Logically Collective
 
    Input Parameters:
 +  adapt - adaptive controller context
@@ -458,7 +457,7 @@ PetscErrorCode TSAdaptSetMaxIgnore(TSAdapt adapt, PetscReal max_ignore)
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscValidLogicalCollectiveReal(adapt, max_ignore, 2);
   adapt->ignore_max = max_ignore;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -483,13 +482,13 @@ PetscErrorCode TSAdaptGetMaxIgnore(TSAdapt adapt, PetscReal *max_ignore)
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscValidRealPointer(max_ignore, 2);
   *max_ignore = adapt->ignore_max;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptSetClip - Sets the admissible decrease/increase factor in step size in the time step adapter
 
-   Logically collective on adapt
+   Logically collective
 
    Input Parameters:
 +  adapt - adaptive controller context
@@ -509,12 +508,12 @@ PetscErrorCode TSAdaptSetClip(TSAdapt adapt, PetscReal low, PetscReal high)
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscValidLogicalCollectiveReal(adapt, low, 2);
   PetscValidLogicalCollectiveReal(adapt, high, 3);
-  PetscCheck(low == PETSC_DEFAULT || low >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Decrease factor %g must be non negative", (double)low);
-  PetscCheck(low == PETSC_DEFAULT || low <= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Decrease factor %g must be less than one", (double)low);
-  PetscCheck(high == PETSC_DEFAULT || high >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Increase factor %g must be greater than one", (double)high);
-  if (low != PETSC_DEFAULT) adapt->clip[0] = low;
-  if (high != PETSC_DEFAULT) adapt->clip[1] = high;
-  PetscFunctionReturn(0);
+  PetscCheck(low == (PetscReal)PETSC_DEFAULT || low >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Decrease factor %g must be non negative", (double)low);
+  PetscCheck(low == (PetscReal)PETSC_DEFAULT || low <= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Decrease factor %g must be less than one", (double)low);
+  PetscCheck(high == (PetscReal)PETSC_DEFAULT || high >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Increase factor %g must be greater than one", (double)high);
+  if (low != (PetscReal)PETSC_DEFAULT) adapt->clip[0] = low;
+  if (high != (PetscReal)PETSC_DEFAULT) adapt->clip[1] = high;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -541,13 +540,13 @@ PetscErrorCode TSAdaptGetClip(TSAdapt adapt, PetscReal *low, PetscReal *high)
   if (high) PetscValidRealPointer(high, 3);
   if (low) *low = adapt->clip[0];
   if (high) *high = adapt->clip[1];
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptSetScaleSolveFailed - Scale step size by this factor if solve fails
 
-   Logically collective on adapt
+   Logically Collective
 
    Input Parameters:
 +  adapt - adaptive controller context
@@ -565,10 +564,10 @@ PetscErrorCode TSAdaptSetScaleSolveFailed(TSAdapt adapt, PetscReal scale)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscValidLogicalCollectiveReal(adapt, scale, 2);
-  PetscCheck(scale == PETSC_DEFAULT || scale > 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Scale factor %g must be positive", (double)scale);
-  PetscCheck(scale == PETSC_DEFAULT || scale <= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Scale factor %g must be less than one", (double)scale);
-  if (scale != PETSC_DEFAULT) adapt->scale_solve_failed = scale;
-  PetscFunctionReturn(0);
+  PetscCheck(scale == (PetscReal)PETSC_DEFAULT || scale > 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Scale factor %g must be positive", (double)scale);
+  PetscCheck(scale == (PetscReal)PETSC_DEFAULT || scale <= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Scale factor %g must be less than one", (double)scale);
+  if (scale != (PetscReal)PETSC_DEFAULT) adapt->scale_solve_failed = scale;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -592,13 +591,13 @@ PetscErrorCode TSAdaptGetScaleSolveFailed(TSAdapt adapt, PetscReal *scale)
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   if (scale) PetscValidRealPointer(scale, 2);
   if (scale) *scale = adapt->scale_solve_failed;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptSetStepLimits - Set the minimum and maximum step sizes to be considered by the time step controller
 
-   Logically collective on adapt
+   Logically Collective
 
    Input Parameters:
 +  adapt - time step adaptivity context, usually gotten with `TSGetAdapt()`
@@ -619,14 +618,14 @@ PetscErrorCode TSAdaptSetStepLimits(TSAdapt adapt, PetscReal hmin, PetscReal hma
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscValidLogicalCollectiveReal(adapt, hmin, 2);
   PetscValidLogicalCollectiveReal(adapt, hmax, 3);
-  PetscCheck(hmin == PETSC_DEFAULT || hmin >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Minimum time step %g must be non negative", (double)hmin);
-  PetscCheck(hmax == PETSC_DEFAULT || hmax >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Minimum time step %g must be non negative", (double)hmax);
-  if (hmin != PETSC_DEFAULT) adapt->dt_min = hmin;
-  if (hmax != PETSC_DEFAULT) adapt->dt_max = hmax;
+  PetscCheck(hmin == (PetscReal)PETSC_DEFAULT || hmin >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Minimum time step %g must be non negative", (double)hmin);
+  PetscCheck(hmax == (PetscReal)PETSC_DEFAULT || hmax >= 0, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Minimum time step %g must be non negative", (double)hmax);
+  if (hmin != (PetscReal)PETSC_DEFAULT) adapt->dt_min = hmin;
+  if (hmax != (PetscReal)PETSC_DEFAULT) adapt->dt_max = hmax;
   hmin = adapt->dt_min;
   hmax = adapt->dt_max;
   PetscCheck(hmax > hmin, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Maximum time step %g must greater than minimum time step %g", (double)hmax, (double)hmin);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -653,16 +652,17 @@ PetscErrorCode TSAdaptGetStepLimits(TSAdapt adapt, PetscReal *hmin, PetscReal *h
   if (hmax) PetscValidRealPointer(hmax, 3);
   if (hmin) *hmin = adapt->dt_min;
   if (hmax) *hmax = adapt->dt_max;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
    TSAdaptSetFromOptions - Sets various `TSAdapt` parameters from user options.
 
-   Collective on adapt
+   Collective
 
    Input Parameter:
-.  adapt - the `TSAdapt` context
++  adapt - the `TSAdapt` context
+-  PetscOptionsObject - object created by `PetscOptionsBegin()`
 
    Options Database Keys:
 +  -ts_adapt_type <type> - algorithm to use for adaptivity
@@ -737,13 +737,13 @@ PetscErrorCode TSAdaptSetFromOptions(TSAdapt adapt, PetscOptionItems *PetscOptio
 
   PetscTryTypeMethod(adapt, setfromoptions, PetscOptionsObject);
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptCandidatesClear - clear any previously set candidate schemes
 
-   Logically collective on adapt
+   Logically Collective
 
    Input Parameter:
 .  adapt - adaptive controller
@@ -757,13 +757,13 @@ PetscErrorCode TSAdaptCandidatesClear(TSAdapt adapt)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(adapt, TSADAPT_CLASSID, 1);
   PetscCall(PetscMemzero(&adapt->candidates, sizeof(adapt->candidates)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSAdaptCandidateAdd - add a candidate scheme for the adaptive controller to select from
 
-   Logically collective on adapt
+   Logically Collective; No Fortran Support
 
    Input Parameters:
 +  adapt - time step adaptivity context, obtained with `TSGetAdapt()` or `TSAdaptCreate()`
@@ -776,9 +776,6 @@ PetscErrorCode TSAdaptCandidatesClear(TSAdapt adapt)
 
    Level: developer
 
-   Fortran Note:
-   This routine is not available in Fortran.
-
 .seealso: [](chapter_ts), `TSAdapt`, `TSAdaptCandidatesClear()`, `TSAdaptChoose()`
 @*/
 PetscErrorCode TSAdaptCandidateAdd(TSAdapt adapt, const char name[], PetscInt order, PetscInt stageorder, PetscReal ccfl, PetscReal cost, PetscBool inuse)
@@ -801,7 +798,7 @@ PetscErrorCode TSAdaptCandidateAdd(TSAdapt adapt, const char name[], PetscInt or
   adapt->candidates.ccfl[c]       = ccfl;
   adapt->candidates.cost[c]       = cost;
   adapt->candidates.n++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -835,16 +832,16 @@ PetscErrorCode TSAdaptCandidatesGet(TSAdapt adapt, PetscInt *n, const PetscInt *
   if (stageorder) *stageorder = adapt->candidates.stageorder;
   if (ccfl) *ccfl = adapt->candidates.ccfl;
   if (cost) *cost = adapt->candidates.cost;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSAdaptChoose - choose which method and step size to use for the next step
 
-   Collective on adapt
+   Collective
 
    Input Parameters:
-+  adapt - adaptive contoller
++  adapt - adaptive controller
 .  ts - time stepper
 -  h - current step size
 
@@ -881,7 +878,7 @@ PetscErrorCode TSAdaptChoose(TSAdapt adapt, TS ts, PetscReal h, PetscInt *next_s
   if (ts->event && ts->event->status != TSEVENT_NONE) {
     *next_h = h;
     *accept = PETSC_TRUE;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscUseTypeMethod(adapt, choose, ts, h, &scheme, next_h, accept, &wlte, &wltea, &wlter);
@@ -926,14 +923,14 @@ PetscErrorCode TSAdaptChoose(TSAdapt adapt, TS ts, PetscReal h, PetscInt *next_s
     }
     PetscCall(PetscViewerASCIISubtractTab(adapt->monitor, ((PetscObject)adapt)->tablevel));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptSetTimeStepIncreaseDelay - The number of timesteps to wait after a decrease in the timestep due to failed solver
                                      before increasing the time step.
 
-   Logicially Collective on adapt
+   Logicially Collective
 
    Input Parameters:
 +  adapt - adaptive controller context
@@ -958,13 +955,13 @@ PetscErrorCode TSAdaptSetTimeStepIncreaseDelay(TSAdapt adapt, PetscInt cnt)
 {
   PetscFunctionBegin;
   adapt->timestepjustdecreased_delay = cnt;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSAdaptCheckStage - checks whether to accept a stage, (e.g. reject and change time step size if nonlinear solve fails or solution vector is infeasible)
 
-   Collective on tsadapt
+   Collective
 
    Input Parameters:
 +  adapt - adaptive controller context
@@ -1029,7 +1026,7 @@ PetscErrorCode TSAdaptCheckStage(TSAdapt adapt, TS ts, PetscReal t, Vec Y, Petsc
       PetscCall(PetscViewerASCIISubtractTab(adapt->monitor, ((PetscObject)adapt)->tablevel));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1079,5 +1076,5 @@ PetscErrorCode TSAdaptCreate(MPI_Comm comm, TSAdapt *inadapt)
   adapt->timestepjustdecreased_delay = 0;
 
   *inadapt = adapt;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
