@@ -3,20 +3,20 @@
 PETSC_EXTERN PetscErrorCode CharacteristicCreate_DA(Characteristic);
 
 /*@C
-  CharacteristicRegisterAll - Registers all of the Krylov subspace methods in the Characteristic package.
+  CharacteristicRegisterAll - Registers all of the methods in the `Characteristic` package.
 
   Not Collective
 
   Level: advanced
 
-.seealso: `CharacteristicRegisterDestroy()`
+.seealso: [](chapter_ts), `CharacteristicRegisterDestroy()`
 @*/
 PetscErrorCode CharacteristicRegisterAll(void)
 {
   PetscFunctionBegin;
-  if (CharacteristicRegisterAllCalled) PetscFunctionReturn(0);
+  if (CharacteristicRegisterAllCalled) PetscFunctionReturn(PETSC_SUCCESS);
   CharacteristicRegisterAllCalled = PETSC_TRUE;
 
   PetscCall(CharacteristicRegister(CHARACTERISTICDA, CharacteristicCreate_DA));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
