@@ -6,14 +6,14 @@
 PetscErrorCode TSEventInitialize(TSEvent event, TS ts, PetscReal t, Vec U)
 {
   PetscFunctionBegin;
-  if (!event) PetscFunctionReturn(0);
+  if (!event) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidPointer(event, 1);
   PetscValidHeaderSpecific(ts, TS_CLASSID, 2);
   PetscValidHeaderSpecific(U, VEC_CLASSID, 4);
   event->ptime_prev = t;
   event->iterctr    = 0;
   PetscCall((*event->eventhandler)(ts, t, U, event->fvalue_prev, event->ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSEventDestroy(TSEvent *event)
@@ -22,10 +22,10 @@ PetscErrorCode TSEventDestroy(TSEvent *event)
 
   PetscFunctionBegin;
   PetscValidPointer(event, 1);
-  if (!*event) PetscFunctionReturn(0);
+  if (!*event) PetscFunctionReturn(PETSC_SUCCESS);
   if (--(*event)->refct > 0) {
     *event = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(PetscFree((*event)->fvalue));
@@ -46,11 +46,11 @@ PetscErrorCode TSEventDestroy(TSEvent *event)
 
   PetscCall(PetscViewerDestroy(&(*event)->monitor));
   PetscCall(PetscFree(*event));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-  TSSetPostEventIntervalStep - Set the time-step used immediately following the event interval
+  TSSetPostEventIntervalStep - Set the time-step used immediately following an event interval
 
   Logically Collective
 
@@ -78,18 +78,18 @@ PetscErrorCode TSSetPostEventIntervalStep(TS ts, PetscReal dt)
 {
   PetscFunctionBegin;
   ts->event->timestep_posteventinterval = dt;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   TSSetEventTolerances - Set tolerances for event zero crossings when using event handler
+   TSSetEventTolerances - Set tolerances for event zero crossings
 
    Logically Collective
 
    Input Parameters:
 +  ts - time integration context
 .  tol - scalar tolerance, `PETSC_DECIDE` to leave current value
--  vtol - array of tolerances or NULL, used in preference to tol if present
+-  vtol - array of tolerances or `NULL`, used in preference to tol if present
 
    Options Database Key:
 .  -ts_event_tol <tol> - tolerance for event zero crossing
@@ -99,7 +99,10 @@ PetscErrorCode TSSetPostEventIntervalStep(TS ts, PetscReal dt)
    Notes:
    Must call `TSSetEventHandler(`) before setting the tolerances.
 
-   The size of vtol is equal to the number of events.
+   The size of `vtol` is equal to the number of events.
+
+   The tolerance is some measure of how close the event function is to zero for the event detector to stop
+   and declare the time of the event has been detected.
 
 .seealso: [](chapter_ts), `TS`, `TSEvent`, `TSSetEventHandler()`
 @*/
@@ -117,17 +120,17 @@ PetscErrorCode TSSetEventTolerances(TS ts, PetscReal tol, PetscReal vtol[])
   if (vtol) {
     for (i = 0; i < event->nevents; i++) event->vtol[i] = vtol[i];
   } else {
-    if (tol != PETSC_DECIDE || tol != PETSC_DEFAULT) {
+    if ((tol != (PetscReal)PETSC_DECIDE) || (tol != (PetscReal)PETSC_DEFAULT)) {
       for (i = 0; i < event->nevents; i++) event->vtol[i] = tol;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSSetEventHandler - Sets a function used for detecting events
 
-   Logically Collective on ts
+   Logically Collective
 
    Input Parameters:
 +  ts - the `TS` context obtained from `TSCreate()`
@@ -136,38 +139,36 @@ PetscErrorCode TSSetEventTolerances(TS ts, PetscReal tol, PetscReal vtol[])
                +1 => Zero crossing in positive direction, 0 => both ways (one for each event)
 .  terminate - flag to indicate whether time stepping should be terminated after
                event is detected (one for each event)
-.  eventhandler - event monitoring routine
-.  postevent - [optional] post-event function
+.  eventhandler - a change in sign of this function (see `direction`) is used to determine an even has occurred
+.  postevent - [optional] post-event function, this function can change properties of the solution, ODE etc at the time of the event
 -  ctx       - [optional] user-defined context for private data for the
-               event monitor and post event routine (use NULL if no
+               event detector and post event routine (use `NULL` if no
                context is desired)
 
-   Calling sequence of eventhandler:
-   PetscErrorCode PetscEventHandler(TS ts,PetscReal t,Vec U,PetscScalar fvalue[],void* ctx)
-
-   Input Parameters:
-+  ts  - the TS context
+   Calling sequence of `eventhandler`:
+$   PetscErrorCode eventhandler(TS ts, PetscReal t, Vec U, PetscScalar fvalue[], void* ctx)
++  ts  - the `TS` context
 .  t   - current time
 .  U   - current iterate
--  ctx - [optional] context passed with eventhandler
+.  ctx - [optional] context passed with eventhandler
+-  fvalue    - function value of events at time t
 
-   Output parameters:
-.  fvalue    - function value of events at time t
-
-   Calling sequence of postevent:
-   PetscErrorCode PostEvent(TS ts,PetscInt nevents_zero,PetscInt events_zero[],PetscReal t,Vec U,PetscBool forwardsolve,void* ctx)
-
-   Input Parameters:
-+  ts - the TS context
+   Calling sequence of `postevent`:
+$   PetscErrorCode postevent(TS ts, PetscInt nevents_zero, PetscInt events_zero[], PetscReal t, Vec U, PetscBool forwardsolve, void *ctx)
++  ts - the `TS` context
 .  nevents_zero - number of local events whose event function is zero
 .  events_zero  - indices of local events which have reached zero
 .  t            - current time
 .  U            - current solution
-.  forwardsolve - Flag to indicate whether TS is doing a forward solve (1) or adjoint solve (0)
+.  forwardsolve - Flag to indicate whether `TS` is doing a forward solve (1) or adjoint solve (0)
 -  ctx          - the context passed with eventhandler
 
    Level: intermediate
 
+   Note:
+   The `eventhandler` is actually the event detector function and the `postevent` function actually handles the desired changes that
+   should take place at the time of the event
+
 .seealso: [](chapter_ts), `TSEvent`, `TSCreate()`, `TSSetTimeStep()`, `TSSetConvergedReason()`
 @*/
 PetscErrorCode TSSetEventHandler(TS ts, PetscInt nevents, PetscInt direction[], PetscBool terminate[], PetscErrorCode (*eventhandler)(TS, PetscReal, Vec, PetscScalar[], void *), PetscErrorCode (*postevent)(TS, PetscInt, PetscInt[], PetscReal, Vec, PetscBool, void *), void *ctx)
@@ -241,7 +242,7 @@ PetscErrorCode TSSetEventHandler(TS ts, PetscInt nevents, PetscInt direction[],
   PetscCall(TSEventDestroy(&ts->event));
   ts->event        = event;
   ts->event->refct = 1;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -287,7 +288,7 @@ static PetscErrorCode TSEventRecorderResize(TSEvent event)
   /* Double size */
   event->recsize *= fact;
 
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -343,7 +344,7 @@ static PetscErrorCode TSPostEvent(TS ts, PetscReal t, Vec U)
   event->recorder.nevents[ctr] = event->nevents_zero;
   for (i = 0; i < event->nevents_zero; i++) event->recorder.eventidx[ctr][i] = event->events_zero[i];
   event->recorder.ctr++;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Uses Anderson-Bjorck variant of regula falsi method */
@@ -397,7 +398,7 @@ static PetscErrorCode TSEventDetection(TS ts)
   in = (PetscInt)event->status;
   PetscCall(MPIU_Allreduce(&in, &out, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)ts)));
   event->status = (TSEventStatus)out;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSEventLocation(TS ts, PetscReal *dt)
@@ -453,7 +454,7 @@ static PetscErrorCode TSEventLocation(TS ts, PetscReal *dt)
   PetscCall(MPIU_Allreduce(in, out, 2, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)ts)));
   event->status = (TSEventStatus)out[0];
   rollback      = out[1];
-  /* If rollback is true, the status will be overwritten so that an event at the endtime of current time step will be postponed to guarantee corret order */
+  /* If rollback is true, the status will be overwritten so that an event at the endtime of current time step will be postponed to guarantee correct order */
   if (rollback) event->status = TSEVENT_LOCATED_INTERVAL;
   if (event->status == TSEVENT_ZERO) {
     for (i = 0; i < event->nevents; i++) {
@@ -467,7 +468,7 @@ static PetscErrorCode TSEventLocation(TS ts, PetscReal *dt)
       event->side[i] = 0;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSEventHandler(TS ts)
@@ -480,7 +481,7 @@ PetscErrorCode TSEventHandler(TS ts)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
-  if (!ts->event) PetscFunctionReturn(0);
+  if (!ts->event) PetscFunctionReturn(PETSC_SUCCESS);
   event = ts->event;
 
   PetscCall(TSGetTime(ts, &t));
@@ -554,7 +555,7 @@ PetscErrorCode TSEventHandler(TS ts)
     for (i = 0; i < event->nevents; i++) event->fvalue_prev[i] = event->fvalue[i];
     event->ptime_prev = t;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSAdjointEventHandler(TS ts)
@@ -567,7 +568,7 @@ PetscErrorCode TSAdjointEventHandler(TS ts)
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
-  if (!ts->event) PetscFunctionReturn(0);
+  if (!ts->event) PetscFunctionReturn(PETSC_SUCCESS);
   event = ts->event;
 
   PetscCall(TSGetTime(ts, &t));
@@ -582,12 +583,12 @@ PetscErrorCode TSAdjointEventHandler(TS ts)
     }
   }
 
-  PetscBarrier((PetscObject)ts);
-  PetscFunctionReturn(0);
+  PetscCall(PetscBarrier((PetscObject)ts));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-  TSGetNumEvents - Get the numbers of events set
+  TSGetNumEvents - Get the numbers of events currently set to be detected
 
   Logically Collective
 
@@ -595,7 +596,7 @@ PetscErrorCode TSAdjointEventHandler(TS ts)
 . ts - the `TS` context
 
   Output Parameter:
-. nevents - number of events
+. nevents - the number of events
 
   Level: intermediate
 
@@ -605,5 +606,5 @@ PetscErrorCode TSGetNumEvents(TS ts, PetscInt *nevents)
 {
   PetscFunctionBegin;
   *nevents = ts->event->nevents;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
