@@ -28,7 +28,7 @@ static PetscErrorCode TSSSPGetWorkVectors(TS ts, PetscInt n, Vec **work)
   }
   *work        = ssp->work;
   ssp->workout = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSSSPRestoreWorkVectors(TS ts, PetscInt n, Vec **work)
@@ -40,7 +40,7 @@ static PetscErrorCode TSSSPRestoreWorkVectors(TS ts, PetscInt n, Vec **work)
   PetscCheck(*work == ssp->work, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Wrong work vectors checked out");
   ssp->workout = PETSC_FALSE;
   *work        = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -50,7 +50,7 @@ static PetscErrorCode TSSSPRestoreWorkVectors(TS ts, PetscInt n, Vec **work)
 
    Level: beginner
 
-.seealso: `TSSSP`, `TSSSPSetType()`, `TSSSPSetNumStages()`
+.seealso: [](chapter_ts), `TSSSP`, `TSSSPSetType()`, `TSSSPSetNumStages()`
 M*/
 static PetscErrorCode TSSSPStep_RK_2(TS ts, PetscReal t0, PetscReal dt, Vec sol)
 {
@@ -72,7 +72,7 @@ static PetscErrorCode TSSSPStep_RK_2(TS ts, PetscReal t0, PetscReal dt, Vec sol)
   PetscCall(TSComputeRHSFunction(ts, t0 + dt, work[0], F));
   PetscCall(VecAXPBYPCZ(sol, (s - 1.) / s, dt / s, 1. / s, work[0], F));
   PetscCall(TSSSPRestoreWorkVectors(ts, 2, &work));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -82,7 +82,7 @@ static PetscErrorCode TSSSPStep_RK_2(TS ts, PetscReal t0, PetscReal dt, Vec sol)
 
    Level: beginner
 
-.seealso: `TSSSP`, `TSSSPSetType()`, `TSSSPSetNumStages()`
+.seealso: [](chapter_ts), `TSSSP`, `TSSSPSetType()`, `TSSSPSetNumStages()`
 M*/
 static PetscErrorCode TSSSPStep_RK_3(TS ts, PetscReal t0, PetscReal dt, Vec sol)
 {
@@ -131,7 +131,7 @@ static PetscErrorCode TSSSPStep_RK_3(TS ts, PetscReal t0, PetscReal dt, Vec sol)
   }
   PetscCall(VecCopy(work[0], sol));
   PetscCall(TSSSPRestoreWorkVectors(ts, 3, &work));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
@@ -141,7 +141,7 @@ static PetscErrorCode TSSSPStep_RK_3(TS ts, PetscReal t0, PetscReal dt, Vec sol)
 
    Level: beginner
 
-.seealso: `TSSSP`, `TSSSPSetType()`
+.seealso: [](chapter_ts), `TSSSP`, `TSSSPSetType()`
 M*/
 static PetscErrorCode TSSSPStep_RK_10_4(TS ts, PetscReal t0, PetscReal dt, Vec sol)
 {
@@ -174,7 +174,7 @@ static PetscErrorCode TSSSPStep_RK_10_4(TS ts, PetscReal t0, PetscReal dt, Vec s
   PetscCall(VecAXPBYPCZ(work[1], 3. / 5, dt / 10, 1, work[0], F));
   PetscCall(VecCopy(work[1], sol));
   PetscCall(TSSSPRestoreWorkVectors(ts, 3, &work));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSSetUp_SSP(TS ts)
@@ -183,7 +183,7 @@ static PetscErrorCode TSSetUp_SSP(TS ts)
   PetscCall(TSCheckImplicitTerm(ts));
   PetscCall(TSGetAdapt(ts, &ts->adapt));
   PetscCall(TSAdaptCandidatesClear(ts->adapt));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSStep_SSP(TS ts)
@@ -199,18 +199,18 @@ static PetscErrorCode TSStep_SSP(TS ts)
   PetscCall(TSAdaptCheckStage(ts->adapt, ts, ts->ptime + ts->time_step, sol, &stageok));
   if (!stageok) {
     ts->reason = TS_DIVERGED_STEP_REJECTED;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(TSAdaptChoose(ts->adapt, ts, ts->time_step, NULL, &next_time_step, &accept));
   if (!accept) {
     ts->reason = TS_DIVERGED_STEP_REJECTED;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   ts->ptime += ts->time_step;
   ts->time_step = next_time_step;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /*------------------------------------------------------------*/
 
@@ -222,7 +222,7 @@ static PetscErrorCode TSReset_SSP(TS ts)
   if (ssp->work) PetscCall(VecDestroyVecs(ssp->nwork, &ssp->work));
   ssp->nwork   = 0;
   ssp->workout = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSDestroy_SSP(TS ts)
@@ -237,12 +237,12 @@ static PetscErrorCode TSDestroy_SSP(TS ts)
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSSSPSetType_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSSSPGetNumStages_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSSSPSetNumStages_C", NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /*------------------------------------------------------------*/
 
 /*@C
-   TSSSPSetType - set the SSP time integration scheme to use
+   TSSSPSetType - set the `TSSSP` time integration scheme to use
 
    Logically Collective
 
@@ -251,12 +251,12 @@ static PetscErrorCode TSDestroy_SSP(TS ts)
 -  ssptype - type of scheme to use
 
    Options Database Keys:
-   -ts_ssp_type <rks2>               : Type of SSP method (one of) rks2 rks3 rk104
-   -ts_ssp_nstages<rks2: 5, rks3: 9> : Number of stages
++   -ts_ssp_type <rks2>               - Type of `TSSSP` method (one of) rks2 rks3 rk104
+-  -ts_ssp_nstages<rks2: 5, rks3: 9> - Number of stages
 
    Level: beginner
 
-.seealso: `TSSSP`, `TSSSPGetType()`, `TSSSPSetNumStages()`, `TSSSPRKS2`, `TSSSPRKS3`, `TSSSPRK104`
+.seealso: [](chapter_ts), `TSSSP`, `TSSSPGetType()`, `TSSSPSetNumStages()`, `TSSSPRKS2`, `TSSSPRKS3`, `TSSSPRK104`
 @*/
 PetscErrorCode TSSSPSetType(TS ts, TSSSPType ssptype)
 {
@@ -264,11 +264,11 @@ PetscErrorCode TSSSPSetType(TS ts, TSSSPType ssptype)
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscValidCharPointer(ssptype, 2);
   PetscTryMethod(ts, "TSSSPSetType_C", (TS, TSSSPType), (ts, ssptype));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   TSSSPGetType - get the SSP time integration scheme
+   TSSSPGetType - get the `TSSSP` time integration scheme
 
    Logically Collective
 
@@ -280,19 +280,19 @@ PetscErrorCode TSSSPSetType(TS ts, TSSSPType ssptype)
 
    Level: beginner
 
-.seealso: `TSSSP`, `TSSSPSettype()`, `TSSSPSetNumStages()`, `TSSSPRKS2`, `TSSSPRKS3`, `TSSSPRK104`
+.seealso: [](chapter_ts), `TSSSP`, `TSSSPSettype()`, `TSSSPSetNumStages()`, `TSSSPRKS2`, `TSSSPRKS3`, `TSSSPRK104`
 @*/
 PetscErrorCode TSSSPGetType(TS ts, TSSSPType *type)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscUseMethod(ts, "TSSSPGetType_C", (TS, TSSSPType *), (ts, type));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   TSSSPSetNumStages - set the number of stages to use with the SSP method. Must be called after
-   TSSSPSetType().
+   TSSSPSetNumStages - set the number of stages to use with the `TSSSP` method. Must be called after
+   `TSSSPSetType()`.
 
    Logically Collective
 
@@ -301,23 +301,23 @@ PetscErrorCode TSSSPGetType(TS ts, TSSSPType *type)
 -  nstages - number of stages
 
    Options Database Keys:
-   -ts_ssp_type <rks2>               : Type of SSP method (one of) rks2 rks3 rk104
-   -ts_ssp_nstages<rks2: 5, rks3: 9> : Number of stages
++   -ts_ssp_type <rks2>               - Type of `TSSSP` method (one of) rks2 rks3 rk104
+-   -ts_ssp_nstages<rks2: 5, rks3: 9> - Number of stages
 
    Level: beginner
 
-.seealso: `TSSSP`, `TSSSPGetNumStages()`, `TSSSPSetNumStages()`, `TSSSPRKS2`, `TSSSPRKS3`, `TSSSPRK104`
+.seealso: [](chapter_ts), `TSSSP`, `TSSSPGetNumStages()`, `TSSSPSetNumStages()`, `TSSSPRKS2`, `TSSSPRKS3`, `TSSSPRK104`
 @*/
 PetscErrorCode TSSSPSetNumStages(TS ts, PetscInt nstages)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscTryMethod(ts, "TSSSPSetNumStages_C", (TS, PetscInt), (ts, nstages));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   TSSSPGetNumStages - get the number of stages in the SSP time integration scheme
+   TSSSPGetNumStages - get the number of stages in the `TSSSP` time integration scheme
 
    Logically Collective
 
@@ -329,14 +329,14 @@ PetscErrorCode TSSSPSetNumStages(TS ts, PetscInt nstages)
 
    Level: beginner
 
-.seealso: `TSSSP`, `TSSSPGetType()`, `TSSSPSetNumStages()`, `TSSSPRKS2`, `TSSSPRKS3`, `TSSSPRK104`
+.seealso: [](chapter_ts), `TSSSP`, `TSSSPGetType()`, `TSSSPSetNumStages()`, `TSSSPRKS2`, `TSSSPRKS3`, `TSSSPRK104`
 @*/
 PetscErrorCode TSSSPGetNumStages(TS ts, PetscInt *nstages)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscUseMethod(ts, "TSSSPGetNumStages_C", (TS, PetscInt *), (ts, nstages));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSSSPSetType_SSP(TS ts, TSSSPType type)
@@ -363,7 +363,7 @@ static PetscErrorCode TSSSPSetType_SSP(TS ts, TSSSPType type)
       ssp->nstages = 5;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 static PetscErrorCode TSSSPGetType_SSP(TS ts, TSSSPType *type)
 {
@@ -371,7 +371,7 @@ static PetscErrorCode TSSSPGetType_SSP(TS ts, TSSSPType *type)
 
   PetscFunctionBegin;
   *type = ssp->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 static PetscErrorCode TSSSPSetNumStages_SSP(TS ts, PetscInt nstages)
 {
@@ -379,7 +379,7 @@ static PetscErrorCode TSSSPSetNumStages_SSP(TS ts, PetscInt nstages)
 
   PetscFunctionBegin;
   ssp->nstages = nstages;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 static PetscErrorCode TSSSPGetNumStages_SSP(TS ts, PetscInt *nstages)
 {
@@ -387,7 +387,7 @@ static PetscErrorCode TSSSPGetNumStages_SSP(TS ts, PetscInt *nstages)
 
   PetscFunctionBegin;
   *nstages = ssp->nstages;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSSetFromOptions_SSP(TS ts, PetscOptionItems *PetscOptionsObject)
@@ -404,7 +404,7 @@ static PetscErrorCode TSSetFromOptions_SSP(TS ts, PetscOptionItems *PetscOptions
     PetscCall(PetscOptionsInt("-ts_ssp_nstages", "Number of stages", "TSSSPSetNumStages", ssp->nstages, &ssp->nstages, NULL));
   }
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSView_SSP(TS ts, PetscViewer viewer)
@@ -415,7 +415,7 @@ static PetscErrorCode TSView_SSP(TS ts, PetscViewer viewer)
   PetscFunctionBegin;
   PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &ascii));
   if (ascii) PetscCall(PetscViewerASCIIPrintf(viewer, "  Scheme: %s\n", ssp->type_name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ------------------------------------------------------------ */
@@ -459,7 +459,7 @@ static PetscErrorCode TSView_SSP(TS ts, PetscViewer viewer)
 +  * - Ketcheson, Highly efficient strong stability preserving Runge Kutta methods with low storage implementations, SISC, 2008.
 -  * - Gottlieb, Ketcheson, and Shu, High order strong stability preserving time discretizations, J Scientific Computing, 2009.
 
-.seealso: `TSCreate()`, `TS`, `TSSetType()`
+.seealso: [](chapter_ts), `TSCreate()`, `TS`, `TSSetType()`
 
 M*/
 PETSC_EXTERN PetscErrorCode TSCreate_SSP(TS ts)
@@ -485,41 +485,41 @@ PETSC_EXTERN PetscErrorCode TSCreate_SSP(TS ts)
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSSSPSetNumStages_C", TSSSPSetNumStages_SSP));
 
   PetscCall(TSSSPSetType(ts, TSSSPRKS2));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  TSSSPInitializePackage - This function initializes everything in the TSSSP package. It is called
-  from TSInitializePackage().
+  TSSSPInitializePackage - This function initializes everything in the `TSSSP` package. It is called
+  from `TSInitializePackage()`.
 
   Level: developer
 
-.seealso: `PetscInitialize()`
+.seealso: [](chapter_ts), `PetscInitialize()`, `TSSSPFinalizePackage()`, `TSInitializePackage()`
 @*/
 PetscErrorCode TSSSPInitializePackage(void)
 {
   PetscFunctionBegin;
-  if (TSSSPPackageInitialized) PetscFunctionReturn(0);
+  if (TSSSPPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   TSSSPPackageInitialized = PETSC_TRUE;
   PetscCall(PetscFunctionListAdd(&TSSSPList, TSSSPRKS2, TSSSPStep_RK_2));
   PetscCall(PetscFunctionListAdd(&TSSSPList, TSSSPRKS3, TSSSPStep_RK_3));
   PetscCall(PetscFunctionListAdd(&TSSSPList, TSSSPRK104, TSSSPStep_RK_10_4));
   PetscCall(PetscRegisterFinalize(TSSSPFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  TSSSPFinalizePackage - This function destroys everything in the TSSSP package. It is
-  called from PetscFinalize().
+  TSSSPFinalizePackage - This function destroys everything in the `TSSSP` package. It is
+  called from `PetscFinalize()`.
 
   Level: developer
 
-.seealso: `PetscFinalize()`
+.seealso: [](chapter_ts), `PetscFinalize()`, `TSSSPInitiallizePackage()`, `TSInitializePackage()`
 @*/
 PetscErrorCode TSSSPFinalizePackage(void)
 {
   PetscFunctionBegin;
   TSSSPPackageInitialized = PETSC_FALSE;
   PetscCall(PetscFunctionListDestroy(&TSSSPList));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
