@@ -116,7 +116,7 @@ PetscErrorCode TSSolve_Radau5(TS ts)
   radau5_(&ND, FVPOL, &X, Y, &XEND, &H, &RTOL, &ATOL, &ITOL, JVPOL, &IJAC, &MLJAC, &MUJAC, FVPOL, &IMAS, &MLMAS, &MUMAS, SOLOUT, &IOUT, WORK, &LWORK, IWORK, &LIWORK, &RPAR, (void *)ts, &IDID);
 
   PetscCall(PetscFree2(WORK, IWORK));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSDestroy_Radau5(TS ts)
@@ -127,22 +127,24 @@ PetscErrorCode TSDestroy_Radau5(TS ts)
   PetscCall(VecDestroy(&cvode->work));
   PetscCall(VecDestroy(&cvode->workf));
   PetscCall(PetscFree(ts->data));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
-      TSRADAU5 - ODE solver using the RADAU5 package
-
-    Notes:
-    This uses its own nonlinear solver and dense matrix direct solver so PETSc SNES and KSP options do not apply.
-           Uses its own time-step adaptivity (but uses the TS rtol and atol, and initial timestep)
-           Uses its own memory for the dense matrix storage and factorization
-           Can only handle ODEs of the form \cdot{u} = -F(t,u) + G(t,u)
+      TSRADAU5 - ODE solver using the external RADAU5 package, requires ./configure --download-radau5
 
     Level: beginner
 
-.seealso: `TSCreate()`, `TS`, `TSSetType()`
+    Notes:
+    This uses its own nonlinear solver and dense matrix direct solver so PETSc `SNES` and `KSP` options do not apply.
 
+    Uses its own time-step adaptivity (but uses the TS rtol and atol, and initial timestep)
+
+    Uses its own memory for the dense matrix storage and factorization
+
+    Can only handle ODEs of the form \cdot{u} = -F(t,u) + G(t,u)
+
+.seealso: [](chapter_ts), `TSCreate()`, `TS`, `TSSetType()`, `TSType`
 M*/
 PETSC_EXTERN PetscErrorCode TSCreate_Radau5(TS ts)
 {
@@ -155,5 +157,5 @@ PETSC_EXTERN PetscErrorCode TSCreate_Radau5(TS ts)
 
   PetscCall(PetscNew(&cvode));
   ts->data = (void *)cvode;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
