@@ -31,7 +31,7 @@ typedef struct {
     TSPseudoComputeTimeStep - Computes the next timestep for a currently running
     pseudo-timestepping process.
 
-    Collective on ts
+    Collective
 
     Input Parameter:
 .   ts - timestep context
@@ -55,14 +55,14 @@ PetscErrorCode TSPseudoComputeTimeStep(TS ts, PetscReal *dt)
   PetscCall(PetscLogEventBegin(TS_PseudoComputeTimeStep, ts, 0, 0, 0));
   PetscCall((*pseudo->dt)(ts, dt, pseudo->dtctx));
   PetscCall(PetscLogEventEnd(TS_PseudoComputeTimeStep, ts, 0, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ------------------------------------------------------------------------------*/
 /*@C
    TSPseudoVerifyTimeStepDefault - Default code to verify the quality of the last timestep.
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the timestep context
@@ -85,13 +85,13 @@ PetscErrorCode TSPseudoVerifyTimeStepDefault(TS ts, Vec update, void *dtctx, Pet
 {
   PetscFunctionBegin;
   *flag = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     TSPseudoVerifyTimeStep - Verifies whether the last timestep was acceptable.
 
-    Collective on ts
+    Collective
 
     Input Parameters:
 +   ts - timestep context
@@ -116,7 +116,7 @@ PetscErrorCode TSPseudoVerifyTimeStep(TS ts, Vec update, PetscReal *dt, PetscBoo
   PetscFunctionBegin;
   *flag = PETSC_TRUE;
   if (pseudo->verify) PetscCall((*pseudo->verify)(ts, update, pseudo->verifyctx, dt, flag));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* --------------------------------------------------------------------------------*/
@@ -153,7 +153,7 @@ static PetscErrorCode TSStep_Pseudo(TS ts)
   if (reject >= ts->max_reject) {
     ts->reason = TS_DIVERGED_STEP_REJECTED;
     PetscCall(PetscInfo(ts, "Step=%" PetscInt_FMT ", step rejections %" PetscInt_FMT " greater than current TS allowed, stopping solve\n", ts->steps, reject));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(VecCopy(pseudo->update, ts->vec_sol));
@@ -168,14 +168,14 @@ static PetscErrorCode TSStep_Pseudo(TS ts)
   if (pseudo->fnorm < pseudo->fatol) {
     ts->reason = TS_CONVERGED_PSEUDO_FATOL;
     PetscCall(PetscInfo(ts, "Step=%" PetscInt_FMT ", converged since fnorm %g < fatol %g\n", ts->steps, (double)pseudo->fnorm, (double)pseudo->frtol));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if (pseudo->fnorm / pseudo->fnorm_initial < pseudo->frtol) {
     ts->reason = TS_CONVERGED_PSEUDO_FRTOL;
     PetscCall(PetscInfo(ts, "Step=%" PetscInt_FMT ", converged since fnorm %g / fnorm_initial %g < frtol %g\n", ts->steps, (double)pseudo->fnorm, (double)pseudo->fnorm_initial, (double)pseudo->fatol));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*------------------------------------------------------------*/
@@ -187,7 +187,7 @@ static PetscErrorCode TSReset_Pseudo(TS ts)
   PetscCall(VecDestroy(&pseudo->update));
   PetscCall(VecDestroy(&pseudo->func));
   PetscCall(VecDestroy(&pseudo->xdot));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSDestroy_Pseudo(TS ts)
@@ -200,7 +200,7 @@ static PetscErrorCode TSDestroy_Pseudo(TS ts)
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSPseudoSetMaxTimeStep_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSPseudoIncrementDtFromInitialDt_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSPseudoSetTimeStep_C", NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*------------------------------------------------------------*/
@@ -226,7 +226,7 @@ static PetscErrorCode TSPseudoGetXdot(TS ts, Vec X, Vec *Xdot)
   PetscCall(VecRestoreArrayRead(X, &xnp1));
   PetscCall(VecRestoreArray(pseudo->xdot, &xdot));
   *Xdot = pseudo->xdot;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -253,7 +253,7 @@ static PetscErrorCode SNESTSFormFunction_Pseudo(SNES snes, Vec X, Vec Y, TS ts)
   PetscFunctionBegin;
   PetscCall(TSPseudoGetXdot(ts, X, &Xdot));
   PetscCall(TSComputeIFunction(ts, ts->ptime + ts->time_step, X, Xdot, Y, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -272,7 +272,7 @@ static PetscErrorCode SNESTSFormJacobian_Pseudo(SNES snes, Vec X, Mat AA, Mat BB
   PetscFunctionBegin;
   PetscCall(TSPseudoGetXdot(ts, X, &Xdot));
   PetscCall(TSComputeIJacobian(ts, ts->ptime + ts->time_step, X, Xdot, 1. / ts->time_step, AA, BB, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSSetUp_Pseudo(TS ts)
@@ -283,7 +283,7 @@ static PetscErrorCode TSSetUp_Pseudo(TS ts)
   PetscCall(VecDuplicate(ts->vec_sol, &pseudo->update));
   PetscCall(VecDuplicate(ts->vec_sol, &pseudo->func));
   PetscCall(VecDuplicate(ts->vec_sol, &pseudo->xdot));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /*------------------------------------------------------------*/
 
@@ -301,7 +301,7 @@ static PetscErrorCode TSPseudoMonitorDefault(TS ts, PetscInt step, PetscReal pti
   PetscCall(PetscViewerASCIIAddTab(viewer, ((PetscObject)ts)->tablevel));
   PetscCall(PetscViewerASCIIPrintf(viewer, "TS %" PetscInt_FMT " dt %g time %g fnorm %g\n", step, (double)ts->time_step, (double)ptime, (double)pseudo->fnorm));
   PetscCall(PetscViewerASCIISubtractTab(viewer, ((PetscObject)ts)->tablevel));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSSetFromOptions_Pseudo(TS ts, PetscOptionItems *PetscOptionsObject)
@@ -325,7 +325,7 @@ static PetscErrorCode TSSetFromOptions_Pseudo(TS ts, PetscOptionItems *PetscOpti
   PetscCall(PetscOptionsReal("-ts_pseudo_fatol", "Tolerance for norm of function", "", pseudo->fatol, &pseudo->fatol, NULL));
   PetscCall(PetscOptionsReal("-ts_pseudo_frtol", "Relative tolerance for norm of function", "", pseudo->frtol, &pseudo->frtol, NULL));
   PetscOptionsHeadEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSView_Pseudo(TS ts, PetscViewer viewer)
@@ -342,7 +342,7 @@ static PetscErrorCode TSView_Pseudo(TS ts, PetscViewer viewer)
     PetscCall(PetscViewerASCIIPrintf(viewer, "  dt_increment - increase in timestep on successful step %g\n", (double)pseudo->dt_increment));
     PetscCall(PetscViewerASCIIPrintf(viewer, "  dt_max - maximum time %g\n", (double)pseudo->dt_max));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ----------------------------------------------------------------------------- */
@@ -350,18 +350,17 @@ static PetscErrorCode TSView_Pseudo(TS ts, PetscViewer viewer)
    TSPseudoSetVerifyTimeStep - Sets a user-defined routine to verify the quality of the
    last timestep.
 
-   Logically Collective on ts
+   Logically Collective
 
    Input Parameters:
 +  ts - timestep context
 .  dt - user-defined function to verify timestep
--  ctx - [optional] user-defined context for private data
-         for the timestep verification routine (may be NULL)
+-  ctx - [optional] user-defined context for private data for the timestep verification routine (may be `NULL`)
 
-   Calling sequence of func:
-$  func (TS ts,Vec update,void *ctx,PetscReal *newdt,PetscBool  *flag);
-
-+  update - latest solution vector
+   Calling sequence of `func`:
+$  PetscErrorCode func(TS ts, Vec update, void *ctx, PetscReal *newdt, PetscBool  *flag);
++  ts - the time-step context
+.  update - latest solution vector
 .  ctx - [optional] timestep context
 .  newdt - the timestep to use for the next step
 -  flag - flag indicating whether the last time step was acceptable
@@ -379,14 +378,14 @@ PetscErrorCode TSPseudoSetVerifyTimeStep(TS ts, PetscErrorCode (*dt)(TS, Vec, vo
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscTryMethod(ts, "TSPseudoSetVerifyTimeStep_C", (TS, PetscErrorCode(*)(TS, Vec, void *, PetscReal *, PetscBool *), void *), (ts, dt, ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     TSPseudoSetTimeStepIncrement - Sets the scaling increment applied to
     dt when using the TSPseudoTimeStepDefault() routine.
 
-   Logically Collective on ts
+   Logically Collective
 
     Input Parameters:
 +   ts - the timestep context
@@ -405,14 +404,14 @@ PetscErrorCode TSPseudoSetTimeStepIncrement(TS ts, PetscReal inc)
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscValidLogicalCollectiveReal(ts, inc, 2);
   PetscTryMethod(ts, "TSPseudoSetTimeStepIncrement_C", (TS, PetscReal), (ts, inc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     TSPseudoSetMaxTimeStep - Sets the maximum time step
     when using the TSPseudoTimeStepDefault() routine.
 
-   Logically Collective on ts
+   Logically Collective
 
     Input Parameters:
 +   ts - the timestep context
@@ -431,7 +430,7 @@ PetscErrorCode TSPseudoSetMaxTimeStep(TS ts, PetscReal maxdt)
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscValidLogicalCollectiveReal(ts, maxdt, 2);
   PetscTryMethod(ts, "TSPseudoSetMaxTimeStep_C", (TS, PetscReal), (ts, maxdt));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -441,7 +440,7 @@ $         dt = initial_dt*initial_fnorm/current_fnorm
       rather than the default update,
 $         dt = current_dt*previous_fnorm/current_fnorm.
 
-   Logically Collective on ts
+   Logically Collective
 
     Input Parameter:
 .   ts - the timestep context
@@ -458,24 +457,22 @@ PetscErrorCode TSPseudoIncrementDtFromInitialDt(TS ts)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscTryMethod(ts, "TSPseudoIncrementDtFromInitialDt_C", (TS), (ts));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSPseudoSetTimeStep - Sets the user-defined routine to be
    called at each pseudo-timestep to update the timestep.
 
-   Logically Collective on ts
+   Logically Collective
 
    Input Parameters:
 +  ts - timestep context
 .  dt - function to compute timestep
--  ctx - [optional] user-defined context for private data
-         required by the function (may be NULL)
-
-   Calling sequence of func:
-$  func (TS ts,PetscReal *newdt,void *ctx);
+-  ctx - [optional] user-defined context for private data required by the function (may be `NULL`)
 
+   Calling sequence of `dt`:
+$  PetscErrorCode dt(TS ts, PetscReal *newdt, void *ctx);
 +  newdt - the newly computed timestep
 -  ctx - [optional] timestep context
 
@@ -494,7 +491,7 @@ PetscErrorCode TSPseudoSetTimeStep(TS ts, PetscErrorCode (*dt)(TS, PetscReal *,
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscTryMethod(ts, "TSPseudoSetTimeStep_C", (TS, PetscErrorCode(*)(TS, PetscReal *, void *), void *), (ts, dt, ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ----------------------------------------------------------------------------- */
@@ -507,7 +504,7 @@ static PetscErrorCode TSPseudoSetVerifyTimeStep_Pseudo(TS ts, FCN1 dt, void *ctx
   PetscFunctionBegin;
   pseudo->verify    = dt;
   pseudo->verifyctx = ctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSPseudoSetTimeStepIncrement_Pseudo(TS ts, PetscReal inc)
@@ -516,7 +513,7 @@ static PetscErrorCode TSPseudoSetTimeStepIncrement_Pseudo(TS ts, PetscReal inc)
 
   PetscFunctionBegin;
   pseudo->dt_increment = inc;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSPseudoSetMaxTimeStep_Pseudo(TS ts, PetscReal maxdt)
@@ -525,7 +522,7 @@ static PetscErrorCode TSPseudoSetMaxTimeStep_Pseudo(TS ts, PetscReal maxdt)
 
   PetscFunctionBegin;
   pseudo->dt_max = maxdt;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSPseudoIncrementDtFromInitialDt_Pseudo(TS ts)
@@ -534,7 +531,7 @@ static PetscErrorCode TSPseudoIncrementDtFromInitialDt_Pseudo(TS ts)
 
   PetscFunctionBegin;
   pseudo->increment_dt_from_initial_dt = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 typedef PetscErrorCode (*FCN2)(TS, PetscReal *, void *); /* force argument to next function to not be extern C*/
@@ -545,7 +542,7 @@ static PetscErrorCode TSPseudoSetTimeStep_Pseudo(TS ts, FCN2 dt, void *ctx)
   PetscFunctionBegin;
   pseudo->dt    = dt;
   pseudo->dtctx = ctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ----------------------------------------------------------------------------- */
@@ -637,13 +634,13 @@ PETSC_EXTERN PetscErrorCode TSCreate_Pseudo(TS ts)
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSPseudoSetMaxTimeStep_C", TSPseudoSetMaxTimeStep_Pseudo));
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSPseudoIncrementDtFromInitialDt_C", TSPseudoIncrementDtFromInitialDt_Pseudo));
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSPseudoSetTimeStep_C", TSPseudoSetTimeStep_Pseudo));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSPseudoTimeStepDefault - Default code to compute pseudo-timestepping.  Use with `TSPseudoSetTimeStep()`.
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the timestep context
@@ -675,5 +672,5 @@ PetscErrorCode TSPseudoTimeStepDefault(TS ts, PetscReal *newdt, void *dtctx)
   else *newdt = inc * ts->time_step * pseudo->fnorm_previous / pseudo->fnorm;
   if (pseudo->dt_max > 0) *newdt = PetscMin(*newdt, pseudo->dt_max);
   pseudo->fnorm_previous = pseudo->fnorm;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
