@@ -3,7 +3,7 @@
 /*@C
    TSPythonSetType - Initialize a `TS` object implemented in Python.
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
@@ -22,7 +22,7 @@ PetscErrorCode TSPythonSetType(TS ts, const char pyname[])
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscValidCharPointer(pyname, 2);
   PetscTryMethod(ts, "TSPythonSetType_C", (TS, const char[]), (ts, pyname));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -46,5 +46,5 @@ PetscErrorCode TSPythonGetType(TS ts, const char *pyname[])
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscValidPointer(pyname, 2);
   PetscUseMethod(ts, "TSPythonGetType_C", (TS, const char *[]), (ts, pyname));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
