@@ -70,7 +70,7 @@ typedef struct {
 
      Level: intermediate
 
-.seealso: `TSROSW`
+.seealso: [](chapter_ts), `TSROSW`
 M*/
 
 /*MC
@@ -80,7 +80,7 @@ M*/
 
      Level: intermediate
 
-.seealso: `TSROSW`
+.seealso: [](chapter_ts), `TSROSW`
 M*/
 
 /*MC
@@ -90,7 +90,7 @@ M*/
 
      Level: intermediate
 
-.seealso: `TSROSW`
+.seealso: [](chapter_ts), `TSROSW`
 M*/
 
 /*MC
@@ -100,7 +100,7 @@ M*/
 
      Level: intermediate
 
-.seealso: `TSROSW`
+.seealso: [](chapter_ts), `TSROSW`
 M*/
 
 /*MC
@@ -110,12 +110,12 @@ M*/
 
      This is strongly A-stable with R(infty) = 0.73. The embedded method of order 2 is strongly A-stable with R(infty) = 0.73.
 
+     Level: intermediate
+
      References:
 .  * - Rang and Angermann, New Rosenbrock W methods of order 3 for partial differential algebraic equations of index 1, 2005.
 
-     Level: intermediate
-
-.seealso: `TSROSW`
+.seealso: [](chapter_ts), `TSROSW`
 M*/
 
 /*MC
@@ -125,12 +125,12 @@ M*/
 
      This is strongly A-stable with R(infty) = 0. The embedded method of order 2 is strongly A-stable with R(infty) = 0.48.
 
+     Level: intermediate
+
      References:
 .  * - Rang and Angermann, New Rosenbrock W methods of order 3 for partial differential algebraic equations of index 1, 2005.
 
-     Level: intermediate
-
-.seealso: `TSROSW`
+.seealso: [](chapter_ts), `TSROSW`
 M*/
 
 /*MC
@@ -140,12 +140,12 @@ M*/
 
      Both the third order and embedded second order methods are stiffly accurate and L-stable.
 
+     Level: intermediate
+
      References:
 .  * - Sandu et al, Benchmarking stiff ODE solvers for atmospheric chemistry problems II, Rosenbrock solvers, 1997.
 
-     Level: intermediate
-
-.seealso: `TSROSW`, `TSROSWSANDU3`
+.seealso: [](chapter_ts), `TSROSW`, `TSROSWSANDU3`
 M*/
 
 /*MC
@@ -158,12 +158,12 @@ M*/
      The internal stages are L-stable.
      This method is called ROS3 in the paper.
 
+     Level: intermediate
+
      References:
 .  * - Sandu et al, Benchmarking stiff ODE solvers for atmospheric chemistry problems II, Rosenbrock solvers, 1997.
 
-     Level: intermediate
-
-.seealso: `TSROSW`, `TSROSWRODAS3`
+.seealso: [](chapter_ts), `TSROSW`, `TSROSWRODAS3`
 M*/
 
 /*MC
@@ -173,12 +173,12 @@ M*/
 
      A-stable SPP explicit order 3, 3 stages, CFL 1 (eff = 1/3)
 
+     Level: intermediate
+
      References:
 . * - Emil Constantinescu
 
-     Level: intermediate
-
-.seealso: `TSROSW`, `TSROSWLASSP3P4S2C`, `TSROSWLLSSP3P4S2C`, `SSP`
+.seealso: [](chapter_ts), `TSROSW`, `TSROSWLASSP3P4S2C`, `TSROSWLLSSP3P4S2C`, `SSP`
 M*/
 
 /*MC
@@ -188,12 +188,12 @@ M*/
 
      L-stable (A-stable embedded) SPP explicit order 3, 4 stages, CFL 2 (eff = 1/2)
 
+     Level: intermediate
+
      References:
 . * - Emil Constantinescu
 
-     Level: intermediate
-
-.seealso: `TSROSW`, `TSROSWASSP3P3S1C`, `TSROSWLLSSP3P4S2C`, `TSSSP`
+.seealso: [](chapter_ts), `TSROSW`, `TSROSWASSP3P3S1C`, `TSROSWLLSSP3P4S2C`, `TSSSP`
 M*/
 
 /*MC
@@ -203,12 +203,12 @@ M*/
 
      L-stable (L-stable embedded) SPP explicit order 3, 4 stages, CFL 2 (eff = 1/2)
 
+     Level: intermediate
+
      References:
 . * - Emil Constantinescu
 
-     Level: intermediate
-
-.seealso: `TSROSW`, `TSROSWASSP3P3S1C`, `TSROSWLASSP3P4S2C`, `TSSSP`
+.seealso: [](chapter_ts), `TSROSW`, `TSROSWASSP3P3S1C`, `TSROSWLASSP3P4S2C`, `TSSSP`
 M*/
 
 /*MC
@@ -220,15 +220,15 @@ M*/
 
      This method does not provide a dense output formula.
 
+     Level: intermediate
+
      References:
 +   * -  Kaps and Rentrop, Generalized Runge Kutta methods of order four with stepsize control for stiff ordinary differential equations, 1979.
 -   * -  Hairer and Wanner, Solving Ordinary Differential Equations II, Section 4 Table 7.2.
 
      Hairer's code ros4.f
 
-     Level: intermediate
-
-.seealso: `TSROSW`, `TSROSWSHAMP4`, `TSROSWVELDD4`, `TSROSW4L`
+.seealso: [](chapter_ts), `TSROSW`, `TSROSWSHAMP4`, `TSROSWVELDD4`, `TSROSW4L`
 M*/
 
 /*MC
@@ -240,15 +240,15 @@ M*/
 
      This method does not provide a dense output formula.
 
+     Level: intermediate
+
      References:
 +   * -  Shampine, Implementation of Rosenbrock methods, 1982.
 -   * -  Hairer and Wanner, Solving Ordinary Differential Equations II, Section 4 Table 7.2.
 
      Hairer's code ros4.f
 
-     Level: intermediate
-
-.seealso: `TSROSW`, `TSROSWGRK4T`, `TSROSWVELDD4`, `TSROSW4L`
+.seealso: [](chapter_ts), `TSROSW`, `TSROSWGRK4T`, `TSROSWVELDD4`, `TSROSW4L`
 M*/
 
 /*MC
@@ -260,15 +260,15 @@ M*/
 
      This method does not provide a dense output formula.
 
+     Level: intermediate
+
      References:
 +   * -  van Veldhuizen, D stability and Kaps Rentrop methods, 1984.
 -   * -  Hairer and Wanner, Solving Ordinary Differential Equations II, Section 4 Table 7.2.
 
      Hairer's code ros4.f
 
-     Level: intermediate
-
-.seealso: `TSROSW`, `TSROSWGRK4T`, `TSROSWSHAMP4`, `TSROSW4L`
+.seealso: [](chapter_ts), `TSROSW`, `TSROSWGRK4T`, `TSROSWSHAMP4`, `TSROSW4L`
 M*/
 
 /*MC
@@ -280,29 +280,29 @@ M*/
 
      This method does not provide a dense output formula.
 
+     Level: intermediate
+
      References:
 .  * -   Hairer and Wanner, Solving Ordinary Differential Equations II, Section 4 Table 7.2.
 
      Hairer's code ros4.f
 
-     Level: intermediate
-
-.seealso: `TSROSW`, `TSROSWGRK4T`, `TSROSWSHAMP4`, `TSROSW4L`
+.seealso: [](chapter_ts), `TSROSW`, `TSROSWGRK4T`, `TSROSWSHAMP4`, `TSROSW4L`
 M*/
 
 /*@C
-  TSRosWRegisterAll - Registers all of the Rosenbrock-W methods in TSRosW
+  TSRosWRegisterAll - Registers all of the Rosenbrock-W methods in `TSROSW`
 
   Not Collective, but should be called by all processes which will need the schemes to be registered
 
   Level: advanced
 
-.seealso: `TSRosWRegisterDestroy()`
+.seealso: [](chapter_ts), `TSROSW`, `TSRosWRegisterDestroy()`
 @*/
 PetscErrorCode TSRosWRegisterAll(void)
 {
   PetscFunctionBegin;
-  if (TSRosWRegisterAllCalled) PetscFunctionReturn(0);
+  if (TSRosWRegisterAllCalled) PetscFunctionReturn(PETSC_SUCCESS);
   TSRosWRegisterAllCalled = PETSC_TRUE;
 
   {
@@ -580,17 +580,17 @@ PetscErrorCode TSRosWRegisterAll(void)
   PetscCall(TSRosWRegisterRos4(TSROSWSHAMP4, 0.5, PETSC_DEFAULT, PETSC_DEFAULT, 0, 125. / 108.));
   PetscCall(TSRosWRegisterRos4(TSROSWVELDD4, 0.22570811482256823492, PETSC_DEFAULT, PETSC_DEFAULT, 0, -1.355958941201148));
   PetscCall(TSRosWRegisterRos4(TSROSW4L, 0.57282, PETSC_DEFAULT, PETSC_DEFAULT, 0, -1.093502252409163));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   TSRosWRegisterDestroy - Frees the list of schemes that were registered by TSRosWRegister().
+   TSRosWRegisterDestroy - Frees the list of schemes that were registered by `TSRosWRegister()`.
 
    Not Collective
 
    Level: advanced
 
-.seealso: `TSRosWRegister()`, `TSRosWRegisterAll()`
+.seealso: [](chapter_ts), `TSRosWRegister()`, `TSRosWRegisterAll()`
 @*/
 PetscErrorCode TSRosWRegisterDestroy(void)
 {
@@ -608,45 +608,45 @@ PetscErrorCode TSRosWRegisterDestroy(void)
     PetscCall(PetscFree(link));
   }
   TSRosWRegisterAllCalled = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  TSRosWInitializePackage - This function initializes everything in the TSRosW package. It is called
-  from TSInitializePackage().
+  TSRosWInitializePackage - This function initializes everything in the `TSROSW` package. It is called
+  from `TSInitializePackage()`.
 
   Level: developer
 
-.seealso: `PetscInitialize()`
+.seealso: [](chapter_ts), `TSROSW`, `PetscInitialize()`, `TSRosWFinalizePackage()`
 @*/
 PetscErrorCode TSRosWInitializePackage(void)
 {
   PetscFunctionBegin;
-  if (TSRosWPackageInitialized) PetscFunctionReturn(0);
+  if (TSRosWPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   TSRosWPackageInitialized = PETSC_TRUE;
   PetscCall(TSRosWRegisterAll());
   PetscCall(PetscRegisterFinalize(TSRosWFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  TSRosWFinalizePackage - This function destroys everything in the TSRosW package. It is
-  called from PetscFinalize().
+  TSRosWFinalizePackage - This function destroys everything in the `TSROSW` package. It is
+  called from `PetscFinalize()`.
 
   Level: developer
 
-.seealso: `PetscFinalize()`
+.seealso: [](chapter_ts), `TSROSW`, `PetscFinalize()`, `TSRosWInitializePackage()`
 @*/
 PetscErrorCode TSRosWFinalizePackage(void)
 {
   PetscFunctionBegin;
   TSRosWPackageInitialized = PETSC_FALSE;
   PetscCall(TSRosWRegisterDestroy());
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   TSRosWRegister - register a Rosenbrock W scheme by providing the entries in the Butcher tableau and optionally embedded approximations and interpolation
+   TSRosWRegister - register a `TSROSW`, Rosenbrock W scheme by providing the entries in the Butcher tableau and optionally embedded approximations and interpolation
 
    Not Collective, but the same schemes should be registered on all processes on which they will be used
 
@@ -661,12 +661,12 @@ PetscErrorCode TSRosWFinalizePackage(void)
 .  pinterp - Order of the interpolation scheme, equal to the number of columns of binterpt
 -  binterpt - Coefficients of the interpolation formula (dimension s*pinterp)
 
-   Notes:
-   Several Rosenbrock W methods are provided, this function is only needed to create new methods.
-
    Level: advanced
 
-.seealso: `TSRosW`
+   Note:
+   Several Rosenbrock W methods are provided, this function is only needed to create new methods.
+
+.seealso: [](chapter_ts), `TSROSW`
 @*/
 PetscErrorCode TSRosWRegister(TSRosWType name, PetscInt order, PetscInt s, const PetscReal A[], const PetscReal Gamma[], const PetscReal b[], const PetscReal bembed[], PetscInt pinterp, const PetscReal binterpt[])
 {
@@ -774,7 +774,7 @@ PetscErrorCode TSRosWRegister(TSRosWType name, PetscInt order, PetscInt s, const
   PetscCall(PetscArraycpy(t->binterpt, binterpt, s * pinterp));
   link->next      = RosWTableauList;
   RosWTableauList = link;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -788,17 +788,16 @@ PetscErrorCode TSRosWRegister(TSRosWType name, PetscInt order, PetscInt s, const
 .  a2 - design parameter, see Table 7.2 of Hairer&Wanner
 .  a3 - design parameter or PETSC_DEFAULT to satisfy one of the order five conditions (Eq 7.22)
 .  b3 - design parameter, see Table 7.2 of Hairer&Wanner
-.  beta43 - design parameter or PETSC_DEFAULT to use Equation 7.21 of Hairer&Wanner
 -  e4 - design parameter for embedded method, see coefficient E4 in ros4.f code from Hairer
 
+   Level: developer
+
    Notes:
    This routine encodes the design of fourth order Rosenbrock methods as described in Hairer and Wanner volume 2.
    It is used here to implement several methods from the book and can be used to experiment with new methods.
    It was written this way instead of by copying coefficients in order to provide better than double precision satisfaction of the order conditions.
 
-   Level: developer
-
-.seealso: `TSRosW`, `TSRosWRegister()`
+.seealso: [](chapter_ts), `TSRosW`, `TSRosWRegister()`
 @*/
 PetscErrorCode TSRosWRegisterRos4(TSRosWType name, PetscReal gamma, PetscReal a2, PetscReal a3, PetscReal b3, PetscReal e4)
 {
@@ -811,8 +810,8 @@ PetscErrorCode TSRosWRegisterRos4(TSRosWType name, PetscReal gamma, PetscReal a2
   PetscFunctionBegin;
   /* Step 1: choose Gamma (input) */
   /* Step 2: choose a2,a3,a4; b1,b2,b3,b4 to satisfy order conditions */
-  if (a3 == PETSC_DEFAULT) a3 = (one / five - a2 / four) / (one / four - a2 / three); /* Eq 7.22 */
-  a4 = a3;                                                                            /* consequence of 7.20 */
+  if (a3 == (PetscReal)PETSC_DEFAULT) a3 = (one / five - a2 / four) / (one / four - a2 / three); /* Eq 7.22 */
+  a4 = a3;                                                                                       /* consequence of 7.20 */
 
   /* Solve order conditions 7.15a, 7.15c, 7.15e */
   M[0][0] = one;
@@ -910,7 +909,7 @@ PetscErrorCode TSRosWRegisterRos4(TSRosWType name, PetscReal gamma, PetscReal a2
     PetscCheck(PetscAbs(misfit) <= PETSC_SMALL, PETSC_COMM_SELF, PETSC_ERR_SUP, "Assumptions violated, could not construct a third order embedded method");
   }
   PetscCall(TSRosWRegister(name, 4, 4, &A[0][0], &Gamma[0][0], b, bm, 0, NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -942,7 +941,7 @@ static PetscErrorCode TSEvaluateStep_RosW(TS ts, PetscInt order, Vec U, PetscBoo
       PetscCall(VecMAXPY(U, tab->s, w, ros->Y));
     } else PetscCall(VecCopy(ts->vec_sol, U));
     if (done) *done = PETSC_TRUE;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   } else if (order == tab->order - 1) {
     if (!tab->bembedt) goto unavailable;
     if (ros->status == TS_STEP_INCOMPLETE) { /* Use embedded completion formula */
@@ -955,14 +954,14 @@ static PetscErrorCode TSEvaluateStep_RosW(TS ts, PetscInt order, Vec U, PetscBoo
       PetscCall(VecMAXPY(U, tab->s, w, ros->Y));
     }
     if (done) *done = PETSC_TRUE;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 unavailable:
   if (done) *done = PETSC_FALSE;
   else
     SETERRQ(PetscObjectComm((PetscObject)ts), PETSC_ERR_SUP, "Rosenbrock-W '%s' of order %" PetscInt_FMT " cannot evaluate step at order %" PetscInt_FMT ". Consider using -ts_adapt_type none or a different method that has an embedded estimate.", tab->name,
             tab->order, order);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSRollBack_RosW(TS ts)
@@ -971,7 +970,7 @@ static PetscErrorCode TSRollBack_RosW(TS ts)
 
   PetscFunctionBegin;
   PetscCall(VecCopy(ros->vec_sol_prev, ts->vec_sol));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSStep_RosW(TS ts)
@@ -1086,7 +1085,7 @@ static PetscErrorCode TSStep_RosW(TS ts)
       PetscCall(PetscInfo(ts, "Step=%" PetscInt_FMT ", step rejections %" PetscInt_FMT " greater than current TS allowed, stopping solve\n", ts->steps, rejections));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSInterpolate_RosW(TS ts, PetscReal itime, Vec U)
@@ -1136,7 +1135,7 @@ static PetscErrorCode TSInterpolate_RosW(TS ts, PetscReal itime, Vec U)
   PetscCall(VecAXPY(U, 1, ros->vec_sol_prev));
 
   PetscCall(PetscFree(bt));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*------------------------------------------------------------*/
@@ -1147,10 +1146,10 @@ static PetscErrorCode TSRosWTableauReset(TS ts)
   RosWTableau tab = ros->tableau;
 
   PetscFunctionBegin;
-  if (!tab) PetscFunctionReturn(0);
+  if (!tab) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecDestroyVecs(tab->s, &ros->Y));
   PetscCall(PetscFree(ros->work));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSReset_RosW(TS ts)
@@ -1164,7 +1163,7 @@ static PetscErrorCode TSReset_RosW(TS ts)
   PetscCall(VecDestroy(&ros->Zdot));
   PetscCall(VecDestroy(&ros->Zstage));
   PetscCall(VecDestroy(&ros->vec_sol_prev));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSRosWGetVecs(TS ts, DM dm, Vec *Ydot, Vec *Zdot, Vec *Ystage, Vec *Zstage)
@@ -1192,7 +1191,7 @@ static PetscErrorCode TSRosWGetVecs(TS ts, DM dm, Vec *Ydot, Vec *Zdot, Vec *Yst
       PetscCall(DMGetNamedGlobalVector(dm, "TSRosW_Zstage", Zstage));
     } else *Zstage = rw->Zstage;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSRosWRestoreVecs(TS ts, DM dm, Vec *Ydot, Vec *Zdot, Vec *Ystage, Vec *Zstage)
@@ -1210,13 +1209,13 @@ static PetscErrorCode TSRosWRestoreVecs(TS ts, DM dm, Vec *Ydot, Vec *Zdot, Vec
   if (Zstage) {
     if (dm && dm != ts->dm) PetscCall(DMRestoreNamedGlobalVector(dm, "TSRosW_Zstage", Zstage));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMCoarsenHook_TSRosW(DM fine, DM coarse, void *ctx)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMRestrictHook_TSRosW(DM fine, Mat restrct, Vec rscale, Mat inject, DM coarse, void *ctx)
@@ -1238,13 +1237,13 @@ static PetscErrorCode DMRestrictHook_TSRosW(DM fine, Mat restrct, Vec rscale, Ma
   PetscCall(VecPointwiseMult(Zstagec, rscale, Zstagec));
   PetscCall(TSRosWRestoreVecs(ts, fine, &Ydot, &Ystage, &Zdot, &Zstage));
   PetscCall(TSRosWRestoreVecs(ts, coarse, &Ydotc, &Ystagec, &Zdotc, &Zstagec));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMSubDomainHook_TSRosW(DM fine, DM coarse, void *ctx)
 {
   PetscFunctionBegin;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMSubDomainRestrictHook_TSRosW(DM dm, VecScatter gscat, VecScatter lscat, DM subdm, void *ctx)
@@ -1271,7 +1270,7 @@ static PetscErrorCode DMSubDomainRestrictHook_TSRosW(DM dm, VecScatter gscat, Ve
 
   PetscCall(TSRosWRestoreVecs(ts, dm, &Ydot, &Ystage, &Zdot, &Zstage));
   PetscCall(TSRosWRestoreVecs(ts, subdm, &Ydots, &Ystages, &Zdots, &Zstages));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -1295,7 +1294,7 @@ static PetscErrorCode SNESTSFormFunction_RosW(SNES snes, Vec U, Vec F, TS ts)
   PetscCall(TSComputeIFunction(ts, ros->stage_time, Ystage, Ydot, F, PETSC_FALSE));
   ts->dm = dmsave;
   PetscCall(TSRosWRestoreVecs(ts, dm, &Ydot, &Zdot, &Ystage, &Zstage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode SNESTSFormJacobian_RosW(SNES snes, Vec U, Mat A, Mat B, TS ts)
@@ -1314,7 +1313,7 @@ static PetscErrorCode SNESTSFormJacobian_RosW(SNES snes, Vec U, Mat A, Mat B, TS
   PetscCall(TSComputeIJacobian(ts, ros->stage_time, Ystage, Ydot, shift, A, B, PETSC_TRUE));
   ts->dm = dmsave;
   PetscCall(TSRosWRestoreVecs(ts, dm, &Ydot, &Zdot, &Ystage, &Zstage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSRosWTableauSetUp(TS ts)
@@ -1325,7 +1324,7 @@ static PetscErrorCode TSRosWTableauSetUp(TS ts)
   PetscFunctionBegin;
   PetscCall(VecDuplicateVecs(ts->vec_sol, tab->s, &ros->Y));
   PetscCall(PetscMalloc1(tab->s, &ros->work));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSSetUp_RosW(TS ts)
@@ -1370,7 +1369,7 @@ static PetscErrorCode TSSetUp_RosW(TS ts)
       PetscCall(MatDestroy(&Amat));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 /*------------------------------------------------------------*/
 
@@ -1401,7 +1400,7 @@ static PetscErrorCode TSSetFromOptions_RosW(TS ts, PetscOptionItems *PetscOption
   /* Rosenbrock methods are linearly implicit, so set that unless the user has specifically asked for something else */
   PetscCall(TSGetSNES(ts, &snes));
   if (!((PetscObject)snes)->type_name) PetscCall(SNESSetType(snes, SNESKSPONLY));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSView_RosW(TS ts, PetscViewer viewer)
@@ -1425,7 +1424,7 @@ static PetscErrorCode TSView_RosW(TS ts, PetscViewer viewer)
     PetscCall(PetscFormatRealArray(buf, sizeof(buf), "% 8.6f", tab->s, abscissa));
     PetscCall(PetscViewerASCIIPrintf(viewer, "  Abscissa of A+Gamma = %s\n", buf));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSLoad_RosW(TS ts, PetscViewer viewer)
@@ -1441,13 +1440,13 @@ static PetscErrorCode TSLoad_RosW(TS ts, PetscViewer viewer)
   /* function and Jacobian context for SNES when used with TS is always ts object */
   PetscCall(SNESSetFunction(snes, NULL, NULL, ts));
   PetscCall(SNESSetJacobian(snes, NULL, NULL, NULL, ts));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  TSRosWSetType - Set the type of Rosenbrock-W scheme
+  TSRosWSetType - Set the type of Rosenbrock-W, `TSROSW`, scheme
 
-  Logically collective
+  Logically Collective
 
   Input Parameters:
 +  ts - timestepping context
@@ -1455,7 +1454,7 @@ static PetscErrorCode TSLoad_RosW(TS ts, PetscViewer viewer)
 
   Level: beginner
 
-.seealso: `TSRosWGetType()`, `TSROSW`, `TSROSW2M`, `TSROSW2P`, `TSROSWRA3PW`, `TSROSWRA34PW2`, `TSROSWRODAS3`, `TSROSWSANDU3`, `TSROSWASSP3P3S1C`, `TSROSWLASSP3P4S2C`, `TSROSWLLSSP3P4S2C`, `TSROSWARK3`
+.seealso: [](chapter_ts), `TSRosWGetType()`, `TSROSW`, `TSROSW2M`, `TSROSW2P`, `TSROSWRA3PW`, `TSROSWRA34PW2`, `TSROSWRODAS3`, `TSROSWSANDU3`, `TSROSWASSP3P3S1C`, `TSROSWLASSP3P4S2C`, `TSROSWLLSSP3P4S2C`, `TSROSWARK3`
 @*/
 PetscErrorCode TSRosWSetType(TS ts, TSRosWType roswtype)
 {
@@ -1463,13 +1462,13 @@ PetscErrorCode TSRosWSetType(TS ts, TSRosWType roswtype)
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscValidCharPointer(roswtype, 2);
   PetscTryMethod(ts, "TSRosWSetType_C", (TS, TSRosWType), (ts, roswtype));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TSRosWGetType - Get the type of Rosenbrock-W scheme
 
-  Logically collective
+  Logically Collective
 
   Input Parameter:
 .  ts - timestepping context
@@ -1479,35 +1478,35 @@ PetscErrorCode TSRosWSetType(TS ts, TSRosWType roswtype)
 
   Level: intermediate
 
-.seealso: `TSRosWGetType()`
+.seealso: [](chapter_ts), `TSRosWType`, `TSRosWSetType()`
 @*/
 PetscErrorCode TSRosWGetType(TS ts, TSRosWType *rostype)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscUseMethod(ts, "TSRosWGetType_C", (TS, TSRosWType *), (ts, rostype));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TSRosWSetRecomputeJacobian - Set whether to recompute the Jacobian at each stage. The default is to update the Jacobian once per step.
 
-  Logically collective
+  Logically Collective
 
   Input Parameters:
 +  ts - timestepping context
--  flg - PETSC_TRUE to recompute the Jacobian at each stage
+-  flg - `PETSC_TRUE` to recompute the Jacobian at each stage
 
   Level: intermediate
 
-.seealso: `TSRosWGetType()`
+.seealso: [](chapter_ts), `TSRosWType`, `TSRosWGetType()`
 @*/
 PetscErrorCode TSRosWSetRecomputeJacobian(TS ts, PetscBool flg)
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   PetscTryMethod(ts, "TSRosWSetRecomputeJacobian_C", (TS, PetscBool), (ts, flg));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSRosWGetType_RosW(TS ts, TSRosWType *rostype)
@@ -1516,7 +1515,7 @@ static PetscErrorCode TSRosWGetType_RosW(TS ts, TSRosWType *rostype)
 
   PetscFunctionBegin;
   *rostype = ros->tableau->name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSRosWSetType_RosW(TS ts, TSRosWType rostype)
@@ -1528,7 +1527,7 @@ static PetscErrorCode TSRosWSetType_RosW(TS ts, TSRosWType rostype)
   PetscFunctionBegin;
   if (ros->tableau) {
     PetscCall(PetscStrcmp(ros->tableau->name, rostype, &match));
-    if (match) PetscFunctionReturn(0);
+    if (match) PetscFunctionReturn(PETSC_SUCCESS);
   }
   for (link = RosWTableauList; link; link = link->next) {
     PetscCall(PetscStrcmp(link->tab.name, rostype, &match));
@@ -1537,7 +1536,7 @@ static PetscErrorCode TSRosWSetType_RosW(TS ts, TSRosWType rostype)
       ros->tableau = &link->tab;
       if (ts->setupcalled) PetscCall(TSRosWTableauSetUp(ts));
       ts->default_adapt_type = ros->tableau->bembed ? TSADAPTBASIC : TSADAPTNONE;
-      PetscFunctionReturn(0);
+      PetscFunctionReturn(PETSC_SUCCESS);
     }
   }
   SETERRQ(PetscObjectComm((PetscObject)ts), PETSC_ERR_ARG_UNKNOWN_TYPE, "Could not find '%s'", rostype);
@@ -1549,7 +1548,7 @@ static PetscErrorCode TSRosWSetRecomputeJacobian_RosW(TS ts, PetscBool flg)
 
   PetscFunctionBegin;
   ros->recompute_jacobian = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSDestroy_RosW(TS ts)
@@ -1564,7 +1563,7 @@ static PetscErrorCode TSDestroy_RosW(TS ts)
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSRosWGetType_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSRosWSetType_C", NULL));
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSRosWSetRecomputeJacobian_C", NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* ------------------------------------------------------------ */
@@ -1573,12 +1572,14 @@ static PetscErrorCode TSDestroy_RosW(TS ts)
 
   These methods are intended for problems with well-separated time scales, especially when a slow scale is strongly
   nonlinear such that it is expensive to solve with a fully implicit method. The user should provide the stiff part
-  of the equation using TSSetIFunction() and the non-stiff part with TSSetRHSFunction().
+  of the equation using `TSSetIFunction()` and the non-stiff part with `TSSetRHSFunction()`.
+
+  Level: beginner
 
   Notes:
   This method currently only works with autonomous ODE and DAE.
 
-  Consider trying TSARKIMEX if the stiff part is strongly nonlinear.
+  Consider trying `TSARKIMEX` if the stiff part is strongly nonlinear.
 
   Since this uses a single linear solve per time-step if you wish to lag the jacobian or preconditioner computation you must use also -snes_lag_jacobian_persists true or -snes_lag_jacobian_preconditioner true
 
@@ -1626,10 +1627,8 @@ $  g(u_0 + sum_j a_ij y_j + y_i, ydot_i) = 0
 
    with initial guess y_i = 0.
 
-  Level: beginner
-
-.seealso: `TSCreate()`, `TS`, `TSSetType()`, `TSRosWSetType()`, `TSRosWRegister()`, `TSROSWTHETA1`, `TSROSWTHETA2`, `TSROSW2M`, `TSROSW2P`, `TSROSWRA3PW`, `TSROSWRA34PW2`, `TSROSWRODAS3`,
-          `TSROSWSANDU3`, `TSROSWASSP3P3S1C`, `TSROSWLASSP3P4S2C`, `TSROSWLLSSP3P4S2C`, `TSROSWGRK4T`, `TSROSWSHAMP4`, `TSROSWVELDD4`, `TSROSW4L`
+.seealso: [](chapter_ts), `TSCreate()`, `TS`, `TSSetType()`, `TSRosWSetType()`, `TSRosWRegister()`, `TSROSWTHETA1`, `TSROSWTHETA2`, `TSROSW2M`, `TSROSW2P`, `TSROSWRA3PW`, `TSROSWRA34PW2`, `TSROSWRODAS3`,
+          `TSROSWSANDU3`, `TSROSWASSP3P3S1C`, `TSROSWLASSP3P4S2C`, `TSROSWLLSSP3P4S2C`, `TSROSWGRK4T`, `TSROSWSHAMP4`, `TSROSWVELDD4`, `TSROSW4L`, `TSType`
 M*/
 PETSC_EXTERN PetscErrorCode TSCreate_RosW(TS ts)
 {
@@ -1661,5 +1660,5 @@ PETSC_EXTERN PetscErrorCode TSCreate_RosW(TS ts)
   PetscCall(PetscObjectComposeFunction((PetscObject)ts, "TSRosWSetRecomputeJacobian_C", TSRosWSetRecomputeJacobian_RosW));
 
   PetscCall(TSRosWSetType(ts, TSRosWDefault));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
