@@ -19,10 +19,13 @@ struct _n_TSMonitorSPEigCtx {
    Collective
 
    Input Parameters:
-+  host - the X display to open, or null for the local machine
++  comm - the communicator to share the monitor
+.  host - the X display to open, or `NULL` for the local machine
 .  label - the title to put in the title bar
-.  x, y - the screen coordinates of the upper left coordinate of the window
-.  m, n - the screen width and height in pixels
+.  x - the horizontal screen coordinates of the upper left coordinate of the window
+.  y - the vertical coordinates of the upper left coordinate of the window
+.  m - the screen width in pixels
+.  n - the screen height in pixels
 -  howoften - if positive then determines the frequency of the plotting, if -1 then only at the final time
 
    Output Parameter:
@@ -74,7 +77,7 @@ PetscErrorCode TSMonitorSPEigCtxCreate(MPI_Comm comm, const char host[], const c
   (*ctx)->xmax = 1.1;
   (*ctx)->ymin = -1.1;
   (*ctx)->ymax = 1.1;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSLinearStabilityIndicator(TS ts, PetscReal xr, PetscReal xi, PetscBool *flg)
@@ -85,7 +88,7 @@ static PetscErrorCode TSLinearStabilityIndicator(TS ts, PetscReal xr, PetscReal
   PetscCall(TSComputeLinearStability(ts, xr, xi, &yr, &yi));
   if ((yr * yr + yi * yi) <= 1.0) *flg = PETSC_TRUE;
   else *flg = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSMonitorSPEig(TS ts, PetscInt step, PetscReal ptime, Vec v, void *monctx)
@@ -100,8 +103,8 @@ PetscErrorCode TSMonitorSPEig(TS ts, PetscInt step, PetscReal ptime, Vec v, void
   SNES              snes;
 
   PetscFunctionBegin;
-  if (step < 0) PetscFunctionReturn(0); /* -1 indicates interpolated solution */
-  if (!step) PetscFunctionReturn(0);
+  if (step < 0) PetscFunctionReturn(PETSC_SUCCESS); /* -1 indicates interpolated solution */
+  if (!step) PetscFunctionReturn(PETSC_SUCCESS);
   if (((ctx->howoften > 0) && (!(step % ctx->howoften))) || ((ctx->howoften == -1) && ts->reason)) {
     PetscCall(VecDuplicate(v, &xdot));
     PetscCall(TSGetSNES(ts, &snes));
@@ -169,13 +172,13 @@ PetscErrorCode TSMonitorSPEig(TS ts, PetscInt step, PetscReal ptime, Vec v, void
     }
     PetscCall(MatDestroy(&B));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorSPEigCtxDestroy - Destroys a scatter plot context that was created with `TSMonitorSPEigCtxCreate()`.
 
-   Collective on ctx
+   Collective
 
    Input Parameter:
 .  ctx - the monitor context
@@ -198,5 +201,5 @@ PetscErrorCode TSMonitorSPEigCtxDestroy(TSMonitorSPEigCtx *ctx)
   PetscCall(KSPDestroy(&(*ctx)->ksp));
   PetscCall(PetscRandomDestroy(&(*ctx)->rand));
   PetscCall(PetscFree(*ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
