@@ -7,7 +7,7 @@
 /*@C
    TSMonitor - Runs all user-provided monitor routines set using `TSMonitorSet()`
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - time stepping context obtained from `TSCreate()`
@@ -40,13 +40,13 @@ PetscErrorCode TSMonitor(TS ts, PetscInt step, PetscReal ptime, Vec u)
   PetscCall(VecLockReadPush(u));
   for (i = 0; i < n; i++) PetscCall((*ts->monitor[i])(ts, step, ptime, u, ts->monitorcontext[i]));
   PetscCall(VecLockReadPop(u));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorSetFromOptions - Sets a monitor function and viewer appropriate for the type indicated by the user
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - `TS` object you wish to monitor
@@ -76,32 +76,32 @@ PetscErrorCode TSMonitorSetFromOptions(TS ts, const char name[], const char help
   PetscCall(PetscOptionsGetViewer(PetscObjectComm((PetscObject)ts), ((PetscObject)ts)->options, ((PetscObject)ts)->prefix, name, &viewer, &format, &flg));
   if (flg) {
     PetscViewerAndFormat *vf;
+    char                  interval_key[1024];
     PetscCall(PetscViewerAndFormatCreate(viewer, format, &vf));
+    PetscCall(PetscSNPrintf(interval_key, sizeof interval_key, "%s_interval", name));
+    PetscCall(PetscOptionsGetInt(((PetscObject)ts)->options, ((PetscObject)ts)->prefix, interval_key, &vf->view_interval, NULL));
     PetscCall(PetscObjectDereference((PetscObject)viewer));
     if (monitorsetup) PetscCall((*monitorsetup)(ts, vf));
     PetscCall(TSMonitorSet(ts, (PetscErrorCode(*)(TS, PetscInt, PetscReal, Vec, void *))monitor, vf, (PetscErrorCode(*)(void **))PetscViewerAndFormatDestroy));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorSet - Sets an ADDITIONAL function that is to be used at every
    timestep to display the iteration's  progress.
 
-   Logically Collective on ts
+   Logically Collective
 
    Input Parameters:
 +  ts - the `TS` context obtained from `TSCreate()`
 .  monitor - monitoring routine
-.  mctx - [optional] user-defined context for private data for the
-             monitor routine (use NULL if no context is desired)
--  monitordestroy - [optional] routine that frees monitor context
-          (may be NULL)
+.  mctx - [optional] user-defined context for private data for the monitor routine (use `NULL` if no context is desired)
+-  monitordestroy - [optional] routine that frees monitor context (may be `NULL`)
 
-   Calling sequence of monitor:
-$    PetscErrorCode monitor(TS ts,PetscInt steps,PetscReal time,Vec u,void *mctx)
-
-+    ts - the TS context
+   Calling sequence of `monitor`:
+$    PetscErrorCode monitor(TS ts, PetscInt steps, PetscReal time, Vec u, void *mctx)
++    ts - the `TS` context
 .    steps - iteration number (after the final time step the monitor routine may be called with a step of -1, this indicates the solution has been interpolated to this time)
 .    time - current time
 .    u - current iterate
@@ -110,11 +110,10 @@ $    PetscErrorCode monitor(TS ts,PetscInt steps,PetscReal time,Vec u,void *mctx
    Level: intermediate
 
    Note:
-   This routine adds an additional monitor to the list of monitors that
-   already has been loaded.
+   This routine adds an additional monitor to the list of monitors that already has been loaded.
 
    Fortran Note:
-    Only a single monitor function can be set for each `TS` object
+   Only a single monitor function can be set for each `TS` object
 
 .seealso: [](chapter_ts), `TSMonitorDefault()`, `TSMonitorCancel()`, `TSDMSwarmMonitorMoments()`, `TSMonitorExtreme()`, `TSMonitorDrawSolution()`,
           `TSMonitorDrawSolutionPhase()`, `TSMonitorDrawSolutionFunction()`, `TSMonitorDrawError()`, `TSMonitorSolution()`, `TSMonitorSolutionVTK()`,
@@ -129,21 +128,21 @@ PetscErrorCode TSMonitorSet(TS ts, PetscErrorCode (*monitor)(TS, PetscInt, Petsc
   PetscValidHeaderSpecific(ts, TS_CLASSID, 1);
   for (i = 0; i < ts->numbermonitors; i++) {
     PetscCall(PetscMonitorCompare((PetscErrorCode(*)(void))monitor, mctx, mdestroy, (PetscErrorCode(*)(void))ts->monitor[i], ts->monitorcontext[i], ts->monitordestroy[i], &identical));
-    if (identical) PetscFunctionReturn(0);
+    if (identical) PetscFunctionReturn(PETSC_SUCCESS);
   }
   PetscCheck(ts->numbermonitors < MAXTSMONITORS, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Too many monitors set");
   ts->monitor[ts->numbermonitors]          = monitor;
   ts->monitordestroy[ts->numbermonitors]   = mdestroy;
   ts->monitorcontext[ts->numbermonitors++] = (void *)mctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorCancel - Clears all the monitors that have been set on a time-step object.
 
-   Logically Collective on ts
+   Logically Collective
 
-   Input Parameters:
+   Input Parameter:
 .  ts - the `TS` context obtained from `TSCreate()`
 
    Level: intermediate
@@ -163,11 +162,11 @@ PetscErrorCode TSMonitorCancel(TS ts)
     if (ts->monitordestroy[i]) PetscCall((*ts->monitordestroy[i])(&ts->monitorcontext[i]));
   }
   ts->numbermonitors = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   TSMonitorDefault - The Default monitor, prints the timestep and time for each step
+   TSMonitorDefault - The default monitor, prints the timestep and time for each step
 
    Options Database Key:
 .  -ts_monitor - monitors the time integration
@@ -215,7 +214,7 @@ PetscErrorCode TSMonitorDefault(TS ts, PetscInt step, PetscReal ptime, Vec v, Pe
     }
   }
   PetscCall(PetscViewerPopFormat(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -223,9 +222,9 @@ PetscErrorCode TSMonitorDefault(TS ts, PetscInt step, PetscReal ptime, Vec v, Pe
 
    Level: intermediate
 
-   Notes:
+   Note:
    This is not called directly by users, rather one calls `TSMonitorSet()`, with this function as an argument, to cause the monitor
-   to be used during the TS integration.
+   to be used during the `TS` integration.
 
 .seealso: [](chapter_ts), `TS`, `TSMonitorSet()`
 @*/
@@ -247,17 +246,17 @@ PetscErrorCode TSMonitorExtreme(TS ts, PetscInt step, PetscReal ptime, Vec v, Pe
     PetscCall(PetscViewerASCIISubtractTab(viewer, ((PetscObject)ts)->tablevel));
   }
   PetscCall(PetscViewerPopFormat(viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorLGCtxCreate - Creates a `TSMonitorLGCtx` context for use with
    `TS` to monitor the solution process graphically in various ways
 
-   Collective on ts
+   Collective
 
    Input Parameters:
-+  host - the X display to open, or null for the local machine
++  host - the X display to open, or `NULL` for the local machine
 .  label - the title to put in the title bar
 .  x, y - the screen coordinates of the upper left coordinate of the window
 .  m, n - the screen width and height in pixels
@@ -306,7 +305,7 @@ PetscErrorCode TSMonitorLGCtxCreate(MPI_Comm comm, const char host[], const char
   PetscCall(PetscDrawLGSetFromOptions((*ctx)->lg));
   PetscCall(PetscDrawDestroy(&draw));
   (*ctx)->howoften = howoften;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSMonitorLGTimeStep(TS ts, PetscInt step, PetscReal ptime, Vec v, void *monctx)
@@ -315,7 +314,7 @@ PetscErrorCode TSMonitorLGTimeStep(TS ts, PetscInt step, PetscReal ptime, Vec v,
   PetscReal      x   = ptime, y;
 
   PetscFunctionBegin;
-  if (step < 0) PetscFunctionReturn(0); /* -1 indicates an interpolated solution */
+  if (step < 0) PetscFunctionReturn(PETSC_SUCCESS); /* -1 indicates an interpolated solution */
   if (!step) {
     PetscDrawAxis axis;
     const char   *ylabel = ctx->semilogy ? "Log Time Step" : "Time Step";
@@ -330,14 +329,13 @@ PetscErrorCode TSMonitorLGTimeStep(TS ts, PetscInt step, PetscReal ptime, Vec v,
     PetscCall(PetscDrawLGDraw(ctx->lg));
     PetscCall(PetscDrawLGSave(ctx->lg));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   TSMonitorLGCtxDestroy - Destroys a line graph context that was created
-   with `TSMonitorLGCtxCreate()`.
+   TSMonitorLGCtxDestroy - Destroys a line graph context that was created with `TSMonitorLGCtxCreate()`.
 
-   Collective on ctx
+   Collective
 
    Input Parameter:
 .  ctx - the monitor context
@@ -359,11 +357,11 @@ PetscErrorCode TSMonitorLGCtxDestroy(TSMonitorLGCtx *ctx)
   PetscCall(PetscFree((*ctx)->displayvariables));
   PetscCall(PetscFree((*ctx)->displayvalues));
   PetscCall(PetscFree(*ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* Creates a TS Monitor SPCtx for use with DMSwarm particle visualizations */
-PetscErrorCode TSMonitorSPCtxCreate(MPI_Comm comm, const char host[], const char label[], int x, int y, int m, int n, PetscInt howoften, PetscInt retain, PetscBool phase, TSMonitorSPCtx *ctx)
+/* Creates a TSMonitorSPCtx for use with DMSwarm particle visualizations */
+PetscErrorCode TSMonitorSPCtxCreate(MPI_Comm comm, const char host[], const char label[], int x, int y, int m, int n, PetscInt howoften, PetscInt retain, PetscBool phase, PetscBool multispecies, TSMonitorSPCtx *ctx)
 {
   PetscDraw draw;
 
@@ -373,36 +371,68 @@ PetscErrorCode TSMonitorSPCtxCreate(MPI_Comm comm, const char host[], const char
   PetscCall(PetscDrawSetFromOptions(draw));
   PetscCall(PetscDrawSPCreate(draw, 1, &(*ctx)->sp));
   PetscCall(PetscDrawDestroy(&draw));
-  (*ctx)->howoften = howoften;
-  (*ctx)->retain   = retain;
-  (*ctx)->phase    = phase;
-  PetscFunctionReturn(0);
+  (*ctx)->howoften     = howoften;
+  (*ctx)->retain       = retain;
+  (*ctx)->phase        = phase;
+  (*ctx)->multispecies = multispecies;
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/*
-  Destroys a TSMonitorSPCtx that was created with TSMonitorSPCtxCreate
-*/
+/* Destroys a TSMonitorSPCtx that was created with TSMonitorSPCtxCreate */
 PetscErrorCode TSMonitorSPCtxDestroy(TSMonitorSPCtx *ctx)
 {
   PetscFunctionBegin;
 
   PetscCall(PetscDrawSPDestroy(&(*ctx)->sp));
   PetscCall(PetscFree(*ctx));
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
 
-  PetscFunctionReturn(0);
+/* Creates a TSMonitorHGCtx for use with DMSwarm particle visualizations */
+PetscErrorCode TSMonitorHGCtxCreate(MPI_Comm comm, const char host[], const char label[], int x, int y, int m, int n, PetscInt howoften, PetscInt Ns, PetscInt Nb, PetscBool velocity, TSMonitorHGCtx *ctx)
+{
+  PetscDraw draw;
+  PetscInt  s;
+
+  PetscFunctionBegin;
+  PetscCall(PetscNew(ctx));
+  PetscCall(PetscMalloc1(Ns, &(*ctx)->hg));
+  for (s = 0; s < Ns; ++s) {
+    PetscCall(PetscDrawCreate(comm, host, label, x + s * m, y, m, n, &draw));
+    PetscCall(PetscDrawSetFromOptions(draw));
+    PetscCall(PetscDrawHGCreate(draw, Nb, &(*ctx)->hg[s]));
+    PetscCall(PetscDrawHGCalcStats((*ctx)->hg[s], PETSC_TRUE));
+    PetscCall(PetscDrawDestroy(&draw));
+  }
+  (*ctx)->howoften = howoften;
+  (*ctx)->Ns       = Ns;
+  (*ctx)->velocity = velocity;
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/* Destroys a TSMonitorHGCtx that was created with TSMonitorHGCtxCreate */
+PetscErrorCode TSMonitorHGCtxDestroy(TSMonitorHGCtx *ctx)
+{
+  PetscInt s;
+
+  PetscFunctionBegin;
+  for (s = 0; s < (*ctx)->Ns; ++s) PetscCall(PetscDrawHGDestroy(&(*ctx)->hg[s]));
+  PetscCall(PetscFree((*ctx)->hg));
+  PetscCall(PetscFree(*ctx));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorDrawSolution - Monitors progress of the `TS` solvers by calling
    `VecView()` for the solution at each timestep
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
 .  step - current time-step
 .  ptime - current time
--  dummy - either a viewer or NULL
+-  dummy - either a viewer or `NULL`
 
    Options Database Keys:
 +   -ts_monitor_draw_solution - draw the solution at each time-step
@@ -411,7 +441,7 @@ PetscErrorCode TSMonitorSPCtxDestroy(TSMonitorSPCtx *ctx)
    Level: intermediate
 
    Notes:
-   The initial solution and current solution are not displayed with a common axis scaling so generally the option -ts_monitor_draw_solution_initial
+   The initial solution and current solution are not displayed with a common axis scaling so generally the option `-ts_monitor_draw_solution_initial`
    will look bad
 
    This is not called directly by users, rather one calls `TSMonitorSet()`, with this function as an argument, as well as the context created with
@@ -429,7 +459,7 @@ PetscErrorCode TSMonitorDrawSolution(TS ts, PetscInt step, PetscReal ptime, Vec
     if (!ictx->initialsolution) PetscCall(VecDuplicate(u, &ictx->initialsolution));
     PetscCall(VecCopy(u, ictx->initialsolution));
   }
-  if (!(((ictx->howoften > 0) && (!(step % ictx->howoften))) || ((ictx->howoften == -1) && ts->reason))) PetscFunctionReturn(0);
+  if (!(((ictx->howoften > 0) && (!(step % ictx->howoften))) || ((ictx->howoften == -1) && ts->reason))) PetscFunctionReturn(PETSC_SUCCESS);
 
   if (ictx->showinitial) {
     PetscReal pause;
@@ -453,19 +483,19 @@ PetscErrorCode TSMonitorDrawSolution(TS ts, PetscInt step, PetscReal ptime, Vec
   }
 
   if (ictx->showinitial) PetscCall(PetscViewerDrawSetHold(ictx->viewer, PETSC_FALSE));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorDrawSolutionPhase - Monitors progress of the `TS` solvers by plotting the solution as a phase diagram
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
 .  step - current time-step
 .  ptime - current time
--  dummy - either a viewer or NULL
+-  dummy - either a viewer or `NULL`
 
    Level: intermediate
 
@@ -504,7 +534,7 @@ PetscErrorCode TSMonitorDrawSolutionPhase(TS ts, PetscInt step, PetscReal ptime,
   U0 = PetscRealPart(U[0]);
   U1 = PetscRealPart(U[1]);
   PetscCall(VecRestoreArrayRead(u, &U));
-  if ((U0 < xl) || (U1 < yl) || (U0 > xr) || (U1 > yr)) PetscFunctionReturn(0);
+  if ((U0 < xl) || (U1 < yl) || (U0 > xr) || (U1 > yr)) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscDrawCollectiveBegin(draw);
   PetscCall(PetscDrawPoint(draw, U0, U1, PETSC_DRAW_BLACK));
@@ -518,15 +548,15 @@ PetscErrorCode TSMonitorDrawSolutionPhase(TS ts, PetscInt step, PetscReal ptime,
   PetscCall(PetscDrawFlush(draw));
   PetscCall(PetscDrawPause(draw));
   PetscCall(PetscDrawSave(draw));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorDrawCtxDestroy - Destroys the monitor context for `TSMonitorDrawSolution()`
 
-   Collective on ts
+   Collective
 
-   Input Parameters:
+   Input Parameter:
 .    ctx - the monitor context
 
    Level: intermediate
@@ -539,13 +569,13 @@ PetscErrorCode TSMonitorDrawCtxDestroy(TSMonitorDrawCtx *ictx)
   PetscCall(PetscViewerDestroy(&(*ictx)->viewer));
   PetscCall(VecDestroy(&(*ictx)->initialsolution));
   PetscCall(PetscFree(*ictx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorDrawCtxCreate - Creates the monitor context for `TSMonitorDrawCtx`
 
-   Collective on ts
+   Collective
 
    Input Parameter:
 .    ts - time-step context
@@ -560,7 +590,7 @@ PetscErrorCode TSMonitorDrawCtxDestroy(TSMonitorDrawCtx *ictx)
    Level: intermediate
 
    Note:
-   The context created by this function,  `PetscMonitorDrawSolution()`, and `TSMonitorDrawCtxDestroy()` should be passed together to `TSMonitorSet()`.
+   The context created by this function, `PetscMonitorDrawSolution()`, and `TSMonitorDrawCtxDestroy()` should be passed together to `TSMonitorSet()`.
 
 .seealso: [](chapter_ts), `TS`, `TSMonitorDrawCtxDestroy()`, `TSMonitorSet()`, `TSMonitorDefault()`, `VecView()`, `TSMonitorDrawCtx`, `PetscMonitorDrawSolution()`
 @*/
@@ -577,20 +607,20 @@ PetscErrorCode TSMonitorDrawCtxCreate(MPI_Comm comm, const char host[], const ch
 
   (*ctx)->showtimestepandtime = PETSC_FALSE;
   PetscCall(PetscOptionsGetBool(NULL, NULL, "-ts_monitor_draw_solution_show_time", &(*ctx)->showtimestepandtime, NULL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorDrawSolutionFunction - Monitors progress of the `TS` solvers by calling
    `VecView()` for the solution provided by `TSSetSolutionFunction()` at each timestep
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
 .  step - current time-step
 .  ptime - current time
--  dummy - either a viewer or NULL
+-  dummy - either a viewer or `NULL`
 
    Options Database Key:
 .  -ts_monitor_draw_solution_function - Monitor error graphically, requires user to have provided `TSSetSolutionFunction()`
@@ -610,25 +640,25 @@ PetscErrorCode TSMonitorDrawSolutionFunction(TS ts, PetscInt step, PetscReal pti
   Vec              work;
 
   PetscFunctionBegin;
-  if (!(((ctx->howoften > 0) && (!(step % ctx->howoften))) || ((ctx->howoften == -1) && ts->reason))) PetscFunctionReturn(0);
+  if (!(((ctx->howoften > 0) && (!(step % ctx->howoften))) || ((ctx->howoften == -1) && ts->reason))) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecDuplicate(u, &work));
   PetscCall(TSComputeSolutionFunction(ts, ptime, work));
   PetscCall(VecView(work, viewer));
   PetscCall(VecDestroy(&work));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorDrawError - Monitors progress of the `TS` solvers by calling
    `VecView()` for the error at each timestep
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
 .  step - current time-step
 .  ptime - current time
--  dummy - either a viewer or NULL
+-  dummy - either a viewer or `NULL`
 
    Options Database Key:
 .  -ts_monitor_draw_error - Monitor error graphically, requires user to have provided `TSSetSolutionFunction()`
@@ -648,19 +678,19 @@ PetscErrorCode TSMonitorDrawError(TS ts, PetscInt step, PetscReal ptime, Vec u,
   Vec              work;
 
   PetscFunctionBegin;
-  if (!(((ctx->howoften > 0) && (!(step % ctx->howoften))) || ((ctx->howoften == -1) && ts->reason))) PetscFunctionReturn(0);
+  if (!(((ctx->howoften > 0) && (!(step % ctx->howoften))) || ((ctx->howoften == -1) && ts->reason))) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(VecDuplicate(u, &work));
   PetscCall(TSComputeSolutionFunction(ts, ptime, work));
   PetscCall(VecAXPY(work, -1.0, u));
   PetscCall(VecView(work, viewer));
   PetscCall(VecDestroy(&work));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   TSMonitorSolution - Monitors progress of the TS solvers by `VecView()` for the solution at each timestep. Normally the viewer is a binary file or a `PetscDraw` object
+   TSMonitorSolution - Monitors progress of the `TS` solvers by `VecView()` for the solution at each timestep. Normally the viewer is a binary file or a `PetscDraw` object
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
@@ -680,16 +710,17 @@ PetscErrorCode TSMonitorDrawError(TS ts, PetscInt step, PetscReal ptime, Vec u,
 PetscErrorCode TSMonitorSolution(TS ts, PetscInt step, PetscReal ptime, Vec u, PetscViewerAndFormat *vf)
 {
   PetscFunctionBegin;
+  if (vf->view_interval > 0 && !ts->reason && step % vf->view_interval != 0) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscViewerPushFormat(vf->viewer, vf->format));
   PetscCall(VecView(u, vf->viewer));
   PetscCall(PetscViewerPopFormat(vf->viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorSolutionVTK - Monitors progress of the `TS` solvers by `VecView()` for the solution at each timestep.
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
@@ -715,12 +746,12 @@ PetscErrorCode TSMonitorSolutionVTK(TS ts, PetscInt step, PetscReal ptime, Vec u
   PetscViewer viewer;
 
   PetscFunctionBegin;
-  if (step < 0) PetscFunctionReturn(0); /* -1 indicates interpolated solution */
+  if (step < 0) PetscFunctionReturn(PETSC_SUCCESS); /* -1 indicates interpolated solution */
   PetscCall(PetscSNPrintf(filename, sizeof(filename), (const char *)filenametemplate, step));
   PetscCall(PetscViewerVTKOpen(PetscObjectComm((PetscObject)ts), filename, FILE_MODE_WRITE, &viewer));
   PetscCall(VecView(u, viewer));
   PetscCall(PetscViewerDestroy(&viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -728,7 +759,7 @@ PetscErrorCode TSMonitorSolutionVTK(TS ts, PetscInt step, PetscReal ptime, Vec u
 
    Not Collective
 
-   Input Parameters:
+   Input Parameter:
 .  filenametemplate - string containing a format specifier for the integer time step (e.g. %03" PetscInt_FMT ")
 
    Level: intermediate
@@ -742,14 +773,14 @@ PetscErrorCode TSMonitorSolutionVTKDestroy(void *filenametemplate)
 {
   PetscFunctionBegin;
   PetscCall(PetscFree(*(char **)filenametemplate));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorLGSolution - Monitors progress of the `TS` solvers by plotting each component of the solution vector
        in a time based line graph
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
@@ -781,7 +812,7 @@ PetscErrorCode TSMonitorLGSolution(TS ts, PetscInt step, PetscReal ptime, Vec u,
   Vec                v;
 
   PetscFunctionBegin;
-  if (step < 0) PetscFunctionReturn(0); /* -1 indicates interpolated solution */
+  if (step < 0) PetscFunctionReturn(PETSC_SUCCESS); /* -1 indicates interpolated solution */
   if (!step) {
     PetscDrawAxis axis;
     PetscInt      dim;
@@ -854,17 +885,17 @@ PetscErrorCode TSMonitorLGSolution(TS ts, PetscInt step, PetscReal ptime, Vec u,
     PetscCall(PetscDrawLGDraw(ctx->lg));
     PetscCall(PetscDrawLGSave(ctx->lg));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorLGSetVariableNames - Sets the name of each component in the solution vector so that it may be displayed in the plot
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
--  names - the names of the components, final string must be NULL
+-  names - the names of the components, final string must be `NULL`
 
    Level: intermediate
 
@@ -884,17 +915,17 @@ PetscErrorCode TSMonitorLGSetVariableNames(TS ts, const char *const *names)
       break;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorLGCtxSetVariableNames - Sets the name of each component in the solution vector so that it may be displayed in the plot
 
-   Collective on ctx
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
--  names - the names of the components, final string must be NULL
+-  names - the names of the components, final string must be `NULL`
 
    Level: intermediate
 
@@ -905,19 +936,19 @@ PetscErrorCode TSMonitorLGCtxSetVariableNames(TSMonitorLGCtx ctx, const char *co
   PetscFunctionBegin;
   PetscCall(PetscStrArrayDestroy(&ctx->names));
   PetscCall(PetscStrArrayallocpy(names, &ctx->names));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorLGGetVariableNames - Gets the name of each component in the solution vector so that it may be displayed in the plot
 
-   Collective on ts
+   Collective
 
    Input Parameter:
 .  ts - the `TS` context
 
    Output Parameter:
-.  names - the names of the components, final string must be NULL
+.  names - the names of the components, final string must be `NULL`
 
    Level: intermediate
 
@@ -939,17 +970,17 @@ PetscErrorCode TSMonitorLGGetVariableNames(TS ts, const char *const **names)
       break;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorLGCtxSetDisplayVariables - Sets the variables that are to be display in the monitor
 
-   Collective on ctx
+   Collective
 
    Input Parameters:
 +  ctx - the `TSMonitorLG` context
--  displaynames - the names of the components, final string must be NULL
+-  displaynames - the names of the components, final string must be `NULL`
 
    Level: intermediate
 
@@ -960,7 +991,7 @@ PetscErrorCode TSMonitorLGCtxSetDisplayVariables(TSMonitorLGCtx ctx, const char
   PetscInt j = 0, k;
 
   PetscFunctionBegin;
-  if (!ctx->names) PetscFunctionReturn(0);
+  if (!ctx->names) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscStrArrayDestroy(&ctx->displaynames));
   PetscCall(PetscStrArrayallocpy(displaynames, &ctx->displaynames));
   while (displaynames[j]) j++;
@@ -981,17 +1012,17 @@ PetscErrorCode TSMonitorLGCtxSetDisplayVariables(TSMonitorLGCtx ctx, const char
     }
     j++;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorLGSetDisplayVariables - Sets the variables that are to be display in the monitor
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
--  displaynames - the names of the components, final string must be NULL
+-  displaynames - the names of the components, final string must be `NULL`
 
    Level: intermediate
 
@@ -1011,13 +1042,13 @@ PetscErrorCode TSMonitorLGSetDisplayVariables(TS ts, const char *const *displayn
       break;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorLGSetTransform - Solution vector will be transformed by provided function before being displayed
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
@@ -1040,13 +1071,13 @@ PetscErrorCode TSMonitorLGSetTransform(TS ts, PetscErrorCode (*transform)(void *
   for (i = 0; i < ts->numbermonitors; i++) {
     if (ts->monitor[i] == TSMonitorLGSolution) PetscCall(TSMonitorLGCtxSetTransform((TSMonitorLGCtx)ts->monitorcontext[i], transform, destroy, tctx));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorLGCtxSetTransform - Solution vector will be transformed by provided function before being displayed
 
-   Collective on ctx
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
@@ -1064,14 +1095,14 @@ PetscErrorCode TSMonitorLGCtxSetTransform(TSMonitorLGCtx ctx, PetscErrorCode (*t
   ctx->transform        = transform;
   ctx->transformdestroy = destroy;
   ctx->transformctx     = tctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorLGError - Monitors progress of the `TS` solvers by plotting each component of the error
        in a time based line graph
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
@@ -1134,7 +1165,7 @@ PetscErrorCode TSMonitorLGError(TS ts, PetscInt step, PetscReal ptime, Vec u, vo
     PetscCall(PetscDrawLGDraw(ctx->lg));
     PetscCall(PetscDrawLGSave(ctx->lg));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1148,9 +1179,10 @@ PetscErrorCode TSMonitorLGError(TS ts, PetscInt step, PetscReal ptime, Vec u, vo
 -  dctx - the `TSMonitorSPCtx` object that contains all the options for the monitoring, this is created with `TSMonitorSPCtxCreate()`
 
    Options Database Keys:
-+ -ts_monitor_sp_swarm <n>          - Monitor the solution every n steps, or -1 for plotting only the final solution
-. -ts_monitor_sp_swarm_retain <n>   - Retain n old points so we can see the history, or -1 for all points
-- -ts_monitor_sp_swarm_phase <bool> - Plot in phase space, as opposed to coordinate space
++ -ts_monitor_sp_swarm <n>                  - Monitor the solution every n steps, or -1 for plotting only the final solution
+. -ts_monitor_sp_swarm_retain <n>           - Retain n old points so we can see the history, or -1 for all points
+. -ts_monitor_sp_swarm_multi_species <bool> - Color each species differently
+- -ts_monitor_sp_swarm_phase <bool>         - Plot in phase space, as opposed to coordinate space
 
    Level: intermediate
 
@@ -1166,10 +1198,12 @@ PetscErrorCode TSMonitorSPSwarmSolution(TS ts, PetscInt step, PetscReal ptime, V
   PetscDraw          draw;
   DM                 dm, cdm;
   const PetscScalar *yy;
-  PetscInt           Np, p, dim = 2;
+  PetscInt           Np, p, dim = 2, *species;
+  PetscReal          species_color;
 
   PetscFunctionBegin;
-  if (step < 0) PetscFunctionReturn(0); /* -1 indicates interpolated solution */
+  if (step < 0) PetscFunctionReturn(PETSC_SUCCESS); /* -1 indicates interpolated solution */
+  PetscCall(TSGetDM(ts, &dm));
   if (!step) {
     PetscDrawAxis axis;
     PetscReal     dmboxlower[2], dmboxupper[2];
@@ -1184,7 +1218,7 @@ PetscErrorCode TSMonitorSPSwarmSolution(TS ts, PetscInt step, PetscReal ptime, V
     PetscCall(PetscDrawSPGetAxis(ctx->sp, &axis));
     if (ctx->phase) {
       PetscCall(PetscDrawAxisSetLabels(axis, "Particles", "X", "V"));
-      PetscCall(PetscDrawAxisSetLimits(axis, dmboxlower[0], dmboxupper[0], -5, 5));
+      PetscCall(PetscDrawAxisSetLimits(axis, dmboxlower[0], dmboxupper[0], -10, 10));
     } else {
       PetscCall(PetscDrawAxisSetLabels(axis, "Particles", "X", "Y"));
       PetscCall(PetscDrawAxisSetLimits(axis, dmboxlower[0], dmboxupper[0], dmboxlower[1], dmboxupper[1]));
@@ -1192,6 +1226,7 @@ PetscErrorCode TSMonitorSPSwarmSolution(TS ts, PetscInt step, PetscReal ptime, V
     PetscCall(PetscDrawAxisSetHoldLimits(axis, PETSC_TRUE));
     PetscCall(PetscDrawSPReset(ctx->sp));
   }
+  if (ctx->multispecies) PetscCall(DMSwarmGetField(dm, "species", NULL, NULL, (void **)&species));
   PetscCall(VecGetLocalSize(u, &Np));
   Np /= dim * 2;
   if (((ctx->howoften > 0) && (!(step % ctx->howoften))) || ((ctx->howoften == -1) && ts->reason)) {
@@ -1210,19 +1245,105 @@ PetscErrorCode TSMonitorSPSwarmSolution(TS ts, PetscInt step, PetscReal ptime, V
         x = PetscRealPart(yy[p * dim * 2]);
         y = PetscRealPart(yy[p * dim * 2 + 1]);
       }
+      if (ctx->multispecies) {
+        species_color = species[p] + 2;
+        PetscCall(PetscDrawSPAddPointColorized(ctx->sp, &x, &y, &species_color));
+      } else {
+        PetscCall(PetscDrawSPAddPoint(ctx->sp, &x, &y));
+      }
       PetscCall(PetscDrawSPAddPoint(ctx->sp, &x, &y));
     }
     PetscCall(VecRestoreArrayRead(u, &yy));
     PetscCall(PetscDrawSPDraw(ctx->sp, PETSC_FALSE));
     PetscCall(PetscDrawSPSave(ctx->sp));
+    if (ctx->multispecies) PetscCall(DMSwarmRestoreField(dm, "species", NULL, NULL, (void **)&species));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
+}
+
+/*@C
+   TSMonitorHGSwarmSolution - Graphically displays histograms of `DMSWARM` particles
+
+   Input Parameters:
++  ts - the `TS` context
+.  step - current time-step
+.  ptime - current time
+.  u - current solution
+-  dctx - the `TSMonitorSPCtx` object that contains all the options for the monitoring, this is created with `TSMonitorHGCtxCreate()`
+
+   Options Database Keys:
++ -ts_monitor_hg_swarm <n>             - Monitor the solution every n steps, or -1 for plotting only the final solution
+. -ts_monitor_hg_swarm_species <num>   - Number of species to histogram
+. -ts_monitor_hg_swarm_bins <num>      - Number of histogram bins
+- -ts_monitor_hg_swarm_velocity <bool> - Plot in velocity space, as opposed to coordinate space
+
+   Level: intermediate
+
+   Note:
+   This is not called directly by users, rather one calls `TSMonitorSet()`, with this function as an argument, to cause the monitor
+   to be used during the `TS` integration.
+
+.seealso: `TSMonitoSet()`
+@*/
+PetscErrorCode TSMonitorHGSwarmSolution(TS ts, PetscInt step, PetscReal ptime, Vec u, void *dctx)
+{
+  TSMonitorHGCtx     ctx = (TSMonitorHGCtx)dctx;
+  PetscDraw          draw;
+  DM                 sw;
+  const PetscScalar *yy;
+  PetscInt          *species;
+  PetscInt           dim, d = 0, Np, p, Ns, s;
+
+  PetscFunctionBegin;
+  if (step < 0) PetscFunctionReturn(PETSC_SUCCESS); /* -1 indicates interpolated solution */
+  PetscCall(TSGetDM(ts, &sw));
+  PetscCall(DMGetDimension(sw, &dim));
+  PetscCall(DMSwarmGetNumSpecies(sw, &Ns));
+  Ns = PetscMin(Ns, ctx->Ns);
+  PetscCall(VecGetLocalSize(u, &Np));
+  Np /= dim * 2;
+  if (!step) {
+    PetscDrawAxis axis;
+    char          title[PETSC_MAX_PATH_LEN];
+
+    for (s = 0; s < Ns; ++s) {
+      PetscCall(PetscDrawHGGetAxis(ctx->hg[s], &axis));
+      PetscCall(PetscSNPrintf(title, PETSC_MAX_PATH_LEN, "Species %" PetscInt_FMT, s));
+      if (ctx->velocity) PetscCall(PetscDrawAxisSetLabels(axis, title, "V", "N"));
+      else PetscCall(PetscDrawAxisSetLabels(axis, title, "X", "N"));
+    }
+  }
+  if (((ctx->howoften > 0) && (!(step % ctx->howoften))) || ((ctx->howoften == -1) && ts->reason)) {
+    PetscCall(DMSwarmGetField(sw, "species", NULL, NULL, (void **)&species));
+    for (s = 0; s < Ns; ++s) {
+      PetscCall(PetscDrawHGReset(ctx->hg[s]));
+      PetscCall(PetscDrawHGGetDraw(ctx->hg[s], &draw));
+      PetscCall(PetscDrawClear(draw));
+      PetscCall(PetscDrawFlush(draw));
+    }
+    PetscCall(VecGetArrayRead(u, &yy));
+    for (p = 0; p < Np; ++p) {
+      const PetscInt s = species[p] < Ns ? species[p] : 0;
+      PetscReal      v;
+
+      if (ctx->velocity) v = PetscRealPart(yy[p * dim * 2 + d + dim]);
+      else v = PetscRealPart(yy[p * dim * 2 + d]);
+      PetscCall(PetscDrawHGAddValue(ctx->hg[s], v));
+    }
+    PetscCall(VecRestoreArrayRead(u, &yy));
+    for (s = 0; s < Ns; ++s) {
+      PetscCall(PetscDrawHGDraw(ctx->hg[s]));
+      PetscCall(PetscDrawHGSave(ctx->hg[s]));
+    }
+    PetscCall(DMSwarmRestoreField(sw, "species", NULL, NULL, (void **)&species));
+  }
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorError - Monitors progress of the `TS` solvers by printing the 2 norm of the error at each timestep
 
-   Collective on ts
+   Collective
 
    Input Parameters:
 +  ts - the `TS` context
@@ -1298,7 +1419,7 @@ PetscErrorCode TSMonitorError(TS ts, PetscInt step, PetscReal ptime, Vec u, Pets
     }
     PetscCall(PetscFree2(exactFuncs, ctxs));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSMonitorLGSNESIterations(TS ts, PetscInt n, PetscReal ptime, Vec v, void *monctx)
@@ -1308,7 +1429,7 @@ PetscErrorCode TSMonitorLGSNESIterations(TS ts, PetscInt n, PetscReal ptime, Vec
   PetscInt       its;
 
   PetscFunctionBegin;
-  if (n < 0) PetscFunctionReturn(0); /* -1 indicates interpolated solution */
+  if (n < 0) PetscFunctionReturn(PETSC_SUCCESS); /* -1 indicates interpolated solution */
   if (!n) {
     PetscDrawAxis axis;
     PetscCall(PetscDrawLGGetAxis(ctx->lg, &axis));
@@ -1324,7 +1445,7 @@ PetscErrorCode TSMonitorLGSNESIterations(TS ts, PetscInt n, PetscReal ptime, Vec
     PetscCall(PetscDrawLGSave(ctx->lg));
   }
   ctx->snes_its = its;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSMonitorLGKSPIterations(TS ts, PetscInt n, PetscReal ptime, Vec v, void *monctx)
@@ -1334,7 +1455,7 @@ PetscErrorCode TSMonitorLGKSPIterations(TS ts, PetscInt n, PetscReal ptime, Vec
   PetscInt       its;
 
   PetscFunctionBegin;
-  if (n < 0) PetscFunctionReturn(0); /* -1 indicates interpolated solution */
+  if (n < 0) PetscFunctionReturn(PETSC_SUCCESS); /* -1 indicates interpolated solution */
   if (!n) {
     PetscDrawAxis axis;
     PetscCall(PetscDrawLGGetAxis(ctx->lg, &axis));
@@ -1350,15 +1471,15 @@ PetscErrorCode TSMonitorLGKSPIterations(TS ts, PetscInt n, PetscReal ptime, Vec
     PetscCall(PetscDrawLGSave(ctx->lg));
   }
   ctx->ksp_its = its;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorEnvelopeCtxCreate - Creates a context for use with `TSMonitorEnvelope()`
 
-   Collective on ts
+   Collective
 
-   Input Parameters:
+   Input Parameter:
 .  ts  - the `TS` solver object
 
    Output Parameter:
@@ -1372,16 +1493,16 @@ PetscErrorCode TSMonitorEnvelopeCtxCreate(TS ts, TSMonitorEnvelopeCtx *ctx)
 {
   PetscFunctionBegin;
   PetscCall(PetscNew(ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorEnvelope - Monitors the maximum and minimum value of each component of the solution
 
-   Collective on ts
+   Collective
 
    Input Parameters:
-+  ts - the TS context
++  ts - the `TS` context
 .  step - current time-step
 .  ptime - current time
 .  u  - current solution
@@ -1414,13 +1535,13 @@ PetscErrorCode TSMonitorEnvelope(TS ts, PetscInt step, PetscReal ptime, Vec u, v
     PetscCall(VecPointwiseMax(ctx->max, u, ctx->max));
     PetscCall(VecPointwiseMin(ctx->min, u, ctx->min));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorEnvelopeGetBounds - Gets the bounds for the components of the solution
 
-   Collective on ts
+   Collective
 
    Input Parameter:
 .  ts - the `TS` context
@@ -1429,11 +1550,11 @@ PetscErrorCode TSMonitorEnvelope(TS ts, PetscInt step, PetscReal ptime, Vec u, v
 +  max - the maximum values
 -  min - the minimum values
 
+   Level: intermediate
+
    Notes:
     If the `TS` does not have a `TSMonitorEnvelopeCtx` associated with it then this function is ignored
 
-   Level: intermediate
-
 .seealso: [](chapter_ts), `TSMonitorEnvelopeCtx`, `TS`, `TSMonitorSet()`, `TSMonitorDefault()`, `VecView()`, `TSMonitorLGSetDisplayVariables()`
 @*/
 PetscErrorCode TSMonitorEnvelopeGetBounds(TS ts, Vec *max, Vec *min)
@@ -1451,13 +1572,13 @@ PetscErrorCode TSMonitorEnvelopeGetBounds(TS ts, Vec *max, Vec *min)
       break;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    TSMonitorEnvelopeCtxDestroy - Destroys a context that was created  with `TSMonitorEnvelopeCtxCreate()`.
 
-   Collective on ctx
+   Collective
 
    Input Parameter:
 .  ctx - the monitor context
@@ -1472,13 +1593,13 @@ PetscErrorCode TSMonitorEnvelopeCtxDestroy(TSMonitorEnvelopeCtx *ctx)
   PetscCall(VecDestroy(&(*ctx)->min));
   PetscCall(VecDestroy(&(*ctx)->max));
   PetscCall(PetscFree(*ctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   TSDMSwarmMonitorMoments - Monitors the first three moments of a `DMSWARM` being evolved by the `TS`
 
-  Not collective
+  Not Collective
 
   Input Parameters:
 + ts   - the `TS` context
@@ -1510,7 +1631,7 @@ PetscErrorCode TSDMSwarmMonitorMoments(TS ts, PetscInt step, PetscReal t, Vec U,
 
   PetscFunctionBeginUser;
   PetscCall(TSGetDM(ts, &sw));
-  if (!sw || step % ts->monitorFrequency != 0) PetscFunctionReturn(0);
+  if (!sw || step % ts->monitorFrequency != 0) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscObjectGetComm((PetscObject)ts, &comm));
   PetscCall(DMGetDimension(sw, &dim));
   PetscCall(VecGetLocalSize(U, &Np));
@@ -1528,5 +1649,5 @@ PetscErrorCode TSDMSwarmMonitorMoments(TS ts, PetscInt step, PetscReal t, Vec U,
   PetscCall(PetscPrintf(comm, "Step %4" PetscInt_FMT " Total Energy: %10.8lf", step, (double)totE));
   for (d = 0; d < dim; ++d) PetscCall(PetscPrintf(comm, "    Total Momentum %c: %10.8lf", (char)('x' + d), (double)totMom[d]));
   PetscCall(PetscPrintf(comm, "\n"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
