@@ -24,7 +24,7 @@ PETSC_EXTERN PetscErrorCode TSCreate_DiscGrad(TS);
 PETSC_EXTERN PetscErrorCode TSCreate_IRK(TS);
 
 /*@C
-  TSRegisterAll - Registers all of the timesteppers in the TS package.
+  TSRegisterAll - Registers all of the timesteppers in the `TS` package.
 
   Not Collective
 
@@ -33,12 +33,12 @@ PETSC_EXTERN PetscErrorCode TSCreate_IRK(TS);
 
   Level: advanced
 
-.seealso: `TSCreate()`, `TSRegister()`, `TSRegisterDestroy()`
+.seealso: [](chapter_ts), `TS`, `TSCreate()`, `TSRegister()`, `TSRegisterDestroy()`
 @*/
 PetscErrorCode TSRegisterAll(void)
 {
   PetscFunctionBegin;
-  if (TSRegisterAllCalled) PetscFunctionReturn(0);
+  if (TSRegisterAllCalled) PetscFunctionReturn(PETSC_SUCCESS);
   TSRegisterAllCalled = PETSC_TRUE;
 
   PetscCall(TSRegister(TSEULER, TSCreate_Euler));
@@ -67,5 +67,5 @@ PetscErrorCode TSRegisterAll(void)
   PetscCall(TSRegister(TSMPRK, TSCreate_MPRK));
   PetscCall(TSRegister(TSDISCGRAD, TSCreate_DiscGrad));
   PetscCall(TSRegister(TSIRK, TSCreate_IRK));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
