@@ -20,7 +20,7 @@ static PetscErrorCode TSTrajectorySet_Singlefile(TSTrajectory tj, TS ts, PetscIn
   }
   PetscCall(VecView(X, sf->viewer));
   PetscCall(PetscViewerBinaryWrite(sf->viewer, &time, 1, PETSC_REAL));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSTrajectoryDestroy_Singlefile(TSTrajectory tj)
@@ -30,16 +30,16 @@ static PetscErrorCode TSTrajectoryDestroy_Singlefile(TSTrajectory tj)
   PetscFunctionBegin;
   PetscCall(PetscViewerDestroy(&sf->viewer));
   PetscCall(PetscFree(sf));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
-      TSTRAJECTORYSINGLEFILE - Stores all solutions of the ODE/ADE into a single file followed by each timestep. Does not save the intermediate stages in a multistage method
+      TSTRAJECTORYSINGLEFILE - Stores all solutions of the ODE/ADE into a single file followed by each timestep.
+      Does not save the intermediate stages in a multistage method
 
   Level: intermediate
 
-.seealso: `TSTrajectoryCreate()`, `TS`, `TSTrajectorySetType()`
-
+.seealso: [](chapter_ts), `TSTrajectoryCreate()`, `TS`, `TSTrajectorySetType()`, `TSTrajectoryType`, `TSTrajectory`
 M*/
 PETSC_EXTERN PetscErrorCode TSTrajectoryCreate_Singlefile(TSTrajectory tj, TS ts)
 {
@@ -52,5 +52,5 @@ PETSC_EXTERN PetscErrorCode TSTrajectoryCreate_Singlefile(TSTrajectory tj, TS ts
   tj->ops->get     = NULL;
   tj->ops->destroy = TSTrajectoryDestroy_Singlefile;
   ts->setupcalled  = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
