@@ -13,8 +13,8 @@ PetscLogEvent     TSTrajectory_Set, TSTrajectory_Get, TSTrajectory_GetVecs, TSTr
   Not Collective
 
   Input Parameters:
-+ name        - the name of a new user-defined creation routine
-- create_func - the creation routine itself
++ sname        - the name of a new user-defined creation routine
+- function - the creation routine itself
 
   Level: developer
 
@@ -27,7 +27,7 @@ PetscErrorCode TSTrajectoryRegister(const char sname[], PetscErrorCode (*functio
 {
   PetscFunctionBegin;
   PetscCall(PetscFunctionListAdd(&TSTrajectoryList, sname, function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -52,7 +52,7 @@ PetscErrorCode TSTrajectoryRegister(const char sname[], PetscErrorCode (*functio
 PetscErrorCode TSTrajectorySet(TSTrajectory tj, TS ts, PetscInt stepnum, PetscReal time, Vec X)
 {
   PetscFunctionBegin;
-  if (!tj) PetscFunctionReturn(0);
+  if (!tj) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
   if (ts) PetscValidHeaderSpecific(ts, TS_CLASSID, 2);
   PetscValidLogicalCollectiveInt(tj, stepnum, 3);
@@ -65,15 +65,15 @@ PetscErrorCode TSTrajectorySet(TSTrajectory tj, TS ts, PetscInt stepnum, PetscRe
   PetscCall(PetscLogEventEnd(TSTrajectory_Set, tj, ts, 0, 0));
   if (tj->usehistory) PetscCall(TSHistoryUpdate(tj->tsh, stepnum, time));
   if (tj->lag.caching) tj->lag.Udotcached.time = PETSC_MIN_REAL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   TSTrajectoryGetNumSteps - Return the number of steps registered in the `TSTrajectory` via `TSTrajectorySet()`.
 
-  Not collective.
+  Not Collective.
 
-  Input Parameters:
+  Input Parameter:
 . tj - the trajectory object
 
   Output Parameter:
@@ -89,7 +89,7 @@ PetscErrorCode TSTrajectoryGetNumSteps(TSTrajectory tj, PetscInt *steps)
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
   PetscValidIntPointer(steps, 2);
   PetscCall(TSHistoryGetNumSteps(tj->tsh, steps));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -129,7 +129,7 @@ PetscErrorCode TSTrajectoryGet(TSTrajectory tj, TS ts, PetscInt stepnum, PetscRe
   PetscCall(PetscLogEventBegin(TSTrajectory_Get, tj, ts, 0, 0));
   PetscUseTypeMethod(tj, get, ts, stepnum, time);
   PetscCall(PetscLogEventEnd(TSTrajectory_Get, tj, ts, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -142,12 +142,10 @@ PetscErrorCode TSTrajectoryGet(TSTrajectory tj, TS ts, PetscInt stepnum, PetscRe
 . ts      - the time stepper object (optional)
 - stepnum - the requested step number
 
-  Input/Output Parameter:
-
   Output Parameters:
 + time - On input time for the step if step number is `PETSC_DECIDE`, on output the time associated with the step number
-. U    - state vector (can be NULL)
-- Udot - time derivative of state vector (can be NULL)
+. U    - state vector (can be `NULL`)
+- Udot - time derivative of state vector (can be `NULL`)
 
   Level: developer
 
@@ -167,7 +165,7 @@ PetscErrorCode TSTrajectoryGetVecs(TSTrajectory tj, TS ts, PetscInt stepnum, Pet
   PetscValidRealPointer(time, 4);
   if (U) PetscValidHeaderSpecific(U, VEC_CLASSID, 5);
   if (Udot) PetscValidHeaderSpecific(Udot, VEC_CLASSID, 6);
-  if (!U && !Udot) PetscFunctionReturn(0);
+  if (!U && !Udot) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheck(tj->setupcalled, PetscObjectComm((PetscObject)tj), PETSC_ERR_ORDER, "TSTrajectorySetUp should be called first");
   PetscCall(PetscLogEventBegin(TSTrajectory_GetVecs, tj, ts, 0, 0));
   if (tj->monitor) {
@@ -215,7 +213,7 @@ PetscErrorCode TSTrajectoryGetVecs(TSTrajectory tj, TS ts, PetscInt stepnum, Pet
   }
   if (!U && !Udot) {
     PetscCall(PetscLogEventEnd(TSTrajectory_GetVecs, tj, ts, 0, 0));
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   if (stepnum == PETSC_DECIDE || Udot) { /* reverse search for requested time in TSHistory */
@@ -251,7 +249,7 @@ PetscErrorCode TSTrajectoryGetVecs(TSTrajectory tj, TS ts, PetscInt stepnum, Pet
     tj->lag.Ucached.step = stepnum;
   }
   PetscCall(PetscLogEventEnd(TSTrajectory_GetVecs, tj, ts, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -273,7 +271,7 @@ PetscErrorCode TSTrajectoryViewFromOptions(TSTrajectory A, PetscObject obj, cons
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A, TSTRAJECTORY_CLASSID, 1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)A, obj, name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -323,7 +321,7 @@ PetscErrorCode TSTrajectoryView(TSTrajectory tj, PetscViewer viewer)
     PetscTryTypeMethod(tj, view, viewer);
     PetscCall(PetscViewerASCIIPopTab(viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -349,7 +347,7 @@ PetscErrorCode TSTrajectorySetVariableNames(TSTrajectory ctx, const char *const
   PetscValidPointer(names, 2);
   PetscCall(PetscStrArrayDestroy(&ctx->names));
   PetscCall(PetscStrArrayallocpy(names, &ctx->names));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -374,7 +372,7 @@ PetscErrorCode TSTrajectorySetTransform(TSTrajectory tj, PetscErrorCode (*transf
   tj->transform        = transform;
   tj->transformdestroy = destroy;
   tj->transformctx     = tctx;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -430,7 +428,7 @@ PetscErrorCode TSTrajectoryCreate(MPI_Comm comm, TSTrajectory *tj)
   t->usehistory           = PETSC_TRUE;
   *tj                     = t;
   PetscCall(TSTrajectorySetFiletemplate(t, "TS-%06" PetscInt_FMT ".bin"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -451,7 +449,7 @@ PetscErrorCode TSTrajectoryCreate(MPI_Comm comm, TSTrajectory *tj)
   Developer Note:
   Why does this option require access to the `TS`
 
-.seealso: [](chapter_ts),  `TSTrajectory`, `TS`, `TSTrajectoryCreate()`, `TSTrajectorySetFromOptions()`, `TSTrajectoryDestroy()`, `TSTrajectoryGetType()`
+.seealso: [](chapter_ts), `TSTrajectory`, `TS`, `TSTrajectoryCreate()`, `TSTrajectorySetFromOptions()`, `TSTrajectoryDestroy()`, `TSTrajectoryGetType()`
 @*/
 PetscErrorCode TSTrajectorySetType(TSTrajectory tj, TS ts, TSTrajectoryType type)
 {
@@ -461,7 +459,7 @@ PetscErrorCode TSTrajectorySetType(TSTrajectory tj, TS ts, TSTrajectoryType type
   PetscFunctionBegin;
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)tj, type, &match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscFunctionListFind(TSTrajectoryList, type, &r));
   PetscCheck(r, PETSC_COMM_SELF, PETSC_ERR_ARG_UNKNOWN_TYPE, "Unknown TSTrajectory type: %s", type);
@@ -474,7 +472,7 @@ PetscErrorCode TSTrajectorySetType(TSTrajectory tj, TS ts, TSTrajectoryType type
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)tj, type));
   PetscCall((*r)(tj, ts));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -486,7 +484,7 @@ PetscErrorCode TSTrajectorySetType(TSTrajectory tj, TS ts, TSTrajectoryType type
 + tj   - the `TSTrajectory` context
 - ts   - the `TS` context
 
-  Output Parameters:
+  Output Parameter:
 . type - a known method
 
   Level: developer
@@ -498,7 +496,7 @@ PetscErrorCode TSTrajectoryGetType(TSTrajectory tj, TS ts, TSTrajectoryType *typ
   PetscFunctionBegin;
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
   if (type) *type = ((PetscObject)tj)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PETSC_EXTERN PetscErrorCode TSTrajectoryCreate_Basic(TSTrajectory, TS);
@@ -518,14 +516,14 @@ PETSC_EXTERN PetscErrorCode TSTrajectoryCreate_Visualization(TSTrajectory, TS);
 PetscErrorCode TSTrajectoryRegisterAll(void)
 {
   PetscFunctionBegin;
-  if (TSTrajectoryRegisterAllCalled) PetscFunctionReturn(0);
+  if (TSTrajectoryRegisterAllCalled) PetscFunctionReturn(PETSC_SUCCESS);
   TSTrajectoryRegisterAllCalled = PETSC_TRUE;
 
   PetscCall(TSTrajectoryRegister(TSTRAJECTORYBASIC, TSTrajectoryCreate_Basic));
   PetscCall(TSTrajectoryRegister(TSTRAJECTORYSINGLEFILE, TSTrajectoryCreate_Singlefile));
   PetscCall(TSTrajectoryRegister(TSTRAJECTORYMEMORY, TSTrajectoryCreate_Memory));
   PetscCall(TSTrajectoryRegister(TSTRAJECTORYVISUALIZATION, TSTrajectoryCreate_Visualization));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -543,14 +541,14 @@ PetscErrorCode TSTrajectoryRegisterAll(void)
 PetscErrorCode TSTrajectoryReset(TSTrajectory tj)
 {
   PetscFunctionBegin;
-  if (!tj) PetscFunctionReturn(0);
+  if (!tj) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
   PetscTryTypeMethod(tj, reset);
   PetscCall(PetscFree(tj->dirfiletemplate));
   PetscCall(TSHistoryDestroy(&tj->tsh));
   PetscCall(TSHistoryCreate(PetscObjectComm((PetscObject)tj), &tj->tsh));
   tj->setupcalled = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -568,11 +566,11 @@ PetscErrorCode TSTrajectoryReset(TSTrajectory tj)
 PetscErrorCode TSTrajectoryDestroy(TSTrajectory *tj)
 {
   PetscFunctionBegin;
-  if (!*tj) PetscFunctionReturn(0);
+  if (!*tj) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific((*tj), TSTRAJECTORY_CLASSID, 1);
   if (--((PetscObject)(*tj))->refct > 0) {
     *tj = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(TSTrajectoryReset(*tj));
@@ -598,7 +596,7 @@ PetscErrorCode TSTrajectoryDestroy(TSTrajectory *tj)
   PetscCall(PetscFree((*tj)->dirname));
   PetscCall(PetscFree((*tj)->filetemplate));
   PetscCall(PetscHeaderDestroy(tj));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -634,7 +632,7 @@ static PetscErrorCode TSTrajectorySetTypeFromOptions_Private(PetscOptionItems *P
   } else {
     PetscCall(TSTrajectorySetType(tj, ts, defaultType));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -659,7 +657,7 @@ PetscErrorCode TSTrajectorySetUseHistory(TSTrajectory tj, PetscBool flg)
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
   PetscValidLogicalCollectiveBool(tj, flg, 2);
   tj->usehistory = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -685,7 +683,7 @@ PetscErrorCode TSTrajectorySetMonitor(TSTrajectory tj, PetscBool flg)
   PetscValidLogicalCollectiveBool(tj, flg, 2);
   if (flg) tj->monitor = PETSC_VIEWER_STDOUT_(PetscObjectComm((PetscObject)tj));
   else tj->monitor = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -713,7 +711,7 @@ PetscErrorCode TSTrajectorySetKeepFiles(TSTrajectory tj, PetscBool flg)
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
   PetscValidLogicalCollectiveBool(tj, flg, 2);
   tj->keepfiles = flg;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -747,7 +745,7 @@ PetscErrorCode TSTrajectorySetDirname(TSTrajectory tj, const char dirname[])
   PetscCheck(flg || !tj->dirfiletemplate, PetscObjectComm((PetscObject)tj), PETSC_ERR_ARG_WRONGSTATE, "Cannot set directoryname after TSTrajectory has been setup");
   PetscCall(PetscFree(tj->dirname));
   PetscCall(PetscStrallocpy(dirname, &tj->dirname));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -774,7 +772,7 @@ PetscErrorCode TSTrajectorySetDirname(TSTrajectory tj, const char dirname[])
 @*/
 PetscErrorCode TSTrajectorySetFiletemplate(TSTrajectory tj, const char filetemplate[])
 {
-  const char *ptr, *ptr2;
+  const char *ptr = NULL, *ptr2 = NULL;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
@@ -792,7 +790,7 @@ PetscErrorCode TSTrajectorySetFiletemplate(TSTrajectory tj, const char filetempl
   }
   PetscCall(PetscFree(tj->filetemplate));
   PetscCall(PetscStrallocpy(filetemplate, &tj->filetemplate));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -845,7 +843,7 @@ PetscErrorCode TSTrajectorySetFromOptions(TSTrajectory tj, TS ts)
   /* Handle specific TSTrajectory options */
   PetscTryTypeMethod(tj, setfromoptions, PetscOptionsObject);
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -867,10 +865,10 @@ PetscErrorCode TSTrajectorySetUp(TSTrajectory tj, TS ts)
   size_t s1, s2;
 
   PetscFunctionBegin;
-  if (!tj) PetscFunctionReturn(0);
+  if (!tj) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
   if (ts) PetscValidHeaderSpecific(ts, TS_CLASSID, 2);
-  if (tj->setupcalled) PetscFunctionReturn(0);
+  if (tj->setupcalled) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PetscLogEventBegin(TSTrajectory_SetUp, tj, ts, 0, 0));
   if (!((PetscObject)tj)->type_name) PetscCall(TSTrajectorySetType(tj, ts, TSTRAJECTORYBASIC));
@@ -888,7 +886,7 @@ PetscErrorCode TSTrajectorySetUp(TSTrajectory tj, TS ts)
   PetscCall(PetscMalloc((s1 + s2 + 10) * sizeof(char), &tj->dirfiletemplate));
   PetscCall(PetscSNPrintf(tj->dirfiletemplate, s1 + s2 + 10, "%s/%s", tj->dirname, tj->filetemplate));
   PetscCall(PetscLogEventEnd(TSTrajectory_SetUp, tj, ts, 0, 0));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -910,13 +908,13 @@ PetscErrorCode TSTrajectorySetSolutionOnly(TSTrajectory tj, PetscBool solution_o
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
   PetscValidLogicalCollectiveBool(tj, solution_only, 2);
   tj->solution_only = solution_only;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    TSTrajectoryGetSolutionOnly - Gets the value set with `TSTrajectorySetSolutionOnly()`.
 
-   Logically collective
+   Logically Collective
 
    Input Parameter:
 .  tj  - the `TSTrajectory` context
@@ -934,7 +932,7 @@ PetscErrorCode TSTrajectoryGetSolutionOnly(TSTrajectory tj, PetscBool *solution_
   PetscValidHeaderSpecific(tj, TSTRAJECTORY_CLASSID, 1);
   PetscValidBoolPointer(solution_only, 2);
   *solution_only = tj->solution_only;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -990,7 +988,7 @@ PetscErrorCode TSTrajectoryGetUpdatedHistoryVecs(TSTrajectory tj, TS ts, PetscRe
     PetscCall(VecLockReadPush(tj->Udot));
     *Udot = tj->Udot;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -1023,5 +1021,5 @@ PetscErrorCode TSTrajectoryRestoreUpdatedHistoryVecs(TSTrajectory tj, Vec *U, Ve
     PetscCall(VecLockReadPop(tj->Udot));
     *Udot = NULL;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
