@@ -47,7 +47,7 @@ static PetscErrorCode ProcessOptions(MPI_Comm comm, AppCtx *options)
   options->bdm              = PETSC_FALSE;
 
   PetscOptionsBegin(comm, "", "Two Stream options", "DMPLEX");
-  PetscCall(PetscStrcpy(options->meshFilename, ""));
+  PetscCall(PetscStrncpy(options->meshFilename, "", sizeof(options->meshFilename)));
   PetscCall(PetscOptionsInt("-dim", "The topological mesh dimension", "ex2.c", options->dim, &options->dim, NULL));
   PetscCall(PetscOptionsInt("-steps", "TS steps to take", "ex2.c", options->steps, &options->steps, NULL));
   PetscCall(PetscOptionsBool("-monitor", "To use the TS monitor or not", "ex2.c", options->monitor, &options->monitor, NULL));
@@ -57,12 +57,12 @@ static PetscErrorCode ProcessOptions(MPI_Comm comm, AppCtx *options)
   PetscCall(PetscOptionsString("-mesh", "Name of the mesh filename if any", "ex2.c", options->meshFilename, options->meshFilename, PETSC_MAX_PATH_LEN, NULL));
   PetscCall(PetscOptionsInt("-k", "Mode number of test", "ex5.c", options->k, &options->k, NULL));
   PetscCall(PetscOptionsInt("-particlesPerCell", "Number of particles per cell", "ex2.c", options->particlesPerCell, &options->particlesPerCell, NULL));
-  PetscCall(PetscOptionsReal("-sigma", "parameter", "<1>", options->sigma, &options->sigma, PETSC_NULL));
-  PetscCall(PetscOptionsReal("-stepSize", "parameter", "<1e-2>", options->stepSize, &options->stepSize, PETSC_NULL));
-  PetscCall(PetscOptionsReal("-timeScale", "parameter", "<1>", options->timeScale, &options->timeScale, PETSC_NULL));
+  PetscCall(PetscOptionsReal("-sigma", "parameter", "<1>", options->sigma, &options->sigma, NULL));
+  PetscCall(PetscOptionsReal("-stepSize", "parameter", "<1e-2>", options->stepSize, &options->stepSize, NULL));
+  PetscCall(PetscOptionsReal("-timeScale", "parameter", "<1>", options->timeScale, &options->timeScale, NULL));
   PetscCall(PetscOptionsReal("-particle_perturbation", "Relative perturbation of particles (0,1)", "ex2.c", options->particleRelDx, &options->particleRelDx, NULL));
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode CreateMesh(MPI_Comm comm, DM *dm, AppCtx *user)
@@ -72,7 +72,7 @@ static PetscErrorCode CreateMesh(MPI_Comm comm, DM *dm, AppCtx *user)
   PetscCall(DMSetType(*dm, DMPLEX));
   PetscCall(DMSetFromOptions(*dm));
   PetscCall(DMViewFromOptions(*dm, NULL, "-dm_view"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static void laplacian_f1(PetscInt dim, PetscInt Nf, PetscInt NfAux, const PetscInt uOff[], const PetscInt uOff_x[], const PetscScalar u[], const PetscScalar u_t[], const PetscScalar u_x[], const PetscInt aOff[], const PetscInt aOff_x[], const PetscScalar a[], const PetscScalar a_t[], const PetscScalar a_x[], PetscReal t, const PetscReal x[], PetscInt numConstants, const PetscScalar constants[], PetscScalar f1[])
@@ -108,7 +108,7 @@ static PetscErrorCode CreateFEM(DM dm, AppCtx *user)
   PetscCall(DMGetDS(dm, &ds));
   PetscCall(PetscDSSetResidual(ds, 0, NULL, laplacian_f1));
   PetscCall(PetscDSSetJacobian(ds, 0, 0, NULL, NULL, NULL, laplacian));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -196,7 +196,7 @@ static PetscErrorCode CreateParticles(DM dm, DM *sw, AppCtx *user)
   PetscCall(PetscObjectSetName((PetscObject)*sw, "Particles"));
   PetscCall(DMViewFromOptions(*sw, NULL, "-sw_view"));
   PetscCall(DMLocalizeCoordinates(*sw));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* Solve for particle position updates */
@@ -219,7 +219,7 @@ static PetscErrorCode RHSFunction1(TS ts, PetscReal t, Vec V, Vec Posres, void *
   }
   PetscCall(VecRestoreArrayRead(V, &v));
   PetscCall(VecRestoreArray(Posres, &posres));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*
@@ -240,8 +240,8 @@ static PetscErrorCode RHSFunction2(TS ts, PetscReal t, Vec X, Vec Vres, void *ct
   PetscReal          m_e = 9.11e-31, q_e = 1.60e-19, epsi_0 = 8.85e-12;
 
   PetscFunctionBeginUser;
-  PetscObjectSetName((PetscObject)X, "rhsf2 position");
-  VecViewFromOptions(X, NULL, "-rhsf2_x_view");
+  PetscCall(PetscObjectSetName((PetscObject)X, "rhsf2 position"));
+  PetscCall(VecViewFromOptions(X, NULL, "-rhsf2_x_view"));
   PetscCall(VecGetArrayRead(X, &x));
   PetscCall(VecGetArray(Vres, &vres));
   PetscCall(TSGetDM(ts, &dm));
@@ -289,10 +289,10 @@ static PetscErrorCode RHSFunction2(TS ts, PetscReal t, Vec X, Vec Vres, void *ct
   for (cell = cStart; cell < cEnd; ++cell) {
     PetscTabulation tab;
     PetscReal       v[3], J[9], invJ[9], detJ;
-    PetscScalar    *ph       = PETSC_NULL;
-    PetscReal      *pcoord   = PETSC_NULL;
-    PetscReal      *refcoord = PETSC_NULL;
-    PetscInt       *points   = PETSC_NULL, Ncp, cp;
+    PetscScalar    *ph       = NULL;
+    PetscReal      *pcoord   = NULL;
+    PetscReal      *refcoord = NULL;
+    PetscInt       *points   = NULL, Ncp, cp;
     PetscScalar     gradPhi[3];
 
     PetscCall(DMPlexComputeCellGeometryFEM(plex, cell, NULL, v, J, invJ, &detJ));
@@ -328,7 +328,7 @@ static PetscErrorCode RHSFunction2(TS ts, PetscReal t, Vec X, Vec Vres, void *ct
   PetscCall(VecRestoreArray(Vres, &vres));
   PetscCall(VecRestoreArrayRead(X, &x));
   PetscCall(VecViewFromOptions(Vres, NULL, "-vel_res_view"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 int main(int argc, char **argv)
@@ -404,7 +404,7 @@ int main(int argc, char **argv)
 
     PetscCall(ISCreateGeneral(comm, locSize, idx1, PETSC_OWN_POINTER, &is1));
     PetscCall(ISCreateGeneral(comm, locSize, idx2, PETSC_OWN_POINTER, &is2));
-    /* DM needs to be set before splits so it propogates to sub TSs */
+    /* DM needs to be set before splits so it propagates to sub TSs */
     PetscCall(TSSetDM(ts, sw));
     PetscCall(TSSetType(ts, TSBASICSYMPLECTIC));
     PetscCall(TSRHSSplitSetIS(ts, "position", is1));
@@ -431,7 +431,7 @@ int main(int argc, char **argv)
     PetscCall(TSStep(ts));
     if (ts->steprollback) PetscCall(TSPostEvaluate(ts));
     if (!ts->steprollback) {
-      TSPostStep(ts);
+      PetscCall(TSPostStep(ts));
       PetscCall(DMSwarmGetField(sw, DMSwarmPICField_coor, NULL, NULL, (void **)&coor));
       PetscCall(DMSwarmGetField(sw, "kinematics", NULL, NULL, (void **)&kin));
       PetscCall(TSGetSolution(ts, &solution));
