@@ -21,7 +21,7 @@ static PetscErrorCode DMTSDestroy_DMDA(DMTS sdm)
 {
   PetscFunctionBegin;
   PetscCall(PetscFree(sdm->data));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMTSDuplicate_DMDA(DMTS oldsdm, DMTS sdm)
@@ -29,7 +29,7 @@ static PetscErrorCode DMTSDuplicate_DMDA(DMTS oldsdm, DMTS sdm)
   PetscFunctionBegin;
   PetscCall(PetscNew((DMTS_DA **)&sdm->data));
   if (oldsdm->data) PetscCall(PetscMemcpy(sdm->data, oldsdm->data, sizeof(DMTS_DA)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMDATSGetContext(DM dm, DMTS sdm, DMTS_DA **dmdats)
@@ -42,7 +42,7 @@ static PetscErrorCode DMDATSGetContext(DM dm, DMTS sdm, DMTS_DA **dmdats)
     sdm->ops->duplicate = DMTSDuplicate_DMDA;
   }
   *dmdats = (DMTS_DA *)sdm->data;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSComputeIFunction_DMDA(TS ts, PetscReal ptime, Vec X, Vec Xdot, Vec F, void *ctx)
@@ -97,7 +97,7 @@ static PetscErrorCode TSComputeIFunction_DMDA(TS ts, PetscReal ptime, Vec X, Vec
   PetscCall(DMRestoreLocalVector(dm, &Xloc));
   PetscCall(DMDAVecRestoreArray(dm, Xdotloc, &xdot));
   PetscCall(DMRestoreLocalVector(dm, &Xdotloc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSComputeIJacobian_DMDA(TS ts, PetscReal ptime, Vec X, Vec Xdot, PetscReal shift, Mat A, Mat B, void *ctx)
@@ -131,7 +131,7 @@ static PetscErrorCode TSComputeIJacobian_DMDA(TS ts, PetscReal ptime, Vec X, Vec
     PetscCall(MatAssemblyBegin(A, MAT_FINAL_ASSEMBLY));
     PetscCall(MatAssemblyEnd(A, MAT_FINAL_ASSEMBLY));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSComputeRHSFunction_DMDA(TS ts, PetscReal ptime, Vec X, Vec F, void *ctx)
@@ -180,7 +180,7 @@ static PetscErrorCode TSComputeRHSFunction_DMDA(TS ts, PetscReal ptime, Vec X, V
   }
   PetscCall(DMDAVecRestoreArray(dm, Xloc, &x));
   PetscCall(DMRestoreLocalVector(dm, &Xloc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSComputeRHSJacobian_DMDA(TS ts, PetscReal ptime, Vec X, Mat A, Mat B, void *ctx)
@@ -212,25 +212,23 @@ static PetscErrorCode TSComputeRHSJacobian_DMDA(TS ts, PetscReal ptime, Vec X, M
     PetscCall(MatAssemblyBegin(A, MAT_FINAL_ASSEMBLY));
     PetscCall(MatAssemblyEnd(A, MAT_FINAL_ASSEMBLY));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   DMDATSSetRHSFunctionLocal - set a local residual evaluation function
+   DMDATSSetRHSFunctionLocal - set a local residual evaluation function for use with `DMDA`
 
    Logically Collective
 
    Input Parameters:
-+  dm - DM to associate callback with
++  dm - `DM` to associate callback with
 .  imode - insert mode for the residual
 .  func - local residual evaluation
 -  ctx - optional context for local residual evaluation
 
-   Calling sequence for func:
-
-$ func(DMDALocalInfo info,PetscReal t,void *x,void *f,void *ctx)
-
-+  info - DMDALocalInfo defining the subdomain to evaluate the residual on
+   Calling sequence of `func`:
+$ PetscErrorCode func(DMDALocalInfo *info, PetscReal t, void *x, void *f, void *ctx)
++  info - defines the subdomain to evaluate the residual on
 .  t - time at which to evaluate residual
 .  x - array of local state information
 .  f - output array of local residual information
@@ -238,7 +236,7 @@ $ func(DMDALocalInfo info,PetscReal t,void *x,void *f,void *ctx)
 
    Level: beginner
 
-.seealso: `DMTSSetRHSFunction()`, `DMDATSSetRHSJacobianLocal()`, `DMDASNESSetFunctionLocal()`
+.seealso: [](chapter_ts), `DMDA`, `TS`, `TSSetRHSFunction()`, `DMTSSetRHSFunction()`, `DMDATSSetRHSJacobianLocal()`, `DMDASNESSetFunctionLocal()`
 @*/
 PetscErrorCode DMDATSSetRHSFunctionLocal(DM dm, InsertMode imode, DMDATSRHSFunctionLocal func, void *ctx)
 {
@@ -253,33 +251,31 @@ PetscErrorCode DMDATSSetRHSFunctionLocal(DM dm, InsertMode imode, DMDATSRHSFunct
   dmdats->rhsfunctionlocal      = func;
   dmdats->rhsfunctionlocalctx   = ctx;
   PetscCall(DMTSSetRHSFunction(dm, TSComputeRHSFunction_DMDA, dmdats));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   DMDATSSetRHSJacobianLocal - set a local residual evaluation function
+   DMDATSSetRHSJacobianLocal - set a local residual evaluation function for use with `DMDA`
 
    Logically Collective
 
    Input Parameters:
-+  dm    - DM to associate callback with
++  dm    - `DM` to associate callback with
 .  func  - local RHS Jacobian evaluation routine
 -  ctx   - optional context for local jacobian evaluation
 
-   Calling sequence for func:
-
-$ func(DMDALocalInfo* info,PetscReal t,void* x,Mat J,Mat B,void *ctx);
-
-+  info - DMDALocalInfo defining the subdomain to evaluate the residual on
+   Calling sequence of `func`:
+$ PetscErrorCode func(DMDALocalInfo *info, PetscReal t, void* x, Mat J, Mat B, void *ctx)
++  info - defines the subdomain to evaluate the residual on
 .  t    - time at which to evaluate residual
 .  x    - array of local state information
 .  J    - Jacobian matrix
-.  B    - preconditioner matrix; often same as J
+.  B    - preconditioner matrix; often same as `J`
 -  ctx  - optional context passed above
 
    Level: beginner
 
-.seealso: `DMTSSetRHSJacobian()`, `DMDATSSetRHSFunctionLocal()`, `DMDASNESSetJacobianLocal()`
+.seealso: [](chapter_ts), `DMDA`, `DMTSSetRHSJacobian()`, `DMDATSSetRHSFunctionLocal()`, `DMDASNESSetJacobianLocal()`
 @*/
 PetscErrorCode DMDATSSetRHSJacobianLocal(DM dm, DMDATSRHSJacobianLocal func, void *ctx)
 {
@@ -293,21 +289,22 @@ PetscErrorCode DMDATSSetRHSJacobianLocal(DM dm, DMDATSRHSJacobianLocal func, voi
   dmdats->rhsjacobianlocal    = func;
   dmdats->rhsjacobianlocalctx = ctx;
   PetscCall(DMTSSetRHSJacobian(dm, TSComputeRHSJacobian_DMDA, dmdats));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   DMDATSSetIFunctionLocal - set a local residual evaluation function
+   DMDATSSetIFunctionLocal - set a local residual evaluation function for use with `DMDA`
 
    Logically Collective
 
    Input Parameters:
-+  dm   - DM to associate callback with
++  dm   - `DM` to associate callback with
 .  func - local residual evaluation
 -  ctx  - optional context for local residual evaluation
 
-   Calling sequence for func:
-+  info - DMDALocalInfo defining the subdomain to evaluate the residual on
+   Calling sequence of `func`:
+$  PetscErrorCode func(DMDALocalInfo *info, PetscReal t, Vec x, Vec xdot, Vec f, void *ctx)
++  info - defines the subdomain to evaluate the residual on
 .  t    - time at which to evaluate residual
 .  x    - array of local state information
 .  xdot - array of local time derivative information
@@ -316,7 +313,7 @@ PetscErrorCode DMDATSSetRHSJacobianLocal(DM dm, DMDATSRHSJacobianLocal func, voi
 
    Level: beginner
 
-.seealso: `DMTSSetIFunction()`, `DMDATSSetIJacobianLocal()`, `DMDASNESSetFunctionLocal()`
+.seealso: [](chapter_ts), `DMDA`, `DMTSSetIFunction()`, `DMDATSSetIJacobianLocal()`, `DMDASNESSetFunctionLocal()`
 @*/
 PetscErrorCode DMDATSSetIFunctionLocal(DM dm, InsertMode imode, DMDATSIFunctionLocal func, void *ctx)
 {
@@ -331,35 +328,33 @@ PetscErrorCode DMDATSSetIFunctionLocal(DM dm, InsertMode imode, DMDATSIFunctionL
   dmdats->ifunctionlocal      = func;
   dmdats->ifunctionlocalctx   = ctx;
   PetscCall(DMTSSetIFunction(dm, TSComputeIFunction_DMDA, dmdats));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   DMDATSSetIJacobianLocal - set a local residual evaluation function
+   DMDATSSetIJacobianLocal - set a local residual evaluation function for use with `DMDA`
 
    Logically Collective
 
    Input Parameters:
-+  dm   - DM to associate callback with
++  dm   - `DM` to associate callback with
 .  func - local residual evaluation
 -  ctx   - optional context for local residual evaluation
 
-   Calling sequence for func:
-
-$ func(DMDALocalInfo* info,PetscReal t,void* x,void *xdot,PetscScalar shift,Mat J,Mat B,void *ctx);
-
-+  info - DMDALocalInfo defining the subdomain to evaluate the residual on
+   Calling sequence of `func`:
+$ PetscErrorCode func(DMDALocalInfo *info, PetscReal t, void* x, void *xdot, PetscScalar shift, Mat J, Mat B, void *ctx)
++  info - defines the subdomain to evaluate the residual on
 .  t    - time at which to evaluate the jacobian
 .  x    - array of local state information
 .  xdot - time derivative at this state
-.  shift - see TSSetIJacobian() for the meaning of this parameter
+.  shift - see `TSSetIJacobian()` for the meaning of this parameter
 .  J    - Jacobian matrix
-.  B    - preconditioner matrix; often same as J
+.  B    - preconditioner matrix; often same as `J`
 -  ctx  - optional context passed above
 
    Level: beginner
 
-.seealso: `DMTSSetJacobian()`, `DMDATSSetIFunctionLocal()`, `DMDASNESSetJacobianLocal()`
+.seealso: [](chapter_ts), `DMDA`, `DMTSSetJacobian()`, `DMDATSSetIFunctionLocal()`, `DMDASNESSetJacobianLocal()`
 @*/
 PetscErrorCode DMDATSSetIJacobianLocal(DM dm, DMDATSIJacobianLocal func, void *ctx)
 {
@@ -373,7 +368,7 @@ PetscErrorCode DMDATSSetIJacobianLocal(DM dm, DMDATSIJacobianLocal func, void *c
   dmdats->ijacobianlocal    = func;
   dmdats->ijacobianlocalctx = ctx;
   PetscCall(DMTSSetIJacobian(dm, TSComputeIJacobian_DMDA, dmdats));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSMonitorDMDARayDestroy(void **mctx)
@@ -386,7 +381,7 @@ PetscErrorCode TSMonitorDMDARayDestroy(void **mctx)
   PetscCall(VecScatterDestroy(&rayctx->scatter));
   PetscCall(PetscViewerDestroy(&rayctx->viewer));
   PetscCall(PetscFree(rayctx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSMonitorDMDARay(TS ts, PetscInt steps, PetscReal time, Vec u, void *mctx)
@@ -399,7 +394,7 @@ PetscErrorCode TSMonitorDMDARay(TS ts, PetscInt steps, PetscReal time, Vec u, vo
   PetscCall(VecScatterBegin(rayctx->scatter, solution, rayctx->ray, INSERT_VALUES, SCATTER_FORWARD));
   PetscCall(VecScatterEnd(rayctx->scatter, solution, rayctx->ray, INSERT_VALUES, SCATTER_FORWARD));
   if (rayctx->viewer) PetscCall(VecView(rayctx->ray, rayctx->viewer));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode TSMonitorLGDMDARay(TS ts, PetscInt step, PetscReal ptime, Vec u, void *ctx)
@@ -441,5 +436,5 @@ PetscErrorCode TSMonitorLGDMDARay(TS ts, PetscInt step, PetscReal ptime, Vec u,
     PetscCall(PetscDrawLGDraw(lgctx->lg));
     PetscCall(PetscDrawLGSave(lgctx->lg));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
