@@ -19,7 +19,7 @@ static PetscErrorCode DMTSDestroy_DMLocal(DMTS tdm)
 {
   PetscFunctionBegin;
   PetscCall(PetscFree(tdm->data));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMTSDuplicate_DMLocal(DMTS oldtdm, DMTS tdm)
@@ -27,7 +27,7 @@ static PetscErrorCode DMTSDuplicate_DMLocal(DMTS oldtdm, DMTS tdm)
   PetscFunctionBegin;
   PetscCall(PetscNew((DMTS_Local **)&tdm->data));
   if (oldtdm->data) PetscCall(PetscMemcpy(tdm->data, oldtdm->data, sizeof(DMTS_Local)));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode DMLocalTSGetContext(DM dm, DMTS tdm, DMTS_Local **dmlocalts)
@@ -41,7 +41,7 @@ static PetscErrorCode DMLocalTSGetContext(DM dm, DMTS tdm, DMTS_Local **dmlocalt
     tdm->ops->duplicate = DMTSDuplicate_DMLocal;
   }
   *dmlocalts = (DMTS_Local *)tdm->data;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSComputeIFunction_DMLocal(TS ts, PetscReal time, Vec X, Vec X_t, Vec F, void *ctx)
@@ -76,7 +76,7 @@ static PetscErrorCode TSComputeIFunction_DMLocal(TS ts, PetscReal time, Vec X, V
   PetscCall(DMRestoreLocalVector(dm, &locX));
   PetscCall(DMRestoreLocalVector(dm, &locX_t));
   PetscCall(DMRestoreLocalVector(dm, &locF));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSComputeRHSFunction_DMLocal(TS ts, PetscReal time, Vec X, Vec F, void *ctx)
@@ -115,7 +115,7 @@ static PetscErrorCode TSComputeRHSFunction_DMLocal(TS ts, PetscReal time, Vec X,
   }
   PetscCall(DMRestoreLocalVector(dm, &locX));
   PetscCall(DMRestoreLocalVector(dm, &locF));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode TSComputeIJacobian_DMLocal(TS ts, PetscReal time, Vec X, Vec X_t, PetscReal a, Mat A, Mat B, void *ctx)
@@ -178,7 +178,7 @@ static PetscErrorCode TSComputeIJacobian_DMLocal(TS ts, PetscReal time, Vec X, V
     PetscCall(MatAssemblyBegin(A, MAT_FINAL_ASSEMBLY));
     PetscCall(MatAssemblyEnd(A, MAT_FINAL_ASSEMBLY));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -186,10 +186,6 @@ static PetscErrorCode TSComputeIJacobian_DMLocal(TS ts, PetscReal time, Vec X, V
     It should set the essential boundary data for the local portion of the solution X, as well its time derivative X_t (if it is not NULL).
     Vectors are initialized to zero before this function, so it is only needed for non homogeneous data.
 
-  Note that this function is somewhat optional: boundary data could potentially be inserted by a function passed to
-  `DMTSSetIFunctionLocal()`.  The use case for this function is for discretizations with constraints (see
-  `DMGetDefaultConstraints()`): this function inserts boundary values before constraint interpolation.
-
   Logically Collective
 
   Input Parameters:
@@ -199,6 +195,11 @@ static PetscErrorCode TSComputeIJacobian_DMLocal(TS ts, PetscReal time, Vec X, V
 
   Level: intermediate
 
+  Note:
+  This function is somewhat optional: boundary data could potentially be inserted by a function passed to
+  `DMTSSetIFunctionLocal()`.  The use case for this function is for discretizations with constraints (see
+  `DMGetDefaultConstraints()`): this function inserts boundary values before constraint interpolation.
+
 .seealso: [](chapter_ts), `DM`, `TS`, `DMTSSetIFunction()`, `DMTSSetIJacobianLocal()`
 @*/
 PetscErrorCode DMTSSetBoundaryLocal(DM dm, PetscErrorCode (*func)(DM, PetscReal, Vec, Vec, void *), void *ctx)
@@ -214,7 +215,7 @@ PetscErrorCode DMTSSetBoundaryLocal(DM dm, PetscErrorCode (*func)(DM, PetscReal,
   dmlocalts->boundarylocal    = func;
   dmlocalts->boundarylocalctx = ctx;
 
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -233,7 +234,7 @@ PetscErrorCode DMTSSetBoundaryLocal(DM dm, PetscErrorCode (*func)(DM, PetscReal,
 
   Level: beginner
 
-.seealso: [](chapter_ts), `DM`, `DMTSSetIFunctionLocal(()`, `DMTSSetIFunction()`, `DMTSSetIJacobianLocal()`
+.seealso: [](chapter_ts), `DM`, `DMTSSetIFunctionLocal()`, `DMTSSetIFunction()`, `DMTSSetIJacobianLocal()`
 @*/
 PetscErrorCode DMTSGetIFunctionLocal(DM dm, PetscErrorCode (**func)(DM, PetscReal, Vec, Vec, Vec, void *), void **ctx)
 {
@@ -255,7 +256,7 @@ PetscErrorCode DMTSGetIFunctionLocal(DM dm, PetscErrorCode (**func)(DM, PetscRea
     PetscValidPointer(ctx, 3);
     *ctx = dmlocalts->ifunctionlocalctx;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -291,7 +292,7 @@ PetscErrorCode DMTSSetIFunctionLocal(DM dm, PetscErrorCode (*func)(DM, PetscReal
   if (!tdm->ops->ijacobian) { /* Call us for the Jacobian too, can be overridden by the user. */
     PetscCall(DMTSSetIJacobian(dm, TSComputeIJacobian_DMLocal, dmlocalts));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -330,7 +331,7 @@ PetscErrorCode DMTSGetIJacobianLocal(DM dm, PetscErrorCode (**func)(DM, PetscRea
     PetscValidPointer(ctx, 3);
     *ctx = dmlocalts->ijacobianlocalctx;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -361,7 +362,7 @@ PetscErrorCode DMTSSetIJacobianLocal(DM dm, PetscErrorCode (*func)(DM, PetscReal
   dmlocalts->ijacobianlocalctx = ctx;
 
   PetscCall(DMTSSetIJacobian(dm, TSComputeIJacobian_DMLocal, dmlocalts));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -402,7 +403,7 @@ PetscErrorCode DMTSGetRHSFunctionLocal(DM dm, PetscErrorCode (**func)(DM, PetscR
     PetscValidPointer(ctx, 3);
     *ctx = dmlocalts->rhsfunctionlocalctx;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -435,15 +436,15 @@ PetscErrorCode DMTSSetRHSFunctionLocal(DM dm, PetscErrorCode (*func)(DM, PetscRe
   dmlocalts->rhsfunctionlocalctx = ctx;
 
   PetscCall(DMTSSetRHSFunction(dm, TSComputeRHSFunction_DMLocal, dmlocalts));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMTSCreateRHSMassMatrix - This creates the mass matrix associated with the given `DM`, and a solver to invert it, and stores them in the `DM` context.
 
-  Collective on dm
+  Collective
 
-  Input Parameters:
+  Input Parameter:
 . dm   - `DM` providing the mass matrix
 
   Level: developer
@@ -470,15 +471,15 @@ PetscErrorCode DMTSCreateRHSMassMatrix(DM dm)
   PetscCall(KSPAppendOptionsPrefix(dmlocalts->kspmass, "mass_"));
   PetscCall(KSPSetFromOptions(dmlocalts->kspmass));
   PetscCall(KSPSetOperators(dmlocalts->kspmass, dmlocalts->mass, dmlocalts->mass));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   DMTSCreateRHSMassMatrixLumped - This creates the lumped mass matrix associated with the given `DM`, and a solver to invert it, and stores them in the `DM` context.
 
-  Collective on dm
+  Collective
 
-  Input Parameters:
+  Input Parameter:
 . dm   - `DM` providing the mass matrix
 
   Level: developer
@@ -501,7 +502,7 @@ PetscErrorCode DMTSCreateRHSMassMatrixLumped(DM dm)
   PetscCall(DMCreateMassMatrixLumped(dm, &dmlocalts->lumpedmassinv));
   PetscCall(VecReciprocal(dmlocalts->lumpedmassinv));
   PetscCall(VecViewFromOptions(dmlocalts->lumpedmassinv, NULL, "-lumped_mass_inv_view"));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -509,7 +510,7 @@ PetscErrorCode DMTSCreateRHSMassMatrixLumped(DM dm)
 
   Logically Collective
 
-  Input Parameters:
+  Input Parameter:
 . dm   - `DM` providing the mass matrix
 
   Level: developer
@@ -528,5 +529,5 @@ PetscErrorCode DMTSDestroyRHSMassMatrix(DM dm)
   PetscCall(VecDestroy(&dmlocalts->lumpedmassinv));
   PetscCall(MatDestroy(&dmlocalts->mass));
   PetscCall(KSPDestroy(&dmlocalts->kspmass));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
