@@ -17,18 +17,18 @@ PetscFunctionList PetscSFList;
 PetscBool         PetscSFRegisterAllCalled;
 
 /*@C
-   PetscSFRegisterAll - Registers all the PetscSF communication implementations
+   PetscSFRegisterAll - Registers all the `PetscSF` communication implementations
 
    Not Collective
 
    Level: advanced
 
-.seealso: `PetscSFRegisterDestroy()`
+.seealso: `PetscSF`, `PetscSFRegister()`, `PetscSFRegisterDestroy()`
 @*/
 PetscErrorCode PetscSFRegisterAll(void)
 {
   PetscFunctionBegin;
-  if (PetscSFRegisterAllCalled) PetscFunctionReturn(0);
+  if (PetscSFRegisterAllCalled) PetscFunctionReturn(PETSC_SUCCESS);
   PetscSFRegisterAllCalled = PETSC_TRUE;
   PetscCall(PetscSFRegister(PETSCSFBASIC, PetscSFCreate_Basic));
 #if defined(PETSC_HAVE_MPI_WIN_CREATE)
@@ -42,21 +42,18 @@ PetscErrorCode PetscSFRegisterAll(void)
 #if defined(PETSC_HAVE_MPI_NEIGHBORHOOD_COLLECTIVES)
   PetscCall(PetscSFRegister(PETSCSFNEIGHBOR, PetscSFCreate_Neighbor));
 #endif
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  PetscSFRegister  - Adds an implementation of the PetscSF communication protocol.
+  PetscSFRegister  - Adds an implementation of the `PetscSF` communication protocol.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  name - name of a new user-defined implementation
 -  create - routine to create method context
 
-   Notes:
-   PetscSFRegister() may be called multiple times to add several user-defined implementations.
-
    Sample usage:
 .vb
    PetscSFRegister("my_impl",MyImplCreate);
@@ -69,12 +66,15 @@ $     -sf_type my_impl
 
    Level: advanced
 
-.seealso: `PetscSFRegisterAll()`, `PetscSFInitializePackage()`
+   Note:
+   `PetscSFRegister()` may be called multiple times to add several user-defined implementations.
+
+.seealso: `PetscSF`, `PetscSFType`, `PetscSFRegisterAll()`, `PetscSFInitializePackage()`
 @*/
 PetscErrorCode PetscSFRegister(const char name[], PetscErrorCode (*create)(PetscSF))
 {
   PetscFunctionBegin;
   PetscCall(PetscSFInitializePackage());
   PetscCall(PetscFunctionListAdd(&PetscSFList, name, create));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
