@@ -18,7 +18,7 @@ typedef struct {
 /*@C
   ISGetPointRange - Returns a description of the points in an `IS` suitable for traversal
 
-  Not collective
+  Not Collective
 
   Input Parameter:
 . pointIS - The `IS` object
@@ -31,14 +31,17 @@ typedef struct {
   Level: intermediate
 
   Notes:
-  If the `IS` contains contiguous indices in an `ISSTRIDE`, then the indices are contained in [pStart, pEnd) and points = NULL. Otherwise, pStart = 0, pEnd = numIndices, and points is an array of the indices. This supports the following pattern
+  If the `IS` contains contiguous indices in an `ISSTRIDE`, then the indices are contained in [pStart, pEnd) and points = `NULL`.
+  Otherwise, `pStart = 0`, `pEnd = numIndices`, and points is an array of the indices. This supports the following pattern
 .vb
   ISGetPointRange(is, &pStart, &pEnd, &points);
   for (p = pStart; p < pEnd; ++p) {
     const PetscInt point = points ? points[p] : p;
+    // use point
   }
   ISRestorePointRange(is, &pstart, &pEnd, &points);
 .ve
+  Hence the same code can be written for `pointIS` being a `ISSTRIDE` or `ISGENERAL`
 
 .seealso: [](sec_scatter), `IS`, `ISRestorePointRange()`, `ISGetPointSubrange()`, `ISGetIndices()`, `ISCreateStride()`
 @*/
@@ -55,13 +58,13 @@ PetscErrorCode ISGetPointRange(IS pointIS, PetscInt *pStart, PetscInt *pEnd, con
   if (isStride) PetscCall(ISStrideGetInfo(pointIS, pStart, &step));
   *pEnd = *pStart + numCells;
   if (!isStride || step != 1) PetscCall(ISGetIndices(pointIS, points));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   ISRestorePointRange - Destroys the traversal description created with `ISGetPointRange()`
 
-  Not collective
+  Not Collective
 
   Input Parameters:
 + pointIS - The `IS` object
@@ -82,17 +85,17 @@ PetscErrorCode ISRestorePointRange(IS pointIS, PetscInt *pStart, PetscInt *pEnd,
   PetscCall(PetscObjectTypeCompare((PetscObject)pointIS, ISSTRIDE, &isStride));
   if (isStride) PetscCall(ISStrideGetInfo(pointIS, pStart, &step));
   if (!isStride || step != 1) PetscCall(ISGetIndices(pointIS, points));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
   ISGetPointSubrange - Configures the input `IS` to be a subrange for the traversal information given
 
-  Not collective
+  Not Collective
 
   Input Parameters:
 + subpointIS - The `IS` object to be configured
-. pStar   t  - The first index of the subrange
+. pStart     - The first index of the subrange
 . pEnd       - One past the last index for the subrange
 - points     - The indices for the entire range, from `ISGetPointRange()`
 
@@ -116,7 +119,7 @@ PetscErrorCode ISGetPointSubrange(IS subpointIS, PetscInt pStart, PetscInt pEnd,
     PetscCall(ISSetType(subpointIS, ISSTRIDE));
     PetscCall(ISStrideSetStride(subpointIS, pEnd - pStart, pStart, 1));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* -----------------------------------------------------------------------------------------*/
@@ -131,7 +134,7 @@ static PetscErrorCode ISGlobalToLocalMappingSetUp(ISLocalToGlobalMapping mapping
   PetscInt i, *idx = mapping->indices, n = mapping->n, end, start;
 
   PetscFunctionBegin;
-  if (mapping->data) PetscFunctionReturn(0);
+  if (mapping->data) PetscFunctionReturn(PETSC_SUCCESS);
   end   = 0;
   start = PETSC_MAX_INT;
 
@@ -154,7 +157,7 @@ static PetscErrorCode ISGlobalToLocalMappingSetUp(ISLocalToGlobalMapping mapping
     }
   }
   PetscTryTypeMethod(mapping, globaltolocalmappingsetup);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode ISGlobalToLocalMappingSetUp_Basic(ISLocalToGlobalMapping mapping)
@@ -174,7 +177,7 @@ static PetscErrorCode ISGlobalToLocalMappingSetUp_Basic(ISLocalToGlobalMapping m
     globals[idx[i] - start] = i;
   }
   mapping->data = (void *)map;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode ISGlobalToLocalMappingSetUp_Hash(ISLocalToGlobalMapping mapping)
@@ -190,7 +193,7 @@ static PetscErrorCode ISGlobalToLocalMappingSetUp_Hash(ISLocalToGlobalMapping ma
     PetscCall(PetscHMapISet(map->globalht, idx[i], i));
   }
   mapping->data = (void *)map;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode ISLocalToGlobalMappingDestroy_Basic(ISLocalToGlobalMapping mapping)
@@ -198,10 +201,10 @@ static PetscErrorCode ISLocalToGlobalMappingDestroy_Basic(ISLocalToGlobalMapping
   ISLocalToGlobalMapping_Basic *map = (ISLocalToGlobalMapping_Basic *)mapping->data;
 
   PetscFunctionBegin;
-  if (!map) PetscFunctionReturn(0);
+  if (!map) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscFree(map->globals));
   PetscCall(PetscFree(mapping->data));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode ISLocalToGlobalMappingDestroy_Hash(ISLocalToGlobalMapping mapping)
@@ -209,10 +212,10 @@ static PetscErrorCode ISLocalToGlobalMappingDestroy_Hash(ISLocalToGlobalMapping
   ISLocalToGlobalMapping_Hash *map = (ISLocalToGlobalMapping_Hash *)mapping->data;
 
   PetscFunctionBegin;
-  if (!map) PetscFunctionReturn(0);
+  if (!map) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCall(PetscHMapIDestroy(&map->globalht));
   PetscCall(PetscFree(mapping->data));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 #define GTOLTYPE _Basic
@@ -278,7 +281,7 @@ PetscErrorCode ISLocalToGlobalMappingDuplicate(ISLocalToGlobalMapping ltog, ISLo
   PetscCall(ISLocalToGlobalMappingCreate(PetscObjectComm((PetscObject)ltog), ltog->bs, ltog->n, ltog->indices, PETSC_COPY_VALUES, nltog));
   PetscCall(ISLocalToGlobalMappingGetType(ltog, &l2gtype));
   PetscCall(ISLocalToGlobalMappingSetType(*nltog, l2gtype));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -302,29 +305,32 @@ PetscErrorCode ISLocalToGlobalMappingGetSize(ISLocalToGlobalMapping mapping, Pet
   PetscValidHeaderSpecific(mapping, IS_LTOGM_CLASSID, 1);
   PetscValidIntPointer(n, 2);
   *n = mapping->bs * mapping->n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    ISLocalToGlobalMappingViewFromOptions - View an `ISLocalToGlobalMapping` based on values in the options database
 
-   Collective on A
+   Collective
 
    Input Parameters:
 +  A - the local to global mapping object
-.  obj - Optional object
+.  obj - Optional object that provides the options prefix used for the options database query
 -  name - command line option
 
    Level: intermediate
 
-.seealso: [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingView`, `PetscObjectViewFromOptions()`, `ISLocalToGlobalMappingCreate()`
+   Note:
+   See `PetscObjectViewFromOptions()` for the available `PetscViewer` and `PetscViewerFormat`
+
+.seealso: [](sec_scatter), `PetscViewer`, ``ISLocalToGlobalMapping`, `ISLocalToGlobalMappingView`, `PetscObjectViewFromOptions()`, `ISLocalToGlobalMappingCreate()`
 @*/
 PetscErrorCode ISLocalToGlobalMappingViewFromOptions(ISLocalToGlobalMapping A, PetscObject obj, const char name[])
 {
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A, IS_LTOGM_CLASSID, 1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)A, obj, name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -338,7 +344,7 @@ PetscErrorCode ISLocalToGlobalMappingViewFromOptions(ISLocalToGlobalMapping A, P
 
     Level: advanced
 
-.seealso: [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingDestroy()`, `ISLocalToGlobalMappingCreate()`
+.seealso: [](sec_scatter), `PetscViewer`, `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingDestroy()`, `ISLocalToGlobalMappingCreate()`
 @*/
 PetscErrorCode ISLocalToGlobalMappingView(ISLocalToGlobalMapping mapping, PetscViewer viewer)
 {
@@ -356,18 +362,22 @@ PetscErrorCode ISLocalToGlobalMappingView(ISLocalToGlobalMapping mapping, PetscV
   if (iascii) {
     PetscCall(PetscObjectPrintClassNamePrefixType((PetscObject)mapping, viewer));
     PetscCall(PetscViewerASCIIPushSynchronized(viewer));
-    for (i = 0; i < mapping->n; i++) PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, "[%d] %" PetscInt_FMT " %" PetscInt_FMT "\n", rank, i, mapping->indices[i]));
+    for (i = 0; i < mapping->n; i++) {
+      PetscInt bs = mapping->bs, g = mapping->indices[i];
+      if (bs == 1) PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, "[%d] %" PetscInt_FMT " %" PetscInt_FMT "\n", rank, i, g));
+      else PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, "[%d] %" PetscInt_FMT ":%" PetscInt_FMT " %" PetscInt_FMT ":%" PetscInt_FMT "\n", rank, i * bs, (i + 1) * bs, g * bs, (g + 1) * bs));
+    }
     PetscCall(PetscViewerFlush(viewer));
     PetscCall(PetscViewerASCIIPopSynchronized(viewer));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     ISLocalToGlobalMappingCreateIS - Creates a mapping between a local (0 to n)
     ordering and a global parallel ordering.
 
-    Not collective
+    Not Collective
 
     Input Parameter:
 .   is - index set containing the global numbers for each local number
@@ -406,7 +416,7 @@ PetscErrorCode ISLocalToGlobalMappingCreateIS(IS is, ISLocalToGlobalMapping *map
     PetscCall(ISLocalToGlobalMappingCreate(comm, bs, n / bs, indices, PETSC_COPY_VALUES, mapping));
     PetscCall(ISBlockRestoreIndices(is, &indices));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -424,8 +434,8 @@ PetscErrorCode ISLocalToGlobalMappingCreateIS(IS is, ISLocalToGlobalMapping *map
 
     Level: advanced
 
-    Notes:
-    If any processor calls this with start = `PETSC_DECIDE` then all processors must, otherwise the program will hang.
+    Note:
+    If any processor calls this with `start` = `PETSC_DECIDE` then all processors must, otherwise the program will hang.
 
 .seealso: [](sec_scatter), `PetscSF`, `ISLocalToGlobalMappingDestroy()`, `ISLocalToGlobalMappingCreate()`, `ISLocalToGlobalMappingCreateIS()`, `ISLocalToGlobalMappingSetFromOptions()`
 @*/
@@ -453,13 +463,13 @@ PetscErrorCode ISLocalToGlobalMappingCreateSF(PetscSF sf, PetscInt start, ISLoca
   PetscCall(PetscSFBcastEnd(sf, MPIU_INT, globals, ltog, MPI_REPLACE));
   PetscCall(ISLocalToGlobalMappingCreate(comm, 1, maxlocal, ltog, PETSC_OWN_POINTER, mapping));
   PetscCall(PetscFree(globals));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     ISLocalToGlobalMappingSetBlockSize - Sets the blocksize of the mapping
 
-    Not collective
+    Not Collective
 
     Input Parameters:
 +   mapping - mapping data structure
@@ -478,7 +488,7 @@ PetscErrorCode ISLocalToGlobalMappingSetBlockSize(ISLocalToGlobalMapping mapping
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mapping, IS_LTOGM_CLASSID, 1);
   PetscCheck(bs >= 1, PETSC_COMM_SELF, PETSC_ERR_ARG_WRONG, "Invalid block size %" PetscInt_FMT, bs);
-  if (bs == mapping->bs) PetscFunctionReturn(0);
+  if (bs == mapping->bs) PetscFunctionReturn(PETSC_SUCCESS);
   on  = mapping->n;
   obs = mapping->bs;
   oid = mapping->indices;
@@ -526,7 +536,7 @@ PetscErrorCode ISLocalToGlobalMappingSetBlockSize(ISLocalToGlobalMapping mapping
   mapping->info_cached = PETSC_FALSE;
 
   PetscTryTypeMethod(mapping, destroy);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -535,7 +545,7 @@ PetscErrorCode ISLocalToGlobalMappingSetBlockSize(ISLocalToGlobalMapping mapping
 
     Not Collective
 
-    Input Parameters:
+    Input Parameter:
 .   mapping - mapping data structure
 
     Output Parameter:
@@ -550,7 +560,7 @@ PetscErrorCode ISLocalToGlobalMappingGetBlockSize(ISLocalToGlobalMapping mapping
   PetscFunctionBegin;
   PetscValidHeaderSpecific(mapping, IS_LTOGM_CLASSID, 1);
   *bs = mapping->bs;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -578,9 +588,11 @@ PetscErrorCode ISLocalToGlobalMappingGetBlockSize(ISLocalToGlobalMapping mapping
     of `ISLOCALTOGLOBALMAPPINGBASIC` will be used; this uses more memory but is faster; this approach is not scalable for extremely large mappings.
 
     For large problems `ISLOCALTOGLOBALMAPPINGHASH` is used, this is scalable.
-    Use `ISLocalToGlobalMappingSetType()` or call `ISLocalToGlobalMappingSetFromOptions()` with the option -islocaltoglobalmapping_type <basic,hash> to control which is used.
+    Use `ISLocalToGlobalMappingSetType()` or call `ISLocalToGlobalMappingSetFromOptions()` with the option
+    `-islocaltoglobalmapping_type` <`basic`,`hash`> to control which is used.
 
-.seealso: [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingDestroy()`, `ISLocalToGlobalMappingCreateIS()`, `ISLocalToGlobalMappingSetFromOptions()`, `ISLOCALTOGLOBALMAPPINGBASIC`, `ISLOCALTOGLOBALMAPPINGHASH`
+.seealso: [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingDestroy()`, `ISLocalToGlobalMappingCreateIS()`, `ISLocalToGlobalMappingSetFromOptions()`,
+          `ISLOCALTOGLOBALMAPPINGBASIC`, `ISLOCALTOGLOBALMAPPINGHASH`
           `ISLocalToGlobalMappingSetType()`, `ISLocalToGlobalMappingType`
 @*/
 PetscErrorCode ISLocalToGlobalMappingCreate(MPI_Comm comm, PetscInt bs, PetscInt n, const PetscInt indices[], PetscCopyMode mode, ISLocalToGlobalMapping *mapping)
@@ -608,7 +620,7 @@ PetscErrorCode ISLocalToGlobalMappingCreate(MPI_Comm comm, PetscInt bs, PetscInt
   } else if (mode == PETSC_USE_POINTER) {
     (*mapping)->indices = (PetscInt *)indices;
   } else SETERRQ(comm, PETSC_ERR_ARG_OUTOFRANGE, "Invalid mode %d", mode);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscFunctionList ISLocalToGlobalMappingList = NULL;
@@ -616,14 +628,18 @@ PetscFunctionList ISLocalToGlobalMappingList = NULL;
 /*@
    ISLocalToGlobalMappingSetFromOptions - Set mapping options from the options database.
 
-   Not collective
+   Not Collective
 
-   Input Parameters:
+   Input Parameter:
 .  mapping - mapping data structure
 
+   Options Database Key:
+.  -islocaltoglobalmapping_type - <basic,hash> nonscalable and scalable versions
+
    Level: advanced
 
-.seealso: [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingDestroy()`, `ISLocalToGlobalMappingCreateIS()`, `ISLocalToGlobalMappingSetFromOptions()`, `ISLOCALTOGLOBALMAPPINGBASIC`, `ISLOCALTOGLOBALMAPPINGHASH`
+.seealso: [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingDestroy()`, `ISLocalToGlobalMappingCreateIS()`, `ISLocalToGlobalMappingSetFromOptions()`,
+          `ISLOCALTOGLOBALMAPPINGBASIC`, `ISLOCALTOGLOBALMAPPINGHASH`
           `ISLocalToGlobalMappingSetType()`, `ISLocalToGlobalMappingType`
 @*/
 PetscErrorCode ISLocalToGlobalMappingSetFromOptions(ISLocalToGlobalMapping mapping)
@@ -639,16 +655,16 @@ PetscErrorCode ISLocalToGlobalMappingSetFromOptions(ISLocalToGlobalMapping mappi
   PetscCall(PetscOptionsFList("-islocaltoglobalmapping_type", "ISLocalToGlobalMapping method", "ISLocalToGlobalMappingSetType", ISLocalToGlobalMappingList, (char *)(((PetscObject)mapping)->type_name) ? ((PetscObject)mapping)->type_name : defaulttype, type, 256, &flg));
   if (flg) PetscCall(ISLocalToGlobalMappingSetType(mapping, type));
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    ISLocalToGlobalMappingDestroy - Destroys a mapping between a local (0 to n)
    ordering and a global parallel ordering.
 
-   Note Collective
+   Not Collective
 
-   Input Parameters:
+   Input Parameter:
 .  mapping - mapping data structure
 
    Level: advanced
@@ -658,11 +674,11 @@ PetscErrorCode ISLocalToGlobalMappingSetFromOptions(ISLocalToGlobalMapping mappi
 PetscErrorCode ISLocalToGlobalMappingDestroy(ISLocalToGlobalMapping *mapping)
 {
   PetscFunctionBegin;
-  if (!*mapping) PetscFunctionReturn(0);
+  if (!*mapping) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific((*mapping), IS_LTOGM_CLASSID, 1);
   if (--((PetscObject)(*mapping))->refct > 0) {
     *mapping = NULL;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
   if ((*mapping)->dealloc_indices) PetscCall(PetscFree((*mapping)->indices));
   PetscCall(PetscFree((*mapping)->info_procs));
@@ -679,7 +695,7 @@ PetscErrorCode ISLocalToGlobalMappingDestroy(ISLocalToGlobalMapping *mapping)
   if ((*mapping)->ops->destroy) PetscCall((*(*mapping)->ops->destroy)(*mapping));
   PetscCall(PetscHeaderDestroy(mapping));
   *mapping = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -687,7 +703,7 @@ PetscErrorCode ISLocalToGlobalMappingDestroy(ISLocalToGlobalMapping *mapping)
     a new index set using the global numbering defined in an `ISLocalToGlobalMapping`
     context.
 
-    Collective on mapping
+    Collective
 
     Input Parameters:
 +   mapping - mapping between local and global numbering
@@ -699,7 +715,7 @@ PetscErrorCode ISLocalToGlobalMappingDestroy(ISLocalToGlobalMapping *mapping)
     Level: advanced
 
     Note:
-    The output `IS` will have the same communicator of the input `IS`.
+    The output `IS` will have the same communicator as the input `IS`.
 
 .seealso: [](sec_scatter), `ISLocalToGlobalMappingApply()`, `ISLocalToGlobalMappingCreate()`,
           `ISLocalToGlobalMappingDestroy()`, `ISGlobalToLocalMappingApply()`
@@ -720,14 +736,14 @@ PetscErrorCode ISLocalToGlobalMappingApplyIS(ISLocalToGlobalMapping mapping, IS
   PetscCall(ISLocalToGlobalMappingApply(mapping, n, idxin, idxout));
   PetscCall(ISRestoreIndices(is, &idxin));
   PetscCall(ISCreateGeneral(PetscObjectComm((PetscObject)is), n, idxout, PETSC_OWN_POINTER, newis));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    ISLocalToGlobalMappingApply - Takes a list of integers in a local numbering
    and converts them to the global numbering.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  mapping - the local to global mapping context
@@ -740,7 +756,7 @@ PetscErrorCode ISLocalToGlobalMappingApplyIS(ISLocalToGlobalMapping mapping, IS
    Level: advanced
 
    Note:
-   The in and out array parameters may be identical.
+   The `in` and `out` array parameters may be identical.
 
 .seealso: [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingApplyBlock()`, `ISLocalToGlobalMappingCreate()`, `ISLocalToGlobalMappingDestroy()`,
           `ISLocalToGlobalMappingApplyIS()`, `AOCreateBasic()`, `AOApplicationToPetsc()`,
@@ -775,13 +791,13 @@ PetscErrorCode ISLocalToGlobalMappingApply(ISLocalToGlobalMapping mapping, Petsc
       out[i] = idx[in[i] / bs] * bs + (in[i] % bs);
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    ISLocalToGlobalMappingApplyBlock - Takes a list of integers in a local block numbering and converts them to the global block numbering
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  mapping - the local to global mapping context
@@ -791,15 +807,15 @@ PetscErrorCode ISLocalToGlobalMappingApply(ISLocalToGlobalMapping mapping, Petsc
    Output Parameter:
 .  out - indices in global block numbering
 
-   Level: advanced
-
-   Note:
-   The in and out array parameters may be identical.
-
    Example:
      If the index values are {0,1,6,7} set with a call to `ISLocalToGlobalMappingCreate`(`PETSC_COMM_SELF`,2,2,{0,3}) then the mapping applied to 0
      (the first block) would produce 0 and the mapping applied to 1 (the second block) would produce 3.
 
+   Level: advanced
+
+   Note:
+   The `in` and `out` array parameters may be identical.
+
 .seealso: [](sec_scatter), `ISLocalToGlobalMappingApply()`, `ISLocalToGlobalMappingCreate()`, `ISLocalToGlobalMappingDestroy()`,
           `ISLocalToGlobalMappingApplyIS()`, `AOCreateBasic()`, `AOApplicationToPetsc()`,
           `AOPetscToApplication()`, `ISGlobalToLocalMappingApply()`
@@ -821,14 +837,14 @@ PetscErrorCode ISLocalToGlobalMappingApplyBlock(ISLocalToGlobalMapping mapping,
     PetscCheck(in[i] < Nmax, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Local block index %" PetscInt_FMT " too large %" PetscInt_FMT " (max) at %" PetscInt_FMT, in[i], Nmax - 1, i);
     out[i] = idx[in[i]];
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     ISGlobalToLocalMappingApply - Provides the local numbering for a list of integers
     specified with a global numbering.
 
-    Not collective
+    Not Collective
 
     Input Parameters:
 +   mapping - mapping between local and global numbering
@@ -848,15 +864,16 @@ PetscErrorCode ISLocalToGlobalMappingApplyBlock(ISLocalToGlobalMapping mapping,
     Level: advanced
 
     Notes:
-    Either nout or idxout may be NULL. idx and idxout may be identical.
+    Either `nout` or `idxout` may be `NULL`. `idx` and `idxout` may be identical.
 
-    For "small" problems when using `ISGlobalToLocalMappingApply()` and `ISGlobalToLocalMappingApplyBlock()`, the `ISLocalToGlobalMappingType` of `ISLOCALTOGLOBALMAPPINGBASIC` will be used;
+    For "small" problems when using `ISGlobalToLocalMappingApply()` and `ISGlobalToLocalMappingApplyBlock()`, the `ISLocalToGlobalMappingType` of
+    `ISLOCALTOGLOBALMAPPINGBASIC` will be used;
     this uses more memory but is faster; this approach is not scalable for extremely large mappings. For large problems `ISLOCALTOGLOBALMAPPINGHASH` is used, this is scalable.
     Use `ISLocalToGlobalMappingSetType()` or call `ISLocalToGlobalMappingSetFromOptions()` with the option -islocaltoglobalmapping_type <basic,hash> to control which is used.
 
     Developer Note:
-    The manual page states that idx and idxout may be identical but the calling
-    sequence declares idx as const so it cannot be the same as idxout.
+    The manual page states that `idx` and `idxout` may be identical but the calling
+    sequence declares `idx` as const so it cannot be the same as `idxout`.
 
 .seealso: [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingApply()`, `ISGlobalToLocalMappingApplyBlock()`, `ISLocalToGlobalMappingCreate()`,
           `ISLocalToGlobalMappingDestroy()`
@@ -867,7 +884,7 @@ PetscErrorCode ISGlobalToLocalMappingApply(ISLocalToGlobalMapping mapping, ISGlo
   PetscValidHeaderSpecific(mapping, IS_LTOGM_CLASSID, 1);
   if (!mapping->data) PetscCall(ISGlobalToLocalMappingSetUp(mapping));
   PetscUseTypeMethod(mapping, globaltolocalmappingapply, type, n, idx, nout, idxout);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -875,7 +892,7 @@ PetscErrorCode ISGlobalToLocalMappingApply(ISLocalToGlobalMapping mapping, ISGlo
     a new index set using the local numbering defined in an `ISLocalToGlobalMapping`
     context.
 
-    Not collective
+    Not Collective
 
     Input Parameters:
 +   mapping - mapping between local and global numbering
@@ -883,7 +900,7 @@ PetscErrorCode ISGlobalToLocalMappingApply(ISLocalToGlobalMapping mapping, ISGlo
            `IS_GTOLM_DROP` - drops the indices with no local value from the output list
 -   is - index set in global numbering
 
-    Output Parameters:
+    Output Parameter:
 .   newis - index set in local numbering
 
     Level: advanced
@@ -915,14 +932,14 @@ PetscErrorCode ISGlobalToLocalMappingApplyIS(ISLocalToGlobalMapping mapping, ISG
   PetscCall(ISGlobalToLocalMappingApply(mapping, type, n, idxin, &nout, idxout));
   PetscCall(ISRestoreIndices(is, &idxin));
   PetscCall(ISCreateGeneral(PETSC_COMM_SELF, nout, idxout, PETSC_OWN_POINTER, newis));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
     ISGlobalToLocalMappingApplyBlock - Provides the local block numbering for a list of integers
     specified with a block global numbering.
 
-    Not collective
+    Not Collective
 
     Input Parameters:
 +   mapping - mapping between local and global numbering
@@ -942,15 +959,16 @@ PetscErrorCode ISGlobalToLocalMappingApplyIS(ISLocalToGlobalMapping mapping, ISG
     Level: advanced
 
     Notes:
-    Either nout or idxout may be NULL. idx and idxout may be identical.
+    Either `nout` or `idxout` may be `NULL`. `idx` and `idxout` may be identical.
 
-    For "small" problems when using `ISGlobalToLocalMappingApply()` and `ISGlobalToLocalMappingApplyBlock()`, the `ISLocalToGlobalMappingType` of `ISLOCALTOGLOBALMAPPINGBASIC` will be used;
+    For "small" problems when using `ISGlobalToLocalMappingApply()` and `ISGlobalToLocalMappingApplyBlock()`, the `ISLocalToGlobalMappingType` of
+    `ISLOCALTOGLOBALMAPPINGBASIC` will be used;
     this uses more memory but is faster; this approach is not scalable for extremely large mappings. For large problems `ISLOCALTOGLOBALMAPPINGHASH` is used, this is scalable.
     Use `ISLocalToGlobalMappingSetType()` or call `ISLocalToGlobalMappingSetFromOptions()` with the option -islocaltoglobalmapping_type <basic,hash> to control which is used.
 
     Developer Note:
-    The manual page states that idx and idxout may be identical but the calling
-    sequence declares idx as const so it cannot be the same as idxout.
+    The manual page states that `idx` and `idxout` may be identical but the calling
+    sequence declares `idx` as const so it cannot be the same as `idxout`.
 
 .seealso: [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingApply()`, `ISGlobalToLocalMappingApply()`, `ISLocalToGlobalMappingCreate()`,
           `ISLocalToGlobalMappingDestroy()`
@@ -961,14 +979,14 @@ PetscErrorCode ISGlobalToLocalMappingApplyBlock(ISLocalToGlobalMapping mapping,
   PetscValidHeaderSpecific(mapping, IS_LTOGM_CLASSID, 1);
   if (!mapping->data) PetscCall(ISGlobalToLocalMappingSetUp(mapping));
   PetscUseTypeMethod(mapping, globaltolocalmappingapplyblock, type, n, idx, nout, idxout);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     ISLocalToGlobalMappingGetBlockInfo - Gets the neighbor information for each processor and
      each index shared by more than one processor
 
-    Collective on mapping
+    Collective
 
     Input Parameter:
 .   mapping - the mapping from local to global indexing
@@ -989,8 +1007,8 @@ PetscErrorCode ISGlobalToLocalMappingApplyBlock(ISLocalToGlobalMapping mapping,
 .ve
 
    Fortran Note:
-        There is no `ISLocalToGlobalMappingRestoreInfo()` in Fortran. You must make sure that procs[], numprocs[] and
-        indices[][] are large enough arrays, either by allocating them dynamically or defining static ones large enough.
+        There is no `ISLocalToGlobalMappingRestoreInfo()` in Fortran. You must make sure that `procs`[], `numprocs`[] and
+        `indices`[][] are large enough arrays, either by allocating them dynamically or defining static ones large enough.
 
 .seealso: [](sec_scatter), `ISLocalToGlobalMappingDestroy()`, `ISLocalToGlobalMappingCreateIS()`, `ISLocalToGlobalMappingCreate()`,
           `ISLocalToGlobalMappingRestoreInfo()`
@@ -1007,7 +1025,7 @@ PetscErrorCode ISLocalToGlobalMappingGetBlockInfo(ISLocalToGlobalMapping mapping
   } else {
     PetscCall(ISLocalToGlobalMappingGetBlockInfo_Private(mapping, nproc, procs, numprocs, indices));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode ISLocalToGlobalMappingGetBlockInfo_Private(ISLocalToGlobalMapping mapping, PetscInt *nproc, PetscInt *procs[], PetscInt *numprocs[], PetscInt **indices[])
@@ -1040,7 +1058,7 @@ static PetscErrorCode ISLocalToGlobalMappingGetBlockInfo_Private(ISLocalToGlobal
     mapping->info_numprocs = *numprocs;
     mapping->info_indices  = *indices;
     mapping->info_cached   = PETSC_TRUE;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   PetscCall(PetscOptionsGetBool(((PetscObject)mapping)->options, NULL, "-islocaltoglobalmappinggetinfo_debug", &debug, NULL));
@@ -1401,13 +1419,13 @@ static PetscErrorCode ISLocalToGlobalMappingGetBlockInfo_Private(ISLocalToGlobal
   mapping->info_numprocs = *numprocs;
   mapping->info_indices  = *indices;
   mapping->info_cached   = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     ISLocalToGlobalMappingRestoreBlockInfo - Frees the memory allocated by `ISLocalToGlobalMappingGetBlockInfo()`
 
-    Collective on mapping
+    Collective
 
     Input Parameter:
 .   mapping - the mapping from local to global indexing
@@ -1441,14 +1459,14 @@ PetscErrorCode ISLocalToGlobalMappingRestoreBlockInfo(ISLocalToGlobalMapping map
   *procs    = NULL;
   *numprocs = NULL;
   *indices  = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     ISLocalToGlobalMappingGetInfo - Gets the neighbor information for each processor and
      each index shared by more than one processor
 
-    Collective on mapping
+    Collective
 
     Input Parameter:
 .   mapping - the mapping from local to global indexing
@@ -1472,8 +1490,8 @@ PetscErrorCode ISLocalToGlobalMappingRestoreBlockInfo(ISLocalToGlobalMapping map
 .ve
 
     Fortran Note:
-        There is no `ISLocalToGlobalMappingRestoreInfo()` in Fortran. You must make sure that procs[], numprocs[] and
-        indices[][] are large enough arrays, either by allocating them dynamically or defining static ones large enough.
+        There is no `ISLocalToGlobalMappingRestoreInfo()` in Fortran. You must make sure that `procs`[], `numprocs`[] and
+        `indices`[][] are large enough arrays, either by allocating them dynamically or defining static ones large enough.
 
 .seealso: [](sec_scatter), `ISLocalToGlobalMappingDestroy()`, `ISLocalToGlobalMappingCreateIS()`, `ISLocalToGlobalMappingCreate()`,
           `ISLocalToGlobalMappingRestoreInfo()`
@@ -1501,13 +1519,13 @@ PetscErrorCode ISLocalToGlobalMappingGetInfo(ISLocalToGlobalMapping mapping, Pet
     *numprocs = bnumprocs;
     *indices  = bindices;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     ISLocalToGlobalMappingRestoreInfo - Frees the memory allocated by `ISLocalToGlobalMappingGetInfo()`
 
-    Collective on mapping
+    Collective
 
     Input Parameter:
 .   mapping - the mapping from local to global indexing
@@ -1527,13 +1545,13 @@ PetscErrorCode ISLocalToGlobalMappingRestoreInfo(ISLocalToGlobalMapping mapping,
 {
   PetscFunctionBegin;
   PetscCall(ISLocalToGlobalMappingRestoreBlockInfo(mapping, nproc, procs, numprocs, indices));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     ISLocalToGlobalMappingGetNodeInfo - Gets the neighbor information for each MPI rank
 
-    Collective on mapping
+    Collective
 
     Input Parameter:
 .   mapping - the mapping from local to global indexing
@@ -1595,13 +1613,13 @@ PetscErrorCode ISLocalToGlobalMappingGetNodeInfo(ISLocalToGlobalMapping mapping,
   if (nnodes) *nnodes = n;
   if (count) *count = mapping->info_nodec;
   if (indices) *indices = mapping->info_nodei;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
     ISLocalToGlobalMappingRestoreNodeInfo - Frees the memory allocated by `ISLocalToGlobalMappingGetNodeInfo()`
 
-    Collective on mapping
+    Collective
 
     Input Parameter:
 .   mapping - the mapping from local to global indexing
@@ -1623,9 +1641,50 @@ PetscErrorCode ISLocalToGlobalMappingRestoreNodeInfo(ISLocalToGlobalMapping mapp
   if (nnodes) *nnodes = 0;
   if (count) *count = NULL;
   if (indices) *indices = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+    ISLocalToGlobalMappingGetIndicesF90 - Get global indices for every local point that is mapped
+
+    Synopsis:
+    ISLocalToGlobalMappingGetIndicesF90(ISLocalToGlobalMapping ltog, PetscInt, pointer :: array(:)}, integer ierr)
+
+    Not Collective
+
+    Input Parameter:
+.   A - the matrix
+
+    Output Parameter:
+.   array - array of indices, the length of this array may be obtained with `ISLocalToGlobalMappingGetSize()`
+
+    Level: advanced
+
+    Note:
+    Use  `ISLocalToGlobalMappingGetIndicesF90()` when you no longer need access to the data
+
+.seealso: [](sec_fortranarrays), [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingGetIndices()`, `ISLocalToGlobalMappingRestoreIndices()`,
+          `ISLocalToGlobalMappingRestoreIndicesF90()`
+M*/
+
+/*MC
+    ISLocalToGlobalMappingRestoreIndicesF90 - restores the global indices for every local point that is mapped obtained with `ISLocalToGlobalMappingGetIndicesF90()`
+
+    Synopsis:
+    ISLocalToGlobalMappingRestoreIndicesF90(ISLocalToGlobalMapping ltog, PetscInt, pointer :: array(:)}, integer ierr)
+
+    Not Collective
+
+    Input Parameters:
++   A - the matrix
+-   array - array of indices, the length of this array may be obtained with `ISLocalToGlobalMappingGetSize()`
+
+    Level: advanced
+
+.seealso: [](sec_fortranarrays), [](sec_scatter), `ISLocalToGlobalMapping`, `ISLocalToGlobalMappingGetIndices()`, `ISLocalToGlobalMappingRestoreIndices()`,
+          `ISLocalToGlobalMappingGetIndicesF90()`
+M*/
+
 /*@C
    ISLocalToGlobalMappingGetIndices - Get global indices for every local point that is mapped
 
@@ -1642,7 +1701,8 @@ PetscErrorCode ISLocalToGlobalMappingRestoreNodeInfo(ISLocalToGlobalMapping mapp
    Note:
     `ISLocalToGlobalMappingGetSize()` returns the length the this array
 
-.seealso: [](sec_scatter), `ISLocalToGlobalMappingCreate()`, `ISLocalToGlobalMappingApply()`, `ISLocalToGlobalMappingRestoreIndices()`, `ISLocalToGlobalMappingGetBlockIndices()`, `ISLocalToGlobalMappingRestoreBlockIndices()`
+.seealso: [](sec_scatter), `ISLocalToGlobalMappingCreate()`, `ISLocalToGlobalMappingApply()`, `ISLocalToGlobalMappingRestoreIndices()`,
+          `ISLocalToGlobalMappingGetBlockIndices()`, `ISLocalToGlobalMappingRestoreBlockIndices()`
 @*/
 PetscErrorCode ISLocalToGlobalMappingGetIndices(ISLocalToGlobalMapping ltog, const PetscInt **array)
 {
@@ -1662,7 +1722,7 @@ PetscErrorCode ISLocalToGlobalMappingGetIndices(ISLocalToGlobalMapping ltog, con
     for (i = 0; i < n; i++)
       for (j = 0; j < bs; j++) jj[k++] = bs * ii[i] + j;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1686,7 +1746,7 @@ PetscErrorCode ISLocalToGlobalMappingRestoreIndices(ISLocalToGlobalMapping ltog,
   PetscCheck(ltog->bs != 1 || *array == ltog->indices, PETSC_COMM_SELF, PETSC_ERR_ARG_BADPTR, "Trying to return mismatched pointer");
 
   if (ltog->bs > 1) PetscCall(PetscFree(*(void **)array));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1710,7 +1770,7 @@ PetscErrorCode ISLocalToGlobalMappingGetBlockIndices(ISLocalToGlobalMapping ltog
   PetscValidHeaderSpecific(ltog, IS_LTOGM_CLASSID, 1);
   PetscValidPointer(array, 2);
   *array = ltog->indices;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1733,7 +1793,7 @@ PetscErrorCode ISLocalToGlobalMappingRestoreBlockIndices(ISLocalToGlobalMapping
   PetscValidPointer(array, 2);
   PetscCheck(*array == ltog->indices, PETSC_COMM_SELF, PETSC_ERR_ARG_BADPTR, "Trying to return mismatched pointer");
   *array = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1782,14 +1842,14 @@ PetscErrorCode ISLocalToGlobalMappingConcatenate(MPI_Comm comm, PetscInt n, cons
     cnt += m;
   }
   PetscCall(ISLocalToGlobalMappingCreate(comm, 1, cnt, idx, PETSC_OWN_POINTER, ltogcat));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
       ISLOCALTOGLOBALMAPPINGBASIC - basic implementation of the `ISLocalToGlobalMapping` object. When `ISGlobalToLocalMappingApply()` is
                                     used this is good for only small and moderate size problems.
 
-   Options Database Keys:
+   Options Database Key:
 .   -islocaltoglobalmapping_type basic - select this method
 
    Level: beginner
@@ -1806,14 +1866,14 @@ PETSC_EXTERN PetscErrorCode ISLocalToGlobalMappingCreate_Basic(ISLocalToGlobalMa
   ltog->ops->globaltolocalmappingsetup      = ISGlobalToLocalMappingSetUp_Basic;
   ltog->ops->globaltolocalmappingapplyblock = ISGlobalToLocalMappingApplyBlock_Basic;
   ltog->ops->destroy                        = ISLocalToGlobalMappingDestroy_Basic;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*MC
       ISLOCALTOGLOBALMAPPINGHASH - hash implementation of the `ISLocalToGlobalMapping` object. When `ISGlobalToLocalMappingApply()` is
                                     used this is good for large memory problems.
 
-   Options Database Keys:
+   Options Database Key:
 .   -islocaltoglobalmapping_type hash - select this method
 
    Level: beginner
@@ -1830,7 +1890,7 @@ PETSC_EXTERN PetscErrorCode ISLocalToGlobalMappingCreate_Hash(ISLocalToGlobalMap
   ltog->ops->globaltolocalmappingsetup      = ISGlobalToLocalMappingSetUp_Hash;
   ltog->ops->globaltolocalmappingapplyblock = ISGlobalToLocalMappingApplyBlock_Hash;
   ltog->ops->destroy                        = ISLocalToGlobalMappingDestroy_Hash;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1840,7 +1900,7 @@ PETSC_EXTERN PetscErrorCode ISLocalToGlobalMappingCreate_Hash(ISLocalToGlobalMap
 
    Input Parameters:
 +  sname - name of a new method
--  routine_create - routine to create method context
+-  function - routine to create method context
 
    Sample usage:
 .vb
@@ -1865,13 +1925,13 @@ PetscErrorCode ISLocalToGlobalMappingRegister(const char sname[], PetscErrorCode
   PetscFunctionBegin;
   PetscCall(ISInitializePackage());
   PetscCall(PetscFunctionListAdd(&ISLocalToGlobalMappingList, sname, function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    ISLocalToGlobalMappingSetType - Sets the implementation type `ISLocalToGlobalMapping` will use
 
-   Logically Collective on ltogf
+   Logically Collective
 
    Input Parameters:
 +  ltog - the `ISLocalToGlobalMapping` object
@@ -1883,7 +1943,7 @@ PetscErrorCode ISLocalToGlobalMappingRegister(const char sname[], PetscErrorCode
   Level: intermediate
 
    Notes:
-   See "petsc/include/petscis.h" for available methods
+   See `ISLocalToGlobalMappingType` for available methods
 
   Normally, it is best to use the `ISLocalToGlobalMappingSetFromOptions()` command and
   then set the `ISLocalToGlobalMappingType` from the options database rather than by using
@@ -1905,7 +1965,7 @@ PetscErrorCode ISLocalToGlobalMappingSetType(ISLocalToGlobalMapping ltog, ISLoca
   if (type) PetscValidCharPointer(type, 2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)ltog, type, &match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* L2G maps defer type setup at globaltolocal calls, allow passing NULL here */
   if (type) {
@@ -1918,7 +1978,7 @@ PetscErrorCode ISLocalToGlobalMappingSetType(ISLocalToGlobalMapping ltog, ISLoca
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)ltog, type));
   if (r) PetscCall((*r)(ltog));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -1942,7 +2002,7 @@ PetscErrorCode ISLocalToGlobalMappingGetType(ISLocalToGlobalMapping ltog, ISLoca
   PetscValidHeaderSpecific(ltog, IS_LTOGM_CLASSID, 1);
   PetscValidPointer(type, 2);
   *type = ((PetscObject)ltog)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscBool ISLocalToGlobalMappingRegisterAllCalled = PETSC_FALSE;
@@ -1959,9 +2019,9 @@ PetscBool ISLocalToGlobalMappingRegisterAllCalled = PETSC_FALSE;
 PetscErrorCode ISLocalToGlobalMappingRegisterAll(void)
 {
   PetscFunctionBegin;
-  if (ISLocalToGlobalMappingRegisterAllCalled) PetscFunctionReturn(0);
+  if (ISLocalToGlobalMappingRegisterAllCalled) PetscFunctionReturn(PETSC_SUCCESS);
   ISLocalToGlobalMappingRegisterAllCalled = PETSC_TRUE;
   PetscCall(ISLocalToGlobalMappingRegister(ISLOCALTOGLOBALMAPPINGBASIC, ISLocalToGlobalMappingCreate_Basic));
   PetscCall(ISLocalToGlobalMappingRegister(ISLOCALTOGLOBALMAPPINGHASH, ISLocalToGlobalMappingCreate_Hash));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
