@@ -10,10 +10,10 @@
 
   Collective
 
-  Input Parameters:
+  Input Parameter:
 . comm - the MPI communicator
 
-  Output Parameters:
+  Output Parameter:
 . map - the new `PetscLayout`
 
   Level: advanced
@@ -65,7 +65,7 @@ PetscErrorCode PetscLayoutCreate(MPI_Comm comm, PetscLayout *map)
   (*map)->oldn        = -1;
   (*map)->oldN        = -1;
   (*map)->oldbs       = -1;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -79,7 +79,7 @@ PetscErrorCode PetscLayoutCreate(MPI_Comm comm, PetscLayout *map)
 . N     - the global size (or `PETSC_DECIDE`)
 - bs    - the block size (or `PETSC_DECIDE`)
 
-  Output Parameters:
+  Output Parameter:
 . map - the new `PetscLayout`
 
   Level: advanced
@@ -106,7 +106,7 @@ PetscErrorCode PetscLayoutCreateFromSizes(MPI_Comm comm, PetscInt n, PetscInt N,
   PetscCall(PetscLayoutSetSize(*map, N));
   PetscCall(PetscLayoutSetBlockSize(*map, bs));
   PetscCall(PetscLayoutSetUp(*map));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -114,7 +114,7 @@ PetscErrorCode PetscLayoutCreateFromSizes(MPI_Comm comm, PetscInt n, PetscInt N,
 
   Collective
 
-  Input Parameters:
+  Input Parameter:
 . map - the `PetscLayout`
 
   Level: developer
@@ -126,14 +126,14 @@ PetscErrorCode PetscLayoutCreateFromSizes(MPI_Comm comm, PetscInt n, PetscInt N,
 PetscErrorCode PetscLayoutDestroy(PetscLayout *map)
 {
   PetscFunctionBegin;
-  if (!*map) PetscFunctionReturn(0);
+  if (!*map) PetscFunctionReturn(PETSC_SUCCESS);
   if (!(*map)->refcnt--) {
     if ((*map)->range_alloc) PetscCall(PetscFree((*map)->range));
     PetscCall(ISLocalToGlobalMappingDestroy(&(*map)->mapping));
     PetscCall(PetscFree((*map)));
   }
   *map = NULL;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -147,7 +147,7 @@ PetscErrorCode PetscLayoutDestroy(PetscLayout *map)
 . mode  - the copy mode for range
 - bs    - the block size (or `PETSC_DECIDE`)
 
-  Output Parameters:
+  Output Parameter:
 . newmap - the new `PetscLayout`
 
   Level: developer
@@ -194,7 +194,7 @@ PetscErrorCode PetscLayoutCreateFromRanges(MPI_Comm comm, const PetscInt range[]
   map->oldN        = map->N;
   map->oldbs       = map->bs;
   *newmap          = map;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -203,7 +203,7 @@ PetscErrorCode PetscLayoutCreateFromRanges(MPI_Comm comm, const PetscInt range[]
 
   Collective
 
-  Input Parameters:
+  Input Parameter:
 . map - pointer to the map
 
   Level: developer
@@ -234,7 +234,7 @@ PetscErrorCode PetscLayoutSetUp(PetscLayout map)
   PetscFunctionBegin;
   PetscCheck(!map->setupcalled || !(map->n != map->oldn || map->N != map->oldN), map->comm, PETSC_ERR_ARG_WRONGSTATE, "Layout is already setup with (local=%" PetscInt_FMT ",global=%" PetscInt_FMT "), cannot call setup again with (local=%" PetscInt_FMT ",global=%" PetscInt_FMT ")",
              map->oldn, map->oldN, map->n, map->N);
-  if (map->setupcalled) PetscFunctionReturn(0);
+  if (map->setupcalled) PetscFunctionReturn(PETSC_SUCCESS);
 
   if (map->n > 0 && map->bs > 1) PetscCheck(map->n % map->bs == 0, PETSC_COMM_SELF, PETSC_ERR_PLIB, "Local size %" PetscInt_FMT " must be divisible by blocksize %" PetscInt_FMT, map->n, map->bs);
   if (map->N > 0 && map->bs > 1) PetscCheck(map->N % map->bs == 0, map->comm, PETSC_ERR_PLIB, "Global size %" PetscInt_FMT " must be divisible by blocksize %" PetscInt_FMT, map->N, map->bs);
@@ -259,13 +259,13 @@ PetscErrorCode PetscLayoutSetUp(PetscLayout map)
   map->oldn        = map->n;
   map->oldN        = map->N;
   map->oldbs       = map->bs;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   PetscLayoutDuplicate - creates a new `PetscLayout` with the same information as a given one. If the `PetscLayout` already exists it is destroyed first.
 
-  Collective on in
+  Collective
 
   Input Parameter:
 . in - input `PetscLayout` to be duplicated
@@ -293,13 +293,13 @@ PetscErrorCode PetscLayoutDuplicate(PetscLayout in, PetscLayout *out)
     PetscCall(PetscArraycpy((*out)->range, in->range, (*out)->size + 1));
   }
   (*out)->refcnt = 0;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   PetscLayoutReference - Causes a PETSc `Vec` or `Mat` to share a `PetscLayout` with one that already exists.
 
-  Collective on in
+  Collective
 
   Input Parameter:
 . in - input `PetscLayout` to be copied
@@ -322,13 +322,13 @@ PetscErrorCode PetscLayoutReference(PetscLayout in, PetscLayout *out)
   in->refcnt++;
   PetscCall(PetscLayoutDestroy(out));
   *out = in;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   PetscLayoutSetISLocalToGlobalMapping - sets a `ISLocalGlobalMapping` into a `PetscLayout`
 
-  Collective on in
+  Collective
 
   Input Parameters:
 + in - input `PetscLayout`
@@ -355,13 +355,13 @@ PetscErrorCode PetscLayoutSetISLocalToGlobalMapping(PetscLayout in, ISLocalToGlo
   }
   PetscCall(ISLocalToGlobalMappingDestroy(&in->mapping));
   in->mapping = ltog;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   PetscLayoutSetLocalSize - Sets the local size for a `PetscLayout` object.
 
-  Collective on map
+  Collective
 
   Input Parameters:
 + map - pointer to the map
@@ -377,7 +377,7 @@ PetscErrorCode PetscLayoutSetLocalSize(PetscLayout map, PetscInt n)
   PetscFunctionBegin;
   PetscCheck(map->bs <= 1 || (n % map->bs) == 0, map->comm, PETSC_ERR_ARG_INCOMP, "Local size %" PetscInt_FMT " not compatible with block size %" PetscInt_FMT, n, map->bs);
   map->n = n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -385,10 +385,10 @@ PetscErrorCode PetscLayoutSetLocalSize(PetscLayout map, PetscInt n)
 
     Not Collective
 
-   Input Parameters:
+   Input Parameter:
 .    map - pointer to the map
 
-   Output Parameters:
+   Output Parameter:
 .    n - the local size
 
    Level: developer
@@ -403,13 +403,13 @@ PetscErrorCode PetscLayoutGetLocalSize(PetscLayout map, PetscInt *n)
 {
   PetscFunctionBegin;
   *n = map->n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   PetscLayoutSetSize - Sets the global size for a `PetscLayout` object.
 
-  Logically Collective on map
+  Logically Collective
 
   Input Parameters:
 + map - pointer to the map
@@ -424,7 +424,7 @@ PetscErrorCode PetscLayoutSetSize(PetscLayout map, PetscInt n)
 {
   PetscFunctionBegin;
   map->N = n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -432,10 +432,10 @@ PetscErrorCode PetscLayoutSetSize(PetscLayout map, PetscInt n)
 
   Not Collective
 
-  Input Parameters:
+  Input Parameter:
 . map - pointer to the map
 
-  Output Parameters:
+  Output Parameter:
 . n - the global size
 
   Level: developer
@@ -450,13 +450,13 @@ PetscErrorCode PetscLayoutGetSize(PetscLayout map, PetscInt *n)
 {
   PetscFunctionBegin;
   *n = map->N;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   PetscLayoutSetBlockSize - Sets the block size for a `PetscLayout` object.
 
-  Logically Collective on map
+  Logically Collective
 
   Input Parameters:
 + map - pointer to the map
@@ -470,7 +470,7 @@ PetscErrorCode PetscLayoutGetSize(PetscLayout map, PetscInt *n)
 PetscErrorCode PetscLayoutSetBlockSize(PetscLayout map, PetscInt bs)
 {
   PetscFunctionBegin;
-  if (bs < 0) PetscFunctionReturn(0);
+  if (bs < 0) PetscFunctionReturn(PETSC_SUCCESS);
   PetscCheck(map->n <= 0 || (map->n % bs) == 0, PETSC_COMM_SELF, PETSC_ERR_ARG_INCOMP, "Local size %" PetscInt_FMT " not compatible with block size %" PetscInt_FMT, map->n, bs);
   if (map->mapping) {
     PetscInt obs;
@@ -479,7 +479,7 @@ PetscErrorCode PetscLayoutSetBlockSize(PetscLayout map, PetscInt bs)
     if (obs > 1) PetscCall(ISLocalToGlobalMappingSetBlockSize(map->mapping, bs));
   }
   map->bs = bs;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -487,10 +487,10 @@ PetscErrorCode PetscLayoutSetBlockSize(PetscLayout map, PetscInt bs)
 
   Not Collective
 
-  Input Parameters:
+  Input Parameter:
 . map - pointer to the map
 
-  Output Parameters:
+  Output Parameter:
 . bs - the size
 
   Level: developer
@@ -505,7 +505,7 @@ PetscErrorCode PetscLayoutGetBlockSize(PetscLayout map, PetscInt *bs)
 {
   PetscFunctionBegin;
   *bs = PetscAbs(map->bs);
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -533,7 +533,7 @@ PetscErrorCode PetscLayoutGetRange(PetscLayout map, PetscInt *rstart, PetscInt *
   PetscFunctionBegin;
   if (rstart) *rstart = map->rstart;
   if (rend) *rend = map->rend;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -541,10 +541,10 @@ PetscErrorCode PetscLayoutGetRange(PetscLayout map, PetscInt *rstart, PetscInt *
 
     Not Collective
 
-   Input Parameters:
+   Input Parameter:
 .    map - pointer to the map
 
-   Output Parameters:
+   Output Parameter:
 .    range - start of each processors range of indices (the final entry is one more than the
              last index on the last process)
 
@@ -554,7 +554,7 @@ PetscErrorCode PetscLayoutGetRange(PetscLayout map, PetscInt *rstart, PetscInt *
     Call this after the call to `PetscLayoutSetUp()`
 
     Fortran Note:
-    Not available from Fortran
+    In Fortran, use PetscLayoutGetRangesF90()
 
 .seealso: [PetscLayout](sec_matlayout), `PetscLayoutCreate()`, `PetscLayoutSetLocalSize()`, `PetscLayoutGetLocalSize()`, `PetscLayoutSetSize()`,
           `PetscLayoutGetSize()`, `PetscLayoutGetRange()`, `PetscLayoutSetBlockSize()`, `PetscLayoutGetSize()`, `PetscLayoutSetUp()`
@@ -563,7 +563,7 @@ PetscErrorCode PetscLayoutGetRanges(PetscLayout map, const PetscInt *range[])
 {
   PetscFunctionBegin;
   *range = map->range;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
@@ -575,7 +575,7 @@ PetscErrorCode PetscLayoutGetRanges(PetscLayout map, const PetscInt *range[])
 + mapa - pointer to the first map
 - mapb - pointer to the second map
 
-  Output Parameters:
+  Output Parameter:
 . congruent - `PETSC_TRUE` if the two layouts are congruent, `PETSC_FALSE` otherwise
 
   Level: beginner
@@ -588,5 +588,5 @@ PetscErrorCode PetscLayoutCompare(PetscLayout mapa, PetscLayout mapb, PetscBool
   PetscFunctionBegin;
   *congruent = PETSC_FALSE;
   if (mapa->N == mapb->N && mapa->range && mapb->range && mapa->size == mapb->size) PetscCall(PetscArraycmp(mapa->range, mapb->range, mapa->size + 1, congruent));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
