@@ -10,19 +10,19 @@ PetscBool         PFRegisterAllCalled = PETSC_FALSE;
 /*@C
    PFSet - Sets the C/C++/Fortran functions to be used by the PF function
 
-   Collective on PF
+   Collective
 
    Input Parameters:
 +  pf - the function context
 .  apply - function to apply to an array
 .  applyvec - function to apply to a Vec
-.  view - function that prints information about the PF
+.  view - function that prints information about the `PF`
 .  destroy - function to free the private function context
 -  ctx - private function context
 
    Level: beginner
 
-.seealso: `PFCreate()`, `PFDestroy()`, `PFSetType()`, `PFApply()`, `PFApplyVec()`
+.seealso: `PF`, `PFCreate()`, `PFDestroy()`, `PFSetType()`, `PFApply()`, `PFApplyVec()`
 @*/
 PetscErrorCode PFSet(PF pf, PetscErrorCode (*apply)(void *, PetscInt, const PetscScalar *, PetscScalar *), PetscErrorCode (*applyvec)(void *, Vec, Vec), PetscErrorCode (*view)(void *, PetscViewer), PetscErrorCode (*destroy)(void *), void *ctx)
 {
@@ -33,27 +33,27 @@ PetscErrorCode PFSet(PF pf, PetscErrorCode (*apply)(void *, PetscInt, const Pets
   pf->ops->apply    = apply;
   pf->ops->applyvec = applyvec;
   pf->ops->view     = view;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PFDestroy - Destroys PF context that was created with PFCreate().
+   PFDestroy - Destroys `PF` context that was created with `PFCreate()`.
 
-   Collective on PF
+   Collective
 
    Input Parameter:
 .  pf - the function context
 
    Level: beginner
 
-.seealso: `PFCreate()`, `PFSet()`, `PFSetType()`
+.seealso: `PF`, `PFCreate()`, `PFSet()`, `PFSetType()`
 @*/
 PetscErrorCode PFDestroy(PF *pf)
 {
   PetscFunctionBegin;
-  if (!*pf) PetscFunctionReturn(0);
+  if (!*pf) PetscFunctionReturn(PETSC_SUCCESS);
   PetscValidHeaderSpecific((*pf), PF_CLASSID, 1);
-  if (--((PetscObject)(*pf))->refct > 0) PetscFunctionReturn(0);
+  if (--((PetscObject)(*pf))->refct > 0) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscCall(PFViewFromOptions(*pf, NULL, "-pf_view"));
   /* if memory was published with SAWs then destroy it */
@@ -61,7 +61,7 @@ PetscErrorCode PFDestroy(PF *pf)
 
   if ((*pf)->ops->destroy) PetscCall((*(*pf)->ops->destroy)((*pf)->data));
   PetscCall(PetscHeaderDestroy(pf));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -79,7 +79,7 @@ PetscErrorCode PFDestroy(PF *pf)
 
    Level: developer
 
-.seealso: `PFSet()`, `PFApply()`, `PFDestroy()`, `PFApplyVec()`
+.seealso: `PF`, `PFSet()`, `PFApply()`, `PFDestroy()`, `PFApplyVec()`
 @*/
 PetscErrorCode PFCreate(MPI_Comm comm, PetscInt dimin, PetscInt dimout, PF *pf)
 {
@@ -100,7 +100,7 @@ PetscErrorCode PFCreate(MPI_Comm comm, PetscInt dimin, PetscInt dimout, PF *pf)
   newpf->dimout        = dimout;
 
   *pf = newpf;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /* -------------------------------------------------------------------------------*/
@@ -108,18 +108,18 @@ PetscErrorCode PFCreate(MPI_Comm comm, PetscInt dimin, PetscInt dimout, PF *pf)
 /*@
    PFApplyVec - Applies the mathematical function to a vector
 
-   Collective on PF
+   Collective
 
    Input Parameters:
 +  pf - the function context
--  x - input vector (or NULL for the vector (0,1, .... N-1)
+-  x - input vector (or `NULL` for the vector (0,1, .... N-1)
 
    Output Parameter:
 .  y - output vector
 
    Level: beginner
 
-.seealso: `PFApply()`, `PFCreate()`, `PFDestroy()`, `PFSetType()`, `PFSet()`
+.seealso: `PF`, `PFApply()`, `PFCreate()`, `PFDestroy()`, `PFSetType()`, `PFSet()`
 @*/
 PetscErrorCode PFApplyVec(PF pf, Vec x, Vec y)
 {
@@ -165,19 +165,19 @@ PetscErrorCode PFApplyVec(PF pf, Vec x, Vec y)
     PetscCall(VecRestoreArray(y, &yy));
   }
   if (nox) PetscCall(VecDestroy(&x));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PFApply - Applies the mathematical function to an array of values.
 
-   Collective on PF
+   Collective
 
    Input Parameters:
 +  pf - the function context
 .  n - number of pointwise function evaluations to perform, each pointwise function evaluation
        is a function of dimin variables and computes dimout variables where dimin and dimout are defined
-       in the call to PFCreate()
+       in the call to `PFCreate()`
 -  x - input array
 
    Output Parameter:
@@ -185,9 +185,7 @@ PetscErrorCode PFApplyVec(PF pf, Vec x, Vec y)
 
    Level: beginner
 
-   Notes:
-
-.seealso: `PFApplyVec()`, `PFCreate()`, `PFDestroy()`, `PFSetType()`, `PFSet()`
+.seealso: `PF`, `PFApplyVec()`, `PFCreate()`, `PFDestroy()`, `PFSetType()`, `PFSet()`
 @*/
 PetscErrorCode PFApply(PF pf, PetscInt n, const PetscScalar *x, PetscScalar *y)
 {
@@ -198,20 +196,24 @@ PetscErrorCode PFApply(PF pf, PetscInt n, const PetscScalar *x, PetscScalar *y)
   PetscCheck(x != y, PETSC_COMM_SELF, PETSC_ERR_ARG_IDN, "x and y must be different arrays");
 
   PetscCall((*pf->ops->apply)(pf->data, n, x, y));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PFViewFromOptions - View from Options
+   PFViewFromOptions - View a `PF` based on options set in the options database
 
-   Collective on PF
+   Collective
 
    Input Parameters:
-+  A - the PF context
-.  obj - Optional object
++  A - the `PF` context
+.  obj - Optional object that provides the prefix used to search the options database
 -  name - command line option
 
    Level: intermediate
+
+   Note:
+  See `PetscObjectViewFromOptions()` for the variety of viewer options available
+
 .seealso: `PF`, `PFView`, `PetscObjectViewFromOptions()`, `PFCreate()`
 @*/
 PetscErrorCode PFViewFromOptions(PF A, PetscObject obj, const char name[])
@@ -219,32 +221,32 @@ PetscErrorCode PFViewFromOptions(PF A, PetscObject obj, const char name[])
   PetscFunctionBegin;
   PetscValidHeaderSpecific(A, PF_CLASSID, 1);
   PetscCall(PetscObjectViewFromOptions((PetscObject)A, obj, name));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    PFView - Prints information about a mathematical function
 
-   Collective on PF unless PetscViewer is PETSC_VIEWER_STDOUT_SELF
+   Collective unless `viewer` is `PETSC_VIEWER_STDOUT_SELF`
 
    Input Parameters:
-+  PF - the PF context
++  PF - the `PF` context
 -  viewer - optional visualization context
 
+   Level: developer
+
    Note:
    The available visualization contexts include
-+     PETSC_VIEWER_STDOUT_SELF - standard output (default)
--     PETSC_VIEWER_STDOUT_WORLD - synchronized standard
++     `PETSC_VIEWER_STDOUT_SELF` - standard output (default)
+-     `PETSC_VIEWER_STDOUT_WORLD` - synchronized standard
          output where only the first processor opens
          the file.  All other processors send their
          data to the first processor to print.
 
    The user can open an alternative visualization contexts with
-   PetscViewerASCIIOpen() (output to a specified file).
+   `PetscViewerASCIIOpen()` (output to a specified file).
 
-   Level: developer
-
-.seealso: `PetscViewerCreate()`, `PetscViewerASCIIOpen()`
+.seealso: `PF`, `PetscViewerCreate()`, `PetscViewerASCIIOpen()`
 @*/
 PetscErrorCode PFView(PF pf, PetscViewer viewer)
 {
@@ -267,20 +269,17 @@ PetscErrorCode PFView(PF pf, PetscViewer viewer)
       PetscCall(PetscViewerASCIIPopTab(viewer));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    PFRegister - Adds a method to the mathematical function package.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
-+  name_solver - name of a new user-defined solver
--  routine_create - routine to create method context
-
-   Notes:
-   PFRegister() may be called multiple times to add several user-defined functions
++  sname - name of a new user-defined solver
+-  function - routine to create method context
 
    Sample usage:
 .vb
@@ -294,18 +293,21 @@ $     -pf_type my_function
 
    Level: advanced
 
-.seealso: `PFRegisterAll()`, `PFRegisterDestroy()`, `PFRegister()`
+   Note:
+   `PFRegister()` may be called multiple times to add several user-defined functions
+
+.seealso: `PF`, `PFRegisterAll()`, `PFRegisterDestroy()`, `PFRegister()`
 @*/
 PetscErrorCode PFRegister(const char sname[], PetscErrorCode (*function)(PF, void *))
 {
   PetscFunctionBegin;
   PetscCall(PFInitializePackage());
   PetscCall(PetscFunctionListAdd(&PFList, sname, function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PFGetType - Gets the PF method type and name (as a string) from the PF
+   PFGetType - Gets the `PFType` name (as a string) from the `PF`
    context.
 
    Not Collective
@@ -318,8 +320,7 @@ PetscErrorCode PFRegister(const char sname[], PetscErrorCode (*function)(PF, voi
 
    Level: intermediate
 
-.seealso: `PFSetType()`
-
+.seealso: `PF`, `PFSetType()`
 @*/
 PetscErrorCode PFGetType(PF pf, PFType *type)
 {
@@ -327,13 +328,13 @@ PetscErrorCode PFGetType(PF pf, PFType *type)
   PetscValidHeaderSpecific(pf, PF_CLASSID, 1);
   PetscValidPointer(type, 2);
   *type = ((PetscObject)pf)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-   PFSetType - Builds PF for a particular function
+   PFSetType - Builds `PF` for a particular function
 
-   Collective on PF
+   Collective
 
    Input Parameters:
 +  pf - the function context.
@@ -343,14 +344,12 @@ PetscErrorCode PFGetType(PF pf, PFType *type)
    Options Database Key:
 .  -pf_type <type> - Sets PF type
 
-  Notes:
-  See "petsc/include/petscpf.h" for available methods (for instance,
-  PFCONSTANT)
-
   Level: intermediate
 
-.seealso: `PFSet()`, `PFRegister()`, `PFCreate()`, `DMDACreatePF()`
+  Note:
+  See "petsc/include/petscpf.h" for available methods (for instance, `PFCONSTANT`)
 
+.seealso: `PF`, `PFSet()`, `PFRegister()`, `PFCreate()`, `DMDACreatePF()`
 @*/
 PetscErrorCode PFSetType(PF pf, PFType type, void *ctx)
 {
@@ -362,7 +361,7 @@ PetscErrorCode PFSetType(PF pf, PFType type, void *ctx)
   PetscValidCharPointer(type, 2);
 
   PetscCall(PetscObjectTypeCompare((PetscObject)pf, type, &match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   PetscTryTypeMethod(pf, destroy);
   pf->data = NULL;
@@ -379,26 +378,24 @@ PetscErrorCode PFSetType(PF pf, PFType type, void *ctx)
   PetscCall((*r)(pf, ctx));
 
   PetscCall(PetscObjectChangeTypeName((PetscObject)pf, type));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
-   PFSetFromOptions - Sets PF options from the options database.
+   PFSetFromOptions - Sets `PF` options from the options database.
 
-   Collective on PF
+   Collective
 
    Input Parameters:
 .  pf - the mathematical function context
 
-   Options Database Keys:
+   Level: intermediate
 
    Notes:
    To see all options, run your program with the -help option
    or consult the users manual.
 
-   Level: intermediate
-
-.seealso:
+.seealso: `PF`
 @*/
 PetscErrorCode PFSetFromOptions(PF pf)
 {
@@ -416,17 +413,17 @@ PetscErrorCode PFSetFromOptions(PF pf)
   /* process any options handlers added with PetscObjectAddOptionsHandler() */
   PetscCall(PetscObjectProcessOptionsHandlers((PetscObject)pf, PetscOptionsObject));
   PetscOptionsEnd();
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscBool PFPackageInitialized = PETSC_FALSE;
 /*@C
-  PFFinalizePackage - This function destroys everything in the Petsc interface to Mathematica. It is
-  called from PetscFinalize().
+  PFFinalizePackage - This function destroys everything in the PETSc `PF` package. It is
+  called from `PetscFinalize()`.
 
   Level: developer
 
-.seealso: `PetscFinalize()`
+.seealso: `PF`, `PetscFinalize()`
 @*/
 PetscErrorCode PFFinalizePackage(void)
 {
@@ -434,17 +431,17 @@ PetscErrorCode PFFinalizePackage(void)
   PetscCall(PetscFunctionListDestroy(&PFList));
   PFPackageInitialized = PETSC_FALSE;
   PFRegisterAllCalled  = PETSC_FALSE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  PFInitializePackage - This function initializes everything in the PF package. It is called
-  from PetscDLLibraryRegister_petscvec() when using dynamic libraries, and on the first call to PFCreate()
+  PFInitializePackage - This function initializes everything in the `PF` package. It is called
+  from PetscDLLibraryRegister_petscvec() when using dynamic libraries, and on the first call to `PFCreate()`
   when using shared or static libraries.
 
   Level: developer
 
-.seealso: `PetscInitialize()`
+.seealso: `PF`, `PetscInitialize()`
 @*/
 PetscErrorCode PFInitializePackage(void)
 {
@@ -452,7 +449,7 @@ PetscErrorCode PFInitializePackage(void)
   PetscBool opt, pkg;
 
   PetscFunctionBegin;
-  if (PFPackageInitialized) PetscFunctionReturn(0);
+  if (PFPackageInitialized) PetscFunctionReturn(PETSC_SUCCESS);
   PFPackageInitialized = PETSC_TRUE;
   /* Register Classes */
   PetscCall(PetscClassIdRegister("PointFunction", &PF_CLASSID));
@@ -473,5 +470,5 @@ PetscErrorCode PFInitializePackage(void)
   }
   /* Register package finalizer */
   PetscCall(PetscRegisterFinalize(PFFinalizePackage));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
