@@ -12,7 +12,7 @@ static PetscErrorCode VecAssemblyBegin_Nest(Vec v)
     PetscCheck(vs->v[i], PetscObjectComm((PetscObject)v), PETSC_ERR_SUP, "Nest  vector cannot contain NULL blocks");
     PetscCall(VecAssemblyBegin(vs->v[i]));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecAssemblyEnd_Nest(Vec v)
@@ -22,7 +22,7 @@ static PetscErrorCode VecAssemblyEnd_Nest(Vec v)
 
   PetscFunctionBegin;
   for (i = 0; i < vs->nb; i++) PetscCall(VecAssemblyEnd(vs->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecDestroy_Nest(Vec v)
@@ -44,7 +44,7 @@ static PetscErrorCode VecDestroy_Nest(Vec v)
   PetscCall(PetscObjectComposeFunction((PetscObject)v, "VecNestGetSize_C", NULL));
 
   PetscCall(PetscFree(vs));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecCopy_Nest(Vec x, Vec y)
@@ -54,10 +54,9 @@ static PetscErrorCode VecCopy_Nest(Vec x, Vec y)
   PetscInt  i;
 
   PetscFunctionBegin;
-  PetscCheckTypeName(y, VECNEST);
   VecNestCheckCompatible2(x, 1, y, 2);
   for (i = 0; i < bx->nb; i++) PetscCall(VecCopy(bx->v[i], by->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecDuplicate_Nest(Vec x, Vec *y)
@@ -74,7 +73,7 @@ static PetscErrorCode VecDuplicate_Nest(Vec x, Vec *y)
   for (i = 0; i < bx->nb; i++) PetscCall(VecDestroy(&sub[i]));
   PetscCall(PetscFree(sub));
   *y = Y;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecDot_Nest(Vec x, Vec y, PetscScalar *val)
@@ -85,6 +84,7 @@ static PetscErrorCode VecDot_Nest(Vec x, Vec y, PetscScalar *val)
   PetscScalar x_dot_y, _val;
 
   PetscFunctionBegin;
+  VecNestCheckCompatible2(x, 1, y, 2);
   nr   = bx->nb;
   _val = 0.0;
   for (i = 0; i < nr; i++) {
@@ -92,7 +92,7 @@ static PetscErrorCode VecDot_Nest(Vec x, Vec y, PetscScalar *val)
     _val = _val + x_dot_y;
   }
   *val = _val;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecTDot_Nest(Vec x, Vec y, PetscScalar *val)
@@ -103,6 +103,7 @@ static PetscErrorCode VecTDot_Nest(Vec x, Vec y, PetscScalar *val)
   PetscScalar x_dot_y, _val;
 
   PetscFunctionBegin;
+  VecNestCheckCompatible2(x, 1, y, 2);
   nr   = bx->nb;
   _val = 0.0;
   for (i = 0; i < nr; i++) {
@@ -110,7 +111,7 @@ static PetscErrorCode VecTDot_Nest(Vec x, Vec y, PetscScalar *val)
     _val = _val + x_dot_y;
   }
   *val = _val;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecDotNorm2_Nest(Vec x, Vec y, PetscScalar *dp, PetscScalar *nm)
@@ -122,6 +123,7 @@ static PetscErrorCode VecDotNorm2_Nest(Vec x, Vec y, PetscScalar *dp, PetscScala
   PetscReal   norm2_y;
 
   PetscFunctionBegin;
+  VecNestCheckCompatible2(x, 1, y, 2);
   nr  = bx->nb;
   _dp = 0.0;
   _nm = 0.0;
@@ -132,7 +134,7 @@ static PetscErrorCode VecDotNorm2_Nest(Vec x, Vec y, PetscScalar *dp, PetscScala
   }
   *dp = _dp;
   *nm = _nm;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecAXPY_Nest(Vec y, PetscScalar alpha, Vec x)
@@ -142,9 +144,10 @@ static PetscErrorCode VecAXPY_Nest(Vec y, PetscScalar alpha, Vec x)
   PetscInt  i, nr;
 
   PetscFunctionBegin;
+  VecNestCheckCompatible2(y, 1, x, 3);
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecAXPY(by->v[i], alpha, bx->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecAYPX_Nest(Vec y, PetscScalar alpha, Vec x)
@@ -154,9 +157,10 @@ static PetscErrorCode VecAYPX_Nest(Vec y, PetscScalar alpha, Vec x)
   PetscInt  i, nr;
 
   PetscFunctionBegin;
+  VecNestCheckCompatible2(y, 1, x, 3);
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecAYPX(by->v[i], alpha, bx->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecAXPBY_Nest(Vec y, PetscScalar alpha, PetscScalar beta, Vec x)
@@ -166,9 +170,10 @@ static PetscErrorCode VecAXPBY_Nest(Vec y, PetscScalar alpha, PetscScalar beta,
   PetscInt  i, nr;
 
   PetscFunctionBegin;
+  VecNestCheckCompatible2(y, 1, x, 4);
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecAXPBY(by->v[i], alpha, beta, bx->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecAXPBYPCZ_Nest(Vec z, PetscScalar alpha, PetscScalar beta, PetscScalar gamma, Vec x, Vec y)
@@ -179,9 +184,10 @@ static PetscErrorCode VecAXPBYPCZ_Nest(Vec z, PetscScalar alpha, PetscScalar bet
   PetscInt  i, nr;
 
   PetscFunctionBegin;
+  VecNestCheckCompatible3(z, 1, x, 5, y, 6);
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecAXPBYPCZ(bz->v[i], alpha, beta, gamma, bx->v[i], by->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecScale_Nest(Vec x, PetscScalar alpha)
@@ -192,7 +198,7 @@ static PetscErrorCode VecScale_Nest(Vec x, PetscScalar alpha)
   PetscFunctionBegin;
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecScale(bx->v[i], alpha));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecPointwiseMult_Nest(Vec w, Vec x, Vec y)
@@ -206,7 +212,7 @@ static PetscErrorCode VecPointwiseMult_Nest(Vec w, Vec x, Vec y)
   VecNestCheckCompatible3(w, 1, x, 2, y, 3);
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecPointwiseMult(bw->v[i], bx->v[i], by->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecPointwiseDivide_Nest(Vec w, Vec x, Vec y)
@@ -218,10 +224,9 @@ static PetscErrorCode VecPointwiseDivide_Nest(Vec w, Vec x, Vec y)
 
   PetscFunctionBegin;
   VecNestCheckCompatible3(w, 1, x, 2, y, 3);
-
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecPointwiseDivide(bw->v[i], bx->v[i], by->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecReciprocal_Nest(Vec x)
@@ -232,7 +237,7 @@ static PetscErrorCode VecReciprocal_Nest(Vec x)
   PetscFunctionBegin;
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecReciprocal(bx->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecNorm_Nest(Vec xin, NormType type, PetscReal *z)
@@ -263,37 +268,31 @@ static PetscErrorCode VecNorm_Nest(Vec xin, NormType type, PetscReal *z)
   }
 
   *z = _z;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecMAXPY_Nest(Vec y, PetscInt nv, const PetscScalar alpha[], Vec *x)
 {
-  PetscInt v;
-
   PetscFunctionBegin;
-  for (v = 0; v < nv; v++) {
-    /* Do axpy on each vector,v */
-    PetscCall(VecAXPY(y, alpha[v], x[v]));
-  }
-  PetscFunctionReturn(0);
+  /* TODO: implement proper MAXPY. For now, do axpy on each vector */
+  for (PetscInt v = 0; v < nv; v++) PetscCall(VecAXPY(y, alpha[v], x[v]));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecMDot_Nest(Vec x, PetscInt nv, const Vec y[], PetscScalar *val)
 {
-  PetscInt j;
-
   PetscFunctionBegin;
-  for (j = 0; j < nv; j++) PetscCall(VecDot(x, y[j], &val[j]));
-  PetscFunctionReturn(0);
+  /* TODO: implement proper MDOT. For now, do dot on each vector */
+  for (PetscInt j = 0; j < nv; j++) PetscCall(VecDot(x, y[j], &val[j]));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecMTDot_Nest(Vec x, PetscInt nv, const Vec y[], PetscScalar *val)
 {
-  PetscInt j;
-
   PetscFunctionBegin;
-  for (j = 0; j < nv; j++) PetscCall(VecTDot(x, y[j], &val[j]));
-  PetscFunctionReturn(0);
+  /* TODO: implement proper MTDOT. For now, do tdot on each vector */
+  for (PetscInt j = 0; j < nv; j++) PetscCall(VecTDot(x, y[j], &val[j]));
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecSet_Nest(Vec x, PetscScalar alpha)
@@ -304,7 +303,7 @@ static PetscErrorCode VecSet_Nest(Vec x, PetscScalar alpha)
   PetscFunctionBegin;
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecSet(bx->v[i], alpha));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecConjugate_Nest(Vec x)
@@ -315,7 +314,7 @@ static PetscErrorCode VecConjugate_Nest(Vec x)
   PetscFunctionBegin;
   nr = bx->nb;
   for (j = 0; j < nr; j++) PetscCall(VecConjugate(bx->v[j]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecSwap_Nest(Vec x, Vec y)
@@ -328,7 +327,7 @@ static PetscErrorCode VecSwap_Nest(Vec x, Vec y)
   VecNestCheckCompatible2(x, 1, y, 2);
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecSwap(bx->v[i], by->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecWAXPY_Nest(Vec w, PetscScalar alpha, Vec x, Vec y)
@@ -340,10 +339,9 @@ static PetscErrorCode VecWAXPY_Nest(Vec w, PetscScalar alpha, Vec x, Vec y)
 
   PetscFunctionBegin;
   VecNestCheckCompatible3(w, 1, x, 3, y, 4);
-
   nr = bx->nb;
   for (i = 0; i < nr; i++) PetscCall(VecWAXPY(bw->v[i], alpha, bx->v[i], by->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecMin_Nest(Vec x, PetscInt *p, PetscReal *v)
@@ -374,9 +372,9 @@ static PetscErrorCode VecMin_Nest(Vec x, PetscInt *p, PetscReal *v)
       *p = idxs[lp - st];
       PetscCall(ISRestoreIndices(bx->is[lw], &idxs));
     }
-    PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, p, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)x)));
+    PetscCall(MPIU_Allreduce(MPI_IN_PLACE, p, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)x)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecMax_Nest(Vec x, PetscInt *p, PetscReal *v)
@@ -407,9 +405,9 @@ static PetscErrorCode VecMax_Nest(Vec x, PetscInt *p, PetscReal *v)
       *p = idxs[lp - st];
       PetscCall(ISRestoreIndices(bx->is[lw], &idxs));
     }
-    PetscCallMPI(MPIU_Allreduce(MPI_IN_PLACE, p, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)x)));
+    PetscCall(MPIU_Allreduce(MPI_IN_PLACE, p, 1, MPIU_INT, MPI_MAX, PetscObjectComm((PetscObject)x)));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecView_Nest(Vec x, PetscViewer viewer)
@@ -441,7 +439,7 @@ static PetscErrorCode VecView_Nest(Vec x, PetscViewer viewer)
     }
     PetscCall(PetscViewerASCIIPopTab(viewer)); /* pop0 */
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecSize_Nest_Recursive(Vec x, PetscBool globalsize, PetscInt *L)
@@ -457,7 +455,7 @@ static PetscErrorCode VecSize_Nest_Recursive(Vec x, PetscBool globalsize, PetscI
     if (globalsize) PetscCall(VecGetSize(x, &size));
     else PetscCall(VecGetLocalSize(x, &size));
     *L = *L + size;
-    PetscFunctionReturn(0);
+    PetscFunctionReturn(PETSC_SUCCESS);
   }
 
   /* Otherwise we have a nest */
@@ -466,23 +464,23 @@ static PetscErrorCode VecSize_Nest_Recursive(Vec x, PetscBool globalsize, PetscI
 
   /* now descend recursively */
   for (i = 0; i < nr; i++) PetscCall(VecSize_Nest_Recursive(bx->v[i], globalsize, L));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* Returns the sum of the global size of all the consituent vectors in the nest */
+/* Returns the sum of the global size of all the constituent vectors in the nest */
 static PetscErrorCode VecGetSize_Nest(Vec x, PetscInt *N)
 {
   PetscFunctionBegin;
   *N = x->map->N;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
-/* Returns the sum of the local size of all the consituent vectors in the nest */
+/* Returns the sum of the local size of all the constituent vectors in the nest */
 static PetscErrorCode VecGetLocalSize_Nest(Vec x, PetscInt *n)
 {
   PetscFunctionBegin;
   *n = x->map->n;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecMaxPointwiseDivide_Nest(Vec x, Vec y, PetscReal *max)
@@ -501,7 +499,7 @@ static PetscErrorCode VecMaxPointwiseDivide_Nest(Vec x, Vec y, PetscReal *max)
     if (local_max > m) m = local_max;
   }
   *max = m;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecGetSubVector_Nest(Vec X, IS is, Vec *x)
@@ -521,7 +519,7 @@ static PetscErrorCode VecGetSubVector_Nest(Vec X, IS is, Vec *x)
     }
   }
   PetscCheck(*x, PetscObjectComm((PetscObject)is), PETSC_ERR_ARG_OUTOFRANGE, "Index set not found in nested Vec");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecRestoreSubVector_Nest(Vec X, IS is, Vec *x)
@@ -529,7 +527,7 @@ static PetscErrorCode VecRestoreSubVector_Nest(Vec X, IS is, Vec *x)
   PetscFunctionBegin;
   PetscCall(PetscObjectStateIncrease((PetscObject)X));
   PetscCall(VecDestroy(x));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecGetArray_Nest(Vec X, PetscScalar **x)
@@ -558,7 +556,7 @@ static PetscErrorCode VecGetArray_Nest(Vec X, PetscScalar **x)
     PetscCall(ISRestoreIndices(isy, &ixy));
     PetscCall(VecRestoreArrayRead(subvec, &y));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecRestoreArray_Nest(Vec X, PetscScalar **x)
@@ -588,21 +586,21 @@ static PetscErrorCode VecRestoreArray_Nest(Vec X, PetscScalar **x)
   }
   PetscCall(PetscFree(*x));
   PetscCall(PetscObjectStateIncrease((PetscObject)X));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecRestoreArrayRead_Nest(Vec X, const PetscScalar **x)
 {
   PetscFunctionBegin;
   PetscCall(PetscFree(*x));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecConcatenate_Nest(PetscInt nx, const Vec X[], Vec *Y, IS *x_is[])
 {
   PetscFunctionBegin;
   PetscCheck(nx <= 0, PetscObjectComm((PetscObject)(*X)), PETSC_ERR_SUP, "VecConcatenate() is not supported for VecNest");
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecCreateLocalVector_Nest(Vec v, Vec *w)
@@ -628,7 +626,7 @@ static PetscErrorCode VecCreateLocalVector_Nest(Vec v, Vec *w)
     PetscCall(ISDestroy(&wis[i]));
   }
   PetscCall(PetscFree2(ww, wis));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecGetLocalVector_Nest(Vec v, Vec w)
@@ -641,7 +639,7 @@ static PetscErrorCode VecGetLocalVector_Nest(Vec v, Vec w)
   PetscCheckSameType(v, 1, w, 2);
   PetscCheck(bv->nb = bw->nb, PetscObjectComm((PetscObject)w), PETSC_ERR_ARG_WRONG, "Invalid local vector");
   for (i = 0; i < bv->nb; i++) PetscCall(VecGetLocalVector(bv->v[i], bw->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecRestoreLocalVector_Nest(Vec v, Vec w)
@@ -655,7 +653,7 @@ static PetscErrorCode VecRestoreLocalVector_Nest(Vec v, Vec w)
   PetscCheck(bv->nb = bw->nb, PetscObjectComm((PetscObject)w), PETSC_ERR_ARG_WRONG, "Invalid local vector");
   for (i = 0; i < bv->nb; i++) PetscCall(VecRestoreLocalVector(bv->v[i], bw->v[i]));
   PetscCall(PetscObjectStateIncrease((PetscObject)v));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecGetLocalVectorRead_Nest(Vec v, Vec w)
@@ -668,7 +666,7 @@ static PetscErrorCode VecGetLocalVectorRead_Nest(Vec v, Vec w)
   PetscCheckSameType(v, 1, w, 2);
   PetscCheck(bv->nb = bw->nb, PetscObjectComm((PetscObject)w), PETSC_ERR_ARG_WRONG, "Invalid local vector");
   for (i = 0; i < bv->nb; i++) PetscCall(VecGetLocalVectorRead(bv->v[i], bw->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecRestoreLocalVectorRead_Nest(Vec v, Vec w)
@@ -681,7 +679,7 @@ static PetscErrorCode VecRestoreLocalVectorRead_Nest(Vec v, Vec w)
   PetscCheckSameType(v, 1, w, 2);
   PetscCheck(bv->nb = bw->nb, PetscObjectComm((PetscObject)w), PETSC_ERR_ARG_WRONG, "Invalid local vector");
   for (i = 0; i < bv->nb; i++) PetscCall(VecRestoreLocalVectorRead(bv->v[i], bw->v[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecSetRandom_Nest(Vec v, PetscRandom r)
@@ -691,7 +689,7 @@ static PetscErrorCode VecSetRandom_Nest(Vec v, PetscRandom r)
 
   PetscFunctionBegin;
   for (i = 0; i < bv->nb; i++) PetscCall(VecSetRandom(bv->v[i], r));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecNestSetOps_Private(struct _VecOps *ops)
@@ -770,7 +768,7 @@ static PetscErrorCode VecNestSetOps_Private(struct _VecOps *ops)
   ops->restorelocalvector      = VecRestoreLocalVector_Nest;
   ops->restorelocalvectorread  = VecRestoreLocalVectorRead_Nest;
   ops->setrandom               = VecSetRandom_Nest;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecNestGetSubVecs_Private(Vec x, PetscInt m, const PetscInt idxm[], Vec vec[])
@@ -780,13 +778,13 @@ static PetscErrorCode VecNestGetSubVecs_Private(Vec x, PetscInt m, const PetscIn
   PetscInt  row;
 
   PetscFunctionBegin;
-  if (!m) PetscFunctionReturn(0);
+  if (!m) PetscFunctionReturn(PETSC_SUCCESS);
   for (i = 0; i < m; i++) {
     row = idxm[i];
     PetscCheck(row < b->nb, PetscObjectComm((PetscObject)x), PETSC_ERR_ARG_OUTOFRANGE, "Row too large: row %" PetscInt_FMT " max %" PetscInt_FMT, row, b->nb - 1);
     vec[i] = b->v[row];
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode VecNestGetSubVec_Nest(Vec X, PetscInt idxm, Vec *sx)
@@ -794,32 +792,30 @@ PetscErrorCode VecNestGetSubVec_Nest(Vec X, PetscInt idxm, Vec *sx)
   PetscFunctionBegin;
   PetscCall(PetscObjectStateIncrease((PetscObject)X));
   PetscCall(VecNestGetSubVecs_Private(X, 1, &idxm, sx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
  VecNestGetSubVec - Returns a single, sub-vector from a nest vector.
 
- Not collective
+ Not Collective
 
  Input Parameters:
 +  X  - nest vector
 -  idxm - index of the vector within the nest
 
  Output Parameter:
-.  sx - vector at index idxm within the nest
-
- Notes:
+.  sx - vector at index `idxm` within the nest
 
  Level: developer
 
-.seealso: `VecNestGetSize()`, `VecNestGetSubVecs()`
+.seealso: `VECNEST`,  [](chapter_vectors), `Vec`, `VecType`, `VecNestGetSize()`, `VecNestGetSubVecs()`
 @*/
 PetscErrorCode VecNestGetSubVec(Vec X, PetscInt idxm, Vec *sx)
 {
   PetscFunctionBegin;
   PetscUseMethod(X, "VecNestGetSubVec_C", (Vec, PetscInt, Vec *), (X, idxm, sx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode VecNestGetSubVecs_Nest(Vec X, PetscInt *N, Vec **sx)
@@ -830,13 +826,13 @@ PetscErrorCode VecNestGetSubVecs_Nest(Vec X, PetscInt *N, Vec **sx)
   PetscCall(PetscObjectStateIncrease((PetscObject)X));
   if (N) *N = b->nb;
   if (sx) *sx = b->v;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
  VecNestGetSubVecs - Returns the entire array of vectors defining a nest vector.
 
- Not collective
+ Not Collective
 
  Input Parameter:
 .  X  - nest vector
@@ -845,21 +841,21 @@ PetscErrorCode VecNestGetSubVecs_Nest(Vec X, PetscInt *N, Vec **sx)
 +  N - number of nested vecs
 -  sx - array of vectors
 
- Notes:
- The user should not free the array sx.
-
- Fortran Notes:
- The caller must allocate the array to hold the subvectors.
-
  Level: developer
 
-.seealso: `VecNestGetSize()`, `VecNestGetSubVec()`
+ Note:
+ The user should not free the array `sx`.
+
+ Fortran Note:
+ The caller must allocate the array to hold the subvectors.
+
+.seealso: `VECNEST`,  [](chapter_vectors), `Vec`, `VecType`, `VecNestGetSize()`, `VecNestGetSubVec()`
 @*/
 PetscErrorCode VecNestGetSubVecs(Vec X, PetscInt *N, Vec **sx)
 {
   PetscFunctionBegin;
   PetscUseMethod(X, "VecNestGetSubVecs_C", (Vec, PetscInt *, Vec **), (X, N, sx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecNestSetSubVec_Private(Vec X, PetscInt idxm, Vec x)
@@ -870,10 +866,10 @@ static PetscErrorCode VecNestSetSubVec_Private(Vec X, PetscInt idxm, Vec x)
   PetscBool issame = PETSC_FALSE;
   PetscInt  N      = 0;
 
+  PetscFunctionBegin;
   /* check if idxm < bx->nb */
   PetscCheck(idxm < bx->nb, PETSC_COMM_SELF, PETSC_ERR_ARG_OUTOFRANGE, "Out of range index value %" PetscInt_FMT " maximum %" PetscInt_FMT, idxm, bx->nb);
 
-  PetscFunctionBegin;
   PetscCall(VecDestroy(&bx->v[idxm]));      /* destroy the existing vector */
   PetscCall(VecDuplicate(x, &bx->v[idxm])); /* duplicate the layout of given vector */
   PetscCall(VecCopy(x, bx->v[idxm]));       /* copy the contents of the given vector */
@@ -927,7 +923,7 @@ static PetscErrorCode VecNestSetSubVec_Private(Vec X, PetscInt idxm, Vec x)
   }
 
   PetscCall(ISDestroy(&is));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode VecNestSetSubVec_Nest(Vec X, PetscInt idxm, Vec sx)
@@ -935,31 +931,31 @@ PetscErrorCode VecNestSetSubVec_Nest(Vec X, PetscInt idxm, Vec sx)
   PetscFunctionBegin;
   PetscCall(PetscObjectStateIncrease((PetscObject)X));
   PetscCall(VecNestSetSubVec_Private(X, idxm, sx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
    VecNestSetSubVec - Set a single component vector in a nest vector at specified index.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  X  - nest vector
 .  idxm - index of the vector within the nest vector
--  sx - vector at index idxm within the nest vector
-
-   Notes:
-   The new vector sx does not have to be of same size as X[idxm]. Arbitrary vector layouts are allowed.
+-  sx - vector at index `idxm` within the nest vector
 
    Level: developer
 
-.seealso: `VecNestSetSubVecs()`, `VecNestGetSubVec()`
+   Note:
+   The new vector `sx` does not have to be of same size as X[idxm]. Arbitrary vector layouts are allowed.
+
+.seealso: `VECNEST`,  [](chapter_vectors), `Vec`, `VecType`, `VecNestSetSubVecs()`, `VecNestGetSubVec()`
 @*/
 PetscErrorCode VecNestSetSubVec(Vec X, PetscInt idxm, Vec sx)
 {
   PetscFunctionBegin;
   PetscUseMethod(X, "VecNestSetSubVec_C", (Vec, PetscInt, Vec), (X, idxm, sx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode VecNestSetSubVecs_Nest(Vec X, PetscInt N, PetscInt *idxm, Vec *sx)
@@ -969,33 +965,33 @@ PetscErrorCode VecNestSetSubVecs_Nest(Vec X, PetscInt N, PetscInt *idxm, Vec *sx
   PetscFunctionBegin;
   PetscCall(PetscObjectStateIncrease((PetscObject)X));
   for (i = 0; i < N; i++) PetscCall(VecNestSetSubVec_Private(X, idxm[i], sx[i]));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
    VecNestSetSubVecs - Sets the component vectors at the specified indices in a nest vector.
 
-   Not collective
+   Not Collective
 
    Input Parameters:
 +  X  - nest vector
-.  N - number of component vecs in sx
-.  idxm - indices of component vecs that are to be replaced
+.  N - number of component vecs in `sx`
+.  idxm - indices of component vectors that are to be replaced
 -  sx - array of vectors
 
-   Notes:
-   The components in the vector array sx do not have to be of the same size as corresponding
-   components in X. The user can also free the array "sx" after the call.
-
    Level: developer
 
-.seealso: `VecNestGetSize()`, `VecNestGetSubVec()`
+   Note:
+   The components in the vector array `sx` do not have to be of the same size as corresponding
+   components in `X`. The user can also free the array `sx` after the call.
+
+.seealso: `VECNEST`,  [](chapter_vectors), `Vec`, `VecType`, `VecNestGetSize()`, `VecNestGetSubVec()`
 @*/
 PetscErrorCode VecNestSetSubVecs(Vec X, PetscInt N, PetscInt *idxm, Vec *sx)
 {
   PetscFunctionBegin;
   PetscUseMethod(X, "VecNestSetSubVecs_C", (Vec, PetscInt, PetscInt *, Vec *), (X, N, idxm, sx));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode VecNestGetSize_Nest(Vec X, PetscInt *N)
@@ -1004,13 +1000,13 @@ PetscErrorCode VecNestGetSize_Nest(Vec X, PetscInt *N)
 
   PetscFunctionBegin;
   *N = b->nb;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
  VecNestGetSize - Returns the size of the nest vector.
 
- Not collective
+ Not Collective
 
  Input Parameter:
 .  X  - nest vector
@@ -1018,11 +1014,9 @@ PetscErrorCode VecNestGetSize_Nest(Vec X, PetscInt *N)
  Output Parameter:
 .  N - number of nested vecs
 
- Notes:
-
  Level: developer
 
-.seealso: `VecNestGetSubVec()`, `VecNestGetSubVecs()`
+.seealso: `VECNEST`,  [](chapter_vectors), `Vec`, `VecType`, `VecNestGetSubVec()`, `VecNestGetSubVecs()`
 @*/
 PetscErrorCode VecNestGetSize(Vec X, PetscInt *N)
 {
@@ -1030,7 +1024,7 @@ PetscErrorCode VecNestGetSize(Vec X, PetscInt *N)
   PetscValidHeaderSpecific(X, VEC_CLASSID, 1);
   PetscValidIntPointer(N, 2);
   PetscUseMethod(X, "VecNestGetSize_C", (Vec, PetscInt *), (X, N));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecSetUp_Nest_Private(Vec V, PetscInt nb, Vec x[])
@@ -1039,7 +1033,7 @@ static PetscErrorCode VecSetUp_Nest_Private(Vec V, PetscInt nb, Vec x[])
   PetscInt  i;
 
   PetscFunctionBegin;
-  if (ctx->setup_called) PetscFunctionReturn(0);
+  if (ctx->setup_called) PetscFunctionReturn(PETSC_SUCCESS);
 
   ctx->nb = nb;
   PetscCheck(ctx->nb >= 0, PetscObjectComm((PetscObject)V), PETSC_ERR_ARG_WRONG, "Cannot create VECNEST with < 0 blocks.");
@@ -1055,7 +1049,7 @@ static PetscErrorCode VecSetUp_Nest_Private(Vec V, PetscInt nb, Vec x[])
   PetscCall(PetscMalloc1(ctx->nb, &ctx->is));
 
   ctx->setup_called = PETSC_TRUE;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 static PetscErrorCode VecSetUp_NestIS_Private(Vec V, PetscInt nb, IS is[])
@@ -1088,26 +1082,38 @@ static PetscErrorCode VecSetUp_NestIS_Private(Vec V, PetscInt nb, IS is[])
       offset += n;
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
+/*MC
+  VECNEST - VECNEST = "nest" - Vector type consisting of nested subvectors, each stored separately.
+
+  Level: intermediate
+
+  Notes:
+  This vector type reduces the number of copies for certain solvers applied to multi-physics problems.
+  It is usually used with `MATNEST` and `DMCOMPOSITE` via `DMSetVecType()`.
+
+.seealso: [](chapter_vectors), `Vec`, `VecType`, `VecCreate()`, `VecType`, `VecCreateNest()`, `MatCreateNest()`
+M*/
+
 /*@C
    VecCreateNest - Creates a new vector containing several nested subvectors, each stored separately
 
-   Collective on Vec
+   Collective
 
    Input Parameters:
-+  comm - Communicator for the new Vec
++  comm - Communicator for the new `Vec`
 .  nb - number of nested blocks
-.  is - array of nb index sets describing each nested block, or NULL to pack subvectors contiguously
--  x - array of nb sub-vectors
+.  is - array of `nb` index sets describing each nested block, or `NULL` to pack subvectors contiguously
+-  x - array of `nb` sub-vectors
 
    Output Parameter:
 .  Y - new vector
 
    Level: advanced
 
-.seealso: `VecCreate()`, `MatCreateNest()`, `DMSetVecType()`, `VECNEST`
+.seealso: `VECNEST`,  [](chapter_vectors), `Vec`, `VecType`, `VecCreate()`, `MatCreateNest()`, `DMSetVecType()`, `VECNEST`
 @*/
 PetscErrorCode VecCreateNest(MPI_Comm comm, PetscInt nb, IS is[], Vec x[], Vec *Y)
 {
@@ -1119,7 +1125,7 @@ PetscErrorCode VecCreateNest(MPI_Comm comm, PetscInt nb, IS is[], Vec x[], Vec *
   PetscCall(VecCreate(comm, &V));
   PetscCall(PetscObjectChangeTypeName((PetscObject)V, VECNEST));
 
-  /* allocate and set pointer for implememtation data */
+  /* allocate and set pointer for implementation data */
   PetscCall(PetscNew(&s));
   V->data         = (void *)s;
   s->setup_called = PETSC_FALSE;
@@ -1149,17 +1155,5 @@ PetscErrorCode VecCreateNest(MPI_Comm comm, PetscInt nb, IS is[], Vec x[], Vec *
   PetscCall(PetscObjectComposeFunction((PetscObject)V, "VecNestGetSize_C", VecNestGetSize_Nest));
 
   *Y = V;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
-
-/*MC
-  VECNEST - VECNEST = "nest" - Vector type consisting of nested subvectors, each stored separately.
-
-  Level: intermediate
-
-  Notes:
-  This vector type reduces the number of copies for certain solvers applied to multi-physics problems.
-  It is usually used with MATNEST and DMComposite via DMSetVecType().
-
-.seealso: `VecCreate()`, `VecType`, `VecCreateNest()`, `MatCreateNest()`
-M*/
