@@ -7,7 +7,7 @@ PetscBool         VecRegisterAllCalled = PETSC_FALSE;
 /*@C
   VecSetType - Builds a vector, for a particular vector implementation.
 
-  Collective on Vec
+  Collective
 
   Input Parameters:
 + vec    - The vector object
@@ -17,14 +17,14 @@ PetscBool         VecRegisterAllCalled = PETSC_FALSE;
 . -vec_type <type> - Sets the vector type; use -help for a list
                      of available types
 
-  Notes:
-  See "petsc/include/petscvec.h" for available vector types (for instance, VECSEQ, VECMPI, or VECSHARED).
-
-  Use VecDuplicate() or VecDuplicateVecs() to form additional vectors of the same type as an existing vector.
-
   Level: intermediate
 
-.seealso: `VecGetType()`, `VecCreate()`
+  Notes:
+  See `VecType` for available vector types (for instance, `VECSEQ` or `VECMPI`)
+
+  Use `VecDuplicate()` or `VecDuplicateVecs()` to form additional vectors of the same type as an existing vector.
+
+.seealso: [](chapter_vectors), `Vec`, `VecType`, `VecGetType()`, `VecCreate()`, `VecDuplicate()`, `VecDuplicateVecs()`
 @*/
 PetscErrorCode VecSetType(Vec vec, VecType method)
 {
@@ -35,7 +35,7 @@ PetscErrorCode VecSetType(Vec vec, VecType method)
   PetscFunctionBegin;
   PetscValidHeaderSpecific(vec, VEC_CLASSID, 1);
   PetscCall(PetscObjectTypeCompare((PetscObject)vec, method, &match));
-  if (match) PetscFunctionReturn(0);
+  if (match) PetscFunctionReturn(PETSC_SUCCESS);
 
   /* Return if asked for VECSTANDARD and Vec is already VECSEQ on 1 process or VECMPI on more.
      Otherwise, we free the Vec array in the call to destroy below and never reallocate it,
@@ -44,35 +44,35 @@ PetscErrorCode VecSetType(Vec vec, VecType method)
   PetscCall(PetscStrcmp(method, VECSTANDARD, &match));
   if (match) {
     PetscCall(PetscObjectTypeCompare((PetscObject)vec, size > 1 ? VECMPI : VECSEQ, &match));
-    if (match) PetscFunctionReturn(0);
+    if (match) PetscFunctionReturn(PETSC_SUCCESS);
   }
   /* same reasons for VECCUDA and VECVIENNACL */
 #if defined(PETSC_HAVE_CUDA)
   PetscCall(PetscStrcmp(method, VECCUDA, &match));
   if (match) {
     PetscCall(PetscObjectTypeCompare((PetscObject)vec, size > 1 ? VECMPICUDA : VECSEQCUDA, &match));
-    if (match) PetscFunctionReturn(0);
+    if (match) PetscFunctionReturn(PETSC_SUCCESS);
   }
 #endif
 #if defined(PETSC_HAVE_HIP)
   PetscCall(PetscStrcmp(method, VECHIP, &match));
   if (match) {
     PetscCall(PetscObjectTypeCompare((PetscObject)vec, size > 1 ? VECMPIHIP : VECSEQHIP, &match));
-    if (match) PetscFunctionReturn(0);
+    if (match) PetscFunctionReturn(PETSC_SUCCESS);
   }
 #endif
 #if defined(PETSC_HAVE_VIENNACL)
   PetscCall(PetscStrcmp(method, VECVIENNACL, &match));
   if (match) {
     PetscCall(PetscObjectTypeCompare((PetscObject)vec, size > 1 ? VECMPIVIENNACL : VECSEQVIENNACL, &match));
-    if (match) PetscFunctionReturn(0);
+    if (match) PetscFunctionReturn(PETSC_SUCCESS);
   }
 #endif
 #if defined(PETSC_HAVE_KOKKOS_KERNELS)
   PetscCall(PetscStrcmp(method, VECKOKKOS, &match));
   if (match) {
     PetscCall(PetscObjectTypeCompare((PetscObject)vec, size > 1 ? VECMPIKOKKOS : VECSEQKOKKOS, &match));
-    if (match) PetscFunctionReturn(0);
+    if (match) PetscFunctionReturn(PETSC_SUCCESS);
   }
 #endif
   PetscCall(PetscFunctionListFind(VecList, method, &r));
@@ -88,11 +88,11 @@ PetscErrorCode VecSetType(Vec vec, VecType method)
   } else {
     PetscCall((*r)(vec));
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  VecGetType - Gets the vector type name (as a string) from the Vec.
+  VecGetType - Gets the vector type name (as a string) from a `Vec`.
 
   Not Collective
 
@@ -100,11 +100,11 @@ PetscErrorCode VecSetType(Vec vec, VecType method)
 . vec  - The vector
 
   Output Parameter:
-. type - The vector type name
+. type - The `VecType` of the vector
 
   Level: intermediate
 
-.seealso: `VecSetType()`, `VecCreate()`
+.seealso: [](chapter_vectors), `Vec`, `VecType`, `VecGetType()`, `VecCreate()`, `VecDuplicate()`, `VecDuplicateVecs()`
 @*/
 PetscErrorCode VecGetType(Vec vec, VecType *type)
 {
@@ -113,7 +113,7 @@ PetscErrorCode VecGetType(Vec vec, VecType *type)
   PetscValidPointer(type, 2);
   PetscCall(VecRegisterAll());
   *type = ((PetscObject)vec)->type_name;
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode VecGetRootType_Private(Vec vec, VecType *vtype)
@@ -138,7 +138,7 @@ PetscErrorCode VecGetRootType_Private(Vec vec, VecType *vtype)
   } else {
     *vtype = VECSTANDARD;
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*--------------------------------------------------------------------------------------------------------------------*/
@@ -149,11 +149,11 @@ PetscErrorCode VecGetRootType_Private(Vec vec, VecType *vtype)
   Not Collective
 
   Input Parameters:
-+ name        - The name of a new user-defined creation routine
-- create_func - The creation routine itself
++ sname        - The name of a new user-defined creation routine
+- function - The creation routine
 
   Notes:
-  VecRegister() may be called multiple times to add several user-defined vectors
+  `VecRegister()` may be called multiple times to add several user-defined vectors
 
   Sample usage:
 .vb
@@ -179,5 +179,5 @@ PetscErrorCode VecRegister(const char sname[], PetscErrorCode (*function)(Vec))
   PetscFunctionBegin;
   PetscCall(VecInitializePackage());
   PetscCall(PetscFunctionListAdd(&VecList, sname, function));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
