@@ -6,9 +6,9 @@
 
 static PetscErrorCode PetscSectionVecView_ASCII(PetscSection s, Vec v, PetscViewer viewer)
 {
-  PetscScalar    *array;
-  PetscInt       p, i;
-  PetscMPIInt    rank;
+  PetscScalar *array;
+  PetscInt     p, i;
+  PetscMPIInt  rank;
 
   PetscFunctionBegin;
   PetscCallMPI(MPI_Comm_rank(PetscObjectComm((PetscObject)viewer), &rank));
@@ -19,14 +19,14 @@ static PetscErrorCode PetscSectionVecView_ASCII(PetscSection s, Vec v, PetscView
     if ((s->bc) && (s->bc->atlasDof[p] > 0)) {
       PetscInt b;
 
-      PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, "  (%4" PetscInt_FMT ") dim %2" PetscInt_FMT " offset %3" PetscInt_FMT, p+s->pStart, s->atlasDof[p], s->atlasOff[p]));
-      for (i = s->atlasOff[p]; i < s->atlasOff[p]+s->atlasDof[p]; ++i) {
+      PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, "  (%4" PetscInt_FMT ") dim %2" PetscInt_FMT " offset %3" PetscInt_FMT, p + s->pStart, s->atlasDof[p], s->atlasOff[p]));
+      for (i = s->atlasOff[p]; i < s->atlasOff[p] + s->atlasDof[p]; ++i) {
         PetscScalar v = array[i];
 #if defined(PETSC_USE_COMPLEX)
         if (PetscImaginaryPart(v) > 0.0) {
-          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer," %g + %g i", (double)PetscRealPart(v), (double)PetscImaginaryPart(v)));
+          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, " %g + %g i", (double)PetscRealPart(v), (double)PetscImaginaryPart(v)));
         } else if (PetscImaginaryPart(v) < 0.0) {
-          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer," %g - %g i", (double)PetscRealPart(v),(double)(-PetscImaginaryPart(v))));
+          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, " %g - %g i", (double)PetscRealPart(v), (double)(-PetscImaginaryPart(v))));
         } else {
           PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, " %g", (double)PetscRealPart(v)));
         }
@@ -35,19 +35,17 @@ static PetscErrorCode PetscSectionVecView_ASCII(PetscSection s, Vec v, PetscView
 #endif
       }
       PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, " constrained"));
-      for (b = 0; b < s->bc->atlasDof[p]; ++b) {
-        PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, " %" PetscInt_FMT, s->bcIndices[s->bc->atlasOff[p]+b]));
-      }
+      for (b = 0; b < s->bc->atlasDof[p]; ++b) PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, " %" PetscInt_FMT, s->bcIndices[s->bc->atlasOff[p] + b]));
       PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, "\n"));
     } else {
-      PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, "  (%4" PetscInt_FMT ") dim %2" PetscInt_FMT " offset %3" PetscInt_FMT, p+s->pStart, s->atlasDof[p], s->atlasOff[p]));
-      for (i = s->atlasOff[p]; i < s->atlasOff[p]+s->atlasDof[p]; ++i) {
+      PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, "  (%4" PetscInt_FMT ") dim %2" PetscInt_FMT " offset %3" PetscInt_FMT, p + s->pStart, s->atlasDof[p], s->atlasOff[p]));
+      for (i = s->atlasOff[p]; i < s->atlasOff[p] + s->atlasDof[p]; ++i) {
         PetscScalar v = array[i];
 #if defined(PETSC_USE_COMPLEX)
         if (PetscImaginaryPart(v) > 0.0) {
-          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer," %g + %g i", (double)PetscRealPart(v), (double)PetscImaginaryPart(v)));
+          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, " %g + %g i", (double)PetscRealPart(v), (double)PetscImaginaryPart(v)));
         } else if (PetscImaginaryPart(v) < 0.0) {
-          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer," %g - %g i", (double)PetscRealPart(v),(double)(-PetscImaginaryPart(v))));
+          PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, " %g - %g i", (double)PetscRealPart(v), (double)(-PetscImaginaryPart(v))));
         } else {
           PetscCall(PetscViewerASCIISynchronizedPrintf(viewer, " %g", (double)PetscRealPart(v)));
         }
@@ -61,38 +59,38 @@ static PetscErrorCode PetscSectionVecView_ASCII(PetscSection s, Vec v, PetscView
   PetscCall(PetscViewerFlush(viewer));
   PetscCall(PetscViewerASCIIPopSynchronized(viewer));
   PetscCall(VecRestoreArray(v, &array));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@
   PetscSectionVecView - View a vector, using the section to structure the values
 
-  Not collective
+  Not Collective
 
   Input Parameters:
-+ s      - the organizing PetscSection
-. v      - the Vec
-- viewer - the PetscViewer
++ s      - the organizing `PetscSection`
+. v      - the `Vec`
+- viewer - the `PetscViewer`
 
   Level: developer
 
-.seealso: PetscSection, PetscSectionCreate(), VecSetValuesSection()
+.seealso: `PetscSection`, `PetscViewer`, `PetscSectionCreate()`, `VecSetValuesSection()`
 @*/
 PetscErrorCode PetscSectionVecView(PetscSection s, Vec v, PetscViewer viewer)
 {
-  PetscBool      isascii;
-  PetscInt       f;
+  PetscBool isascii;
+  PetscInt  f;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(s, PETSC_SECTION_CLASSID, 1);
   PetscValidHeaderSpecific(v, VEC_CLASSID, 2);
   if (!viewer) PetscCall(PetscViewerASCIIGetStdout(PetscObjectComm((PetscObject)v), &viewer));
   PetscValidHeaderSpecific(viewer, PETSC_VIEWER_CLASSID, 3);
-  PetscCall(PetscObjectTypeCompare((PetscObject) viewer, PETSCVIEWERASCII, &isascii));
+  PetscCall(PetscObjectTypeCompare((PetscObject)viewer, PETSCVIEWERASCII, &isascii));
   if (isascii) {
     const char *name;
 
-    PetscCall(PetscObjectGetName((PetscObject) v, &name));
+    PetscCall(PetscObjectGetName((PetscObject)v, &name));
     if (s->numFields) {
       PetscCall(PetscViewerASCIIPrintf(viewer, "%s with %" PetscInt_FMT " fields\n", name, s->numFields));
       for (f = 0; f < s->numFields; ++f) {
@@ -104,17 +102,17 @@ PetscErrorCode PetscSectionVecView(PetscSection s, Vec v, PetscViewer viewer)
       PetscCall(PetscSectionVecView_ASCII(s, v, viewer));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  VecGetValuesSection - Gets all the values associated with a given point, according to the section, in the given Vec
+  VecGetValuesSection - Gets all the values associated with a given point, according to the section, in the given `Vec`
 
-  Not collective
+  Not Collective
 
   Input Parameters:
-+ v - the Vec
-. s - the organizing PetscSection
++ v - the `Vec`
+. s - the organizing `PetscSection`
 - point - the point
 
   Output Parameter:
@@ -122,11 +120,11 @@ PetscErrorCode PetscSectionVecView(PetscSection s, Vec v, PetscViewer viewer)
 
   Level: developer
 
-.seealso: PetscSection, PetscSectionCreate(), VecSetValuesSection()
+.seealso: `PetscSection`, `PetscSectionCreate()`, `VecSetValuesSection()`
 @*/
 PetscErrorCode VecGetValuesSection(Vec v, PetscSection s, PetscInt point, PetscScalar **values)
 {
-  PetscScalar    *baseArray;
+  PetscScalar   *baseArray;
   const PetscInt p = point - s->pStart;
 
   PetscFunctionBegin;
@@ -135,36 +133,35 @@ PetscErrorCode VecGetValuesSection(Vec v, PetscSection s, PetscInt point, PetscS
   PetscCall(VecGetArray(v, &baseArray));
   *values = &baseArray[s->atlasOff[p]];
   PetscCall(VecRestoreArray(v, &baseArray));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
-  VecSetValuesSection - Sets all the values associated with a given point, according to the section, in the given Vec
+  VecSetValuesSection - Sets all the values associated with a given point, according to the section, in the given `Vec`
 
-  Not collective
+  Not Collective
 
   Input Parameters:
-+ v - the Vec
-. s - the organizing PetscSection
++ v - the `Vec`
+. s - the organizing `PetscSection`
 . point - the point
 . values - the array of input values
-- mode - the insertion mode, either ADD_VALUES or INSERT_VALUES
+- mode - the insertion mode, either `ADD_VALUES` or `INSERT_VALUES`
 
   Level: developer
 
-  Note: This is similar to MatSetValuesStencil(). The Fortran binding is
-$
+  Fortran Note:
+  This is similar to MatSetValuesStencil(). The binding is
 $   VecSetValuesSectionF90(vec, section, point, values, mode, ierr)
-$
 
-.seealso: PetscSection, PetscSectionCreate(), VecGetValuesSection()
+.seealso: `PetscSection`, `PetscSectionCreate()`, `VecGetValuesSection()`
 @*/
 PetscErrorCode VecSetValuesSection(Vec v, PetscSection s, PetscInt point, PetscScalar values[], InsertMode mode)
 {
-  PetscScalar     *baseArray, *array;
-  const PetscBool doInsert    = mode == INSERT_VALUES     || mode == INSERT_ALL_VALUES || mode == INSERT_BC_VALUES                          ? PETSC_TRUE : PETSC_FALSE;
-  const PetscBool doInterior  = mode == INSERT_ALL_VALUES || mode == ADD_ALL_VALUES    || mode == INSERT_VALUES    || mode == ADD_VALUES    ? PETSC_TRUE : PETSC_FALSE;
-  const PetscBool doBC        = mode == INSERT_ALL_VALUES || mode == ADD_ALL_VALUES    || mode == INSERT_BC_VALUES || mode == ADD_BC_VALUES ? PETSC_TRUE : PETSC_FALSE;
+  PetscScalar    *baseArray, *array;
+  const PetscBool doInsert    = mode == INSERT_VALUES || mode == INSERT_ALL_VALUES || mode == INSERT_BC_VALUES ? PETSC_TRUE : PETSC_FALSE;
+  const PetscBool doInterior  = mode == INSERT_ALL_VALUES || mode == ADD_ALL_VALUES || mode == INSERT_VALUES || mode == ADD_VALUES ? PETSC_TRUE : PETSC_FALSE;
+  const PetscBool doBC        = mode == INSERT_ALL_VALUES || mode == ADD_ALL_VALUES || mode == INSERT_BC_VALUES || mode == ADD_BC_VALUES ? PETSC_TRUE : PETSC_FALSE;
   const PetscInt  p           = point - s->pStart;
   const PetscInt  orientation = 0; /* Needs to be included for use in closure operations */
   PetscInt        cDim        = 0;
@@ -192,14 +189,14 @@ PetscErrorCode VecSetValuesSection(Vec v, PetscSection s, PetscInt point, PetscS
       for (field = 0; field < s->numFields; ++field) {
         const PetscInt dim = s->field[field]->atlasDof[p]; /* PetscSectionGetFieldDof() */
 
-        for (i = dim-1; i >= 0; --i) array[++j] = values[i+offset];
+        for (i = dim - 1; i >= 0; --i) array[++j] = values[i + offset];
         offset += dim;
       }
     }
   } else if (cDim) {
     if (orientation >= 0) {
-      const PetscInt dim  = s->atlasDof[p];
-      PetscInt       cInd = 0, i;
+      const PetscInt  dim  = s->atlasDof[p];
+      PetscInt        cInd = 0, i;
       const PetscInt *cDof;
 
       PetscCall(PetscSectionGetConstraintIndices(s, point, &cDof));
@@ -225,34 +222,37 @@ PetscErrorCode VecSetValuesSection(Vec v, PetscSection s, PetscInt point, PetscS
     } else {
       /* TODO This is broken for add and constrained update */
       const PetscInt *cDof;
-      PetscInt       offset  = 0;
-      PetscInt       cOffset = 0;
-      PetscInt       j       = 0, field;
+      PetscInt        offset  = 0;
+      PetscInt        cOffset = 0;
+      PetscInt        j       = 0, field;
 
       PetscCall(PetscSectionGetConstraintIndices(s, point, &cDof));
       for (field = 0; field < s->numFields; ++field) {
         const PetscInt dim  = s->field[field]->atlasDof[p];     /* PetscSectionGetFieldDof() */
         const PetscInt tDim = s->field[field]->bc->atlasDof[p]; /* PetscSectionGetFieldConstraintDof() */
         const PetscInt sDim = dim - tDim;
-        PetscInt       cInd = 0, i ,k;
+        PetscInt       cInd = 0, i, k;
 
-        for (i = 0, k = dim+offset-1; i < dim; ++i, ++j, --k) {
-          if ((cInd < sDim) && (j == cDof[cInd+cOffset])) {++cInd; continue;}
-          if (doInterior) array[j] = values[k];   /* Unconstrained update */
+        for (i = 0, k = dim + offset - 1; i < dim; ++i, ++j, --k) {
+          if ((cInd < sDim) && (j == cDof[cInd + cOffset])) {
+            ++cInd;
+            continue;
+          }
+          if (doInterior) array[j] = values[k]; /* Unconstrained update */
         }
-        offset  += dim;
+        offset += dim;
         cOffset += dim - tDim;
       }
     }
   }
   PetscCall(VecRestoreArray(v, &baseArray));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscSectionGetField_Internal(PetscSection section, PetscSection sectionGlobal, Vec v, PetscInt field, PetscInt pStart, PetscInt pEnd, IS *is, Vec *subv)
 {
-  PetscInt      *subIndices;
-  PetscInt       Nc, subSize = 0, subOff = 0, p;
+  PetscInt *subIndices;
+  PetscInt  Nc, subSize = 0, subOff = 0, p;
 
   PetscFunctionBegin;
   PetscCall(PetscSectionGetFieldComponents(section, field, &Nc));
@@ -278,13 +278,13 @@ PetscErrorCode PetscSectionGetField_Internal(PetscSection section, PetscSection
         poff += fdof;
       }
       PetscCall(PetscSectionGetFieldDof(section, p, field, &fdof));
-      for (fc = 0; fc < fdof; ++fc, ++subOff) subIndices[subOff] = goff+poff+fc;
+      for (fc = 0; fc < fdof; ++fc, ++subOff) subIndices[subOff] = goff + poff + fc;
     }
   }
-  PetscCall(ISCreateGeneral(PetscObjectComm((PetscObject) v), subSize, subIndices, PETSC_OWN_POINTER, is));
+  PetscCall(ISCreateGeneral(PetscObjectComm((PetscObject)v), subSize, subIndices, PETSC_OWN_POINTER, is));
   PetscCall(VecGetSubVector(v, *is, subv));
   PetscCall(VecSetBlockSize(*subv, Nc));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 PetscErrorCode PetscSectionRestoreField_Internal(PetscSection section, PetscSection sectionGlobal, Vec v, PetscInt field, PetscInt pStart, PetscInt pEnd, IS *is, Vec *subv)
@@ -292,7 +292,7 @@ PetscErrorCode PetscSectionRestoreField_Internal(PetscSection section, PetscSect
   PetscFunctionBegin;
   PetscCall(VecRestoreSubVector(v, *is, subv));
   PetscCall(ISDestroy(is));
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
 
 /*@C
@@ -302,18 +302,18 @@ PetscErrorCode PetscSectionRestoreField_Internal(PetscSection section, PetscSect
 + s    - the local Section
 . gs   - the global section
 . x    - the vector
-- type - one of NORM_1, NORM_2, NORM_INFINITY.
+- type - one of `NORM_1`, `NORM_2`, `NORM_INFINITY`.
 
   Output Parameter:
 . val  - the array of norms
 
   Level: intermediate
 
-.seealso: VecNorm(), PetscSectionCreate()
+.seealso: `VecNorm()`, `PetscSectionCreate()`
 @*/
 PetscErrorCode PetscSectionVecNorm(PetscSection s, PetscSection gs, Vec x, NormType type, PetscReal val[])
 {
-  PetscInt       Nf, f, pStart, pEnd;
+  PetscInt Nf, f, pStart, pEnd;
 
   PetscFunctionBegin;
   PetscValidHeaderSpecific(s, PETSC_SECTION_CLASSID, 1);
@@ -333,5 +333,5 @@ PetscErrorCode PetscSectionVecNorm(PetscSection s, PetscSection gs, Vec x, NormT
       PetscCall(PetscSectionRestoreField_Internal(s, gs, x, f, pStart, pEnd, &is, &subv));
     }
   }
-  PetscFunctionReturn(0);
+  PetscFunctionReturn(PETSC_SUCCESS);
 }
